﻿-- Database: Friidrett


-- Sletter tabellene

-- For å få et skript som kan kjøres flere ganger:

-- DROP TABLE Resultat;
-- DROP TABLE Medlem;
-- DROP TABLE Løp;


-- MySQL
-- For å få et skript som kan kjøres flere ganger,
-- og som fungerer enten tabellen(e) finnes eller ikke:

-- DROP TABLE IF EXISTS Resultat;
-- DROP TABLE IF EXISTS Medlem;
-- DROP TABLE IF EXISTS Løp;



-- Oppretter tabellene

CREATE TABLE Løp
(
  LøpsNr   INTEGER,
  Dato     DATE,
  Distanse SMALLINT,
  CONSTRAINT LøpPK PRIMARY KEY (LøpsNr)
);

CREATE TABLE Medlem
(
  MedlemsNr INTEGER,
  Fornavn   VARCHAR(15),
  Etternavn VARCHAR(15),
  Kjønn     CHAR(1),
  Fødselsår SMALLINT,
  CONSTRAINT MedlemPK PRIMARY KEY (MedlemsNr)
);

CREATE TABLE Resultat
(
  LøpsNr    INTEGER,
  MedlemsNr INTEGER,
  Tid       FLOAT,
  CONSTRAINT ResultatPK PRIMARY KEY (LøpsNr, MedlemsNr),
  CONSTRAINT ResultatLøpFK FOREIGN KEY (LøpsNr)
    REFERENCES Løp (LøpsNr),
  CONSTRAINT ResultatMedlemFK FOREIGN KEY (MedlemsNr)
    REFERENCES Medlem (MedlemsNr)
);



-- Setter inn eksempeldata

INSERT INTO Løp(LøpsNr, Dato, Distanse) VALUES
  ( 1, '2015-05-12',  400),
  ( 2, '2015-05-12',  800),
  ( 3, '2015-05-12', 5000),
  ( 4, '2015-06-07', 1500),
  ( 5, '2015-06-24',  400),
  ( 6, '2015-06-24', 1500),
  ( 7, '2015-06-24', 5000),
  ( 8, '2015-07-20',  400),
  ( 9, '2015-07-20',  800),
  (10, '2015-07-30', 5000),
  (11, '2015-08-15', 3000);


INSERT INTO Medlem(MedlemsNr, Fornavn, Etternavn, Kjønn, Fødselsår) VALUES
  (1, 'Lise',    'Jensen',    'K', 2002),
  (2, 'Joakim',  'Gjertsen',  'M', 1993),
  (3, 'Katrine', 'Garvik',    'K', 1996),
  (4, 'Emilie',  'Marcussen', 'K', 1987),
  (5, 'Valter',  'Eilertsen', 'M', 2001),
  (6, 'Tormod',  'Vaksdal',   'M', 1984),
  (7, 'Asle',    'Eckhoff',   'M', 1999),
  (8, 'Birthe',  'Aass',      'K', 1996);


-- Alle tider i sekunder.
INSERT INTO Resultat(MedlemsNr, LøpsNr, Tid) VALUES
  (1,  1, 83.50),
  (1,  5, 81.75),

  (2,  2, 134.38),
  (2,  6, 337.22),
  (2,  9, 165.90),

  (3, 11, 645.73),

  (4,  3, 10982.42),
  (4, 10, 10975.76),

  (5,  2, 78.44),
  (5,  9, 159.93),

  (6,  1, 61.46),
  (6,  5, 62.50),
  (6,  8, 60.71),

  (7,  4, 339.40),
  (7,  6, 337.88),

  (8, 10, 1102.21);



