﻿-- SQL-skript som lager databasen Hobbyhuset med eksempeldata.

-- ---------------------------------------------------------------------------

--
-- Sletter alle tabellene
--


-- For å få et skript som kan kjøres flere ganger:

-- DROP TABLE Ordrelinje;
-- DROP TABLE Ordre;
-- DROP TABLE Kunde;
-- DROP TABLE Ansatt;
-- DROP TABLE Prishistorikk;
-- DROP TABLE Vare;
-- DROP TABLE Kategori;
-- DROP TABLE Poststed;


-- MySQL
-- For å få et skript som kan kjøres flere ganger,
-- og som fungerer enten tabellen(e) finnes eller ikke:

-- DROP TABLE IF EXISTS Ordrelinje;
-- DROP TABLE IF EXISTS Ordre;
-- DROP TABLE IF EXISTS Kunde;
-- DROP TABLE IF EXISTS Ansatt;
-- DROP TABLE IF EXISTS Prishistorikk;
-- DROP TABLE IF EXISTS Vare;
-- DROP TABLE IF EXISTS Kategori;
-- DROP TABLE IF EXISTS Poststed;


-- ---------------------------------------------------------------------------

--
-- Oppretter alle tabellene
--


--
-- Tabellstruktur for tabell Poststed
--

CREATE TABLE Poststed
(
  PostNr     CHAR(4),
  Poststed   VARCHAR(50) NOT NULL,
  CONSTRAINT PoststedPN PRIMARY KEY (PostNr)
);


--
-- Tabellstruktur for tabell Kategori
--

CREATE TABLE Kategori
(
  KatNr      SMALLINT,
  Navn       VARCHAR(50),
  CONSTRAINT KategoriPN PRIMARY KEY (KatNr)
);


--
-- Tabellstruktur for tabell Vare
--

CREATE TABLE Vare
(
  VNr        CHAR(5),
  Betegnelse VARCHAR(100) NOT NULL,
  Pris       DECIMAL(8,2) NOT NULL,
  KatNr      SMALLINT,
  Antall     INTEGER NOT NULL,
  Hylle      CHAR(3),
  CONSTRAINT VarePN PRIMARY KEY (VNr),
  CONSTRAINT VareKategoriFN FOREIGN KEY (KatNr) REFERENCES Kategori (KatNr)
);


--
-- Tabellstruktur for tabell Prishistorikk
--

CREATE TABLE Prishistorikk
(
  VNr        CHAR(5),
  Dato       DATE,
  GammelPris DECIMAL(8,2) NOT NULL,
  CONSTRAINT PrishistorikkPN PRIMARY KEY (VNr, Dato),
  CONSTRAINT PrishistorikkVareFN FOREIGN KEY (VNr) REFERENCES Vare (VNr)
);


--
-- Tabellstruktur for tabell Ansatt
--

CREATE TABLE Ansatt
(
  AnsNr       SMALLINT,
  Fornavn     VARCHAR(50) NOT NULL,
  Etternavn   VARCHAR(50) NOT NULL,
  Adresse     VARCHAR(100),
  PostNr      CHAR(4) NOT NULL,
  Fødselsdato DATE,
  Kjønn       CHAR(1),
  Stilling    VARCHAR(50),
  Årslønn     DECIMAL(8,2) NOT NULL,
  CONSTRAINT  AnsattPN PRIMARY KEY (AnsNr),
  CONSTRAINT  AnsattPoststedFN FOREIGN KEY (PostNr) REFERENCES Poststed (PostNr)
);


--
-- Tabellstruktur for tabell Kunde
--

CREATE TABLE Kunde
(
  KNr        INTEGER,
  Fornavn    VARCHAR(50) NOT NULL,
  Etternavn  VARCHAR(50) NOT NULL,
  Adresse    VARCHAR(100) NOT NULL,
  PostNr     CHAR(4) NOT NULL,
  CONSTRAINT KundePN PRIMARY KEY (KNr),
  CONSTRAINT KundePoststedFN FOREIGN KEY (PostNr) REFERENCES Poststed (PostNr)
);


--
-- Tabellstruktur for tabell Ordre
--

CREATE TABLE Ordre
(
  OrdreNr    INTEGER,
  OrdreDato  DATE NOT NULL,
  SendtDato  DATE,
  BetaltDato DATE,
  KNr        INTEGER NOT NULL,
  CONSTRAINT OrdrePN PRIMARY KEY (OrdreNr),
  CONSTRAINT OrdreKundeFN FOREIGN KEY (KNr) REFERENCES Kunde (KNr)
);


--
-- Tabellstruktur for tabell Ordrelinje
--

CREATE TABLE Ordrelinje
(
  OrdreNr     INTEGER,
  VNr         CHAR(5),
  PrisPrEnhet DECIMAL(8,2) NOT NULL,
  Antall      INTEGER NOT NULL,
  CONSTRAINT  OrdrelinjePN PRIMARY KEY (OrdreNr, VNr),
  CONSTRAINT  OrdrelinjeOrdreFN FOREIGN KEY (OrdreNr) REFERENCES Ordre (OrdreNr),
  CONSTRAINT  OrdrelinjeVareFN FOREIGN KEY (VNr) REFERENCES Vare (VNr)
);


-- ---------------------------------------------------------------------------


--
-- Setter inn eksempeldata i tabellene
--



--
-- Dataark for tabell Poststed
--

INSERT INTO Poststed(PostNr, Poststed) VALUES
('0001', 'OSLO'),
('0009', 'OSLO'),
('0010', 'OSLO'),
('0014', 'OSLO'),
('0015', 'OSLO'),
('0016', 'OSLO'),
('0017', 'OSLO'),
('0018', 'OSLO'),
('0019', 'OSLO'),
('0020', 'OSLO'),
('0021', 'OSLO'),
('0022', 'OSLO'),
('0023', 'OSLO'),
('0024', 'OSLO'),
('0025', 'OSLO'),
('0026', 'OSLO'),
('0027', 'OSLO'),
('0028', 'OSLO'),
('0030', 'OSLO'),
('0031', 'OSLO'),
('0032', 'OSLO'),
('0033', 'OSLO'),
('0034', 'OSLO'),
('0037', 'OSLO'),
('0040', 'OSLO'),
('0041', 'OSLO'),
('0042', 'OSLO'),
('0043', 'OSLO'),
('0045', 'OSLO'),
('0046', 'OSLO'),
('0047', 'OSLO'),
('0048', 'OSLO'),
('0050', 'OSLO'),
('0051', 'OSLO'),
('0055', 'OSLO'),
('0080', 'OSLO'),
('0085', 'OSLO'),
('0101', 'OSLO'),
('0102', 'OSLO'),
('0103', 'OSLO'),
('0104', 'OSLO'),
('0105', 'OSLO'),
('0106', 'OSLO'),
('0107', 'OSLO'),
('0110', 'OSLO'),
('0111', 'OSLO'),
('0112', 'OSLO'),
('0113', 'OSLO'),
('0114', 'OSLO'),
('0115', 'OSLO'),
('0116', 'OSLO'),
('0117', 'OSLO'),
('0118', 'OSLO'),
('0119', 'OSLO'),
('0120', 'OSLO'),
('0121', 'OSLO'),
('0122', 'OSLO'),
('0123', 'OSLO'),
('0124', 'OSLO'),
('0125', 'OSLO'),
('0128', 'OSLO'),
('0129', 'OSLO'),
('0130', 'OSLO'),
('0131', 'OSLO'),
('0132', 'OSLO'),
('0133', 'OSLO'),
('0134', 'OSLO'),
('0135', 'OSLO'),
('0136', 'OSLO'),
('0137', 'OSLO'),
('0138', 'OSLO'),
('0139', 'OSLO'),
('0150', 'OSLO'),
('0151', 'OSLO'),
('0152', 'OSLO'),
('0153', 'OSLO'),
('0154', 'OSLO'),
('0155', 'OSLO'),
('0157', 'OSLO'),
('0158', 'OSLO'),
('0159', 'OSLO'),
('0160', 'OSLO'),
('0161', 'OSLO'),
('0162', 'OSLO'),
('0164', 'OSLO'),
('0165', 'OSLO'),
('0166', 'OSLO'),
('0167', 'OSLO'),
('0168', 'OSLO'),
('0169', 'OSLO'),
('0170', 'OSLO'),
('0171', 'OSLO'),
('0172', 'OSLO'),
('0173', 'OSLO'),
('0174', 'OSLO'),
('0175', 'OSLO'),
('0176', 'OSLO'),
('0177', 'OSLO'),
('0178', 'OSLO'),
('0179', 'OSLO'),
('0180', 'OSLO'),
('0181', 'OSLO'),
('0182', 'OSLO'),
('0183', 'OSLO'),
('0184', 'OSLO'),
('0185', 'OSLO'),
('0186', 'OSLO'),
('0187', 'OSLO'),
('0188', 'OSLO'),
('0190', 'OSLO'),
('0191', 'OSLO'),
('0192', 'OSLO'),
('0193', 'OSLO'),
('0196', 'OSLO'),
('0198', 'OSLO'),
('0201', 'OSLO'),
('0202', 'OSLO'),
('0203', 'OSLO'),
('0204', 'OSLO'),
('0207', 'OSLO'),
('0208', 'OSLO'),
('0211', 'OSLO'),
('0212', 'OSLO'),
('0213', 'OSLO'),
('0214', 'OSLO'),
('0215', 'OSLO'),
('0216', 'OSLO'),
('0230', 'OSLO'),
('0240', 'OSLO'),
('0241', 'OSLO'),
('0242', 'OSLO'),
('0243', 'OSLO'),
('0244', 'OSLO'),
('0245', 'OSLO'),
('0246', 'OSLO'),
('0247', 'OSLO'),
('0250', 'OSLO'),
('0251', 'OSLO'),
('0253', 'OSLO'),
('0254', 'OSLO'),
('0255', 'OSLO'),
('0256', 'OSLO'),
('0257', 'OSLO'),
('0258', 'OSLO'),
('0259', 'OSLO'),
('0260', 'OSLO'),
('0262', 'OSLO'),
('0263', 'OSLO'),
('0264', 'OSLO'),
('0265', 'OSLO'),
('0266', 'OSLO'),
('0267', 'OSLO'),
('0268', 'OSLO'),
('0270', 'OSLO'),
('0271', 'OSLO'),
('0272', 'OSLO'),
('0273', 'OSLO'),
('0274', 'OSLO'),
('0275', 'OSLO'),
('0276', 'OSLO'),
('0277', 'OSLO'),
('0278', 'OSLO'),
('0280', 'OSLO'),
('0281', 'OSLO'),
('0282', 'OSLO'),
('0283', 'OSLO'),
('0284', 'OSLO'),
('0286', 'OSLO'),
('0287', 'OSLO'),
('0301', 'OSLO'),
('0302', 'OSLO'),
('0303', 'OSLO'),
('0304', 'OSLO'),
('0305', 'OSLO'),
('0306', 'OSLO'),
('0307', 'OSLO'),
('0308', 'OSLO'),
('0309', 'OSLO'),
('0310', 'OSLO'),
('0311', 'OSLO'),
('0312', 'OSLO'),
('0313', 'OSLO'),
('0314', 'OSLO'),
('0315', 'OSLO'),
('0316', 'OSLO'),
('0317', 'OSLO'),
('0318', 'OSLO'),
('0319', 'OSLO'),
('0320', 'OSLO'),
('0323', 'OSLO'),
('0330', 'OSLO'),
('0340', 'OSLO'),
('0341', 'OSLO'),
('0342', 'OSLO'),
('0349', 'OSLO'),
('0350', 'OSLO'),
('0351', 'OSLO'),
('0352', 'OSLO'),
('0353', 'OSLO'),
('0354', 'OSLO'),
('0355', 'OSLO'),
('0356', 'OSLO'),
('0357', 'OSLO'),
('0358', 'OSLO'),
('0359', 'OSLO'),
('0360', 'OSLO'),
('0361', 'OSLO'),
('0362', 'OSLO'),
('0363', 'OSLO'),
('0364', 'OSLO'),
('0365', 'OSLO'),
('0366', 'OSLO'),
('0367', 'OSLO'),
('0368', 'OSLO'),
('0369', 'OSLO'),
('0370', 'OSLO'),
('0371', 'OSLO'),
('0372', 'OSLO'),
('0373', 'OSLO'),
('0374', 'OSLO'),
('0375', 'OSLO'),
('0376', 'OSLO'),
('0377', 'OSLO'),
('0378', 'OSLO'),
('0379', 'OSLO'),
('0380', 'OSLO'),
('0381', 'OSLO'),
('0382', 'OSLO'),
('0383', 'OSLO'),
('0401', 'OSLO'),
('0402', 'OSLO'),
('0403', 'OSLO'),
('0404', 'OSLO'),
('0405', 'OSLO'),
('0406', 'OSLO'),
('0407', 'OSLO'),
('0408', 'OSLO'),
('0409', 'OSLO'),
('0411', 'OSLO'),
('0412', 'OSLO'),
('0413', 'OSLO'),
('0415', 'OSLO'),
('0421', 'OSLO'),
('0422', 'OSLO'),
('0423', 'OSLO'),
('0424', 'OSLO'),
('0425', 'OSLO'),
('0426', 'OSLO'),
('0440', 'OSLO'),
('0441', 'OSLO'),
('0444', 'OSLO'),
('0445', 'OSLO'),
('0450', 'OSLO'),
('0451', 'OSLO'),
('0452', 'OSLO'),
('0454', 'OSLO'),
('0455', 'OSLO'),
('0456', 'OSLO'),
('0457', 'OSLO'),
('0458', 'OSLO'),
('0459', 'OSLO'),
('0460', 'OSLO'),
('0461', 'OSLO'),
('0462', 'OSLO'),
('0463', 'OSLO'),
('0464', 'OSLO'),
('0465', 'OSLO'),
('0467', 'OSLO'),
('0468', 'OSLO'),
('0469', 'OSLO'),
('0470', 'OSLO'),
('0472', 'OSLO'),
('0473', 'OSLO'),
('0474', 'OSLO'),
('0475', 'OSLO'),
('0476', 'OSLO'),
('0477', 'OSLO'),
('0478', 'OSLO'),
('0479', 'OSLO'),
('0480', 'OSLO'),
('0481', 'OSLO'),
('0482', 'OSLO'),
('0483', 'OSLO'),
('0484', 'OSLO'),
('0485', 'OSLO'),
('0486', 'OSLO'),
('0487', 'OSLO'),
('0488', 'OSLO'),
('0489', 'OSLO'),
('0490', 'OSLO'),
('0491', 'OSLO'),
('0492', 'OSLO'),
('0493', 'OSLO'),
('0494', 'OSLO'),
('0495', 'OSLO'),
('0496', 'OSLO'),
('0501', 'OSLO'),
('0502', 'OSLO'),
('0503', 'OSLO'),
('0504', 'OSLO'),
('0505', 'OSLO'),
('0506', 'OSLO'),
('0508', 'OSLO'),
('0509', 'OSLO'),
('0510', 'OSLO'),
('0511', 'OSLO'),
('0512', 'OSLO'),
('0513', 'OSLO'),
('0514', 'OSLO'),
('0515', 'OSLO'),
('0516', 'OSLO'),
('0517', 'OSLO'),
('0518', 'OSLO'),
('0520', 'OSLO'),
('0530', 'OSLO'),
('0531', 'OSLO'),
('0532', 'OSLO'),
('0540', 'OSLO'),
('0550', 'OSLO'),
('0551', 'OSLO'),
('0552', 'OSLO'),
('0553', 'OSLO'),
('0554', 'OSLO'),
('0555', 'OSLO'),
('0556', 'OSLO'),
('0557', 'OSLO'),
('0558', 'OSLO'),
('0559', 'OSLO'),
('0560', 'OSLO'),
('0561', 'OSLO'),
('0562', 'OSLO'),
('0563', 'OSLO'),
('0564', 'OSLO'),
('0565', 'OSLO'),
('0566', 'OSLO'),
('0567', 'OSLO'),
('0568', 'OSLO'),
('0569', 'OSLO'),
('0570', 'OSLO'),
('0571', 'OSLO'),
('0572', 'OSLO'),
('0573', 'OSLO'),
('0574', 'OSLO'),
('0575', 'OSLO'),
('0576', 'OSLO'),
('0577', 'OSLO'),
('0578', 'OSLO'),
('0579', 'OSLO'),
('0580', 'OSLO'),
('0581', 'OSLO'),
('0582', 'OSLO'),
('0583', 'OSLO'),
('0584', 'OSLO'),
('0585', 'OSLO'),
('0586', 'OSLO'),
('0587', 'OSLO'),
('0588', 'OSLO'),
('0589', 'OSLO'),
('0590', 'OSLO'),
('0591', 'OSLO'),
('0592', 'OSLO'),
('0593', 'OSLO'),
('0594', 'OSLO'),
('0595', 'OSLO'),
('0596', 'OSLO'),
('0597', 'OSLO'),
('0598', 'OSLO'),
('0601', 'OSLO'),
('0602', 'OSLO'),
('0603', 'OSLO'),
('0604', 'OSLO'),
('0605', 'OSLO'),
('0606', 'OSLO'),
('0607', 'OSLO'),
('0608', 'OSLO'),
('0609', 'OSLO'),
('0610', 'OSLO'),
('0611', 'OSLO'),
('0612', 'OSLO'),
('0613', 'OSLO'),
('0614', 'OSLO'),
('0616', 'OSLO'),
('0617', 'OSLO'),
('0618', 'OSLO'),
('0619', 'OSLO'),
('0620', 'OSLO'),
('0621', 'OSLO'),
('0622', 'OSLO'),
('0623', 'OSLO'),
('0624', 'OSLO'),
('0630', 'OSLO'),
('0640', 'OSLO'),
('0645', 'OSLO'),
('0650', 'OSLO'),
('0651', 'OSLO'),
('0652', 'OSLO'),
('0653', 'OSLO'),
('0654', 'OSLO'),
('0655', 'OSLO'),
('0656', 'OSLO'),
('0657', 'OSLO'),
('0658', 'OSLO'),
('0659', 'OSLO'),
('0660', 'OSLO'),
('0661', 'OSLO'),
('0662', 'OSLO'),
('0663', 'OSLO'),
('0664', 'OSLO'),
('0665', 'OSLO'),
('0666', 'OSLO'),
('0667', 'OSLO'),
('0668', 'OSLO'),
('0669', 'OSLO'),
('0670', 'OSLO'),
('0671', 'OSLO'),
('0672', 'OSLO'),
('0673', 'OSLO'),
('0674', 'OSLO'),
('0675', 'OSLO'),
('0676', 'OSLO'),
('0677', 'OSLO'),
('0678', 'OSLO'),
('0679', 'OSLO'),
('0680', 'OSLO'),
('0681', 'OSLO'),
('0682', 'OSLO'),
('0683', 'OSLO'),
('0684', 'OSLO'),
('0685', 'OSLO'),
('0686', 'OSLO'),
('0687', 'OSLO'),
('0688', 'OSLO'),
('0689', 'OSLO'),
('0690', 'OSLO'),
('0691', 'OSLO'),
('0692', 'OSLO'),
('0693', 'OSLO'),
('0694', 'OSLO'),
('0701', 'OSLO'),
('0702', 'OSLO'),
('0703', 'OSLO'),
('0705', 'OSLO'),
('0710', 'OSLO'),
('0712', 'OSLO'),
('0750', 'OSLO'),
('0751', 'OSLO'),
('0752', 'OSLO'),
('0753', 'OSLO'),
('0754', 'OSLO'),
('0755', 'OSLO'),
('0756', 'OSLO'),
('0757', 'OSLO'),
('0758', 'OSLO'),
('0759', 'OSLO'),
('0760', 'OSLO'),
('0763', 'OSLO'),
('0764', 'OSLO'),
('0765', 'OSLO'),
('0766', 'OSLO'),
('0767', 'OSLO'),
('0768', 'OSLO'),
('0770', 'OSLO'),
('0771', 'OSLO'),
('0772', 'OSLO'),
('0773', 'OSLO'),
('0774', 'OSLO'),
('0775', 'OSLO'),
('0776', 'OSLO'),
('0777', 'OSLO'),
('0778', 'OSLO'),
('0779', 'OSLO'),
('0781', 'OSLO'),
('0782', 'OSLO'),
('0783', 'OSLO'),
('0784', 'OSLO'),
('0785', 'OSLO'),
('0786', 'OSLO'),
('0787', 'OSLO'),
('0788', 'OSLO'),
('0789', 'OSLO'),
('0790', 'OSLO'),
('0791', 'OSLO'),
('0801', 'OSLO'),
('0805', 'OSLO'),
('0806', 'OSLO'),
('0807', 'OSLO'),
('0840', 'OSLO'),
('0850', 'OSLO'),
('0851', 'OSLO'),
('0852', 'OSLO'),
('0853', 'OSLO'),
('0854', 'OSLO'),
('0855', 'OSLO'),
('0856', 'OSLO'),
('0857', 'OSLO'),
('0858', 'OSLO'),
('0860', 'OSLO'),
('0861', 'OSLO'),
('0862', 'OSLO'),
('0863', 'OSLO'),
('0864', 'OSLO'),
('0870', 'OSLO'),
('0871', 'OSLO'),
('0872', 'OSLO'),
('0873', 'OSLO'),
('0874', 'OSLO'),
('0875', 'OSLO'),
('0876', 'OSLO'),
('0877', 'OSLO'),
('0880', 'OSLO'),
('0881', 'OSLO'),
('0882', 'OSLO'),
('0883', 'OSLO'),
('0884', 'OSLO'),
('0890', 'OSLO'),
('0891', 'OSLO'),
('0901', 'OSLO'),
('0902', 'OSLO'),
('0903', 'OSLO'),
('0904', 'OSLO'),
('0905', 'OSLO'),
('0907', 'OSLO'),
('0913', 'OSLO'),
('0915', 'OSLO'),
('0950', 'OSLO'),
('0951', 'OSLO'),
('0952', 'OSLO'),
('0953', 'OSLO'),
('0954', 'OSLO'),
('0955', 'OSLO'),
('0956', 'OSLO'),
('0957', 'OSLO'),
('0958', 'OSLO'),
('0959', 'OSLO'),
('0960', 'OSLO'),
('0962', 'OSLO'),
('0963', 'OSLO'),
('0964', 'OSLO'),
('0968', 'OSLO'),
('0969', 'OSLO'),
('0970', 'OSLO'),
('0971', 'OSLO'),
('0972', 'OSLO'),
('0973', 'OSLO'),
('0975', 'OSLO'),
('0976', 'OSLO'),
('0977', 'OSLO'),
('0978', 'OSLO'),
('0979', 'OSLO'),
('0980', 'OSLO'),
('0981', 'OSLO'),
('0982', 'OSLO'),
('0983', 'OSLO'),
('0984', 'OSLO'),
('0985', 'OSLO'),
('0986', 'OSLO'),
('0987', 'OSLO'),
('0988', 'OSLO'),
('1001', 'OSLO'),
('1003', 'OSLO'),
('1005', 'OSLO'),
('1006', 'OSLO'),
('1007', 'OSLO'),
('1008', 'OSLO'),
('1009', 'OSLO'),
('1011', 'OSLO'),
('1051', 'OSLO'),
('1052', 'OSLO'),
('1053', 'OSLO'),
('1054', 'OSLO'),
('1055', 'OSLO'),
('1056', 'OSLO'),
('1061', 'OSLO'),
('1062', 'OSLO'),
('1063', 'OSLO'),
('1064', 'OSLO'),
('1065', 'OSLO'),
('1067', 'OSLO'),
('1068', 'OSLO'),
('1069', 'OSLO'),
('1071', 'OSLO'),
('1081', 'OSLO'),
('1083', 'OSLO'),
('1084', 'OSLO'),
('1086', 'OSLO'),
('1087', 'OSLO'),
('1088', 'OSLO'),
('1089', 'OSLO'),
('1101', 'OSLO'),
('1109', 'OSLO'),
('1112', 'OSLO'),
('1150', 'OSLO'),
('1151', 'OSLO'),
('1152', 'OSLO'),
('1153', 'OSLO'),
('1154', 'OSLO'),
('1155', 'OSLO'),
('1156', 'OSLO'),
('1157', 'OSLO'),
('1158', 'OSLO'),
('1160', 'OSLO'),
('1161', 'OSLO'),
('1162', 'OSLO'),
('1163', 'OSLO'),
('1164', 'OSLO'),
('1165', 'OSLO'),
('1166', 'OSLO'),
('1167', 'OSLO'),
('1168', 'OSLO'),
('1169', 'OSLO'),
('1170', 'OSLO'),
('1172', 'OSLO'),
('1176', 'OSLO'),
('1177', 'OSLO'),
('1178', 'OSLO'),
('1179', 'OSLO'),
('1181', 'OSLO'),
('1182', 'OSLO'),
('1184', 'OSLO'),
('1185', 'OSLO'),
('1187', 'OSLO'),
('1188', 'OSLO'),
('1189', 'OSLO'),
('1201', 'OSLO'),
('1202', 'OSLO'),
('1203', 'OSLO'),
('1204', 'OSLO'),
('1205', 'OSLO'),
('1206', 'OSLO'),
('1207', 'OSLO'),
('1214', 'OSLO'),
('1215', 'OSLO'),
('1250', 'OSLO'),
('1251', 'OSLO'),
('1252', 'OSLO'),
('1253', 'OSLO'),
('1254', 'OSLO'),
('1255', 'OSLO'),
('1256', 'OSLO'),
('1257', 'OSLO'),
('1258', 'OSLO'),
('1259', 'OSLO'),
('1262', 'OSLO'),
('1263', 'OSLO'),
('1266', 'OSLO'),
('1270', 'OSLO'),
('1271', 'OSLO'),
('1272', 'OSLO'),
('1273', 'OSLO'),
('1274', 'OSLO'),
('1275', 'OSLO'),
('1277', 'OSLO'),
('1278', 'OSLO'),
('1279', 'OSLO'),
('1281', 'OSLO'),
('1283', 'OSLO'),
('1284', 'OSLO'),
('1285', 'OSLO'),
('1286', 'OSLO'),
('1290', 'OSLO'),
('1291', 'OSLO'),
('1294', 'OSLO'),
('1295', 'OSLO'),
('1300', 'SANDVIKA'),
('1301', 'SANDVIKA'),
('1302', 'SANDVIKA'),
('1303', 'SANDVIKA'),
('1304', 'SANDVIKA'),
('1305', 'HASLUM'),
('1306', 'BÆRUM POSTTERMINAL'),
('1309', 'RUD'),
('1311', 'KUNSTSENTRET HØVIKODDEN'),
('1312', 'SLEPENDEN'),
('1313', 'VØYENENGA'),
('1314', 'VØYENENGA'),
('1316', 'EIKSMARKA'),
('1317', 'BÆRUMS VERK'),
('1318', 'BEKKESTUA'),
('1319', 'BEKKESTUA'),
('1321', 'STABEKK'),
('1322', 'HØVIK'),
('1323', 'HØVIK'),
('1324', 'LYSAKER'),
('1325', 'LYSAKER'),
('1326', 'LYSAKER'),
('1327', 'LYSAKER'),
('1330', 'FORNEBU'),
('1331', 'FORNEBU'),
('1332', 'ØSTERÅS'),
('1333', 'KOLSÅS'),
('1334', 'RYKKINN'),
('1335', 'SNARØYA'),
('1336', 'SANDVIKA'),
('1337', 'SANDVIKA'),
('1338', 'SANDVIKA'),
('1339', 'VØYENENGA'),
('1340', 'SKUI'),
('1341', 'SLEPENDEN'),
('1344', 'HASLUM'),
('1346', 'GJETTUM'),
('1348', 'RYKKINN'),
('1349', 'RYKKINN'),
('1350', 'LOMMEDALEN'),
('1351', 'RUD'),
('1352', 'KOLSÅS'),
('1353', 'BÆRUMS VERK'),
('1354', 'BÆRUMS VERK'),
('1356', 'BEKKESTUA'),
('1357', 'BEKKESTUA'),
('1358', 'JAR'),
('1359', 'EIKSMARKA'),
('1361', 'ØSTERÅS'),
('1362', 'HOSLE'),
('1363', 'HØVIK'),
('1365', 'BLOMMENHOLM'),
('1366', 'LYSAKER'),
('1367', 'SNARØYA'),
('1368', 'STABEKK'),
('1369', 'STABEKK'),
('1371', 'ASKER'),
('1372', 'ASKER'),
('1373', 'ASKER'),
('1375', 'BILLINGSTAD'),
('1376', 'BILLINGSTAD'),
('1377', 'BILLINGSTAD'),
('1378', 'NESBRU'),
('1379', 'NESBRU'),
('1380', 'HEGGEDAL'),
('1381', 'VETTRE'),
('1383', 'ASKER'),
('1384', 'ASKER'),
('1385', 'ASKER'),
('1386', 'ASKER'),
('1387', 'ASKER'),
('1388', 'BORGEN'),
('1389', 'HEGGEDAL'),
('1390', 'VOLLEN'),
('1391', 'VOLLEN'),
('1392', 'VETTRE'),
('1393', 'VOLLEN'),
('1394', 'NESBRU'),
('1395', 'HVALSTAD'),
('1396', 'BILLINGSTAD'),
('1397', 'NESØYA'),
('1399', 'ASKER'),
('1400', 'SKI'),
('1401', 'SKI'),
('1402', 'SKI'),
('1403', 'LANGHUS'),
('1404', 'SIGGERUD'),
('1405', 'LANGHUS'),
('1406', 'SKI'),
('1407', 'VINTERBRO'),
('1408', 'KRÅKSTAD'),
('1409', 'SKOTBU'),
('1410', 'KOLBOTN'),
('1411', 'KOLBOTN'),
('1412', 'SOFIEMYR'),
('1413', 'TÅRNÅSEN'),
('1414', 'TROLLÅSEN'),
('1415', 'OPPEGÅRD'),
('1416', 'OPPEGÅRD'),
('1417', 'SOFIEMYR'),
('1419', 'OPPEGÅRD'),
('1420', 'SVARTSKOG'),
('1421', 'TROLLÅSEN'),
('1430', 'ÅS'),
('1431', 'ÅS'),
('1432', 'ÅS (Landbrukshøyskolen)'),
('1440', 'DRØBAK'),
('1441', 'DRØBAK'),
('1442', 'DRØBAK'),
('1443', 'OSCARSBORG'),
('1444', 'SKIPHELLE'),
('1445', 'HEER'),
('1450', 'NESODDTANGEN'),
('1451', 'NESODDTANGEN'),
('1453', 'BJØRNEMYR'),
('1454', 'FAGERSTRAND'),
('1455', 'NORDRE FROGN'),
('1458', 'FJELLSTRAND'),
('1459', 'FJELLSTRAND'),
('1470', 'LØRENSKOG'),
('1471', 'LØRENSKOG'),
('1472', 'FJELLHAMAR'),
('1473', 'LØRENSKOG'),
('1474', 'NORDBYHAGEN'),
('1475', 'FINSTADJORDET'),
('1476', 'RASTA'),
('1477', 'FJELLHAMAR'),
('1480', 'SLATTUM'),
('1481', 'HAGAN'),
('1482', 'NITTEDAL'),
('1483', 'SKYTTA'),
('1484', 'ÅNEBY'),
('1487', 'TØYENHAUGEN'),
('1488', 'HAKADAL'),
('1501', 'MOSS'),
('1502', 'MOSS'),
('1503', 'MOSS'),
('1504', 'MOSS'),
('1505', 'MOSS'),
('1506', 'MOSS'),
('1509', 'MOSS'),
('1510', 'MOSS'),
('1511', 'MOSS'),
('1512', 'MOSS'),
('1513', 'MOSS'),
('1514', 'MOSS'),
('1515', 'MOSS'),
('1516', 'MOSS'),
('1517', 'MOSS'),
('1518', 'MOSS'),
('1519', 'MOSS'),
('1520', 'MOSS'),
('1521', 'MOSS'),
('1522', 'MOSS'),
('1523', 'MOSS'),
('1524', 'MOSS'),
('1525', 'MOSS'),
('1526', 'MOSS'),
('1528', 'MOSS'),
('1529', 'MOSS'),
('1530', 'MOSS'),
('1531', 'MOSS'),
('1532', 'MOSS'),
('1533', 'MOSS'),
('1534', 'MOSS'),
('1535', 'MOSS'),
('1536', 'MOSS'),
('1537', 'MOSS'),
('1538', 'MOSS'),
('1539', 'MOSS'),
('1540', 'VESTBY'),
('1541', 'VESTBY'),
('1545', 'HVITSTEN'),
('1550', 'HØLEN'),
('1555', 'SON'),
('1556', 'SON'),
('1560', 'LARKOLLEN'),
('1570', 'DILLING'),
('1580', 'RYGGE'),
('1581', 'RYGGE'),
('1583', 'RYGGE'),
('1590', 'RYGGE FLYSTASJON'),
('1591', 'SPERREBOTN'),
('1592', 'VÅLER I ØSTFOLD'),
('1593', 'SVINNDAL'),
('1596', 'MOSS'),
('1597', 'MOSS'),
('1598', 'MOSS'),
('1599', 'MOSS'),
('1601', 'FREDRIKSTAD'),
('1602', 'FREDRIKSTAD'),
('1603', 'FREDRIKSTAD'),
('1604', 'FREDRIKSTAD'),
('1605', 'FREDRIKSTAD'),
('1606', 'FREDRIKSTAD'),
('1607', 'FREDRIKSTAD'),
('1608', 'FREDRIKSTAD'),
('1610', 'FREDRIKSTAD'),
('1612', 'FREDRIKSTAD'),
('1613', 'FREDRIKSTAD'),
('1614', 'FREDRIKSTAD'),
('1615', 'FREDRIKSTAD'),
('1616', 'FREDRIKSTAD'),
('1617', 'FREDRIKSTAD'),
('1618', 'FREDRIKSTAD'),
('1619', 'FREDRIKSTAD'),
('1620', 'GRESSVIK'),
('1621', 'GRESSVIK'),
('1624', 'GRESSVIK'),
('1625', 'MANSTAD'),
('1626', 'MANSTAD'),
('1628', 'ENGALSVIK'),
('1630', 'GAMLE FREDRIKSTAD'),
('1631', 'GAMLE FREDRIKSTAD'),
('1632', 'GAMLE FREDRIKSTAD'),
('1633', 'GAMLE FREDRIKSTAD'),
('1634', 'GAMLE FREDRIKSTAD'),
('1636', 'GAMLE FREDRIKSTAD'),
('1637', 'GAMLE FREDRIKSTAD'),
('1639', 'GAMLE FREDRIKSTAD'),
('1640', 'RÅDE'),
('1641', 'RÅDE'),
('1650', 'SELLEBAKK'),
('1651', 'SELLEBAKK'),
('1653', 'SELLEBAKK'),
('1654', 'SELLEBAKK'),
('1655', 'SELLEBAKK'),
('1657', 'TORP'),
('1658', 'TORP'),
('1659', 'TORP'),
('1661', 'ROLVSØY'),
('1662', 'ROLVSØY'),
('1663', 'ROLVSØY'),
('1664', 'ROLVSØY'),
('1665', 'ROLVSØY'),
('1666', 'ROLVSØY'),
('1670', 'KRÅKERØY'),
('1671', 'KRÅKERØY'),
('1672', 'KRÅKERØY'),
('1673', 'KRÅKERØY'),
('1675', 'KRÅKERØY'),
('1676', 'KRÅKERØY'),
('1678', 'KRÅKERØY'),
('1679', 'KRÅKERØY'),
('1680', 'SKJÆRHALLEN'),
('1682', 'SKJÆRHALLEN'),
('1683', 'VESTERØY'),
('1684', 'VESTERØY'),
('1690', 'HERFØL'),
('1692', 'NEDGÅRDEN'),
('1701', 'SARPSBORG'),
('1702', 'SARPSBORG'),
('1703', 'SARPSBORG'),
('1704', 'SARPSBORG'),
('1705', 'SARPSBORG'),
('1706', 'SARPSBORG'),
('1707', 'SARPSBORG'),
('1708', 'SARPSBORG'),
('1709', 'SARPSBORG'),
('1710', 'SARPSBORG'),
('1711', 'SARPSBORG'),
('1712', 'GRÅLUM'),
('1713', 'GRÅLUM'),
('1714', 'SARPSBORG'),
('1715', 'YVEN'),
('1718', 'GREÅKER'),
('1719', 'GREÅKER'),
('1720', 'GREÅKER'),
('1721', 'SARPSBORG'),
('1722', 'SARPSBORG'),
('1723', 'SARPSBORG'),
('1724', 'SARPSBORG'),
('1725', 'SARPSBORG'),
('1726', 'SARPSBORG'),
('1727', 'SARPSBORG'),
('1730', 'ISE'),
('1733', 'HAFSLUNDSØY'),
('1734', 'HAFSLUNDSØY'),
('1735', 'VARTEIG'),
('1738', 'BORGENHAUGEN'),
('1739', 'BORGENHAUGEN'),
('1740', 'BORGENHAUGEN'),
('1742', 'KLAVESTADHAUGEN'),
('1743', 'KLAVESTADHAUGEN'),
('1745', 'SKJEBERG'),
('1746', 'SKJEBERG'),
('1747', 'SKJEBERG'),
('1751', 'HALDEN'),
('1752', 'HALDEN'),
('1753', 'HALDEN'),
('1754', 'HALDEN'),
('1755', 'HALDEN'),
('1756', 'HALDEN'),
('1757', 'HALDEN'),
('1758', 'HALDEN'),
('1759', 'HALDEN'),
('1760', 'HALDEN'),
('1761', 'HALDEN'),
('1763', 'HALDEN'),
('1764', 'HALDEN'),
('1765', 'HALDEN'),
('1766', 'HALDEN'),
('1767', 'HALDEN'),
('1768', 'HALDEN'),
('1769', 'HALDEN'),
('1771', 'HALDEN'),
('1772', 'HALDEN'),
('1776', 'HALDEN'),
('1777', 'HALDEN'),
('1778', 'HALDEN'),
('1779', 'HALDEN'),
('1781', 'HALDEN'),
('1782', 'HALDEN'),
('1783', 'HALDEN'),
('1784', 'HALDEN'),
('1785', 'HALDEN'),
('1786', 'HALDEN'),
('1787', 'BERG I ØSTFOLD'),
('1788', 'BERG I ØSTFOLD'),
('1789', 'BERG I ØSTFOLD'),
('1790', 'TISTEDAL'),
('1791', 'TISTEDAL'),
('1792', 'TISTEDAL'),
('1793', 'TISTEDAL'),
('1794', 'SPONVIKA'),
('1796', 'KORNSJØ'),
('1798', 'AREMARK'),
('1799', 'AREMARK'),
('1801', 'ASKIM'),
('1802', 'ASKIM'),
('1803', 'ASKIM'),
('1804', 'SPYDEBERG'),
('1805', 'TOMTER'),
('1806', 'SKIPTVET'),
('1807', 'ASKIM'),
('1808', 'ASKIM'),
('1809', 'ASKIM'),
('1811', 'ASKIM'),
('1812', 'ASKIM'),
('1813', 'ASKIM'),
('1814', 'ASKIM'),
('1815', 'ASKIM'),
('1816', 'SKIPTVET'),
('1820', 'SPYDEBERG'),
('1823', 'KNAPSTAD'),
('1827', 'HOBØL'),
('1830', 'ASKIM'),
('1831', 'ASKIM'),
('1832', 'ASKIM'),
('1850', 'MYSEN'),
('1851', 'MYSEN'),
('1859', 'SLITU'),
('1860', 'TRØGSTAD'),
('1861', 'TRØGSTAD'),
('1866', 'BÅSTAD'),
('1867', 'BÅSTAD'),
('1870', 'ØRJE'),
('1871', 'ØRJE'),
('1875', 'OTTEID'),
('1878', 'HÆRLAND'),
('1880', 'EIDSBERG'),
('1890', 'RAKKESTAD'),
('1891', 'RAKKESTAD'),
('1892', 'DEGERNES'),
('1893', 'DEGERNES'),
('1900', 'FETSUND'),
('1901', 'FETSUND'),
('1903', 'GAN'),
('1910', 'ENEBAKKNESET'),
('1911', 'FLATEBY'),
('1912', 'ENEBAKK'),
('1914', 'YTRE ENEBAKK'),
('1920', 'SØRUMSAND'),
('1921', 'SØRUMSAND'),
('1923', 'SØRUM'),
('1925', 'BLAKER'),
('1927', 'RÅNÅSFOSS'),
('1929', 'AULI'),
('1930', 'AURSKOG'),
('1940', 'BJØRKELANGEN'),
('1941', 'BJØRKELANGEN'),
('1950', 'RØMSKOG'),
('1954', 'SETSKOG'),
('1960', 'LØKEN'),
('1963', 'FOSSER'),
('1970', 'HEMNES'),
('2001', 'LILLESTRØM'),
('2003', 'LILLESTRØM'),
('2006', 'LØVENSTAD'),
('2007', 'KJELLER'),
('2008', 'FJERDINGBY'),
('2009', 'NORDBY'),
('2010', 'STRØMMEN'),
('2011', 'STRØMMEN'),
('2013', 'SKJETTEN'),
('2014', 'BLYSTADLIA'),
('2015', 'LEIRSUND'),
('2016', 'FROGNER'),
('2019', 'SKEDSMOKORSET'),
('2020', 'SKEDSMOKORSET'),
('2021', 'SKEDSMOKORSET'),
('2022', 'GJERDRUM'),
('2024', 'GJERDRUM'),
('2025', 'FJERDINGBY'),
('2026', 'SKJETTEN'),
('2027', 'KJELLER'),
('2030', 'NANNESTAD'),
('2031', 'NANNESTAD'),
('2032', 'MAURA'),
('2033', 'ÅSGREINA'),
('2034', 'HOLTER'),
('2040', 'KLØFTA'),
('2041', 'KLØFTA'),
('2050', 'JESSHEIM'),
('2051', 'JESSHEIM'),
('2052', 'JESSHEIM'),
('2054', 'MOGREINA'),
('2055', 'NORDKISA'),
('2056', 'ALGARHEIM'),
('2057', 'JESSHEIM'),
('2058', 'SESSVOLLMOEN'),
('2059', 'TRANDUM'),
('2060', 'GARDERMOEN'),
('2061', 'GARDERMOEN'),
('2065', 'GARDERMOEN'),
('2070', 'RÅHOLT'),
('2071', 'RÅHOLT'),
('2072', 'DAL'),
('2073', 'BØN'),
('2074', 'EIDSVOLL VERK'),
('2076', 'DAL'),
('2080', 'EIDSVOLL'),
('2081', 'EIDSVOLL'),
('2090', 'HURDAL'),
('2091', 'HURDAL'),
('2092', 'MINNESUND'),
('2093', 'FEIRING'),
('2100', 'SKARNES'),
('2101', 'SKARNES'),
('2110', 'SLÅSTAD'),
('2114', 'DISENÅ'),
('2116', 'SANDER'),
('2120', 'SAGSTUA'),
('2123', 'BRUVOLL'),
('2130', 'KNAPPER'),
('2133', 'GARDVIK'),
('2134', 'AUSTVATN'),
('2150', 'ÅRNES'),
('2151', 'ÅRNES'),
('2160', 'VORMSUND'),
('2162', 'BRÅRUD'),
('2164', 'SKOGBYGDA'),
('2165', 'HVAM'),
('2166', 'OPPAKER'),
('2170', 'FENSTAD'),
('2201', 'KONGSVINGER'),
('2202', 'KONGSVINGER'),
('2203', 'KONGSVINGER'),
('2204', 'KONGSVINGER'),
('2205', 'KONGSVINGER'),
('2206', 'KONGSVINGER'),
('2208', 'KONGSVINGER'),
('2209', 'KONGSVINGER'),
('2210', 'GRANLI'),
('2211', 'KONGSVINGER'),
('2212', 'KONGSVINGER'),
('2213', 'KONGSVINGER'),
('2214', 'KONGSVINGER'),
('2216', 'ROVERUD'),
('2217', 'HOKKÅSEN'),
('2218', 'LUNDERSÆTER'),
('2219', 'BRANDVAL'),
('2220', 'ÅBOGEN'),
('2223', 'GALTERUD'),
('2224', 'AUSTMARKA'),
('2225', 'KONGSVINGER'),
('2226', 'KONGSVINGER'),
('2230', 'SKOTTERUD'),
('2232', 'TOBØL'),
('2233', 'VESTMARKA'),
('2235', 'MATRAND'),
('2240', 'MAGNOR'),
('2242', 'MOROKULIEN'),
('2256', 'GRUE FINNSKOG'),
('2260', 'KIRKENÆR'),
('2264', 'GRINDER'),
('2265', 'NAMNÅ'),
('2266', 'ARNEBERG'),
('2270', 'FLISA'),
('2271', 'FLISA'),
('2280', 'GJESÅSEN'),
('2283', 'ÅSNES FINNSKOG'),
('2301', 'HAMAR'),
('2302', 'HAMAR'),
('2303', 'HAMAR'),
('2304', 'HAMAR'),
('2305', 'HAMAR'),
('2306', 'HAMAR'),
('2307', 'HAMAR'),
('2308', 'HAMAR'),
('2309', 'HAMAR'),
('2312', 'OTTESTAD'),
('2315', 'HAMAR'),
('2316', 'HAMAR'),
('2317', 'HAMAR'),
('2318', 'HAMAR'),
('2319', 'HAMAR'),
('2320', 'FURNES'),
('2321', 'HAMAR'),
('2322', 'RIDABU'),
('2323', 'INGEBERG'),
('2324', 'VANG PÅ HEDMARK'),
('2325', 'HAMAR'),
('2326', 'HAMAR'),
('2327', 'HAMAR'),
('2330', 'VALLSET'),
('2332', 'ÅSVANG'),
('2334', 'ROMEDAL'),
('2335', 'STANGE'),
('2336', 'STANGE'),
('2337', 'TANGEN'),
('2338', 'ESPA'),
('2340', 'LØTEN'),
('2341', 'LØTEN'),
('2344', 'ILSENG'),
('2345', 'ÅDALSBRUK'),
('2350', 'NES PÅ HEDMARK'),
('2353', 'STAVSJØ'),
('2355', 'GAUPEN'),
('2360', 'RUDSHØGDA'),
('2364', 'NÆROSET'),
('2365', 'ÅSMARKA'),
('2372', 'BRØTTUM'),
('2380', 'BRUMUNDDAL'),
('2381', 'BRUMUNDDAL'),
('2390', 'MOELV'),
('2391', 'MOELV'),
('2401', 'ELVERUM'),
('2402', 'ELVERUM'),
('2403', 'ELVERUM'),
('2404', 'ELVERUM'),
('2405', 'ELVERUM'),
('2406', 'ELVERUM'),
('2407', 'ELVERUM'),
('2408', 'ELVERUM'),
('2409', 'ELVERUM'),
('2410', 'HERNES'),
('2411', 'ELVERUM'),
('2412', 'SØRSKOGBYGDA'),
('2415', 'HERADSBYGD'),
('2416', 'JØMNA'),
('2418', 'ELVERUM'),
('2420', 'TRYSIL'),
('2421', 'TRYSIL'),
('2422', 'NYBERGSUND'),
('2423', 'ØSTBY'),
('2425', 'LJØRDALEN'),
('2427', 'PLASSEN'),
('2428', 'SØRE OSEN'),
('2429', 'TØRBERGET'),
('2430', 'JORDET'),
('2432', 'SLETTÅS'),
('2435', 'BRASKEREIDFOSS'),
('2436', 'VÅLER I SOLØR'),
('2437', 'HASLEMOEN'),
('2438', 'GRAVBERGET'),
('2440', 'ENGERDAL'),
('2443', 'DREVSJØ'),
('2446', 'ELGÅ'),
('2448', 'SØMÅDALEN'),
('2450', 'RENA'),
('2451', 'RENA'),
('2460', 'OSEN'),
('2476', 'ATNA'),
('2477', 'SOLLIA'),
('2478', 'HANESTAD'),
('2480', 'KOPPANG'),
('2481', 'KOPPANG'),
('2485', 'RENDALEN'),
('2500', 'TYNSET'),
('2501', 'TYNSET'),
('2510', 'TYLLDALEN'),
('2512', 'KVIKNE'),
('2540', 'TOLGA'),
('2542', 'VINGELEN'),
('2544', 'ØVERSJØDALEN'),
('2550', 'OS I ØSTERDALEN'),
('2552', 'DALSBYGDA'),
('2555', 'TUFSINGDALEN'),
('2560', 'ALVDAL'),
('2561', 'ALVDAL'),
('2580', 'FOLLDAL'),
('2581', 'FOLLDAL'),
('2582', 'GRIMSBU'),
('2584', 'DALHOLEN'),
('2601', 'LILLEHAMMER'),
('2602', 'LILLEHAMMER'),
('2603', 'LILLEHAMMER'),
('2604', 'LILLEHAMMER'),
('2605', 'LILLEHAMMER'),
('2606', 'LILLEHAMMER'),
('2607', 'VINGROM'),
('2608', 'LILLEHAMMER'),
('2609', 'LILLEHAMMER'),
('2610', 'MESNALI'),
('2611', 'LILLEHAMMER'),
('2612', 'SJUSJØEN'),
('2613', 'LILLEHAMMER'),
('2614', 'LILLEHAMMER'),
('2615', 'LILLEHAMMER'),
('2616', 'LISMARKA'),
('2617', 'JØRSTADMOEN'),
('2618', 'LILLEHAMMER'),
('2619', 'LILLEHAMMER'),
('2624', 'LILLEHAMMER'),
('2625', 'FÅBERG'),
('2626', 'LILLEHAMMER'),
('2629', 'LILLEHAMMER'),
('2630', 'RINGEBU'),
('2631', 'RINGEBU'),
('2632', 'VENABYGD'),
('2633', 'FÅVANG'),
('2634', 'FÅVANG'),
('2635', 'TRETTEN'),
('2636', 'ØYER'),
('2637', 'ØYER'),
('2639', 'VINSTRA'),
('2640', 'VINSTRA'),
('2642', 'KVAM'),
('2643', 'SKÅBU'),
('2645', 'SØR-FRON'),
('2646', 'GÅLÅ'),
('2647', 'SØR-FRON'),
('2648', 'SØR-FRON'),
('2649', 'ØSTRE GAUSDAL'),
('2651', 'ØSTRE GAUSDAL'),
('2652', 'SVINGVOLL'),
('2653', 'VESTRE GAUSDAL'),
('2656', 'FOLLEBU'),
('2657', 'SVATSUM'),
('2658', 'ESPEDALEN'),
('2659', 'DOMBÅS'),
('2660', 'DOMBÅS'),
('2661', 'HJERKINN'),
('2662', 'DOVRE'),
('2663', 'DOVRESKOGEN'),
('2664', 'DOVRE'),
('2665', 'LESJA'),
('2666', 'LORA'),
('2667', 'LESJAVERK'),
('2668', 'LESJASKOG'),
('2669', 'BJORLI'),
('2670', 'OTTA'),
('2672', 'SEL'),
('2673', 'HØVRINGEN'),
('2674', 'MYSUSÆTER'),
('2675', 'OTTA'),
('2676', 'HEIDAL'),
('2677', 'NEDRE HEIDAL'),
('2680', 'VÅGÅ'),
('2682', 'LALM'),
('2683', 'TESSANDEN'),
('2684', 'VÅGÅ'),
('2685', 'GARMO'),
('2686', 'LOM'),
('2687', 'BØVERDALEN'),
('2688', 'LOM'),
('2690', 'SKJÅK'),
('2693', 'NORDBERG'),
('2694', 'SKJÅK'),
('2695', 'GROTLI'),
('2711', 'GRAN'),
('2712', 'BRANDBU'),
('2713', 'ROA'),
('2714', 'JAREN'),
('2715', 'LUNNER'),
('2716', 'HARESTUA'),
('2717', 'GRUA'),
('2718', 'BRANDBU'),
('2720', 'GRINDVOLL'),
('2730', 'LUNNER'),
('2740', 'ROA'),
('2742', 'GRUA'),
('2743', 'HARESTUA'),
('2750', 'GRAN'),
('2760', 'BRANDBU'),
('2770', 'JAREN'),
('2801', 'GJØVIK'),
('2802', 'GJØVIK'),
('2803', 'GJØVIK'),
('2804', 'GJØVIK'),
('2805', 'GJØVIK'),
('2807', 'HUNNDALEN'),
('2808', 'GJØVIK'),
('2809', 'GJØVIK'),
('2810', 'GJØVIK'),
('2811', 'HUNNDALEN'),
('2815', 'GJØVIK'),
('2818', 'GJØVIK'),
('2819', 'GJØVIK'),
('2821', 'GJØVIK'),
('2822', 'BYBRUA'),
('2825', 'GJØVIK'),
('2827', 'HUNNDALEN'),
('2830', 'RAUFOSS'),
('2831', 'RAUFOSS'),
('2832', 'BIRI'),
('2836', 'BIRI'),
('2837', 'BIRISTRAND'),
('2838', 'SNERTINGDAL'),
('2839', 'ØVRE SNERTINGDAL'),
('2840', 'REINSVOLL'),
('2843', 'EINA'),
('2846', 'BØVERBRU'),
('2847', 'KOLBU'),
('2848', 'SKREIA'),
('2849', 'KAPP'),
('2850', 'LENA'),
('2851', 'LENA'),
('2853', 'REINSVOLL'),
('2854', 'EINA'),
('2857', 'SKREIA'),
('2858', 'KAPP'),
('2860', 'HOV'),
('2861', 'LANDÅSBYGDA'),
('2862', 'FLUBERG'),
('2864', 'FALL'),
('2866', 'ENGER'),
('2867', 'HOV'),
('2870', 'DOKKA'),
('2879', 'ODNES'),
('2880', 'NORD-TORPA'),
('2881', 'AUST-TORPA'),
('2882', 'DOKKA'),
('2890', 'ETNEDAL'),
('2893', 'ETNEDAL'),
('2900', 'FAGERNES'),
('2901', 'FAGERNES'),
('2907', 'LEIRA I VALDRES'),
('2910', 'AURDAL'),
('2917', 'SKRAUTVÅL'),
('2918', 'ULNES'),
('2920', 'LEIRA I VALDRES'),
('2923', 'TISLEIDALEN'),
('2929', 'BAGN'),
('2930', 'BAGN'),
('2933', 'REINLI'),
('2936', 'BEGNADALEN'),
('2937', 'BEGNA'),
('2939', 'HEGGENES'),
('2940', 'HEGGENES'),
('2943', 'ROGNE'),
('2950', 'SKAMMESTEIN'),
('2952', 'BEITO'),
('2953', 'BEITOSTØLEN'),
('2959', 'RØN'),
('2960', 'RØN'),
('2966', 'SLIDRE'),
('2967', 'LOMEN'),
('2973', 'RYFOSS'),
('2974', 'VANG I VALDRES'),
('2975', 'VANG I VALDRES'),
('2977', 'ØYE'),
('2985', 'TYINKRYSSET'),
('3001', 'DRAMMEN'),
('3002', 'DRAMMEN'),
('3003', 'DRAMMEN'),
('3004', 'DRAMMEN'),
('3005', 'DRAMMEN'),
('3006', 'DRAMMEN'),
('3007', 'DRAMMEN'),
('3008', 'DRAMMEN'),
('3012', 'DRAMMEN'),
('3013', 'DRAMMEN'),
('3014', 'DRAMMEN'),
('3015', 'DRAMMEN'),
('3016', 'DRAMMEN'),
('3017', 'DRAMMEN'),
('3018', 'DRAMMEN'),
('3019', 'DRAMMEN'),
('3020', 'DRAMMEN'),
('3021', 'DRAMMEN'),
('3022', 'DRAMMEN'),
('3023', 'DRAMMEN'),
('3024', 'DRAMMEN'),
('3025', 'DRAMMEN'),
('3026', 'DRAMMEN'),
('3027', 'DRAMMEN'),
('3028', 'DRAMMEN'),
('3029', 'DRAMMEN'),
('3030', 'DRAMMEN'),
('3032', 'DRAMMEN'),
('3033', 'DRAMMEN'),
('3034', 'DRAMMEN'),
('3035', 'DRAMMEN'),
('3036', 'DRAMMEN'),
('3037', 'DRAMMEN'),
('3038', 'DRAMMEN'),
('3039', 'DRAMMEN'),
('3040', 'DRAMMEN'),
('3041', 'DRAMMEN'),
('3042', 'DRAMMEN'),
('3043', 'DRAMMEN'),
('3044', 'DRAMMEN'),
('3045', 'DRAMMEN'),
('3046', 'DRAMMEN'),
('3047', 'DRAMMEN'),
('3050', 'MJØNDALEN'),
('3051', 'MJØNDALEN'),
('3053', 'STEINBERG'),
('3054', 'KROKSTADELVA'),
('3055', 'KROKSTADELVA'),
('3056', 'SOLBERGELVA'),
('3057', 'SOLBERGELVA'),
('3058', 'SOLBERGMOEN'),
('3060', 'SVELVIK'),
('3061', 'SVELVIK'),
('3070', 'SANDE I VESTFOLD'),
('3071', 'SANDE I VESTFOLD'),
('3075', 'BERGER'),
('3080', 'HOLMESTRAND'),
('3081', 'HOLMESTRAND'),
('3087', 'BOTNE'),
('3088', 'BOTNE'),
('3090', 'HOF'),
('3092', 'SUNDBYFOSS'),
('3095', 'EIDSFOSS'),
('3101', 'TØNSBERG'),
('3102', 'TØNSBERG'),
('3103', 'TØNSBERG'),
('3104', 'TØNSBERG'),
('3105', 'TØNSBERG'),
('3106', 'TØNSBERG'),
('3107', 'SEM'),
('3108', 'VEAR'),
('3109', 'TØNSBERG'),
('3110', 'TØNSBERG'),
('3111', 'TØNSBERG'),
('3112', 'TØNSBERG'),
('3113', 'TØNSBERG'),
('3114', 'TØNSBERG'),
('3116', 'TØNSBERG'),
('3117', 'TØNSBERG'),
('3118', 'TØNSBERG'),
('3122', 'TØNSBERG'),
('3123', 'TØNSBERG'),
('3124', 'TØNSBERG'),
('3125', 'TØNSBERG'),
('3126', 'TØNSBERG'),
('3129', 'TØNSBERG'),
('3131', 'HUSØYSUND'),
('3132', 'HUSØYSUND'),
('3133', 'DUKEN'),
('3135', 'TORØD'),
('3137', 'TORØD'),
('3138', 'SKALLESTAD'),
('3140', 'BORGHEIM'),
('3141', 'KJØPMANNSKJÆR'),
('3142', 'VESTSKOGEN'),
('3143', 'KJØPMANNSKJÆR'),
('3144', 'VEIERLAND'),
('3145', 'TJØME'),
('3147', 'VERDENS ENDE'),
('3148', 'HVASSER'),
('3150', 'TOLVSRØD'),
('3151', 'TOLVSRØD'),
('3152', 'TOLVSRØD'),
('3153', 'TOLVSRØD'),
('3154', 'TOLVSRØD'),
('3157', 'BARKÅKER'),
('3159', 'MELSOMVIK'),
('3160', 'STOKKE'),
('3161', 'STOKKE'),
('3162', 'ANDEBU'),
('3163', 'BORGHEIM'),
('3164', 'REVETAL'),
('3165', 'TJØME'),
('3166', 'TOLVSRØD'),
('3167', 'ÅSGÅRDSTRAND'),
('3169', 'STOKKE'),
('3170', 'SEM'),
('3172', 'VEAR'),
('3174', 'REVETAL'),
('3175', 'RAMNES'),
('3177', 'VÅLE'),
('3178', 'VÅLE'),
('3179', 'ÅSGÅRDSTRAND'),
('3180', 'NYKIRKE'),
('3181', 'HORTEN'),
('3182', 'HORTEN'),
('3183', 'HORTEN'),
('3184', 'BORRE'),
('3186', 'HORTEN'),
('3187', 'HORTEN'),
('3188', 'HORTEN'),
('3189', 'HORTEN'),
('3191', 'HORTEN'),
('3192', 'HORTEN'),
('3193', 'HORTEN'),
('3194', 'HORTEN'),
('3195', 'SKOPPUM'),
('3196', 'HORTEN'),
('3197', 'HORTEN'),
('3198', 'HORTEN'),
('3199', 'HORTEN'),
('3201', 'SANDEFJORD'),
('3202', 'SANDEFJORD'),
('3203', 'SANDEFJORD'),
('3204', 'SANDEFJORD'),
('3205', 'SANDEFJORD'),
('3206', 'SANDEFJORD'),
('3207', 'SANDEFJORD'),
('3208', 'SANDEFJORD'),
('3209', 'SANDEFJORD'),
('3210', 'SANDEFJORD'),
('3211', 'SANDEFJORD'),
('3212', 'SANDEFJORD'),
('3213', 'SANDEFJORD'),
('3214', 'SANDEFJORD'),
('3215', 'SANDEFJORD'),
('3216', 'SANDEFJORD'),
('3217', 'SANDEFJORD'),
('3218', 'SANDEFJORD'),
('3219', 'SANDEFJORD'),
('3220', 'SANDEFJORD'),
('3221', 'SANDEFJORD'),
('3222', 'SANDEFJORD'),
('3223', 'SANDEFJORD'),
('3224', 'SANDEFJORD'),
('3225', 'SANDEFJORD'),
('3226', 'SANDEFJORD'),
('3227', 'SANDEFJORD'),
('3228', 'SANDEFJORD'),
('3229', 'SANDEFJORD'),
('3230', 'SANDEFJORD'),
('3231', 'SANDEFJORD'),
('3233', 'SANDEFJORD'),
('3234', 'SANDEFJORD'),
('3235', 'SANDEFJORD'),
('3236', 'SANDEFJORD'),
('3237', 'SANDEFJORD'),
('3238', 'SANDEFJORD'),
('3239', 'SANDEFJORD'),
('3241', 'SANDEFJORD'),
('3242', 'SANDEFJORD'),
('3243', 'KODAL'),
('3244', 'SANDEFJORD'),
('3245', 'KODAL'),
('3246', 'SANDEFJORD'),
('3247', 'SANDEFJORD'),
('3248', 'SANDEFJORD'),
('3249', 'SANDEFJORD'),
('3251', 'LARVIK'),
('3252', 'LARVIK'),
('3253', 'LARVIK'),
('3254', 'LARVIK'),
('3255', 'LARVIK'),
('3256', 'LARVIK'),
('3257', 'LARVIK'),
('3258', 'LARVIK'),
('3259', 'LARVIK'),
('3260', 'LARVIK'),
('3261', 'LARVIK'),
('3262', 'LARVIK'),
('3263', 'LARVIK'),
('3264', 'LARVIK'),
('3265', 'LARVIK'),
('3267', 'LARVIK'),
('3268', 'LARVIK'),
('3269', 'LARVIK'),
('3271', 'LARVIK'),
('3274', 'LARVIK'),
('3275', 'SVARSTAD'),
('3276', 'SVARSTAD'),
('3277', 'STEINSHOLT'),
('3280', 'TJODALYNG'),
('3281', 'TJODALYNG'),
('3282', 'KVELDE'),
('3284', 'KVELDE'),
('3285', 'LARVIK'),
('3290', 'STAVERN'),
('3291', 'STAVERN'),
('3292', 'STAVERN'),
('3294', 'STAVERN'),
('3295', 'HELGEROA'),
('3296', 'NEVLUNGHAMN'),
('3297', 'HELGEROA'),
('3300', 'HOKKSUND'),
('3301', 'HOKKSUND'),
('3320', 'VESTFOSSEN'),
('3321', 'VESTFOSSEN'),
('3322', 'DARBU'),
('3330', 'SKOTSELV'),
('3331', 'SKOTSELV'),
('3340', 'ÅMOT'),
('3341', 'ÅMOT'),
('3342', 'ÅMOT'),
('3350', 'PRESTFOSS'),
('3351', 'PRESTFOSS'),
('3355', 'SOLUMSMOEN'),
('3358', 'NEDRE EGGEDAL'),
('3359', 'EGGEDAL'),
('3360', 'GEITHUS'),
('3361', 'GEITHUS'),
('3370', 'VIKERSUND'),
('3371', 'VIKERSUND'),
('3387', 'SNARUM'),
('3400', 'LIER'),
('3401', 'LIER'),
('3407', 'TRANBY'),
('3408', 'TRANBY'),
('3410', 'SYLLING'),
('3411', 'SYLLING'),
('3412', 'LIERSTRANDA'),
('3420', 'LIERSKOGEN'),
('3421', 'LIERSKOGEN'),
('3425', 'REISTAD'),
('3428', 'LIER'),
('3430', 'SPIKKESTAD'),
('3431', 'SPIKKESTAD'),
('3441', 'RØYKEN'),
('3442', 'HYGGEN'),
('3470', 'SLEMMESTAD'),
('3471', 'SLEMMESTAD'),
('3472', 'BØDALEN'),
('3474', 'ÅROS'),
('3476', 'SÆTRE'),
('3477', 'BÅTSTØ'),
('3478', 'NÆRSNES'),
('3480', 'FILTVET'),
('3481', 'TOFTE'),
('3482', 'TOFTE'),
('3483', 'KANA'),
('3484', 'HOLMSBU'),
('3490', 'KLOKKARSTUA'),
('3491', 'KLOKKARSTUA'),
('3501', 'HØNEFOSS'),
('3502', 'HØNEFOSS'),
('3503', 'HØNEFOSS'),
('3504', 'HØNEFOSS'),
('3505', 'HØNEFOSS'),
('3506', 'HØNEFOSS'),
('3507', 'HØNEFOSS'),
('3510', 'HØNEFOSS'),
('3511', 'HØNEFOSS'),
('3513', 'HØNEFOSS'),
('3514', 'HØNEFOSS'),
('3515', 'HØNEFOSS'),
('3516', 'HØNEFOSS'),
('3517', 'HØNEFOSS'),
('3518', 'HØNEFOSS'),
('3519', 'HØNEFOSS'),
('3520', 'JEVNAKER'),
('3521', 'JEVNAKER'),
('3522', 'BJONEROA'),
('3523', 'NES I ÅDAL'),
('3524', 'NES I ÅDAL'),
('3525', 'HALLINGBY'),
('3526', 'HALLINGBY'),
('3528', 'HEDALEN'),
('3529', 'RØYSE'),
('3530', 'RØYSE'),
('3531', 'KROKKLEIVA'),
('3533', 'TYRISTRAND'),
('3534', 'SOKNA'),
('3535', 'KRØDEREN'),
('3536', 'NORESUND'),
('3537', 'KRØDEREN'),
('3539', 'FLÅ'),
('3540', 'NESBYEN'),
('3541', 'NESBYEN'),
('3550', 'GOL'),
('3551', 'GOL'),
('3560', 'HEMSEDAL'),
('3561', 'HEMSEDAL'),
('3570', 'ÅL'),
('3571', 'ÅL'),
('3575', 'HOL'),
('3576', 'HOL'),
('3577', 'HOVET'),
('3579', 'TORPO'),
('3580', 'GEILO'),
('3581', 'GEILO'),
('3593', 'USTAOSET'),
('3595', 'HAUGASTØL'),
('3596', 'HALNE FJELLSTOVA'),
('3598', 'DYRANUT'),
('3599', 'SANDHAUG'),
('3601', 'KONGSBERG'),
('3602', 'KONGSBERG'),
('3603', 'KONGSBERG'),
('3604', 'KONGSBERG'),
('3605', 'KONGSBERG'),
('3606', 'KONGSBERG'),
('3608', 'HEISTADMOEN'),
('3610', 'KONGSBERG'),
('3611', 'KONGSBERG'),
('3612', 'KONGSBERG'),
('3613', 'KONGSBERG'),
('3614', 'KONGSBERG'),
('3615', 'KONGSBERG'),
('3616', 'KONGSBERG'),
('3617', 'KONGSBERG'),
('3618', 'SKOLLENBORG'),
('3619', 'SKOLLENBORG'),
('3620', 'FLESBERG'),
('3621', 'LAMPELAND'),
('3622', 'SVENE'),
('3623', 'LAMPELAND'),
('3624', 'LYNGDAL I NUMEDAL'),
('3626', 'ROLLAG'),
('3627', 'VEGGLI'),
('3628', 'VEGGLI'),
('3629', 'NORE'),
('3630', 'RØDBERG'),
('3631', 'RØDBERG'),
('3632', 'UVDAL'),
('3646', 'HVITTINGFOSS'),
('3647', 'HVITTINGFOSS'),
('3648', 'PASSEBEKK'),
('3650', 'TINN AUSTBYGD'),
('3652', 'HOVIN I TELEMARK'),
('3656', 'ATRÅ'),
('3658', 'MILAND'),
('3660', 'RJUKAN'),
('3661', 'RJUKAN'),
('3665', 'SAULAND'),
('3666', 'TINN AUSTBYGD'),
('3671', 'NOTODDEN'),
('3672', 'NOTODDEN'),
('3673', 'NOTODDEN'),
('3674', 'NOTODDEN'),
('3675', 'NOTODDEN'),
('3676', 'NOTODDEN'),
('3677', 'NOTODDEN'),
('3678', 'NOTODDEN'),
('3679', 'NOTODDEN'),
('3680', 'NOTODDEN'),
('3681', 'NOTODDEN'),
('3683', 'NOTODDEN'),
('3684', 'NOTODDEN'),
('3690', 'HJARTDAL'),
('3691', 'GRANSHERAD'),
('3692', 'SAULAND'),
('3697', 'TUDDAL'),
('3699', 'GAUSTATOPPEN TURISTHYTTE'),
('3701', 'SKIEN'),
('3702', 'SKIEN'),
('3703', 'SKIEN'),
('3704', 'SKIEN'),
('3705', 'SKIEN'),
('3706', 'SKIEN'),
('3707', 'SKIEN'),
('3708', 'SKIEN'),
('3709', 'SKIEN'),
('3710', 'SKIEN'),
('3711', 'SKIEN'),
('3712', 'SKIEN'),
('3713', 'SKIEN'),
('3714', 'SKIEN'),
('3715', 'SKIEN'),
('3716', 'SKIEN'),
('3717', 'SKIEN'),
('3718', 'SKIEN'),
('3719', 'SKIEN'),
('3720', 'SKIEN'),
('3722', 'SKIEN'),
('3723', 'SKIEN'),
('3724', 'SKIEN'),
('3725', 'SKIEN'),
('3726', 'SKIEN'),
('3727', 'SKIEN'),
('3728', 'SKIEN'),
('3729', 'SKIEN'),
('3730', 'SKIEN'),
('3731', 'SKIEN'),
('3732', 'SKIEN'),
('3733', 'SKIEN'),
('3734', 'SKIEN'),
('3735', 'SKIEN'),
('3736', 'SKIEN'),
('3737', 'SKIEN'),
('3738', 'SKIEN'),
('3739', 'SKIEN'),
('3740', 'SKIEN'),
('3741', 'SKIEN'),
('3742', 'SKIEN'),
('3743', 'SKIEN'),
('3744', 'SKIEN'),
('3746', 'SKIEN'),
('3747', 'SKIEN'),
('3748', 'SILJAN'),
('3749', 'SILJAN'),
('3750', 'DRANGEDAL'),
('3753', 'TØRDAL'),
('3760', 'NESLANDSVATN'),
('3766', 'SANNIDAL'),
('3770', 'KRAGERØ'),
('3780', 'SKÅTØY'),
('3781', 'JOMFRULAND'),
('3782', 'KRAGERØ SOMMERRUTE'),
('3783', 'KRAGERØ SKJÆRGÅRDSRUTE'),
('3784', 'LANGØY GRUVER'),
('3786', 'SKIEN'),
('3787', 'SKIEN'),
('3788', 'STABBESTAD'),
('3789', 'KRAGERØ'),
('3790', 'HELLE'),
('3791', 'KRAGERØ'),
('3792', 'SKIEN'),
('3793', 'SANNIDAL'),
('3794', 'HELLE'),
('3795', 'DRANGEDAL'),
('3796', 'SKIEN'),
('3797', 'SKIEN'),
('3798', 'SKIEN'),
('3799', 'SKIEN'),
('3800', 'BØ I TELEMARK'),
('3810', 'GVARV'),
('3812', 'AKKERHAUGEN'),
('3820', 'NORDAGUTU'),
('3825', 'LUNDE'),
('3830', 'ULEFOSS'),
('3831', 'ULEFOSS'),
('3832', 'LUNDE'),
('3833', 'BØ I TELEMARK'),
('3834', 'GVARV'),
('3835', 'SELJORD'),
('3836', 'KVITESEID'),
('3840', 'SELJORD'),
('3841', 'FLATDAL'),
('3848', 'MORGEDAL'),
('3849', 'VRÅLIOSEN'),
('3850', 'KVITESEID'),
('3853', 'VRÅDAL'),
('3854', 'NISSEDAL'),
('3855', 'TREUNGEN'),
('3864', 'RAULAND'),
('3870', 'FYRESDAL'),
('3880', 'DALEN'),
('3882', 'ÅMDALS VERK'),
('3883', 'TREUNGEN'),
('3884', 'RAULAND'),
('3885', 'FYRESDAL'),
('3886', 'DALEN'),
('3887', 'VINJE'),
('3888', 'EDLAND'),
('3890', 'VINJE'),
('3891', 'HØYDALSMO'),
('3893', 'VINJESVINGEN'),
('3895', 'EDLAND'),
('3901', 'PORSGRUNN'),
('3902', 'PORSGRUNN'),
('3903', 'PORSGRUNN'),
('3904', 'PORSGRUNN'),
('3905', 'PORSGRUNN'),
('3906', 'PORSGRUNN'),
('3908', 'PORSGRUNN'),
('3909', 'PORSGRUNN'),
('3910', 'PORSGRUNN'),
('3911', 'PORSGRUNN'),
('3912', 'PORSGRUNN'),
('3913', 'PORSGRUNN'),
('3915', 'PORSGRUNN'),
('3916', 'PORSGRUNN'),
('3917', 'PORSGRUNN'),
('3918', 'PORSGRUNN'),
('3919', 'PORSGRUNN'),
('3920', 'PORSGRUNN'),
('3921', 'PORSGRUNN'),
('3922', 'PORSGRUNN'),
('3924', 'PORSGRUNN'),
('3925', 'PORSGRUNN'),
('3928', 'PORSGRUNN'),
('3929', 'PORSGRUNN'),
('3930', 'PORSGRUNN'),
('3931', 'PORSGRUNN'),
('3932', 'PORSGRUNN'),
('3933', 'PORSGRUNN'),
('3936', 'PORSGRUNN'),
('3937', 'PORSGRUNN'),
('3940', 'PORSGRUNN'),
('3941', 'PORSGRUNN'),
('3942', 'PORSGRUNN'),
('3943', 'PORSGRUNN'),
('3944', 'PORSGRUNN'),
('3945', 'PORSGRUNN'),
('3946', 'PORSGRUNN'),
('3947', 'LANGANGEN'),
('3948', 'PORSGRUNN'),
('3949', 'PORSGRUNN'),
('3950', 'BREVIK'),
('3960', 'STATHELLE'),
('3965', 'HERRE'),
('3966', 'STATHELLE'),
('3967', 'BAMBLE SOMMERRUTE'),
('3970', 'LANGESUND'),
('3991', 'BREVIK'),
('3993', 'LANGESUND'),
('3994', 'LANGESUND'),
('3995', 'STATHELLE'),
('3996', 'PORSGRUNN'),
('3997', 'PORSGRUNN'),
('3998', 'PORSGRUNN'),
('3999', 'HERRE'),
('4001', 'STAVANGER'),
('4002', 'STAVANGER'),
('4003', 'STAVANGER'),
('4004', 'STAVANGER'),
('4005', 'STAVANGER'),
('4006', 'STAVANGER'),
('4007', 'STAVANGER'),
('4008', 'STAVANGER'),
('4009', 'STAVANGER'),
('4010', 'STAVANGER'),
('4011', 'STAVANGER'),
('4012', 'STAVANGER'),
('4013', 'STAVANGER'),
('4014', 'STAVANGER'),
('4015', 'STAVANGER'),
('4016', 'STAVANGER'),
('4017', 'STAVANGER'),
('4018', 'STAVANGER'),
('4019', 'STAVANGER'),
('4020', 'STAVANGER'),
('4021', 'STAVANGER'),
('4022', 'STAVANGER'),
('4023', 'STAVANGER'),
('4024', 'STAVANGER'),
('4025', 'STAVANGER'),
('4026', 'STAVANGER'),
('4028', 'STAVANGER'),
('4029', 'STAVANGER'),
('4032', 'STAVANGER'),
('4034', 'STAVANGER'),
('4035', 'STAVANGER'),
('4041', 'HAFRSFJORD'),
('4042', 'HAFRSFJORD'),
('4043', 'HAFRSFJORD'),
('4045', 'HAFRSFJORD'),
('4046', 'HAFRSFJORD'),
('4047', 'HAFRSFJORD'),
('4048', 'HAFRSFJORD'),
('4050', 'SOLA'),
('4052', 'RØYNEBERG'),
('4053', 'RÆGE'),
('4054', 'TJELTA'),
('4055', 'STAVANGER LUFTHAVN'),
('4056', 'TANANGER'),
('4064', 'STAVANGER'),
('4065', 'STAVANGER'),
('4066', 'STAVANGER'),
('4067', 'STAVANGER'),
('4068', 'STAVANGER'),
('4069', 'STAVANGER'),
('4070', 'RANDABERG'),
('4076', 'VASSØY'),
('4078', 'STAVANGER'),
('4079', 'STAVANGER'),
('4081', 'STAVANGER'),
('4082', 'STAVANGER'),
('4084', 'STAVANGER'),
('4085', 'HUNDVÅG'),
('4086', 'HUNDVÅG'),
('4087', 'STAVANGER'),
('4088', 'STAVANGER'),
('4089', 'HAFRSFJORD'),
('4090', 'HAFRSFJORD'),
('4091', 'STAVANGER'),
('4092', 'STAVANGER'),
('4093', 'STAVANGER'),
('4095', 'STAVANGER'),
('4096', 'RANDABERG'),
('4097', 'SOLA'),
('4098', 'TANANGER'),
('4100', 'JØRPELAND'),
('4102', 'IDSE'),
('4110', 'FORSAND'),
('4119', 'FORSAND'),
('4120', 'TAU'),
('4122', 'FISKÅ'),
('4123', 'SØR-HIDLE'),
('4124', 'TAU'),
('4126', 'JØRPELAND'),
('4127', 'LYSEBOTN'),
('4128', 'FLØYRLI'),
('4129', 'SONGESAND'),
('4130', 'HJELMELAND'),
('4134', 'JØSENFJORDEN'),
('4137', 'ÅRDAL I RYFYLKE'),
('4139', 'FISTER'),
('4146', 'SKIFTUN'),
('4148', 'HJELMELAND'),
('4150', 'RENNESØY'),
('4152', 'VESTRE ÅMØY'),
('4153', 'BRIMSE'),
('4154', 'AUSTRE ÅMØY'),
('4156', 'MOSTERØY'),
('4158', 'BRU'),
('4159', 'RENNESØY'),
('4160', 'FINNØY'),
('4161', 'FINNØY'),
('4163', 'TALGJE'),
('4164', 'FOGN'),
('4167', 'HELGØY I RYFYLKE'),
('4168', 'BYRE'),
('4169', 'SØRBOKN'),
('4170', 'SJERNARØY'),
('4173', 'NORD-HIDLE'),
('4174', 'HELGØYSUND'),
('4180', 'KVITSØY'),
('4182', 'SKARTVEIT'),
('4187', 'OMBO'),
('4198', 'FOLDØY'),
('4200', 'SAUDA'),
('4201', 'SAUDA'),
('4208', 'SAUDASJØEN'),
('4209', 'VANVIK'),
('4230', 'SAND'),
('4233', 'ERFJORD'),
('4234', 'JELSA'),
('4235', 'HEBNES'),
('4237', 'SULDALSOSEN'),
('4239', 'SAND'),
('4240', 'SULDALSOSEN'),
('4244', 'NESFLATEN'),
('4250', 'KOPERVIK'),
('4260', 'TORVASTAD'),
('4262', 'AVALDSNES'),
('4264', 'KVALAVÅG'),
('4265', 'HÅVIK'),
('4270', 'ÅKREHAMN'),
('4272', 'SANDVE'),
('4274', 'STOL'),
('4275', 'SÆVELANDSVIK'),
('4276', 'VEDAVÅGEN'),
('4280', 'SKUDENESHAVN'),
('4291', 'KOPERVIK'),
('4294', 'KOPERVIK'),
('4295', 'VEDAVÅGEN'),
('4296', 'ÅKREHAMN'),
('4297', 'SKUDENESHAVN'),
('4298', 'TORVASTAD'),
('4299', 'AVALDSNES'),
('4301', 'SANDNES'),
('4302', 'SANDNES'),
('4303', 'SANDNES'),
('4304', 'SANDNES'),
('4305', 'SANDNES'),
('4306', 'SANDNES'),
('4307', 'SANDNES'),
('4308', 'SANDNES'),
('4309', 'SANDNES'),
('4310', 'HOMMERSÅK'),
('4311', 'HOMMERSÅK'),
('4312', 'SANDNES'),
('4314', 'SANDNES'),
('4315', 'SANDNES'),
('4316', 'SANDNES'),
('4317', 'SANDNES'),
('4318', 'SANDNES'),
('4319', 'SANDNES'),
('4321', 'SANDNES'),
('4322', 'SANDNES'),
('4323', 'SANDNES'),
('4324', 'SANDNES'),
('4325', 'SANDNES'),
('4326', 'SANDNES'),
('4327', 'SANDNES'),
('4328', 'SANDNES'),
('4329', 'SANDNES'),
('4330', 'ÅLGÅRD'),
('4332', 'FIGGJO'),
('4333', 'OLTEDAL'),
('4335', 'DIRDAL'),
('4339', 'ÅLGÅRD'),
('4340', 'BRYNE'),
('4342', 'UNDHEIM'),
('4343', 'ORRE'),
('4349', 'BRYNE'),
('4352', 'KLEPPE'),
('4353', 'KLEPP STASJON'),
('4354', 'VOLL'),
('4355', 'KVERNALAND'),
('4356', 'KVERNALAND'),
('4357', 'KLEPP STASJON'),
('4358', 'KLEPPE'),
('4360', 'VARHAUG'),
('4362', 'VIGRESTAD'),
('4363', 'BRUSAND'),
('4364', 'SIREVÅG'),
('4365', 'NÆRBØ'),
('4367', 'NÆRBØ'),
('4368', 'VARHAUG'),
('4369', 'VIGRESTAD'),
('4370', 'EGERSUND'),
('4375', 'HELLVIK'),
('4376', 'HELLELAND'),
('4379', 'EGERSUND'),
('4380', 'HAUGE I DALANE'),
('4381', 'HAUGE I DALANE'),
('4387', 'BJERKREIM'),
('4389', 'VIKESÅ'),
('4391', 'SANDNES'),
('4392', 'SANDNES'),
('4393', 'SANDNES'),
('4394', 'SANDNES'),
('4395', 'HOMMERSÅK'),
('4396', 'SANDNES'),
('4397', 'SANDNES'),
('4398', 'SANDNES'),
('4400', 'FLEKKEFJORD'),
('4401', 'FLEKKEFJORD'),
('4402', 'FLEKKEFJORD'),
('4403', 'FLEKKEFJORD'),
('4420', 'ÅNA-SIRA'),
('4432', 'HIDRASUND'),
('4434', 'ANDABELØY'),
('4436', 'GYLAND'),
('4438', 'SIRA'),
('4440', 'TONSTAD'),
('4441', 'TONSTAD'),
('4443', 'TJØRHOM'),
('4460', 'MOI'),
('4462', 'HOVSHERAD'),
('4463', 'UALAND'),
('4465', 'MOI'),
('4473', 'KVINLOG'),
('4480', 'KVINESDAL'),
('4484', 'ØYESTRANDA'),
('4485', 'FEDA'),
('4490', 'KVINESDAL'),
('4491', 'KVINESDAL'),
('4492', 'KVINESDAL'),
('4501', 'MANDAL'),
('4502', 'MANDAL'),
('4503', 'MANDAL'),
('4504', 'MANDAL'),
('4505', 'MANDAL'),
('4506', 'MANDAL'),
('4509', 'MANDAL'),
('4512', 'LINDESNES'),
('4513', 'MANDAL'),
('4514', 'MANDAL'),
('4515', 'MANDAL'),
('4517', 'MANDAL'),
('4519', 'HOLUM'),
('4520', 'SØR-AUDNEDAL'),
('4521', 'SPANGEREID'),
('4523', 'SØR-AUDNEDAL'),
('4524', 'SØR-AUDNEDAL'),
('4525', 'KONSMO'),
('4528', 'KOLLUNGTVEIT'),
('4529', 'BYREMO'),
('4532', 'ØYSLEBØ'),
('4534', 'MARNARDAL'),
('4536', 'BJELLAND'),
('4540', 'ÅSERAL'),
('4544', 'FOSSDAL'),
('4550', 'FARSUND'),
('4551', 'FARSUND'),
('4552', 'FARSUND'),
('4553', 'FARSUND'),
('4554', 'FARSUND'),
('4557', 'VANSE'),
('4558', 'VANSE'),
('4560', 'VANSE'),
('4563', 'BORHAUG'),
('4575', 'LYNGDAL'),
('4576', 'LYNGDAL'),
('4577', 'LYNGDAL'),
('4579', 'LYNGDAL'),
('4580', 'LYNGDAL'),
('4586', 'KORSHAMN'),
('4588', 'KVÅS'),
('4590', 'SNARTEMO'),
('4595', 'TINGVATN'),
('4596', 'EIKEN'),
('4604', 'KRISTIANSAND S'),
('4605', 'KRISTIANSAND S'),
('4606', 'KRISTIANSAND S'),
('4609', 'KARDEMOMME BY'),
('4610', 'KRISTIANSAND S'),
('4611', 'KRISTIANSAND S'),
('4612', 'KRISTIANSAND S'),
('4613', 'KRISTIANSAND S'),
('4614', 'KRISTIANSAND S'),
('4615', 'KRISTIANSAND S'),
('4616', 'KRISTIANSAND S'),
('4617', 'KRISTIANSAND S'),
('4618', 'KRISTIANSAND S'),
('4619', 'MOSBY'),
('4620', 'KRISTIANSAND S'),
('4621', 'KRISTIANSAND S'),
('4622', 'KRISTIANSAND S'),
('4623', 'KRISTIANSAND S'),
('4624', 'KRISTIANSAND S'),
('4625', 'FLEKKERØY'),
('4626', 'KRISTIANSAND S'),
('4629', 'KRISTIANSAND S'),
('4630', 'KRISTIANSAND S'),
('4631', 'KRISTIANSAND S'),
('4632', 'KRISTIANSAND S'),
('4633', 'KRISTIANSAND S'),
('4634', 'KRISTIANSAND S'),
('4635', 'KRISTIANSAND S'),
('4636', 'KRISTIANSAND S'),
('4637', 'KRISTIANSAND S'),
('4638', 'KRISTIANSAND S'),
('4639', 'KRISTIANSAND S'),
('4640', 'SØGNE'),
('4645', 'NODELAND'),
('4646', 'FINSLAND'),
('4647', 'BRENNÅSEN'),
('4651', 'HAMRESANDEN'),
('4656', 'HAMRESANDEN'),
('4657', 'KJEVIK'),
('4658', 'TVEIT'),
('4659', 'KRISTIANSAND S'),
('4661', 'KRISTIANSAND S'),
('4662', 'KRISTIANSAND S'),
('4663', 'KRISTIANSAND S'),
('4664', 'KRISTIANSAND S'),
('4665', 'KRISTIANSAND S'),
('4666', 'KRISTIANSAND S'),
('4668', 'KRISTIANSAND S'),
('4669', 'KRISTIANSAND S'),
('4671', 'MOSBY'),
('4672', 'KRISTIANSAND S'),
('4673', 'KRISTIANSAND S'),
('4674', 'KRISTIANSAND S'),
('4675', 'KRISTIANSAND S'),
('4676', 'KRISTIANSAND S'),
('4677', 'KRISTIANSAND S'),
('4678', 'KRISTIANSAND S'),
('4679', 'FLEKKERØY'),
('4682', 'SØGNE'),
('4683', 'SØGNE'),
('4685', 'NODELAND'),
('4686', 'KRISTIANSAND S'),
('4687', 'KRISTIANSAND S'),
('4688', 'KRISTIANSAND S'),
('4689', 'KRISTIANSAND S'),
('4691', 'KRISTIANSAND S'),
('4693', 'KRISTIANSAND S'),
('4696', 'KRISTIANSAND S'),
('4697', 'KRISTIANSAND S'),
('4699', 'TVEIT'),
('4700', 'VENNESLA'),
('4701', 'VENNESLA'),
('4702', 'VENNESLA'),
('4703', 'VENNESLA'),
('4705', 'ØVREBØ'),
('4715', 'ØVREBØ'),
('4720', 'HÆGELAND'),
('4724', 'IVELAND'),
('4730', 'VATNESTRØM'),
('4733', 'EVJE'),
('4734', 'EVJE'),
('4735', 'EVJE'),
('4737', 'HORNNES'),
('4738', 'EVJEMOEN'),
('4741', 'BYGLANDSFJORD'),
('4742', 'GRENDI'),
('4745', 'BYGLAND'),
('4747', 'VALLE'),
('4748', 'RYSSTAD'),
('4754', 'BYKLE'),
('4755', 'HOVDEN I SETESDAL'),
('4760', 'BIRKELAND'),
('4766', 'HEREFOSS'),
('4768', 'ENGESLAND'),
('4770', 'HØVÅG'),
('4780', 'BREKKESTØ'),
('4790', 'LILLESAND'),
('4791', 'LILLESAND'),
('4792', 'LILLESAND'),
('4794', 'LILLESAND'),
('4795', 'BIRKELAND'),
('4801', 'ARENDAL'),
('4802', 'ARENDAL'),
('4803', 'ARENDAL'),
('4804', 'ARENDAL'),
('4808', 'ARENDAL'),
('4809', 'ARENDAL'),
('4810', 'EYDEHAVN'),
('4812', 'KONGSHAVN'),
('4815', 'SALTRØD'),
('4816', 'KOLBJØRNSVIK'),
('4817', 'HIS'),
('4818', 'FÆRVIK'),
('4820', 'FROLAND'),
('4821', 'RYKENE'),
('4823', 'NEDENES'),
('4824', 'BJORBEKK'),
('4825', 'ARENDAL'),
('4827', 'FROLANDS VERK'),
('4828', 'MJÅVATN'),
('4830', 'HYNNEKLEIV'),
('4832', 'MYKLAND'),
('4834', 'RISDAL'),
('4835', 'SKJEGGEDAL'),
('4836', 'ARENDAL'),
('4838', 'ARENDAL'),
('4839', 'ARENDAL'),
('4841', 'ARENDAL'),
('4842', 'ARENDAL'),
('4843', 'ARENDAL'),
('4844', 'ARENDAL'),
('4846', 'ARENDAL'),
('4847', 'ARENDAL'),
('4848', 'ARENDAL'),
('4849', 'ARENDAL'),
('4851', 'SALTRØD'),
('4852', 'FÆRVIK'),
('4853', 'HIS'),
('4854', 'NEDENES'),
('4855', 'FROLAND'),
('4856', 'ARENDAL'),
('4857', 'ARENDAL'),
('4858', 'ARENDAL'),
('4859', 'ARENDAL'),
('4861', 'ARENDAL'),
('4862', 'EYDEHAVN'),
('4863', 'NELAUG'),
('4864', 'ÅMLI'),
('4865', 'ÅMLI'),
('4868', 'SELÅSVATN'),
('4869', 'DØLEMO'),
('4870', 'FEVIK'),
('4876', 'GRIMSTAD'),
('4877', 'GRIMSTAD'),
('4878', 'GRIMSTAD'),
('4879', 'GRIMSTAD'),
('4884', 'GRIMSTAD'),
('4885', 'GRIMSTAD'),
('4886', 'GRIMSTAD'),
('4887', 'GRIMSTAD'),
('4888', 'HOMBORSUND'),
('4889', 'FEVIK'),
('4891', 'GRIMSTAD'),
('4892', 'GRIMSTAD'),
('4894', 'GRIMSTAD'),
('4895', 'GRIMSTAD'),
('4896', 'GRIMSTAD'),
('4898', 'GRIMSTAD'),
('4900', 'TVEDESTRAND'),
('4901', 'TVEDESTRAND'),
('4902', 'TVEDESTRAND'),
('4909', 'SONGE'),
('4910', 'LYNGØR'),
('4912', 'GJEVING'),
('4915', 'VESTRE SANDØYA'),
('4916', 'BORØY'),
('4920', 'STAUBØ'),
('4934', 'NESGRENDA'),
('4950', 'RISØR'),
('4951', 'RISØR'),
('4952', 'RISØR'),
('4953', 'RISØR'),
('4955', 'RISØR'),
('4971', 'SUNDEBRU'),
('4972', 'GJERSTAD'),
('4973', 'VEGÅRSHEI'),
('4974', 'SØNDELED'),
('4980', 'GJERSTAD'),
('4985', 'VEGÅRSHEI'),
('4990', 'SØNDELED'),
('4993', 'SUNDEBRU'),
('4994', 'AKLAND'),
('5003', 'BERGEN'),
('5004', 'BERGEN'),
('5005', 'BERGEN'),
('5006', 'BERGEN'),
('5007', 'BERGEN'),
('5008', 'BERGEN'),
('5009', 'BERGEN'),
('5010', 'BERGEN'),
('5011', 'BERGEN'),
('5012', 'BERGEN'),
('5013', 'BERGEN'),
('5014', 'BERGEN'),
('5015', 'BERGEN'),
('5016', 'BERGEN'),
('5017', 'BERGEN'),
('5018', 'BERGEN'),
('5019', 'BERGEN'),
('5020', 'BERGEN'),
('5021', 'BERGEN'),
('5031', 'BERGEN'),
('5032', 'BERGEN'),
('5033', 'BERGEN'),
('5034', 'BERGEN'),
('5035', 'BERGEN'),
('5036', 'BERGEN'),
('5037', 'BERGEN'),
('5038', 'BERGEN'),
('5039', 'BERGEN'),
('5041', 'BERGEN'),
('5042', 'BERGEN'),
('5043', 'BERGEN'),
('5045', 'BERGEN'),
('5052', 'BERGEN'),
('5053', 'BERGEN'),
('5054', 'BERGEN'),
('5055', 'BERGEN'),
('5056', 'BERGEN'),
('5057', 'BERGEN'),
('5058', 'BERGEN'),
('5059', 'BERGEN'),
('5063', 'BERGEN'),
('5067', 'BERGEN'),
('5068', 'BERGEN'),
('5072', 'BERGEN'),
('5073', 'BERGEN'),
('5075', 'BERGEN'),
('5081', 'BERGEN'),
('5089', 'BERGEN'),
('5093', 'BERGEN'),
('5094', 'BERGEN'),
('5096', 'BERGEN'),
('5097', 'BERGEN'),
('5098', 'BERGEN'),
('5101', 'EIDSVÅGNESET'),
('5104', 'EIDSVÅG i Åsane'),
('5105', 'EIDSVÅG i Åsane'),
('5106', 'ØVRE ERVIK'),
('5107', 'SALHUS'),
('5108', 'HORDVIK'),
('5109', 'HYLKJE'),
('5111', 'BREISTEIN'),
('5113', 'TERTNES'),
('5114', 'TERTNES'),
('5115', 'ULSET'),
('5116', 'ULSET'),
('5117', 'ULSET'),
('5118', 'ULSET'),
('5119', 'ULSET'),
('5121', 'ULSET'),
('5122', 'MORVIK'),
('5124', 'MORVIK'),
('5131', 'NYBORG'),
('5132', 'NYBORG'),
('5134', 'FLAKTVEIT'),
('5135', 'FLAKTVEIT'),
('5136', 'MJØLKERÅEN'),
('5137', 'MJØLKERÅEN'),
('5141', 'FYLLINGSDALEN'),
('5142', 'FYLLINGSDALEN'),
('5143', 'FYLLINGSDALEN'),
('5144', 'FYLLINGSDALEN'),
('5145', 'FYLLINGSDALEN'),
('5146', 'FYLLINGSDALEN'),
('5147', 'FYLLINGSDALEN'),
('5148', 'FYLLINGSDALEN'),
('5151', 'STRAUMSGREND'),
('5152', 'BØNES'),
('5155', 'BØNES'),
('5161', 'LAKSEVÅG'),
('5162', 'LAKSEVÅG'),
('5163', 'LAKSEVÅG'),
('5164', 'LAKSEVÅG'),
('5171', 'LODDEFJORD'),
('5172', 'LODDEFJORD'),
('5173', 'LODDEFJORD'),
('5174', 'MATHOPEN'),
('5177', 'BJØRØYHAMN'),
('5178', 'LODDEFJORD'),
('5179', 'GODVIK'),
('5183', 'OLSVIK'),
('5184', 'OLSVIK'),
('5200', 'OS'),
('5201', 'OS'),
('5202', 'OS'),
('5203', 'OS'),
('5207', 'SØFTELAND'),
('5212', 'SØFTELAND'),
('5215', 'LYSEKLOSTER'),
('5216', 'LEPSØY'),
('5217', 'HAGAVIK'),
('5218', 'NORDSTRØNO'),
('5219', 'SKORPO FERIEHEIM'),
('5221', 'NESTTUN'),
('5222', 'NESTTUN'),
('5223', 'NESTTUN'),
('5224', 'NESTTUN'),
('5225', 'NESTTUN'),
('5226', 'NESTTUN'),
('5227', 'NESTTUN'),
('5229', 'KALANDSEIDET'),
('5231', 'PARADIS'),
('5232', 'PARADIS'),
('5235', 'RÅDAL'),
('5236', 'RÅDAL'),
('5238', 'RÅDAL'),
('5239', 'RÅDAL'),
('5243', 'FANA'),
('5244', 'FANA'),
('5251', 'SØREIDGREND'),
('5252', 'SØREIDGREND'),
('5253', 'SANDSLI'),
('5254', 'SANDSLI'),
('5257', 'KOKSTAD'),
('5258', 'BLOMSTERDALEN'),
('5259', 'HJELLESTAD'),
('5260', 'INDRE ARNA'),
('5261', 'INDRE ARNA'),
('5262', 'ARNATVEIT'),
('5263', 'TRENGEREID'),
('5264', 'GARNES'),
('5265', 'YTRE ARNA'),
('5267', 'ESPELAND'),
('5268', 'HAUKELAND'),
('5281', 'VALESTRANDSFOSSEN'),
('5282', 'LONEVÅG'),
('5283', 'FOTLANDSVÅG'),
('5284', 'TYSSEBOTNEN'),
('5285', 'BRUVIK'),
('5286', 'HAUS'),
('5291', 'VALESTRANDSFOSSEN'),
('5293', 'LONEVÅG'),
('5295', 'FOTLANDSVÅG'),
('5299', 'HAUS'),
('5300', 'KLEPPESTØ'),
('5302', 'STRUSSHAMN'),
('5303', 'FOLLESE'),
('5304', 'HETLEVIK'),
('5305', 'FLORVÅG'),
('5306', 'ERDAL'),
('5307', 'ASK'),
('5310', 'HAUGLANDSHELLA'),
('5314', 'KJERRGARDEN'),
('5315', 'HERDLA'),
('5318', 'STRUSSHAMN'),
('5321', 'KLEPPESTØ'),
('5322', 'KLEPPESTØ'),
('5323', 'KLEPPESTØ'),
('5325', 'FOLLESE'),
('5326', 'ASK'),
('5327', 'HAUGLANDSHELLA'),
('5329', 'FLORVÅG'),
('5331', 'RONG'),
('5333', 'TJELDSTØ'),
('5334', 'HELLESØY'),
('5335', 'HERNAR'),
('5336', 'TJELDSTØ'),
('5337', 'RONG'),
('5341', 'STRAUME'),
('5342', 'STRAUME'),
('5343', 'STRAUME'),
('5345', 'KNARREVIK'),
('5346', 'ÅGOTNES'),
('5347', 'KYSTBASEN ÅGOTNES'),
('5350', 'BRATTHOLMEN'),
('5353', 'STRAUME'),
('5355', 'KNARREVIK'),
('5357', 'FJELL'),
('5363', 'ÅGOTNES'),
('5365', 'TURØY'),
('5371', 'SKOGSVÅG'),
('5373', 'KLOKKARVIK'),
('5374', 'STEINSLAND'),
('5378', 'KLOKKARVIK'),
('5379', 'STEINSLAND'),
('5380', 'TÆLAVÅG'),
('5381', 'GLESVÆR'),
('5382', 'SKOGSVÅG');
INSERT INTO Poststed VALUES
('5384', 'TORANGSVÅG'),
('5385', 'BAKKASUND'),
('5387', 'MØKSTER'),
('5388', 'LITLAKALSØY'),
('5392', 'STOREBØ'),
('5393', 'STOREBØ'),
('5394', 'KOLBEINSVIK'),
('5396', 'VESTRE VINNESVÅG'),
('5397', 'BEKKJARVIK'),
('5398', 'STOLMEN'),
('5399', 'BEKKJARVIK'),
('5401', 'STORD'),
('5402', 'STORD'),
('5403', 'STORD'),
('5404', 'STORD'),
('5405', 'STORD'),
('5406', 'STORD'),
('5407', 'STORD'),
('5408', 'SAGVÅG'),
('5409', 'STORD'),
('5410', 'SAGVÅG'),
('5411', 'STORD'),
('5412', 'STORD'),
('5414', 'STORD'),
('5415', 'STORD'),
('5416', 'STORD'),
('5417', 'STORD'),
('5418', 'FITJAR'),
('5419', 'FITJAR'),
('5420', 'RUBBESTADNESET'),
('5423', 'BRANDASUND'),
('5427', 'URANGSVÅG'),
('5428', 'FOLDRØYHAMN'),
('5430', 'BREMNES'),
('5437', 'FINNÅS'),
('5440', 'MOSTERHAMN'),
('5443', 'BØMLO'),
('5444', 'ESPEVÆR'),
('5445', 'BREMNES'),
('5447', 'MOSTERHAMN'),
('5448', 'RUBBESTADNESET'),
('5449', 'BØMLO'),
('5450', 'SUNDE I SUNNHORDLAND'),
('5451', 'VALEN'),
('5452', 'SANDVOLL'),
('5453', 'UTÅKER'),
('5454', 'SÆBØVIK'),
('5455', 'HALSNØY KLOSTER'),
('5457', 'HØYLANDSBYGD'),
('5458', 'ARNAVIK'),
('5459', 'FJELBERG'),
('5460', 'HUSNES'),
('5462', 'HERØYSUNDET'),
('5463', 'USKEDALEN'),
('5464', 'DIMMELSVIK'),
('5465', 'USKEDALEN'),
('5470', 'ROSENDAL'),
('5472', 'SEIMSFOSS'),
('5473', 'SNILSTVEITØY'),
('5474', 'LØFALLSTRAND'),
('5475', 'ÆNES'),
('5476', 'MAURANGER'),
('5480', 'HUSNES'),
('5484', 'SÆBØVIK'),
('5486', 'ROSENDAL'),
('5497', 'HUGLO'),
('5498', 'MATRE'),
('5499', 'ÅKRA'),
('5501', 'HAUGESUND'),
('5502', 'HAUGESUND'),
('5503', 'HAUGESUND'),
('5504', 'HAUGESUND'),
('5505', 'HAUGESUND'),
('5506', 'HAUGESUND'),
('5507', 'HAUGESUND'),
('5508', 'KARMSUND'),
('5509', 'HAUGESUND'),
('5511', 'HAUGESUND'),
('5513', 'HAUGESUND'),
('5514', 'HAUGESUND'),
('5515', 'HAUGESUND'),
('5516', 'HAUGESUND'),
('5517', 'HAUGESUND'),
('5518', 'HAUGESUND'),
('5519', 'HAUGESUND'),
('5521', 'HAUGESUND'),
('5522', 'HAUGESUND'),
('5523', 'HAUGESUND'),
('5525', 'HAUGESUND'),
('5527', 'HAUGESUND'),
('5528', 'HAUGESUND'),
('5529', 'HAUGESUND'),
('5531', 'HAUGESUND'),
('5532', 'HAUGESUND'),
('5533', 'HAUGESUND'),
('5534', 'HAUGESUND'),
('5535', 'HAUGESUND'),
('5536', 'HAUGESUND'),
('5537', 'HAUGESUND'),
('5538', 'HAUGESUND'),
('5541', 'KOLNES'),
('5542', 'KARMSUND'),
('5544', 'VORMEDAL'),
('5545', 'VORMEDAL'),
('5546', 'RØYKSUND'),
('5547', 'UTSIRA'),
('5548', 'FEØY'),
('5549', 'RØVÆR'),
('5550', 'SVEIO'),
('5551', 'AUKLANDSHAMN'),
('5554', 'VALEVÅG'),
('5555', 'FØRDE I HORDALAND'),
('5559', 'SVEIO'),
('5560', 'NEDSTRAND'),
('5561', 'BOKN'),
('5563', 'FØRRESFJORDEN'),
('5565', 'TYSVÆRVÅG'),
('5566', 'HERVIK'),
('5567', 'SKJOLDASTRAUMEN'),
('5568', 'VIKEBYGD'),
('5570', 'AKSDAL'),
('5574', 'SKJOLD'),
('5575', 'AKSDAL'),
('5576', 'ØVRE VATS'),
('5578', 'NEDRE VATS'),
('5580', 'ØLEN'),
('5582', 'ØLENSVÅG'),
('5583', 'VIKEDAL'),
('5584', 'BJOA'),
('5585', 'SANDEID'),
('5586', 'VIKEDAL'),
('5588', 'ØLEN'),
('5589', 'SANDEID'),
('5590', 'ETNE'),
('5591', 'ETNE'),
('5593', 'SKÅNEVIK'),
('5594', 'SKÅNEVIK'),
('5596', 'MARKHUS'),
('5598', 'FJÆRA'),
('5600', 'NORHEIMSUND'),
('5601', 'NORHEIMSUND'),
('5602', 'NORHEIMSUND'),
('5604', 'ØYSTESE'),
('5605', 'ÅLVIK'),
('5610', 'ØYSTESE'),
('5612', 'STEINSTØ'),
('5614', 'ÅLVIK'),
('5620', 'TØRVIKBYGD'),
('5626', 'KYSNESSTRAND'),
('5627', 'JONDAL'),
('5628', 'HERAND'),
('5629', 'JONDAL'),
('5630', 'STRANDEBARM'),
('5632', 'OMASTRAND'),
('5635', 'HATLESTRAND'),
('5636', 'VARALDSØY'),
('5637', 'ØLVE'),
('5640', 'EIKELANDSOSEN'),
('5641', 'FUSA'),
('5642', 'HOLMEFJORD'),
('5643', 'STRANDVIK'),
('5645', 'SÆVAREID'),
('5646', 'NORDTVEITGREND'),
('5647', 'BALDERSHEIM'),
('5649', 'EIKELANDSOSEN'),
('5650', 'TYSSE'),
('5652', 'ÅRLAND'),
('5653', 'ÅRLAND'),
('5680', 'TYSNES'),
('5682', 'GODØYSUND'),
('5683', 'REKSTEREN'),
('5685', 'UGGDAL'),
('5687', 'FLATRÅKER'),
('5690', 'LUNDEGREND'),
('5693', 'ÅRBAKKA'),
('5694', 'ONARHEIM'),
('5695', 'UGGDAL'),
('5696', 'TYSNES'),
('5700', 'VOSS'),
('5701', 'VOSS'),
('5702', 'VOSS'),
('5703', 'VOSS'),
('5707', 'EVANGER'),
('5710', 'SKULESTADMO'),
('5712', 'VOSSESTRAND'),
('5713', 'VOSSESTRAND'),
('5715', 'STALHEIM'),
('5718', 'MYRDAL'),
('5719', 'FINSE'),
('5721', 'DALEKVAM'),
('5722', 'DALEKVAM'),
('5723', 'BOLSTADØYRI'),
('5724', 'STANGHELLE'),
('5725', 'VAKSDAL'),
('5726', 'VAKSDAL'),
('5727', 'STAMNES'),
('5728', 'EIDSLANDET'),
('5729', 'MODALEN'),
('5730', 'ULVIK'),
('5731', 'ULVIK'),
('5733', 'GRANVIN'),
('5734', 'VALLAVIK'),
('5736', 'GRANVIN'),
('5741', 'AURLAND'),
('5742', 'FLÅM'),
('5743', 'FLÅM'),
('5745', 'AURLAND'),
('5746', 'UNDREDAL'),
('5747', 'GUDVANGEN'),
('5748', 'STYVI'),
('5749', 'BAKKA'),
('5750', 'ODDA'),
('5751', 'ODDA'),
('5760', 'RØLDAL'),
('5763', 'SKARE'),
('5770', 'TYSSEDAL'),
('5773', 'HOVLAND'),
('5776', 'NÅ'),
('5777', 'GRIMO'),
('5778', 'UTNE'),
('5779', 'UTNE'),
('5780', 'KINSARVIK'),
('5781', 'LOFTHUS'),
('5782', 'KINSARVIK'),
('5783', 'EIDFJORD'),
('5784', 'ØVRE EIDFJORD'),
('5785', 'VØRINGSFOSS'),
('5786', 'EIDFJORD'),
('5787', 'LOFTHUS'),
('5802', 'BERGEN'),
('5803', 'BERGEN'),
('5804', 'BERGEN'),
('5805', 'BERGEN'),
('5806', 'BERGEN'),
('5807', 'BERGEN'),
('5808', 'BERGEN'),
('5809', 'BERGEN'),
('5811', 'BERGEN'),
('5812', 'BERGEN'),
('5815', 'BERGEN'),
('5816', 'BERGEN'),
('5817', 'BERGEN'),
('5818', 'BERGEN'),
('5819', 'BERGEN'),
('5821', 'BERGEN'),
('5822', 'BERGEN'),
('5824', 'BERGEN'),
('5825', 'BERGEN'),
('5828', 'BERGEN'),
('5829', 'BERGEN'),
('5835', 'BERGEN'),
('5836', 'BERGEN'),
('5837', 'BERGEN'),
('5838', 'BERGEN'),
('5845', 'BERGEN'),
('5846', 'BERGEN'),
('5847', 'BERGEN'),
('5848', 'BERGEN'),
('5849', 'BERGEN'),
('5851', 'BERGEN'),
('5852', 'BERGEN'),
('5853', 'BERGEN'),
('5854', 'BERGEN'),
('5856', 'BERGEN'),
('5857', 'BERGEN'),
('5858', 'BERGEN'),
('5859', 'BERGEN'),
('5861', 'BERGEN'),
('5862', 'BERGEN'),
('5863', 'BERGEN'),
('5864', 'BERGEN'),
('5868', 'BERGEN'),
('5869', 'BERGEN'),
('5871', 'BERGEN'),
('5872', 'BERGEN'),
('5873', 'BERGEN'),
('5876', 'BERGEN'),
('5877', 'BERGEN'),
('5878', 'BERGEN'),
('5879', 'BERGEN'),
('5881', 'BERGEN'),
('5882', 'BERGEN'),
('5883', 'BERGEN'),
('5884', 'BERGEN'),
('5886', 'BERGEN'),
('5888', 'BERGEN'),
('5889', 'BERGEN'),
('5892', 'BERGEN'),
('5893', 'BERGEN'),
('5896', 'BERGEN'),
('5899', 'BERGEN'),
('5902', 'ISDALSTØ'),
('5903', 'ISDALSTØ'),
('5904', 'ISDALSTØ'),
('5906', 'FREKHAUG'),
('5907', 'ALVERSUND'),
('5911', 'ALVERSUND'),
('5912', 'SEIM'),
('5913', 'EIKANGERVÅG'),
('5914', 'ISDALSTØ'),
('5915', 'HJELMÅS'),
('5917', 'ROSSLAND'),
('5918', 'FREKHAUG'),
('5931', 'MANGER'),
('5936', 'MANGER'),
('5937', 'BØVÅGEN'),
('5938', 'SÆBØVÅGEN'),
('5939', 'SLETTA'),
('5941', 'AUSTRHEIM'),
('5943', 'AUSTRHEIM'),
('5947', 'FEDJE'),
('5948', 'FEDJE'),
('5951', 'LINDÅS'),
('5953', 'FONNES'),
('5954', 'MONGSTAD'),
('5955', 'LINDÅS'),
('5956', 'VÅGSEIDET'),
('5957', 'MYKING'),
('5960', 'DALSØYRA'),
('5961', 'BREKKE'),
('5962', 'BJORDAL'),
('5966', 'EIVINDVIK'),
('5967', 'EIVINDVIK'),
('5970', 'BYRKNESØY'),
('5977', 'ÅNNELAND'),
('5978', 'MJØMNA'),
('5979', 'BYRKNESØY'),
('5981', 'MASFJORDNES'),
('5983', 'HAUGSVÆR'),
('5984', 'MATREDAL'),
('5986', 'HOSTELAND'),
('5987', 'HOSTELAND'),
('5991', 'OSTEREIDET'),
('5993', 'OSTEREIDET'),
('5994', 'VIKANES'),
('6001', 'ÅLESUND'),
('6002', 'ÅLESUND'),
('6003', 'ÅLESUND'),
('6004', 'ÅLESUND'),
('6005', 'ÅLESUND'),
('6006', 'ÅLESUND'),
('6007', 'ÅLESUND'),
('6008', 'ÅLESUND'),
('6009', 'ÅLESUND'),
('6010', 'ÅLESUND'),
('6011', 'ÅLESUND'),
('6012', 'ÅLESUND'),
('6013', 'ÅLESUND'),
('6014', 'ÅLESUND'),
('6015', 'ÅLESUND'),
('6016', 'ÅLESUND'),
('6017', 'ÅLESUND'),
('6018', 'ÅLESUND'),
('6019', 'ÅLESUND'),
('6020', 'ÅLESUND'),
('6021', 'ÅLESUND'),
('6022', 'ÅLESUND'),
('6023', 'ÅLESUND'),
('6024', 'ÅLESUND'),
('6025', 'ÅLESUND'),
('6026', 'ÅLESUND'),
('6028', 'ÅLESUND'),
('6029', 'ÅLESUND'),
('6030', 'LANGEVÅG'),
('6035', 'FISKARSTRAND'),
('6036', 'MAUSEIDVÅG'),
('6037', 'EIDSNES'),
('6038', 'FISKARSTRAND'),
('6039', 'LANGEVÅG'),
('6040', 'VIGRA'),
('6045', 'ÅLESUND'),
('6046', 'ÅLESUND'),
('6050', 'VALDERØY'),
('6051', 'VALDERØY'),
('6052', 'GISKE'),
('6055', 'GODØY'),
('6057', 'ELLINGSØY'),
('6058', 'VALDERØY'),
('6059', 'VIGRA'),
('6060', 'HAREID'),
('6062', 'BRANDAL'),
('6063', 'HJØRUNGAVÅG'),
('6064', 'HADDAL'),
('6065', 'ULSTEINVIK'),
('6067', 'ULSTEINVIK'),
('6069', 'HAREID'),
('6070', 'TJØRVÅG'),
('6076', 'MOLDTUSTRANDA'),
('6080', 'GURSKØY'),
('6082', 'GURSKEN'),
('6083', 'GJERDSVIKA'),
('6084', 'LARSNES'),
('6085', 'LARSNES'),
('6087', 'KVAMSØY'),
('6089', 'SANDSHAMN'),
('6090', 'FOSNAVÅG'),
('6092', 'EGGESBØNES'),
('6094', 'LEINØY'),
('6095', 'BØLANDET'),
('6096', 'RUNDE'),
('6098', 'NERLANDSØY'),
('6099', 'FOSNAVÅG'),
('6100', 'VOLDA'),
('6101', 'VOLDA'),
('6102', 'VOLDA'),
('6110', 'AUSTEFJORDEN'),
('6120', 'FOLKESTAD'),
('6133', 'LAUVSTAD'),
('6139', 'FISKÅBYGD'),
('6140', 'SYVDE'),
('6141', 'ROVDE'),
('6142', 'EIDSÅ'),
('6143', 'FISKÅBYGD'),
('6144', 'SYLTE'),
('6146', 'ÅHEIM'),
('6149', 'ÅRAM'),
('6150', 'ØRSTA'),
('6151', 'ØRSTA'),
('6160', 'HOVDEBYGDA'),
('6161', 'HOVDEBYGDA'),
('6165', 'SÆBØ'),
('6166', 'SÆBØ'),
('6170', 'VARTDAL'),
('6174', 'BARSTADVIK'),
('6183', 'TRANDAL'),
('6184', 'STORESTANDAL'),
('6190', 'BJØRKE'),
('6196', 'NORANGSFJORDEN'),
('6200', 'STRANDA'),
('6201', 'STRANDA'),
('6210', 'VALLDAL'),
('6212', 'LIABYGDA'),
('6213', 'TAFJORD'),
('6214', 'NORDDAL'),
('6215', 'EIDSDAL'),
('6216', 'GEIRANGER'),
('6217', 'DJUPEVATN'),
('6218', 'HELLESYLT'),
('6220', 'STRAUMGJERDE'),
('6222', 'IKORNNES'),
('6224', 'HUNDEIDVIK'),
('6230', 'SYKKYLVEN'),
('6238', 'STRAUMGJERDE'),
('6239', 'SYKKYLVEN'),
('6240', 'ØRSKOG'),
('6249', 'ØRSKOG'),
('6250', 'STORDAL'),
('6259', 'STORDAL'),
('6260', 'SKODJE'),
('6263', 'SKODJE'),
('6264', 'TENNFJORD'),
('6265', 'VATNE'),
('6270', 'BRATTVÅG'),
('6272', 'HILDRE'),
('6280', 'SØVIK'),
('6281', 'SØVIK'),
('6282', 'BRATTVÅG'),
('6283', 'VATNE'),
('6285', 'STOREKALVØY'),
('6290', 'HARAMSØY'),
('6292', 'KJERSTAD'),
('6293', 'LONGVA'),
('6294', 'FJØRTOFT'),
('6300', 'ÅNDALSNES'),
('6301', 'ÅNDALSNES'),
('6309', 'ÅNDALSNES LEIRPLASS'),
('6310', 'VEBLUNGSNES'),
('6315', 'INNFJORDEN'),
('6320', 'ISFJORDEN'),
('6330', 'VERMA'),
('6335', 'TROLLSTIGEN'),
('6339', 'ISFJORDEN'),
('6350', 'EIDSBYGDA'),
('6360', 'ÅFARNES'),
('6363', 'MITTET'),
('6364', 'VISTDAL'),
('6386', 'MÅNDALEN'),
('6387', 'VÅGSTRANDA'),
('6390', 'VESTNES'),
('6391', 'TRESFJORD'),
('6392', 'VIKEBUKT'),
('6393', 'TOMREFJORD'),
('6394', 'FIKSDAL'),
('6395', 'REKDAL'),
('6396', 'VIKEBUKT'),
('6397', 'TRESFJORD'),
('6398', 'TOMREFJORD'),
('6399', 'VESTNES'),
('6401', 'MOLDE'),
('6402', 'MOLDE'),
('6403', 'MOLDE'),
('6404', 'MOLDE'),
('6405', 'MOLDE'),
('6407', 'MOLDE'),
('6408', 'AUREOSEN'),
('6410', 'MOLDE'),
('6411', 'MOLDE'),
('6412', 'MOLDE'),
('6413', 'MOLDE'),
('6414', 'MOLDE'),
('6415', 'MOLDE'),
('6416', 'MOLDE'),
('6418', 'SEKKEN'),
('6419', 'MOLDE'),
('6421', 'MOLDE'),
('6422', 'MOLDE'),
('6425', 'MOLDE'),
('6429', 'MOLDE'),
('6430', 'BUD'),
('6433', 'HUSTAD'),
('6440', 'ELNESVÅGEN'),
('6443', 'TORNES I ROMSDAL'),
('6444', 'FARSTAD'),
('6445', 'MALMEFJORDEN'),
('6447', 'ELNESVÅGEN'),
('6449', 'FARSTAD'),
('6450', 'HJELSET'),
('6453', 'KLEIVE'),
('6454', 'HJELSET'),
('6455', 'KORTGARDEN'),
('6456', 'SKÅLA'),
('6457', 'BOLSØYA'),
('6460', 'EIDSVÅG I ROMSDAL'),
('6462', 'RAUDSAND'),
('6470', 'ERESFJORD'),
('6472', 'EIKESDAL'),
('6475', 'MIDSUND'),
('6476', 'MIDSUND'),
('6480', 'AUKRA'),
('6481', 'AUKRA'),
('6483', 'ONA'),
('6484', 'SANDØY'),
('6486', 'ORTEN'),
('6487', 'HARØY'),
('6488', 'MYKLEBOST'),
('6490', 'EIDE'),
('6493', 'LYNGSTAD'),
('6494', 'VEVANG'),
('6499', 'EIDE'),
('6501', 'KRISTIANSUND N'),
('6502', 'KRISTIANSUND N'),
('6503', 'KRISTIANSUND N'),
('6504', 'KRISTIANSUND N'),
('6505', 'KRISTIANSUND N'),
('6506', 'KRISTIANSUND N'),
('6507', 'KRISTIANSUND N'),
('6508', 'KRISTIANSUND N'),
('6509', 'KRISTIANSUND N'),
('6510', 'KRISTIANSUND N'),
('6511', 'KRISTIANSUND N'),
('6512', 'KRISTIANSUND N'),
('6514', 'KRISTIANSUND N'),
('6515', 'KRISTIANSUND N'),
('6516', 'KRISTIANSUND N'),
('6517', 'KRISTIANSUND N'),
('6518', 'KRISTIANSUND N'),
('6520', 'FREI'),
('6523', 'FREI'),
('6529', 'FREI'),
('6530', 'AVERØY'),
('6538', 'AVERØY'),
('6539', 'AVERØY'),
('6570', 'SMØLA'),
('6571', 'SMØLA'),
('6590', 'TUSTNA'),
('6600', 'SUNNDALSØRA'),
('6601', 'SUNNDALSØRA'),
('6610', 'ØKSENDAL'),
('6611', 'FURUGRENDA'),
('6612', 'GRØA'),
('6613', 'GJØRA'),
('6620', 'ÅLVUNDEID'),
('6622', 'ÅLVUNDFJORD'),
('6628', 'MEISINGSET'),
('6629', 'TORJULVÅGEN'),
('6630', 'TINGVOLL'),
('6631', 'BATNFJORDSØRA'),
('6633', 'GJEMNES'),
('6636', 'ANGVIK'),
('6637', 'FLEMMA'),
('6638', 'OSMARKA'),
('6639', 'TORVIKBUKT'),
('6640', 'KVANNE'),
('6642', 'STANGVIK'),
('6643', 'BØFJORDEN'),
('6644', 'BÆVERFJORD'),
('6645', 'TODALEN'),
('6650', 'SURNADAL'),
('6652', 'SURNA'),
('6653', 'ØVRE SURNADAL'),
('6655', 'VINDØLA'),
('6656', 'SURNADAL'),
('6657', 'RINDAL'),
('6658', 'RINDALSSKOGEN'),
('6659', 'RINDAL'),
('6670', 'ØYDEGARD'),
('6674', 'KVISVIK'),
('6680', 'HALSANAUSTAN'),
('6683', 'VÅGLAND'),
('6686', 'VALSØYBOTN'),
('6687', 'VALSØYFJORD'),
('6688', 'VÅGLAND'),
('6689', 'AURE'),
('6690', 'AURE'),
('6693', 'MJOSUNDET'),
('6694', 'FOLDFJORDEN'),
('6697', 'VIHALS'),
('6698', 'LESUND'),
('6699', 'KJØRSVIKBUGEN'),
('6700', 'MÅLØY'),
('6701', 'MÅLØY'),
('6702', 'MÅLØY'),
('6703', 'MÅLØY'),
('6704', 'DEKNEPOLLEN'),
('6706', 'MÅLØY'),
('6707', 'RAUDEBERG'),
('6708', 'BRYGGJA'),
('6710', 'RAUDEBERG'),
('6711', 'BRYGGJA'),
('6713', 'ALMENNINGEN'),
('6714', 'SILDA'),
('6715', 'BARMEN'),
('6716', 'HUSEVÅG'),
('6717', 'FLATRAKET'),
('6718', 'DEKNEPOLLEN'),
('6719', 'SKATESTRAUMEN'),
('6721', 'SVELGEN'),
('6723', 'SVELGEN'),
('6726', 'BREMANGER'),
('6727', 'BREMANGER'),
('6728', 'KALVÅG'),
('6729', 'KALVÅG'),
('6730', 'DAVIK'),
('6731', 'DAVIK'),
('6734', 'RUGSUND'),
('6737', 'ÅLFOTEN'),
('6740', 'SELJE'),
('6741', 'SELJE'),
('6750', 'STADLANDET'),
('6751', 'STADLANDET'),
('6761', 'HORNINDAL'),
('6763', 'HORNINDAL'),
('6770', 'NORDFJORDEID'),
('6771', 'NORDFJORDEID'),
('6772', 'NORDFJORDEID'),
('6775', 'NORDFJORDEID'),
('6776', 'KJØLSDALEN'),
('6777', 'STÅRHEIM'),
('6778', 'LOTE'),
('6779', 'HOLMØYANE'),
('6781', 'STRYN'),
('6782', 'STRYN'),
('6783', 'STRYN'),
('6784', 'OLDEN'),
('6785', 'STRYN'),
('6788', 'OLDEN'),
('6789', 'LOEN'),
('6791', 'OLDEDALEN'),
('6792', 'BRIKSDALSBRE'),
('6793', 'INNVIK'),
('6795', 'BLAKSÆTER'),
('6796', 'HOPLAND'),
('6797', 'UTVIK'),
('6798', 'HJELLEDALEN'),
('6799', 'OPPSTRYN'),
('6800', 'FØRDE'),
('6801', 'FØRDE'),
('6802', 'FØRDE'),
('6803', 'FØRDE'),
('6804', 'FØRDE'),
('6805', 'FØRDE'),
('6806', 'NAUSTDAL'),
('6807', 'FØRDE'),
('6816', 'NAUSTDAL'),
('6817', 'NAUSTDAL'),
('6818', 'HAUKEDALEN'),
('6819', 'HOLSEN'),
('6821', 'SANDANE'),
('6822', 'SANDANE'),
('6823', 'SANDANE'),
('6824', 'SANDANE'),
('6826', 'BYRKJELO'),
('6827', 'BREIM'),
('6828', 'HESTENESØYRA'),
('6829', 'HYEN'),
('6841', 'SKEI I JØLSTER'),
('6843', 'SKEI I JØLSTER'),
('6847', 'VASSENDEN'),
('6851', 'SOGNDAL'),
('6852', 'SOGNDAL'),
('6853', 'SOGNDAL'),
('6854', 'KAUPANGER'),
('6855', 'FRØNNINGEN'),
('6856', 'SOGNDAL'),
('6857', 'SOGNDAL'),
('6858', 'FARDAL'),
('6859', 'SLINDE'),
('6861', 'LEIKANGER'),
('6863', 'LEIKANGER'),
('6866', 'GAUPNE'),
('6868', 'GAUPNE'),
('6869', 'HAFSLO'),
('6870', 'ORNES'),
('6871', 'JOSTEDAL'),
('6872', 'LUSTER'),
('6873', 'MARIFJØRA'),
('6875', 'HØYHEIMSVIK'),
('6876', 'SKJOLDEN'),
('6877', 'FORTUN'),
('6878', 'VEITASTROND'),
('6879', 'SOLVORN'),
('6881', 'ÅRDALSTANGEN'),
('6882', 'ØVRE ÅRDAL'),
('6884', 'ØVRE ÅRDAL'),
('6885', 'ÅRDALSTANGEN'),
('6886', 'LÆRDAL'),
('6887', 'LÆRDAL'),
('6888', 'STEINKLEPP'),
('6891', 'VIK I SOGN'),
('6893', 'VIK I SOGN'),
('6894', 'VANGSNES'),
('6895', 'FEIOS'),
('6896', 'FRESVIK'),
('6898', 'BALESTRAND'),
('6899', 'BALESTRAND'),
('6900', 'FLORØ'),
('6901', 'FLORØ'),
('6902', 'FLORØ'),
('6903', 'FLORØ'),
('6904', 'FLORØ'),
('6907', 'FLORØ'),
('6909', 'FLORØ'),
('6912', 'KINN'),
('6914', 'SVANØYBUKT'),
('6915', 'ROGNALDSVÅG'),
('6916', 'BAREKSTAD'),
('6917', 'BATALDEN'),
('6918', 'SØR-SKORPA'),
('6919', 'TANSØY'),
('6921', 'HARDBAKKE'),
('6924', 'HARDBAKKE'),
('6926', 'KRAKHELLA'),
('6927', 'YTRØYGREND'),
('6928', 'KOLGROV'),
('6929', 'HERSVIKBYGDA'),
('6939', 'STAVANG'),
('6940', 'EIKEFJORD'),
('6941', 'EIKEFJORD'),
('6942', 'SVORTEVIK'),
('6944', 'STAVANG'),
('6946', 'LAVIK'),
('6947', 'LAVIK'),
('6951', 'LEIRVIK I SOGN'),
('6953', 'LEIRVIK I SOGN'),
('6957', 'HYLLESTAD'),
('6958', 'SØRBØVÅG'),
('6961', 'DALE I SUNNFJORD'),
('6963', 'DALE I SUNNFJORD'),
('6964', 'KORSSUND'),
('6966', 'GUDDAL'),
('6967', 'HELLEVIK I FJALER'),
('6968', 'FLEKKE'),
('6969', 'STRAUMSNES'),
('6971', 'SANDE I SUNNFJORD'),
('6973', 'SANDE I SUNNFJORD'),
('6975', 'SKILBREI'),
('6977', 'BYGSTAD'),
('6978', 'VIKSDALEN'),
('6980', 'ASKVOLL'),
('6981', 'HOLMEDAL'),
('6982', 'HOLMEDAL'),
('6983', 'KVAMMEN'),
('6984', 'STONGFJORDEN'),
('6985', 'ATLØY'),
('6986', 'VÆRLANDET'),
('6987', 'BULANDET'),
('6988', 'ASKVOLL'),
('6991', 'HØYANGER'),
('6993', 'HØYANGER'),
('6995', 'KYRKJEBØ'),
('6996', 'VADHEIM'),
('7003', 'TRONDHEIM'),
('7004', 'TRONDHEIM'),
('7005', 'TRONDHEIM'),
('7006', 'TRONDHEIM'),
('7007', 'TRONDHEIM'),
('7010', 'TRONDHEIM'),
('7011', 'TRONDHEIM'),
('7012', 'TRONDHEIM'),
('7013', 'TRONDHEIM'),
('7014', 'TRONDHEIM'),
('7015', 'TRONDHEIM'),
('7016', 'TRONDHEIM'),
('7018', 'TRONDHEIM'),
('7019', 'TRONDHEIM'),
('7020', 'TRONDHEIM'),
('7021', 'TRONDHEIM'),
('7022', 'TRONDHEIM'),
('7023', 'TRONDHEIM'),
('7024', 'TRONDHEIM'),
('7025', 'TRONDHEIM'),
('7026', 'TRONDHEIM'),
('7027', 'TRONDHEIM'),
('7028', 'TRONDHEIM'),
('7029', 'TRONDHEIM'),
('7030', 'TRONDHEIM'),
('7031', 'TRONDHEIM'),
('7032', 'TRONDHEIM'),
('7033', 'TRONDHEIM'),
('7034', 'TRONDHEIM'),
('7036', 'TRONDHEIM'),
('7037', 'TRONDHEIM'),
('7038', 'TRONDHEIM'),
('7039', 'TRONDHEIM'),
('7040', 'TRONDHEIM'),
('7041', 'TRONDHEIM'),
('7042', 'TRONDHEIM'),
('7043', 'TRONDHEIM'),
('7044', 'TRONDHEIM'),
('7045', 'TRONDHEIM'),
('7046', 'TRONDHEIM'),
('7047', 'TRONDHEIM'),
('7048', 'TRONDHEIM'),
('7049', 'TRONDHEIM'),
('7050', 'TRONDHEIM'),
('7051', 'TRONDHEIM'),
('7052', 'TRONDHEIM'),
('7053', 'RANHEIM'),
('7054', 'RANHEIM'),
('7056', 'RANHEIM'),
('7057', 'JONSVATNET'),
('7058', 'JAKOBSLI'),
('7059', 'JAKOBSLI'),
('7070', 'BOSBERG'),
('7072', 'HEIMDAL'),
('7074', 'SPONGDAL'),
('7075', 'TILLER'),
('7078', 'SAUPSTAD'),
('7079', 'FLATÅSEN'),
('7080', 'HEIMDAL'),
('7081', 'SJETNEMARKA'),
('7082', 'KATTEM'),
('7083', 'LEINSTRAND'),
('7088', 'HEIMDAL'),
('7089', 'HEIMDAL'),
('7091', 'TILLER'),
('7092', 'TILLER'),
('7097', 'SAUPSTAD'),
('7098', 'SAUPSTAD'),
('7099', 'FLATÅSEN'),
('7100', 'RISSA'),
('7101', 'RISSA'),
('7105', 'STADSBYGD'),
('7110', 'FEVÅG'),
('7112', 'HASSELVIKA'),
('7113', 'HUSBYSJØEN'),
('7114', 'RÅKVÅG'),
('7119', 'STADSBYGD'),
('7120', 'LEKSVIK'),
('7121', 'LEKSVIK'),
('7125', 'VANVIKAN'),
('7126', 'VANVIKAN'),
('7127', 'OPPHAUG'),
('7128', 'UTHAUG'),
('7129', 'BREKSTAD'),
('7130', 'BREKSTAD'),
('7140', 'OPPHAUG'),
('7142', 'UTHAUG'),
('7150', 'STORFOSNA'),
('7152', 'KRÅKVÅG'),
('7153', 'GARTEN'),
('7156', 'LEKSA'),
('7159', 'BJUGN'),
('7160', 'BJUGN'),
('7165', 'OKSVOLL'),
('7166', 'TARVA'),
('7167', 'VALLERSUND'),
('7168', 'LYSØYSUNDET'),
('7169', 'ÅFJORD'),
('7170', 'ÅFJORD'),
('7176', 'LINESØYA'),
('7177', 'REVSNES'),
('7178', 'STOKKØY'),
('7180', 'ROAN'),
('7190', 'BESSAKER'),
('7194', 'BRANDSFJORD'),
('7200', 'KYRKSÆTERØRA'),
('7201', 'KYRKSÆTERØRA'),
('7203', 'VINJEØRA'),
('7206', 'HELLANDSJØEN'),
('7211', 'KORSVEGEN'),
('7212', 'KORSVEGEN'),
('7213', 'GÅSBAKKEN'),
('7221', 'MELHUS'),
('7223', 'MELHUS'),
('7224', 'MELHUS'),
('7227', 'GIMSE'),
('7228', 'KVÅL'),
('7229', 'KVÅL'),
('7231', 'LUNDAMO'),
('7232', 'LUNDAMO'),
('7234', 'LER'),
('7236', 'HOVIN I GAULDAL'),
('7238', 'HOVIN I GAULDAL'),
('7239', 'HITRA'),
('7240', 'HITRA'),
('7241', 'ANSNES'),
('7242', 'KNARRLAGSUND'),
('7243', 'KVENVÆR'),
('7246', 'SANDSTAD'),
('7247', 'HESTVIKA'),
('7250', 'MELANDSJØ'),
('7252', 'DOLMØY'),
('7255', 'SUNDLANDET'),
('7256', 'HEMNSKJEL'),
('7257', 'SNILLFJORD'),
('7259', 'SNILLFJORD'),
('7260', 'SISTRANDA'),
('7261', 'SISTRANDA'),
('7263', 'HAMARVIK'),
('7264', 'HAMARVIK'),
('7266', 'KVERVA'),
('7268', 'TITRAN'),
('7270', 'DYRVIK'),
('7273', 'NORDDYRØY'),
('7280', 'SULA'),
('7282', 'BOGØYVÆR'),
('7284', 'MAUSUND'),
('7285', 'GJÆSINGEN'),
('7286', 'SØRBURØY'),
('7287', 'SAUØY'),
('7288', 'SOKNEDAL'),
('7289', 'SOKNEDAL'),
('7290', 'STØREN'),
('7291', 'STØREN'),
('7295', 'ROGNES'),
('7298', 'BUDALEN'),
('7300', 'ORKANGER'),
('7301', 'ORKANGER'),
('7302', 'ORKANGER'),
('7310', 'GJØLME'),
('7315', 'LENSVIK'),
('7316', 'LENSVIK'),
('7318', 'AGDENES'),
('7319', 'AGDENES'),
('7320', 'FANNREM'),
('7321', 'FANNREM'),
('7327', 'SVORKMO'),
('7329', 'SVORKMO'),
('7331', 'LØKKEN VERK'),
('7332', 'LØKKEN VERK'),
('7333', 'STORÅS'),
('7334', 'STORÅS'),
('7335', 'JERPSTAD'),
('7336', 'MELDAL'),
('7338', 'MELDAL'),
('7340', 'OPPDAL'),
('7341', 'OPPDAL'),
('7342', 'LØNSET'),
('7343', 'VOGNILL'),
('7344', 'GJEVILVASSHYTTA'),
('7345', 'DRIVA'),
('7350', 'BUVIKA'),
('7351', 'BUVIKA'),
('7353', 'BØRSA'),
('7354', 'VIGGJA'),
('7355', 'EGGKLEIVA'),
('7357', 'SKAUN'),
('7358', 'BØRSA'),
('7361', 'RØROS'),
('7366', 'RØROS'),
('7370', 'BREKKEBYGD'),
('7372', 'GLÅMOS'),
('7374', 'RØROS'),
('7380', 'ÅLEN'),
('7383', 'HALTDALEN'),
('7384', 'ÅLEN'),
('7386', 'SINGSÅS'),
('7387', 'SINGSÅS'),
('7391', 'RENNEBU, Berkåk'),
('7392', 'RENNEBU, Stamnan'),
('7393', 'RENNEBU, Voll'),
('7397', 'RENNEBU, Ulsberg'),
('7398', 'RENNEBU, Innset'),
('7399', 'RENNEBU'),
('7400', 'TRONDHEIM'),
('7401', 'TRONDHEIM'),
('7402', 'TRONDHEIM'),
('7403', 'TRONDHEIM'),
('7404', 'TRONDHEIM'),
('7405', 'TRONDHEIM'),
('7406', 'TRONDHEIM'),
('7407', 'TRONDHEIM'),
('7408', 'TRONDHEIM'),
('7409', 'TRONDHEIM'),
('7410', 'TRONDHEIM'),
('7411', 'TRONDHEIM'),
('7412', 'TRONDHEIM'),
('7413', 'TRONDHEIM'),
('7414', 'TRONDHEIM'),
('7415', 'TRONDHEIM'),
('7416', 'TRONDHEIM'),
('7417', 'TRONDHEIM'),
('7418', 'TRONDHEIM'),
('7419', 'TRONDHEIM'),
('7420', 'TRONDHEIM'),
('7421', 'TRONDHEIM'),
('7422', 'TRONDHEIM'),
('7423', 'TRONDHEIM'),
('7424', 'TRONDHEIM'),
('7425', 'TRONDHEIM'),
('7426', 'TRONDHEIM'),
('7427', 'TRONDHEIM'),
('7428', 'TRONDHEIM'),
('7429', 'TRONDHEIM'),
('7430', 'TRONDHEIM'),
('7431', 'TRONDHEIM'),
('7432', 'TRONDHEIM'),
('7433', 'TRONDHEIM'),
('7434', 'TRONDHEIM'),
('7435', 'TRONDHEIM'),
('7436', 'TRONDHEIM'),
('7437', 'TRONDHEIM'),
('7438', 'TRONDHEIM'),
('7439', 'TRONDHEIM'),
('7440', 'TRONDHEIM'),
('7441', 'TRONDHEIM'),
('7442', 'TRONDHEIM'),
('7443', 'TRONDHEIM'),
('7444', 'TRONDHEIM'),
('7445', 'TRONDHEIM'),
('7446', 'TRONDHEIM'),
('7447', 'TRONDHEIM'),
('7448', 'TRONDHEIM'),
('7449', 'TRONDHEIM'),
('7450', 'TRONDHEIM'),
('7451', 'TRONDHEIM'),
('7452', 'TRONDHEIM'),
('7453', 'TRONDHEIM'),
('7456', 'TRONDHEIM'),
('7457', 'TRONDHEIM'),
('7458', 'TRONDHEIM'),
('7459', 'TRONDHEIM'),
('7462', 'TRONDHEIM'),
('7463', 'TRONDHEIM'),
('7464', 'TRONDHEIM'),
('7465', 'TRONDHEIM'),
('7466', 'TRONDHEIM'),
('7467', 'TRONDHEIM'),
('7468', 'TRONDHEIM'),
('7469', 'TRONDHEIM'),
('7471', 'TRONDHEIM'),
('7472', 'TRONDHEIM'),
('7473', 'TRONDHEIM'),
('7474', 'TRONDHEIM'),
('7475', 'TRONDHEIM'),
('7476', 'TRONDHEIM'),
('7477', 'TRONDHEIM'),
('7478', 'TRONDHEIM'),
('7479', 'TRONDHEIM'),
('7481', 'TRONDHEIM'),
('7483', 'TRONDHEIM'),
('7484', 'TRONDHEIM'),
('7485', 'TRONDHEIM'),
('7486', 'TRONDHEIM'),
('7488', 'TRONDHEIM'),
('7489', 'TRONDHEIM'),
('7491', 'TRONDHEIM'),
('7492', 'TRONDHEIM'),
('7493', 'TRONDHEIM'),
('7495', 'TRONDHEIM'),
('7496', 'TRONDHEIM'),
('7498', 'TRONDHEIM'),
('7499', 'TRONDHEIM'),
('7500', 'STJØRDAL'),
('7501', 'STJØRDAL'),
('7505', 'STJØRDAL'),
('7506', 'STJØRDAL'),
('7508', 'STJØRDAL'),
('7510', 'SKATVAL'),
('7517', 'HELL'),
('7519', 'ELVARLI'),
('7520', 'HEGRA'),
('7525', 'FLORNES'),
('7529', 'HEGRA'),
('7530', 'MERÅKER'),
('7531', 'MERÅKER'),
('7533', 'KOPPERÅ'),
('7540', 'KLÆBU'),
('7541', 'KLÆBU'),
('7548', 'TANEM'),
('7549', 'TANEM'),
('7550', 'HOMMELVIK'),
('7551', 'HOMMELVIK'),
('7560', 'VIKHAMMER'),
('7562', 'HUNDHAMAREN'),
('7563', 'MALVIK'),
('7566', 'VIKHAMMER'),
('7570', 'HELL'),
('7580', 'SELBU'),
('7581', 'SELBU'),
('7583', 'SELBU'),
('7584', 'SELBUSTRAND'),
('7586', 'SELBUSTRAND'),
('7590', 'TYDAL'),
('7591', 'TYDAL'),
('7596', 'FLAKNAN'),
('7600', 'LEVANGER'),
('7601', 'LEVANGER'),
('7609', 'LEVANGER'),
('7610', 'LEVANGER'),
('7619', 'SKOGN'),
('7620', 'SKOGN'),
('7622', 'MARKABYGDA'),
('7623', 'RONGLAN'),
('7624', 'EKNE'),
('7629', 'YTTERØY'),
('7630', 'ÅSEN'),
('7631', 'ÅSEN'),
('7632', 'ÅSENFJORD'),
('7633', 'FROSTA'),
('7634', 'FROSTA'),
('7650', 'VERDAL'),
('7651', 'VERDAL'),
('7658', 'VERDAL'),
('7659', 'VERDAL'),
('7660', 'VUKU'),
('7663', 'STIKLESTAD'),
('7670', 'INDERØY'),
('7671', 'INDERØY'),
('7690', 'MOSVIK'),
('7701', 'STEINKJER'),
('7702', 'STEINKJER'),
('7703', 'STEINKJER'),
('7704', 'STEINKJER'),
('7705', 'STEINKJER'),
('7706', 'STEINKJER'),
('7707', 'STEINKJER'),
('7708', 'STEINKJER'),
('7709', 'STEINKJER'),
('7710', 'SPARBU'),
('7711', 'STEINKJER'),
('7712', 'STEINKJER'),
('7713', 'STEINKJER'),
('7715', 'STEINKJER'),
('7716', 'STEINKJER'),
('7717', 'STEINKJER'),
('7718', 'STEINKJER'),
('7724', 'STEINKJER'),
('7725', 'STEINKJER'),
('7726', 'STEINKJER'),
('7728', 'STEINKJER'),
('7729', 'STEINKJER'),
('7730', 'BEITSTAD'),
('7732', 'STEINKJER'),
('7734', 'STEINKJER'),
('7735', 'STEINKJER'),
('7736', 'STEINKJER'),
('7737', 'STEINKJER'),
('7738', 'STEINKJER'),
('7739', 'BEITSTAD'),
('7740', 'STEINSDALEN'),
('7744', 'HEPSØY'),
('7745', 'OPPLAND'),
('7746', 'HASVÅG'),
('7748', 'SÆTERVIK'),
('7750', 'NAMDALSEID'),
('7751', 'NAMDALSEID'),
('7760', 'SNÅSA'),
('7761', 'SNÅSA'),
('7770', 'FLATANGER'),
('7771', 'FLATANGER'),
('7777', 'NORD-STATLAND'),
('7790', 'MALM'),
('7791', 'MALM'),
('7796', 'FOLLAFOSS'),
('7797', 'VERRABOTN'),
('7800', 'NAMSOS'),
('7801', 'NAMSOS'),
('7808', 'NAMSOS'),
('7809', 'NAMSOS'),
('7817', 'SALSNES'),
('7818', 'LUND'),
('7819', 'FOSSLANDSOSEN'),
('7820', 'SPILLUM'),
('7822', 'BANGSUND'),
('7856', 'JØA'),
('7860', 'SKAGE I NAMDALEN'),
('7863', 'OVERHALLA'),
('7864', 'OVERHALLA'),
('7869', 'SKAGE I NAMDALEN'),
('7870', 'GRONG'),
('7871', 'GRONG'),
('7873', 'HARRAN'),
('7882', 'NORDLI'),
('7884', 'SØRLI'),
('7890', 'NAMSSKOGAN'),
('7892', 'TRONES'),
('7893', 'SKOROVATN'),
('7896', 'BREKKVASSELV'),
('7898', 'LIMINGEN'),
('7900', 'RØRVIK'),
('7901', 'RØRVIK'),
('7940', 'OTTERSØY'),
('7944', 'INDRE NÆRØY'),
('7950', 'ABELVÆR'),
('7960', 'SALSBRUKET'),
('7970', 'KOLVEREID'),
('7971', 'KOLVEREID'),
('7973', 'GJERDINGA'),
('7976', 'KONGSMOEN'),
('7977', 'HØYLANDET'),
('7980', 'TERRÅK'),
('7981', 'HARANGSFJORD'),
('7982', 'BINDALSEIDET'),
('7985', 'FOLDEREID'),
('7990', 'NAUSTBUKTA'),
('7993', 'GUTVIK'),
('7994', 'LEKA'),
('8001', 'BODØ'),
('8002', 'BODØ'),
('8003', 'BODØ'),
('8004', 'BODØ'),
('8005', 'BODØ'),
('8006', 'BODØ'),
('8007', 'BODØ'),
('8008', 'BODØ'),
('8009', 'BODØ'),
('8010', 'BODØ'),
('8011', 'BODØ'),
('8012', 'BODØ'),
('8013', 'BODØ'),
('8014', 'BODØ'),
('8015', 'BODØ'),
('8016', 'BODØ'),
('8019', 'BODØ'),
('8020', 'BODØ'),
('8021', 'BODØ'),
('8022', 'BODØ'),
('8023', 'BODØ'),
('8026', 'BODØ'),
('8027', 'BODØ'),
('8028', 'BODØ'),
('8029', 'BODØ'),
('8030', 'BODØ'),
('8031', 'BODØ'),
('8032', 'BODØ'),
('8037', 'BODØ'),
('8038', 'BODØ'),
('8039', 'BODØ'),
('8041', 'BODØ'),
('8047', 'BODØ'),
('8048', 'BODØ'),
('8049', 'BODØ'),
('8050', 'TVERLANDET'),
('8056', 'SALTSTRAUMEN'),
('8058', 'TVERLANDET'),
('8063', 'VÆRØY'),
('8064', 'RØST'),
('8070', 'BODØ'),
('8071', 'BODØ'),
('8072', 'BODØ'),
('8073', 'BODØ'),
('8074', 'BODØ'),
('8075', 'BODØ'),
('8076', 'BODØ'),
('8079', 'BODØ'),
('8084', 'BODØ'),
('8086', 'BODØ'),
('8087', 'BODØ'),
('8088', 'BODØ'),
('8089', 'BODØ'),
('8091', 'BODØ'),
('8092', 'BODØ'),
('8093', 'KJERRINGØY'),
('8094', 'FLEINVÆR'),
('8095', 'HELLIGVÆR'),
('8096', 'BLIKSVÆR'),
('8097', 'GIVÆR'),
('8098', 'LANDEGODE'),
('8099', 'JAN MAYEN'),
('8100', 'MISVÆR'),
('8102', 'SKJERSTAD'),
('8103', 'BREIVIK I SALTEN'),
('8108', 'MISVÆR'),
('8110', 'MOLDJORD'),
('8114', 'TOLLÅ'),
('8118', 'MOLDJORD'),
('8120', 'NYGÅRDSJØEN'),
('8128', 'YTRE BEIARN'),
('8130', 'SANDHORNØY'),
('8135', 'SØRARNØY'),
('8136', 'NORDARNØY'),
('8138', 'INNDYR'),
('8140', 'INNDYR'),
('8145', 'STORVIK'),
('8146', 'REIPÅ'),
('8149', 'NEVERDAL'),
('8150', 'ØRNES'),
('8151', 'ØRNES'),
('8157', 'MELØY'),
('8158', 'BOLGA'),
('8159', 'STØTT'),
('8160', 'GLOMFJORD'),
('8161', 'GLOMFJORD'),
('8168', 'ENGAVÅGEN'),
('8170', 'ENGAVÅGEN'),
('8171', 'SVARTISEN GÅRD'),
('8178', 'HALSA'),
('8181', 'MYKEN'),
('8182', 'MELFJORDBOTN'),
('8184', 'ÅGSKARDET'),
('8185', 'VÅGAHOLMEN'),
('8186', 'TJONGSFJORDEN'),
('8187', 'JEKTVIK'),
('8188', 'NORDVERNES'),
('8189', 'GJERSVIKGRENDA'),
('8190', 'SØRFJORDEN'),
('8193', 'RØDØY'),
('8195', 'GJERØY'),
('8196', 'SELSØYVIK'),
('8197', 'STORSELSØY'),
('8198', 'NORDNESØY'),
('8200', 'FAUSKE'),
('8201', 'FAUSKE'),
('8202', 'FAUSKE'),
('8205', 'FAUSKE'),
('8210', 'FAUSKE'),
('8215', 'VALNESFJORD'),
('8220', 'RØSVIK'),
('8226', 'STRAUMEN'),
('8230', 'SULITJELMA'),
('8231', 'SULITJELMA'),
('8232', 'STRAUMEN'),
('8233', 'VALNESFJORD'),
('8250', 'ROGNAN'),
('8251', 'ROGNAN'),
('8255', 'RØKLAND'),
('8256', 'RØKLAND'),
('8260', 'INNHAVET'),
('8261', 'INNHAVET'),
('8264', 'ENGAN'),
('8266', 'MØRSVIKBOTN'),
('8270', 'DRAG'),
('8271', 'DRAG'),
('8273', 'NEVERVIK'),
('8274', 'MUSKEN'),
('8275', 'STORJORD I TYSFJORD'),
('8276', 'ULVSVÅG'),
('8281', 'LEINESFJORD'),
('8283', 'LEINESFJORD'),
('8285', 'LEINES'),
('8286', 'NORDFOLD'),
('8288', 'BOGØY'),
('8289', 'VÅG'),
('8290', 'SKUTVIK'),
('8294', 'HAMARØY'),
('8297', 'TRANØY'),
('8298', 'HAMARØY'),
('8300', 'SVOLVÆR'),
('8301', 'SVOLVÆR'),
('8305', 'SVOLVÆR'),
('8309', 'KABELVÅG'),
('8310', 'KABELVÅG'),
('8311', 'HENNINGSVÆR'),
('8312', 'HENNINGSVÆR'),
('8313', 'KLEPPSTAD'),
('8314', 'GIMSØYSAND'),
('8315', 'LAUKVIK'),
('8316', 'LAUPSTAD'),
('8317', 'STRØNSTAD'),
('8320', 'SKROVA'),
('8322', 'BRETTESNES'),
('8323', 'STORFJELL'),
('8324', 'DIGERMULEN'),
('8325', 'TENGELFJORD'),
('8328', 'STOREMOLLA'),
('8340', 'STAMSUND'),
('8352', 'SENNESVIK'),
('8360', 'BØSTAD'),
('8370', 'LEKNES'),
('8372', 'GRAVDAL'),
('8373', 'BALLSTAD'),
('8375', 'LEKNES'),
('8376', 'LEKNES'),
('8377', 'GRAVDAL'),
('8378', 'STAMSUND'),
('8380', 'RAMBERG'),
('8382', 'NAPP'),
('8384', 'SUND I LOFOTEN'),
('8387', 'FREDVANG'),
('8388', 'RAMBERG'),
('8390', 'REINE'),
('8392', 'SØRVÅGEN'),
('8393', 'SØRVÅGEN'),
('8398', 'REINE'),
('8400', 'SORTLAND'),
('8401', 'SORTLAND'),
('8405', 'SORTLAND'),
('8407', 'GODFJORD'),
('8408', 'SANDSET'),
('8409', 'GULLESFJORD'),
('8413', 'KVITNES'),
('8414', 'HENNES'),
('8415', 'HENNES'),
('8426', 'BARKESTAD'),
('8428', 'TUNSTAD'),
('8430', 'MYRE'),
('8432', 'ALSVÅG'),
('8438', 'STØ'),
('8439', 'MYRE'),
('8445', 'MELBU'),
('8446', 'MELBU'),
('8447', 'LONKAN'),
('8448', 'MYRLAND'),
('8450', 'STOKMARKNES'),
('8452', 'STOKMARKNES'),
('8455', 'STOKMARKNES'),
('8459', 'MELBU'),
('8465', 'STRAUMSJØEN'),
('8469', 'BØ I VESTERÅLEN'),
('8470', 'BØ I VESTERÅLEN'),
('8475', 'STRAUMSJØEN'),
('8480', 'ANDENES'),
('8481', 'BLEIK'),
('8483', 'ANDENES'),
('8484', 'RISØYHAMN'),
('8485', 'DVERBERG'),
('8487', 'BØGARD'),
('8488', 'NØSS'),
('8489', 'NORDMELA'),
('8493', 'RISØYHAMN'),
('8501', 'NARVIK'),
('8502', 'NARVIK'),
('8503', 'NARVIK'),
('8504', 'NARVIK'),
('8505', 'NARVIK'),
('8506', 'NARVIK'),
('8507', 'NARVIK'),
('8508', 'NARVIK'),
('8509', 'NARVIK'),
('8510', 'NARVIK'),
('8511', 'NARVIK'),
('8512', 'NARVIK'),
('8513', 'ANKENESSTRAND'),
('8514', 'NARVIK'),
('8515', 'NARVIK'),
('8516', 'NARVIK'),
('8517', 'NARVIK'),
('8518', 'NARVIK'),
('8520', 'ANKENESSTRAND'),
('8522', 'BEISFJORD'),
('8523', 'ELVEGARD'),
('8530', 'BJERKVIK'),
('8531', 'BJERKVIK'),
('8533', 'BOGEN I OFOTEN'),
('8534', 'LILAND'),
('8535', 'TÅRSTAD'),
('8536', 'EVENES'),
('8539', 'BOGEN I OFOTEN'),
('8540', 'BALLANGEN'),
('8542', 'KJELDEBOTN'),
('8543', 'KJELDEBOTN'),
('8546', 'BALLANGEN'),
('8550', 'LØDINGEN'),
('8551', 'LØDINGEN'),
('8581', 'VESTBYGD'),
('8587', 'STORÅ'),
('8590', 'KJØPSVIK'),
('8591', 'KJØPSVIK'),
('8601', 'MO I RANA'),
('8602', 'MO I RANA'),
('8603', 'GRUBHEI'),
('8604', 'SELFORS'),
('8605', 'MO I RANA'),
('8606', 'MO I RANA'),
('8607', 'MO I RANA'),
('8608', 'MO I RANA'),
('8609', 'YTTEREN'),
('8610', 'GRUBHEI'),
('8611', 'MO I RANA'),
('8613', 'SELFORS'),
('8614', 'YTTEREN'),
('8615', 'SKONSENG'),
('8616', 'BÅSMOEN'),
('8617', 'DALSELV'),
('8618', 'ANDFISKÅ'),
('8622', 'MO I RANA'),
('8624', 'MO I RANA'),
('8626', 'MO I RANA'),
('8629', 'SVARTISDAL'),
('8630', 'STORFORSHEI'),
('8634', 'MO I RANA'),
('8635', 'POLARSIRKELEN'),
('8638', 'STORFORSHEI'),
('8640', 'HEMNESBERGET'),
('8641', 'HEMNESBERGET'),
('8642', 'FINNEIDFJORD'),
('8643', 'BJERKA'),
('8646', 'KORGEN'),
('8647', 'BLEIKVASSLIA'),
('8648', 'KORGEN'),
('8651', 'MOSJØEN'),
('8654', 'MOSJØEN'),
('8655', 'MOSJØEN'),
('8656', 'MOSJØEN'),
('8657', 'MOSJØEN'),
('8658', 'MOSJØEN'),
('8659', 'MOSJØEN'),
('8661', 'MOSJØEN'),
('8663', 'MOSJØEN'),
('8664', 'MOSJØEN'),
('8665', 'MOSJØEN'),
('8672', 'ELSFJORD'),
('8679', 'SUNDØY'),
('8680', 'TROFORS'),
('8681', 'TROFORS'),
('8690', 'HATTFJELLDAL'),
('8691', 'HATTFJELLDAL'),
('8700', 'NESNA'),
('8701', 'NESNA'),
('8720', 'VIKHOLMEN'),
('8723', 'HUSBY'),
('8724', 'SAURA'),
('8725', 'UTSKARPEN'),
('8726', 'UTSKARPEN'),
('8730', 'BRATLAND'),
('8732', 'ALDRA'),
('8733', 'STUVLAND'),
('8735', 'STOKKVÅGEN'),
('8740', 'NORD-SOLVÆR'),
('8742', 'SELVÆR'),
('8743', 'INDRE KVARØY'),
('8750', 'TONNES'),
('8752', 'KONSVIKOSEN'),
('8753', 'KONSVIKOSEN'),
('8762', 'SLENESET'),
('8764', 'LOVUND'),
('8766', 'LURØY'),
('8767', 'LURØY'),
('8770', 'TRÆNA'),
('8800', 'SANDNESSJØEN'),
('8801', 'SANDNESSJØEN'),
('8805', 'SANDNESSJØEN'),
('8813', 'KOPARDAL'),
('8820', 'DØNNA'),
('8826', 'NORDØYVÅGEN'),
('8827', 'DØNNA'),
('8830', 'VANDVE'),
('8842', 'BRASØY'),
('8844', 'SANDVÆR'),
('8850', 'HERØY'),
('8851', 'HERØY'),
('8852', 'HERØY'),
('8854', 'AUSTBØ'),
('8860', 'TJØTTA'),
('8865', 'TRO'),
('8870', 'VISTHUS'),
('8880', 'BÆRØYVÅGEN'),
('8883', 'HUSVIKA'),
('8890', 'LEIRFJORD'),
('8891', 'LEIRFJORD'),
('8900', 'BRØNNØYSUND'),
('8901', 'BRØNNØYSUND'),
('8905', 'BRØNNØYSUND'),
('8910', 'BRØNNØYSUNDREGISTRENE'),
('8920', 'SØMNA'),
('8921', 'SØMNA'),
('8922', 'SØMNA'),
('8960', 'HOMMELSTØ'),
('8961', 'HOMMELSTØ'),
('8976', 'VEVELSTAD'),
('8978', 'HESSTUN'),
('8980', 'VEGA'),
('8981', 'VEGA'),
('8985', 'YLVINGEN'),
('9001', 'TROMSØ'),
('9002', 'TROMSØ'),
('9003', 'TROMSØ'),
('9006', 'TROMSØ'),
('9007', 'TROMSØ'),
('9008', 'TROMSØ'),
('9009', 'TROMSØ'),
('9010', 'TROMSØ'),
('9011', 'TROMSØ'),
('9012', 'TROMSØ'),
('9013', 'TROMSØ'),
('9014', 'TROMSØ'),
('9015', 'TROMSØ'),
('9016', 'TROMSØ'),
('9017', 'TROMSØ'),
('9018', 'TROMSØ'),
('9019', 'TROMSØ'),
('9020', 'TROMSDALEN'),
('9022', 'KROKELVDALEN'),
('9024', 'TOMASJORD'),
('9027', 'RAMFJORDBOTN'),
('9030', 'SJURSNES'),
('9034', 'OLDERVIK'),
('9037', 'TROMSØ'),
('9038', 'TROMSØ'),
('9040', 'NORDKJOSBOTN'),
('9042', 'LAKSVATN'),
('9043', 'JØVIK'),
('9046', 'OTEREN'),
('9049', 'NORDKJOSBOTN'),
('9050', 'STORSTEINNES'),
('9054', 'MALANGSEIDET'),
('9055', 'MEISTERVIK'),
('9056', 'MORTENHALS'),
('9057', 'VIKRAN'),
('9059', 'STORSTEINNES'),
('9060', 'LYNGSEIDET'),
('9062', 'FURUFLATEN'),
('9064', 'SVENSBY'),
('9068', 'NORD-LENANGEN'),
('9069', 'LYNGSEIDET'),
('9100', 'KVALØYSLETTA'),
('9103', 'SKULSFJORD'),
('9106', 'STRAUMSBUKTA'),
('9107', 'TROMVIK'),
('9110', 'SOMMARØY'),
('9118', 'BRENSHOLMEN'),
('9119', 'SOMMARØY'),
('9120', 'VENGSØY'),
('9128', 'TUSSØY'),
('9130', 'HANSNES'),
('9131', 'KÅRVIK'),
('9132', 'STAKKVIK'),
('9134', 'HANSNES'),
('9135', 'VANNVÅG'),
('9136', 'VANNAREID'),
('9137', 'VANNVÅG'),
('9138', 'KARLSØY'),
('9140', 'REBBENES'),
('9141', 'MJØLVIK'),
('9142', 'SKIBOTN'),
('9143', 'SKIBOTN'),
('9144', 'SAMUELSBERG'),
('9146', 'OLDERDALEN'),
('9147', 'BIRTAVARRE'),
('9148', 'OLDERDALEN'),
('9151', 'STORSLETT'),
('9152', 'SØRKJOSEN'),
('9153', 'ROTSUND'),
('9156', 'STORSLETT'),
('9159', 'HAVNNES'),
('9161', 'BURFJORD'),
('9162', 'SØRSTRAUMEN'),
('9163', 'JØKELFJORD'),
('9164', 'KVÆNANGSFJELLET'),
('9169', 'BURFJORD'),
('9170', 'LONGYEARBYEN'),
('9171', 'LONGYEARBYEN'),
('9172', 'ISFJORD PÅ SVALBARD'),
('9173', 'NY-ÅLESUND'),
('9174', 'HOPEN'),
('9175', 'SVEAGRUVA'),
('9176', 'BJØRNØYA'),
('9177', 'HORNSUND'),
('9178', 'BARENTSBURG'),
('9179', 'PYRAMIDEN'),
('9180', 'SKJERVØY'),
('9181', 'HAMNEIDET'),
('9182', 'SEGLVIK'),
('9184', 'REINFJORD'),
('9185', 'SPILDRA'),
('9186', 'ANDSNES'),
('9189', 'SKJERVØY'),
('9190', 'AKKARVIK'),
('9192', 'ARNØYHAMN'),
('9193', 'NIKKEBY'),
('9194', 'LAUKSLETTA'),
('9195', 'ÅRVIKSAND'),
('9197', 'ULØYBUKT'),
('9251', 'TROMSØ'),
('9252', 'TROMSØ'),
('9253', 'TROMSØ'),
('9254', 'TROMSØ'),
('9255', 'TROMSØ'),
('9256', 'TROMSØ'),
('9257', 'TROMSØ'),
('9258', 'TROMSØ'),
('9259', 'TROMSØ'),
('9260', 'TROMSØ'),
('9261', 'TROMSØ'),
('9262', 'TROMSØ'),
('9263', 'TROMSØ'),
('9265', 'TROMSØ'),
('9266', 'TROMSØ'),
('9267', 'TROMSØ'),
('9268', 'TROMSØ'),
('9269', 'TROMSØ'),
('9270', 'TROMSØ'),
('9271', 'TROMSØ'),
('9272', 'TROMSØ'),
('9273', 'TROMSØ'),
('9274', 'TROMSØ'),
('9275', 'TROMSØ'),
('9276', 'TROMSØ'),
('9277', 'TROMSØ'),
('9278', 'TROMSØ'),
('9279', 'TROMSØ'),
('9280', 'TROMSØ'),
('9281', 'TROMSØ'),
('9282', 'TROMSØ'),
('9283', 'TROMSØ'),
('9284', 'TROMSØ'),
('9285', 'TROMSØ'),
('9286', 'TROMSØ'),
('9287', 'TROMSØ'),
('9288', 'TROMSØ'),
('9290', 'TROMSØ'),
('9291', 'TROMSØ'),
('9292', 'TROMSØ'),
('9293', 'TROMSØ'),
('9294', 'TROMSØ'),
('9295', 'TROMSØ'),
('9296', 'TROMSØ'),
('9297', 'TROMSØ'),
('9298', 'TROMSØ'),
('9299', 'TROMSØ'),
('9300', 'FINNSNES'),
('9302', 'ROSSFJORDSTRAUMEN'),
('9303', 'SILSAND'),
('9304', 'VANGSVIK'),
('9305', 'FINNSNES'),
('9306', 'FINNSNES'),
('9310', 'SØRREISA'),
('9311', 'BRØSTADBOTN'),
('9315', 'SØRREISA'),
('9316', 'BRØSTADBOTN'),
('9321', 'MOEN'),
('9322', 'KARLSTAD'),
('9325', 'BARDUFOSS'),
('9326', 'BARDUFOSS'),
('9327', 'BARDUFOSS'),
('9329', 'MOEN'),
('9334', 'ØVERBYGD'),
('9335', 'ØVERBYGD'),
('9336', 'RUNDHAUG'),
('9350', 'SJØVEGAN'),
('9355', 'SJØVEGAN'),
('9360', 'BARDU'),
('9365', 'BARDU'),
('9370', 'SILSAND'),
('9372', 'GIBOSTAD'),
('9373', 'BOTNHAMN'),
('9379', 'GRYLLEFJORD'),
('9380', 'GRYLLEFJORD'),
('9381', 'TORSKEN'),
('9382', 'GIBOSTAD'),
('9384', 'SKALAND'),
('9385', 'SKALAND'),
('9386', 'SENJAHOPEN'),
('9387', 'SENJAHOPEN'),
('9388', 'FJORDGARD'),
('9389', 'HUSØY I SENJA'),
('9391', 'STONGLANDSEIDET'),
('9392', 'STONGLANDSEIDET'),
('9393', 'FLAKSTADVÅG'),
('9395', 'KALDFARNES'),
('9402', 'HARSTAD'),
('9403', 'HARSTAD'),
('9404', 'HARSTAD'),
('9405', 'HARSTAD'),
('9406', 'HARSTAD'),
('9407', 'HARSTAD'),
('9408', 'HARSTAD'),
('9409', 'HARSTAD'),
('9411', 'HARSTAD'),
('9414', 'HARSTAD'),
('9415', 'HARSTAD'),
('9419', 'SØRVIK'),
('9420', 'LUNDENES'),
('9423', 'GRØTAVÆR'),
('9424', 'KJØTTA'),
('9425', 'SANDSØY'),
('9426', 'BJARKØY'),
('9427', 'MELØYVÆR'),
('9430', 'SANDTORG'),
('9436', 'KONGSVIK'),
('9439', 'EVENSKJER'),
('9440', 'EVENSKJER'),
('9441', 'FJELLDAL'),
('9442', 'RAMSUND'),
('9443', 'MYKLEBOSTAD'),
('9444', 'HOL I TJELDSUND'),
('9445', 'TOVIK'),
('9446', 'GROVFJORD'),
('9447', 'GROVFJORD'),
('9448', 'RAMSUND'),
('9450', 'HAMNVIK'),
('9451', 'HAMNVIK'),
('9453', 'KRÅKRØHAMN'),
('9454', 'ÅNSTAD'),
('9455', 'ENGENES'),
('9465', 'TENNEVOLL'),
('9466', 'TENNEVOLL'),
('9470', 'GRATANGEN'),
('9471', 'GRATANGEN'),
('9475', 'BORKENES'),
('9476', 'BORKENES'),
('9477', 'HARSTAD'),
('9478', 'HARSTAD'),
('9479', 'HARSTAD'),
('9480', 'HARSTAD'),
('9481', 'HARSTAD'),
('9482', 'HARSTAD'),
('9483', 'HARSTAD'),
('9484', 'HARSTAD'),
('9485', 'HARSTAD'),
('9486', 'HARSTAD'),
('9487', 'HARSTAD'),
('9488', 'HARSTAD'),
('9489', 'HARSTAD'),
('9490', 'HARSTAD'),
('9491', 'HARSTAD'),
('9496', 'HARSTAD'),
('9497', 'HARSTAD'),
('9498', 'HARSTAD'),
('9499', 'HARSTAD'),
('9501', 'ALTA'),
('9502', 'ALTA'),
('9503', 'ALTA'),
('9504', 'ALTA'),
('9505', 'ALTA'),
('9506', 'ALTA'),
('9507', 'ALTA'),
('9508', 'ALTA'),
('9509', 'ALTA'),
('9510', 'ALTA'),
('9511', 'ALTA'),
('9512', 'ALTA'),
('9513', 'ALTA'),
('9514', 'ALTA'),
('9515', 'ALTA'),
('9516', 'ALTA'),
('9517', 'ALTA'),
('9518', 'ALTA'),
('9519', 'KVIBY'),
('9520', 'KAUTOKEINO'),
('9521', 'KAUTOKEINO'),
('9525', 'MAZE'),
('9526', 'SUOLOVUOPMI'),
('9531', 'KVALFJORD'),
('9532', 'HAKKSTABBEN'),
('9533', 'KONGSHUS'),
('9536', 'KORSFJORDEN'),
('9540', 'TALVIK'),
('9545', 'LANGFJORDBOTN'),
('9550', 'ØKSFJORD'),
('9551', 'ØKSFJORD'),
('9580', 'BERGSFJORD'),
('9582', 'NUVSVÅG'),
('9583', 'LANGFJORDHAMN'),
('9584', 'SØR-TVERRFJORD'),
('9585', 'SANDLAND'),
('9586', 'LOPPA'),
('9587', 'SKAVNAKK'),
('9590', 'HASVIK'),
('9593', 'BREIVIKBOTN'),
('9595', 'SØRVÆR'),
('9600', 'HAMMERFEST'),
('9609', 'HØNSEBY'),
('9610', 'RYPEFJORD'),
('9613', 'HAMMERFEST'),
('9615', 'HAMMERFEST'),
('9616', 'HAMMERFEST'),
('9620', 'KVALSUND'),
('9621', 'KVALSUND'),
('9624', 'REVSNESHAMN'),
('9650', 'AKKARFJORD'),
('9653', 'HELLEFJORD'),
('9657', 'KÅRHAMN'),
('9663', 'SKARVFJORDHAMN'),
('9664', 'SANDØYBOTN'),
('9670', 'TUFJORD'),
('9672', 'INGØY'),
('9690', 'HAVØYSUND'),
('9691', 'HAVØYSUND'),
('9692', 'MÅSØY'),
('9700', 'LAKSELV'),
('9709', 'PORSANGMOEN'),
('9710', 'INDRE BILLEFJORD'),
('9711', 'LAKSELV'),
('9712', 'LAKSELV'),
('9713', 'RUSSENES'),
('9714', 'SNEFJORD'),
('9715', 'KOKELV'),
('9716', 'BØRSELV'),
('9717', 'VEIDNESKLUBBEN'),
('9722', 'SKOGANVARRE'),
('9730', 'KARASJOK'),
('9735', 'KARASJOK'),
('9740', 'LEBESBY'),
('9742', 'KUNES'),
('9750', 'HONNINGSVÅG'),
('9751', 'HONNINGSVÅG'),
('9755', 'HONNINGSVÅG'),
('9760', 'NORDVÅGEN'),
('9763', 'SKARSVÅG'),
('9764', 'NORDKAPP'),
('9765', 'GJESVÆR'),
('9768', 'REPVÅG'),
('9770', 'MEHAMN'),
('9771', 'SKJÅNES'),
('9772', 'LANGFJORDNES'),
('9773', 'NERVEI'),
('9775', 'GAMVIK'),
('9782', 'DYFJORD'),
('9783', 'NORDMANNSET I LAKSEFJORD'),
('9790', 'KJØLLEFJORD'),
('9800', 'VADSØ'),
('9802', 'VESTRE JAKOBSELV'),
('9810', 'VESTRE JAKOBSELV'),
('9811', 'VADSØ'),
('9815', 'VADSØ'),
('9820', 'VARANGERBOTN'),
('9826', 'SIRMA'),
('9840', 'VARANGERBOTN'),
('9845', 'TANA'),
('9846', 'TANA'),
('9900', 'KIRKENES'),
('9910', 'BJØRNEVATN'),
('9912', 'HESSENG'),
('9914', 'BJØRNEVATN'),
('9915', 'KIRKENES'),
('9916', 'HESSENG'),
('9917', 'KIRKENES'),
('9925', 'SVANVIK'),
('9930', 'NEIDEN'),
('9934', 'BUGØYFJORD'),
('9935', 'BUGØYNES'),
('9950', 'VARDØ'),
('9951', 'VARDØ'),
('9952', 'VARDØ'),
('9960', 'KIBERG'),
('9980', 'BERLEVÅG'),
('9981', 'BERLEVÅG'),
('9982', 'KONGSFJORD'),
('9990', 'BÅTSFJORD'),
('9991', 'BÅTSFJORD');



--
-- Dataark for tabell Kategori
--

INSERT INTO Kategori VALUES
(1, 'Hageutstyr'),
(2, 'Hobbymaling'),
(3, 'Keramikk'),
(4, 'Konfekt og marsipan'),
(5, 'Kurver og fletting'),
(6, 'Tekstil, søm og strikking'),
(7, 'Fiske'),
(8, 'Jakt'),
(9, 'Modellbygging'),
(10, 'Bøker'),
(11, 'Leker'),
(12, 'Hagemøbler'),
(13, 'Dukker og nisser'),
(14, 'Busker'),
(15, 'Blomsterfrø'),
(16, 'Blomsterløker'),
(17, 'Dekorasjoner'),
(18, 'Grønnsaksfrø'),
(19, 'Tresløyd'),
(20, 'Hobbypakker'),
(21, 'Gjødsel');



--
-- Dataark for tabell Vare
--

INSERT INTO Vare (VNr, Betegnelse, Pris, KatNr, Antall, Hylle) VALUES
('10820', 'Dukkehår, hvitt', 46.50, 13, 106, 'E12'),
('10822', 'Dukkehår, lys brunt', 46.50, 13, 0, 'E12'),
('10830', 'Nisseskjegg, 30 cm', 57.50, 13, 42, ''),
('10835', 'Trollhår, hvitt', 83.00, 13, 0, 'E12'),
('10854', 'Bomullsgarn, grått', 39.50, 6, 0, 'C07'),
('11630', 'Skinnsnor, natur', 46.50, 13, 0, 'E02'),
('12054', 'Hengebjørk', 358.50, 14, 0, 'D01'),
('12055', 'Røsslyng', 238.50, 14, 0, 'D01'),
('12056', 'Einer ''''Blåmann''''', 191.50, 14, 0, 'D01'),
('12088', 'Einer ''''Tyrihans''''', 215.00, 14, 0, 'D01'),
('12089', 'Gran, standard', 144.00, 14, 0, 'D01'),
('12090', 'Hvitgran', 192.00, 14, 0, 'D01'),
('12091', 'Sølvgran ''''Globosa''''', 286.50, 14, 0, 'D01'),
('12092', 'Europabarlind', 238.50, 14, 0, 'D01'),
('13001', 'Glasskuler, 100 gr', 38.00, 13, 0, 'E11'),
('15207', 'Antron garn, hvit', 24.50, 7, 21, 'B41'),
('15208', 'Antron garn, gul', 24.50, 7, 65, 'B41'),
('15211', 'Tubeflue verktøy', 209.00, 7, 39, 'B42'),
('15217', 'Kram tørrfluekorker, 5stk', 32.00, 7, 213, 'B42'),
('15559', 'Kakepapir, sølv', 38.00, 17, 0, 'B29'),
('20936', 'Fjær, natur', 25.00, 17, 0, 'B29'),
('20980', 'Naturfjær', 27.50, 17, 0, 'B25'),
('21032', 'Furuspon, 3 cm', 57.50, 17, 240, 'B32'),
('21034', 'Parasoll, 2.5 m, stål', 504.00, 12, 0, 'F03'),
('21037', 'Figurtråd, 50 m', 294.00, 17, 0, 'B36'),
('21510', 'Ispinner, 100 stk', 35.50, 17, 0, 'B36'),
('21514', 'Cocktailpinner, 100 st', 28.00, 17, 0, 'B36'),
('21515', 'Blomsterpinner, 5 stk', 27.00, 17, 0, 'B36'),
('21517', 'Tannpirkere, 100 stk', 16.00, 17, 0, 'B36'),
('21580', 'Sponflis, natur', 13.50, 17, 0, 'B36'),
('22002', 'Fyrstikker, 150gr', 55.50, 17, 460, 'C17'),
('22054', 'Vannkanne, 5 ltr.', 70.50, 1, 24, 'A27'),
('22055', 'Bensinkanne 5 ltr., grønn', 214.50, 1, 110, 'A27'),
('22056', 'Nettingbøtte, plast', 130.00, 1, 6, 'A27'),
('22165', 'Hafa gressklipper G8, bensin', 5400.00, 1, 16, 'A01'),
('22179', 'Hafa gresklipper G9, elektrisk', 1440.00, 1, 24, 'A01'),
('22870', 'Dukkeøyne, 7 mm blå', 21.00, 13, 252, 'E12'),
('25079', 'Trillebår', 334.00, 1, 46, 'A11'),
('25121', 'Hafa elektrisk hekksaks Z3', 418.50, 1, 110, 'A12'),
('25131', 'Juwa Motorsag XY65', 1078.00, 1, 42, 'A29'),
('25136', 'Juwa Anleggspade', 180.00, 1, 6, 'A30'),
('25137', 'Juwa Snøskuffe, standard', 228.00, 1, 30, 'A04'),
('25138', 'Grensaks med sideskjær', 166.50, 1, 2, 'A21'),
('25154', 'Ljå', 276.00, 1, 4, 'A17'),
('32055', 'Juwa Barkespade', 130.50, 1, 0, 'A15'),
('32067', 'Juwa Hagerive, 14 rette tinder', 94.50, 1, 440, 'A14'),
('32069', 'Stikkspade', 154.00, 1, 26, 'A12'),
('32191', 'Formgummi 0.5 l', 402.00, 3, 88, 'B04'),
('32610', 'Gipsform lysestaker', 106.50, 3, 58, 'B02'),
('33044', 'Blandet blomsterfrø', 14.50, 15, 1080, 'E05'),
('33045', 'Blomkarse', 17.50, 15, 1206, 'E05'),
('33046', 'Brudeslør', 15.00, 15, 640, 'E05'),
('33047', 'Rød pelargonium', 16.00, 15, 240, 'E05'),
('35911', 'Meksikansk solsikke', 11.50, 15, 46, 'E05'),
('35912', 'Stemorsblomst', 11.50, 15, 0, 'E05'),
('37710', 'Balkongtomat', 35.00, 18, 0, 'E24'),
('37720', 'Bifftomat', 42.00, 18, 88, 'E24'),
('37725', 'Gul pottetomat', 36.00, 18, 24, 'E24'),
('37730', 'Slangeagurk', 23.50, 18, 52, 'E24'),
('37731', 'Sylteagurk', 30.00, 18, 402, 'E24'),
('37732', 'Rødløk', 27.00, 18, 0, 'E25'),
('41020', 'Hobbyleire terrakotta, 1 kg', 94.50, 3, 58, 'B02'),
('41096', 'Blåleire, 10kg', 115.00, 3, 460, 'B02'),
('41097', 'Rød leire, 10kg', 142.50, 3, 580, 'B02'),
('41098', 'Keramisk leire', 83.00, 3, 834, 'B02'),
('42613', 'Gipsform klovner', 106.00, 3, 210, 'B02'),
('42615', 'Gipsform marihøner', 106.00, 3, 124, 'B03'),
('42626', 'Gipsform fisker m.m.', 141.50, 3, 62, 'B03'),
('42929', 'Pepperkakeformer', 83.00, 4, 38, 'B09'),
('42933', 'Former til leire, stjerner', 69.50, 3, 78, 'B04'),
('42934', 'Former til leire, hjerter', 69.50, 3, 204, 'B04'),
('42939', 'Pepperkakeformer, 15stk', 95.00, 4, 640, 'B09'),
('42941', 'Julesett', 71.00, 17, 1040, 'B29'),
('42945', 'Metallform praliner, 9stk', 81.50, 4, 24, 'B04'),
('43000', 'Startsett papir', 540.00, 17, 134, 'B25'),
('43014', 'Treramme A4', 372.00, 17, 24, 'B25'),
('43015', 'Treramme A5', 288.00, 17, 0, 'B32'),
('44939', 'Hobbymaling, 6 farger', 115.00, 2, 2, 'B02'),
('45101', 'Papirleire, 450 gr', 57.00, 3, 80, 'B04'),
('45105', 'Pappmachepulver', 45.00, 3, 162, 'B04'),
('45923', 'Krukke med føtter, 12cm', 42.00, 17, 604, 'B32'),
('45935', 'Potteskål, diameter 10cm', 19.50, 17, 258, 'B30'),
('46702', 'Terrakottafigur katt', 71.50, 17, 138, 'B30'),
('46706', 'Sparegris terrakotta', 27.50, 17, 176, 'B30'),
('46738', 'Terrakottafat med hjerter', 40.00, 17, 22, 'B31'),
('46741', 'Lyskrukke, 4cm', 10.00, 17, 118, 'B31'),
('46745', 'Terrakottakrukke 20x10cm', 43.50, 17, 24, 'B31'),
('47903', 'HaFa snøfreser Maxi', 11214.00, 1, 6, 'A04'),
('49916', 'Lezlo leire, brun, 150gr.', 25.00, 3, 24, 'B04'),
('49917', 'Lezlo leire, sort, 150 gr.', 25.50, 3, 184, 'B04'),
('49919', 'Lezlo leiresett', 58.50, 3, 42, 'B04'),
('49921', 'Lezlo leire, økonomipakke', 357.00, 3, 164, 'B04'),
('55112', 'HaFa løvblåser AX30', 598.50, 1, 22, 'A03'),
('55129', 'Lek med lakris', 154.00, 10, 64, 'C20'),
('55130', 'Moro med marsipan', 298.50, 10, 140, 'C20'),
('55550', 'Juwa jordfreser mx40', 1558.50, 1, 14, 'A03'),
('58028', 'Cernit dukkeleire lys', 142.50, 3, 44, 'B04'),
('59915', 'Juwa leire grønn, 150 gr.', 25.00, 3, 34, 'B04'),
('64509', 'Kongelilje, 10 stk.', 142.00, 16, 132, 'E03'),
('64510', 'Lilje mercedes, 10 stk.', 154.00, 16, 164, 'E03'),
('64511', 'Lilje sibir, 20 stk.', 227.50, 16, 278, 'E03'),
('64550', 'Småsymre, 10 stk.', 126.00, 16, 58, 'E03'),
('64551', 'Hengebegonia, 10 stk.', 118.00, 16, 206, ''),
('64552', 'Storblomstret begonia, 20 stk.', 276.00, 16, 42, 'E03'),
('65032', 'Hafa gressklipper skyv', 598.50, 1, 34, 'A01'),
('65033', 'Hafa Y15 gresstrimmer', 1044.00, 1, 80, 'A02'),
('65034', 'Hafa SX90 plentraktor', 15000.00, 1, 8, 'A05'),
('65060', 'Strandtennis', 46.50, 11, 94, 'C31'),
('65070', 'Boule', 118.50, 11, 100, 'C31'),
('65080', 'Barnetrillebår', 478.00, 11, 50, 'C31'),
('65081', 'Plantegreip', 112.00, 1, 34, 'A22'),
('65082', 'Kvistsag', 174.00, 1, 8, 'A25'),
('65122', 'Skjermvegg med gresspyd', 1558.00, 12, 0, 'F07'),
('65142', 'Gressaks, svingbar', 93.00, 1, 20, 'A21'),
('65143', 'Fruktplukker', 83.50, 1, 16, 'A13'),
('65147', 'Fluktstol, sammenleggbar', 238.50, 12, 46, 'F09'),
('65190', 'Hageslange, 20 m., grønn', 190.50, 1, 2, 'A28'),
('65191', 'Blomsterkasse', 23.00, 1, 26, 'A27'),
('65247', 'Liten plantespade', 75.00, 1, 76, 'A25'),
('71912', 'Eggemaler med maling', 35.00, 17, 182, 'C17'),
('72777', 'Julehobbypakke for barn', 154.00, 20, 820, 'A06'),
('72942', 'Plukksalat', 35.50, 18, 280, 'E21'),
('72943', 'Brekkbønner', 35.50, 18, 342, 'E21'),
('72944', 'Sukkererter', 42.00, 18, 478, 'A06'),
('76032', 'Kalk, granulert, 25 kg', 334.50, 21, 60, 'E20'),
('77033', 'Japanbarlind', 358.00, 14, 168, 'D01'),
('77036', 'Dvergtuja', 358.00, 14, 46, 'D01'),
('77038', 'Gul søyletuja', 478.00, 14, 8, 'D01'),
('77249', 'Hagebenk, furu', 1558.00, 12, 4, 'F01'),
('77251', 'Bord, 102 cm diameter', 658.00, 12, 68, 'F03'),
('77252', 'Stol, hvit plast', 34.50, 12, 36, 'F03'),
('77276', 'Sofagruppe, 2+3', 4558.00, 12, 14, 'F01'),
('77277', 'Parasoll, 2.5 meter, stål, kr', 358.00, 12, 18, 'F02'),
('78029', 'Cernit dukkeleire mørk', 142.50, 3, 82, 'B04'),
('80032', 'Arena høst, 25 kg', 154.50, 21, 114, 'E20'),
('80082', 'Aluminiumsulfat, 25 kg', 118.50, 21, 62, 'E20'),
('80088', 'Fullgjødsel, 40 kg', 213.00, 21, 452, 'E20'),
('80692', 'Rørespatel', 39.50, 4, 602, 'B17'),
('81007', 'Hobbyleire, hvit 500g', 62.50, 3, 112, 'B02'),
('82090', 'Matløk', 30.00, 18, 38, 'E25'),
('82092', 'Sommergulrot', 18.00, 18, 178, 'E25'),
('82093', 'Rund gulrot', 24.00, 18, 658, 'E25'),
('82095', 'Hodesalat', 23.50, 18, 500, 'E21'),
('82096', 'Issalat', 27.50, 18, 388, 'E21'),
('83013', 'Tilda maling teddybrun', 46.00, 2, 86, 'B01'),
('90106', 'Deigskrape av plast', 38.00, 4, 46, 'B04'),
('90109', 'Metallskrape', 40.50, 4, 38, 'B05'),
('90116', 'Smaksemne sjokolade 10ml', 50.00, 4, 164, 'B06'),
('90164', 'Lakrisekstrakt, 100g', 75.50, 4, 104, 'B06'),
('90192', 'Dropsform skjell', 70.50, 4, 176, 'B17'),
('90208', 'Form nisse', 71.00, 4, 70, 'B17'),
('90209', 'Form vingummi', 71.00, 4, 32, 'B17'),
('90212', 'Form skjell', 71.00, 4, 240, 'B17'),
('90510', 'Kakestativ', 430.50, 4, 60, 'B17'),
('90521', 'Kakemønstermaler', 142.50, 4, 38, 'B18'),
('90531', 'Kakekutter', 83.00, 4, 160, 'B18'),
('90545', 'Kakesprøyte sett', 288.00, 4, 46, 'B18'),
('90693', 'Marsipantang', 57.00, 4, 0, 'B17'),
('90737', 'Startsett lakris', 354.00, 4, 126, 'B09'),
('91008', 'Hobbyleire, hvit 1 kg', 94.00, 3, 20, 'B02'),
('92606', 'Gipsform nisser 6-14cm', 106.00, 13, 46, 'E11');



--
-- Dataark for tabell Prishistorikk
--

INSERT INTO Prishistorikk (VNr, Dato, GammelPris) VALUES
('10820', '2013-11-01', 40.50),
('10820', '2013-11-29', 40.50),
('10820', '2013-12-20', 44.50),
('10820', '2014-01-17', 45.50),
('10820', '2014-08-07', 41.50),
('10820', '2014-09-04', 44.50),
('10820', '2015-07-26', 43.50),
('10820', '2015-08-23', 46.50),
('10820', '2016-08-11', 44.50),
('10822', '2013-10-25', 44.00),
('10822', '2013-11-08', 45.50),
('10822', '2013-12-05', 41.50),
('10822', '2013-12-27', 40.50),
('10822', '2014-01-24', 43.50),
('10822', '2014-08-14', 46.50),
('10822', '2015-08-02', 44.50),
('10822', '2015-08-30', 44.50),
('10822', '2016-08-18', 42.50),
('10830', '2014-01-24', 53.50),
('10830', '2014-02-07', 56.50),
('10830', '2014-03-26', 51.50),
('10830', '2014-04-09', 54.50),
('10830', '2014-10-30', 54.50),
('10830', '2014-11-13', 57.50),
('10830', '2015-11-01', 55.50),
('10830', '2015-11-03', 53.50),
('10835', '2013-10-25', 80.00),
('10835', '2014-08-08', 83.00),
('10835', '2014-09-26', 79.00),
('10835', '2014-10-24', 81.00),
('10835', '2015-05-14', 77.00),
('10835', '2016-04-20', 78.00),
('10835', '2016-05-02', 82.00),
('10835', '2016-05-18', 80.00),
('10835', '2016-05-30', 82.00),
('10854', '2013-04-25', 38.50),
('10854', '2013-07-11', 38.50),
('10854', '2013-09-13', 36.50),
('10854', '2013-10-25', 38.50),
('10854', '2014-04-17', 39.50),
('10854', '2015-04-05', 37.50),
('10854', '2015-04-19', 37.50),
('10854', '2016-04-07', 35.50),
('10854', '2016-04-21', 35.50),
('11630', '2013-11-15', 42.50),
('11630', '2014-01-03', 40.50),
('11630', '2014-01-31', 40.50),
('11630', '2014-08-21', 43.50),
('11630', '2015-08-09', 41.50),
('11630', '2015-09-06', 44.50),
('11630', '2016-07-28', 43.50),
('11630', '2016-08-25', 46.50),
('12054', '2013-10-25', 344.50),
('12054', '2016-04-08', 357.50),
('12054', '2016-04-10', 355.50),
('12054', '2016-04-13', 352.50),
('12054', '2016-04-15', 357.50),
('12054', '2016-07-07', 358.50),
('12054', '2016-07-14', 358.50),
('12054', '2016-09-09', 356.50),
('12054', '2016-09-16', 356.50),
('12055', '2015-10-10', 234.50),
('12055', '2015-10-15', 236.50),
('12055', '2015-10-20', 238.50),
('12055', '2016-01-07', 237.50),
('12055', '2016-01-28', 237.50),
('12055', '2016-03-02', 235.50),
('12055', '2016-03-23', 235.50),
('12055', '2016-09-29', 236.50),
('12056', '2013-12-20', 183.00),
('12056', '2015-10-01', 188.50),
('12056', '2015-10-08', 188.50),
('12056', '2015-12-03', 186.50),
('12056', '2015-12-10', 186.50),
('12056', '2016-07-02', 187.50),
('12056', '2016-07-04', 185.50),
('12056', '2016-07-07', 189.50),
('12056', '2016-07-09', 187.50),
('12088', '2013-10-25', 206.50),
('12088', '2015-11-26', 211.00),
('12088', '2015-12-02', 214.00),
('12088', '2016-01-28', 209.00),
('12088', '2016-02-04', 212.00),
('12088', '2016-08-27', 210.00),
('12088', '2016-08-29', 215.00),
('12088', '2016-09-01', 215.00),
('12088', '2016-09-03', 213.00),
('12089', '2013-10-25', 138.50),
('12089', '2015-06-11', 140.00),
('12089', '2015-06-18', 140.00),
('12089', '2015-08-13', 138.00),
('12089', '2015-08-20', 138.00),
('12089', '2016-03-12', 139.00),
('12089', '2016-03-14', 144.00),
('12089', '2016-03-17', 141.00),
('12089', '2016-03-19', 139.00),
('12090', '2013-12-20', 184.00),
('12090', '2015-10-15', 190.00),
('12090', '2015-10-22', 190.00),
('12090', '2015-12-17', 188.00),
('12090', '2016-07-11', 187.00),
('12090', '2016-07-14', 191.00),
('12090', '2016-07-16', 189.00),
('12090', '2016-07-18', 187.00),
('12090', '2016-07-21', 191.00),
('12091', '2015-11-24', 281.50),
('12091', '2015-11-26', 286.50),
('12091', '2015-11-28', 284.50),
('12091', '2015-12-01', 283.50),
('12091', '2015-12-03', 281.50),
('12091', '2016-02-25', 280.50),
('12091', '2016-03-02', 282.50),
('12091', '2016-04-27', 285.50),
('12092', '2013-12-20', 229.00),
('12092', '2015-10-03', 232.50),
('12092', '2015-10-08', 234.50),
('12092', '2015-10-13', 236.50),
('12092', '2015-10-24', 232.50),
('12092', '2015-10-29', 234.50),
('12092', '2015-12-30', 233.50),
('12092', '2016-01-21', 235.50),
('12092', '2016-03-16', 233.50),
('13001', '2013-06-07', 36.00),
('13001', '2013-06-28', 36.00),
('13001', '2013-08-02', 34.00),
('13001', '2013-08-23', 34.00),
('13001', '2013-10-25', 29.50),
('13001', '2013-12-20', 36.00),
('13001', '2014-01-10', 38.50),
('13001', '2014-03-20', 37.00),
('13001', '2015-03-15', 35.00),
('13001', '2016-03-10', 33.00),
('13001', '2016-03-31', 33.00),
('15207', '2012-10-05', 23.50),
('15207', '2012-10-19', 23.50),
('15207', '2012-12-07', 21.50),
('15207', '2013-07-11', 24.50),
('15207', '2014-06-29', 20.50),
('15207', '2014-07-13', 22.50),
('15207', '2015-07-01', 20.50),
('15207', '2015-07-15', 20.50),
('15208', '2012-10-12', 22.50),
('15208', '2012-11-30', 18.50),
('15208', '2012-12-14', 20.50),
('15208', '2013-07-04', 23.50),
('15208', '2013-07-18', 23.50),
('15208', '2014-07-06', 21.50),
('15208', '2014-07-20', 21.50),
('15208', '2015-07-08', 19.50),
('15211', '2015-10-29', 208.00),
('15211', '2015-12-24', 206.00),
('15211', '2015-12-31', 206.00),
('15211', '2016-07-23', 207.00),
('15211', '2016-07-25', 205.00),
('15211', '2016-07-28', 209.00),
('15211', '2016-07-30', 207.00),
('15211', '2016-08-01', 208.00),
('15217', '2013-03-06', 27.00),
('15217', '2013-03-13', 27.00),
('15217', '2013-05-08', 32.00),
('15217', '2013-12-05', 28.00),
('15217', '2013-12-12', 28.00),
('15217', '2014-12-07', 26.00),
('15217', '2015-12-02', 31.00),
('15217', '2015-12-09', 31.00),
('15559', '2013-06-21', 33.00),
('15559', '2013-08-16', 38.00),
('15559', '2013-10-25', 36.00),
('15559', '2014-03-13', 34.00),
('15559', '2014-04-03', 37.00),
('15559', '2015-03-08', 32.00),
('15559', '2015-03-29', 32.00),
('15559', '2016-03-03', 37.00),
('15559', '2016-03-24', 37.00),
('20936', '2012-10-26', 21.00),
('20936', '2012-11-16', 24.00),
('20936', '2012-12-21', 19.00),
('20936', '2013-01-11', 22.00),
('20936', '2013-08-08', 25.00),
('20936', '2014-08-03', 23.00),
('20936', '2015-07-29', 25.00),
('20936', '2015-08-19', 21.00),
('20980', '2012-12-27', 27.50),
('20980', '2013-01-18', 22.50),
('20980', '2013-03-13', 27.50),
('20980', '2013-10-10', 23.50),
('20980', '2013-10-25', 26.00),
('20980', '2014-10-05', 21.50),
('20980', '2014-10-26', 21.50),
('20980', '2015-09-30', 24.50),
('20980', '2015-10-21', 26.50),
('21032', '2014-01-31', 57.50),
('21032', '2014-02-14', 53.50),
('21032', '2014-04-02', 51.50),
('21032', '2014-11-06', 54.50),
('21032', '2015-10-25', 56.50),
('21032', '2015-10-27', 54.50),
('21032', '2015-11-08', 52.50),
('21032', '2015-11-10', 57.50),
('21034', '2013-10-25', 483.50),
('21034', '2015-11-25', 501.00),
('21034', '2015-12-02', 503.00),
('21034', '2016-06-24', 502.00),
('21034', '2016-06-26', 500.00),
('21034', '2016-06-29', 504.00),
('21034', '2016-07-01', 504.00),
('21034', '2016-07-03', 502.00),
('21034', '2016-09-30', 503.00),
('21037', '2015-12-26', 294.00),
('21037', '2015-12-29', 291.00),
('21037', '2015-12-31', 289.00),
('21037', '2016-01-02', 290.00),
('21037', '2016-01-05', 294.00),
('21037', '2016-03-30', 290.00),
('21037', '2016-04-06', 293.00),
('21037', '2016-06-01', 291.00),
('21510', '2013-04-17', 33.50),
('21510', '2013-05-07', 29.50),
('21510', '2013-07-02', 34.50),
('21510', '2013-10-25', 33.50),
('21510', '2014-01-30', 34.50),
('21510', '2015-01-25', 32.50),
('21510', '2015-02-15', 35.50),
('21510', '2016-01-20', 30.50),
('21510', '2016-02-10', 33.50),
('21514', '2013-02-01', 24.00),
('21514', '2013-02-08', 24.00),
('21514', '2013-04-03', 22.00),
('21514', '2013-10-31', 22.00),
('21514', '2013-11-07', 25.00),
('21514', '2014-11-02', 23.00),
('21514', '2014-11-09', 23.00),
('21514', '2015-11-04', 28.00),
('21515', '2012-12-13', 24.00),
('21515', '2013-02-15', 22.00),
('21515', '2013-09-05', 25.00),
('21515', '2013-09-19', 25.00),
('21515', '2014-09-07', 23.00),
('21515', '2014-09-21', 23.00),
('21515', '2015-09-09', 21.00),
('21515', '2015-09-23', 21.00),
('21517', '2012-06-15', 16.00),
('21517', '2012-06-29', 16.00),
('21517', '2012-08-17', 14.00),
('21517', '2013-03-21', 10.00),
('21517', '2013-10-25', 16.00),
('21517', '2014-03-09', 15.00),
('21517', '2014-03-23', 15.00),
('21517', '2015-03-11', 13.00),
('21517', '2015-03-25', 13.00),
('21580', '2012-05-08', 13.50),
('21580', '2012-07-03', 11.50),
('21580', '2012-07-10', 11.50),
('21580', '2013-02-07', 7.50),
('21580', '2013-02-14', 7.50),
('21580', '2013-10-25', 13.00),
('21580', '2014-02-09', 12.50),
('21580', '2015-02-04', 10.50),
('21580', '2015-02-11', 10.50),
('22002', '2013-10-25', 52.50),
('22002', '2013-12-26', 49.50),
('22002', '2014-02-21', 54.50),
('22002', '2014-02-28', 54.50),
('22002', '2014-09-25', 50.50),
('22002', '2015-09-20', 55.50),
('22002', '2015-09-27', 55.50),
('22002', '2016-09-22', 53.50),
('22002', '2016-09-29', 53.50),
('22054', '2013-10-25', 67.50),
('22054', '2014-04-02', 64.50),
('22054', '2014-04-16', 64.50),
('22054', '2014-06-04', 69.50),
('22054', '2014-06-18', 69.50),
('22054', '2015-01-08', 65.50),
('22054', '2015-12-29', 65.50),
('22054', '2016-01-10', 70.50),
('22054', '2016-01-12', 68.50),
('22055', '2015-11-19', 211.50),
('22055', '2016-01-14', 209.50),
('22055', '2016-01-21', 209.50),
('22055', '2016-08-15', 208.50),
('22055', '2016-08-18', 212.50),
('22055', '2016-08-20', 210.50),
('22055', '2016-08-22', 208.50),
('22055', '2016-08-25', 212.50),
('22056', '2013-10-25', 125.50),
('22056', '2015-03-18', 127.00),
('22056', '2015-05-13', 125.00),
('22056', '2015-05-20', 125.00),
('22056', '2015-12-12', 126.00),
('22056', '2015-12-14', 124.00),
('22056', '2015-12-17', 128.00),
('22056', '2015-12-19', 126.00),
('22056', '2015-12-21', 124.00),
('22165', '2012-08-10', 5394.00),
('22165', '2012-08-17', 5394.00),
('22165', '2012-10-12', 5399.00),
('22165', '2013-05-09', 5395.00),
('22165', '2013-05-16', 5395.00),
('22165', '2013-12-20', 5184.00),
('22165', '2014-05-11', 5400.00),
('22165', '2014-05-18', 5400.00),
('22165', '2015-05-13', 5398.00),
('22179', '2012-06-15', 1436.00),
('22179', '2012-06-22', 1436.00),
('22179', '2012-08-17', 1434.00),
('22179', '2013-03-14', 1437.00),
('22179', '2013-03-21', 1437.00),
('22179', '2013-12-20', 1382.00),
('22179', '2014-03-16', 1435.00),
('22179', '2014-03-23', 1435.00),
('22179', '2015-03-18', 1440.00),
('22870', '2012-08-10', 17.00),
('22870', '2012-10-05', 15.00),
('22870', '2012-10-12', 15.00),
('22870', '2013-05-09', 18.00),
('22870', '2013-12-20', 20.00),
('22870', '2014-05-04', 16.00),
('22870', '2014-05-11', 16.00),
('22870', '2015-05-06', 21.00),
('22870', '2015-05-13', 21.00),
('25079', '2013-10-25', 321.00),
('25079', '2016-01-19', 331.00),
('25079', '2016-01-21', 329.00),
('25079', '2016-01-23', 334.00),
('25079', '2016-01-26', 331.00),
('25079', '2016-01-28', 329.00),
('25079', '2016-04-20', 330.00),
('25079', '2016-04-27', 330.00),
('25079', '2016-06-22', 328.00),
('25121', '2013-10-25', 402.00),
('25121', '2015-10-14', 413.50),
('25121', '2016-05-11', 416.50),
('25121', '2016-05-13', 414.50),
('25121', '2016-05-15', 412.50),
('25121', '2016-05-18', 416.50),
('25121', '2016-05-20', 414.50),
('25121', '2016-08-12', 415.50),
('25121', '2016-08-19', 415.50),
('25131', '2012-06-08', 1076.00),
('25131', '2012-08-03', 1074.00),
('25131', '2012-08-10', 1074.00),
('25131', '2013-03-07', 1077.00),
('25131', '2013-10-25', 1035.50),
('25131', '2014-03-02', 1075.00),
('25131', '2014-03-09', 1075.00),
('25131', '2015-03-04', 1073.00),
('25131', '2015-03-11', 1073.00),
('25136', '2013-10-25', 172.50),
('25136', '2015-09-10', 178.00),
('25136', '2015-09-17', 178.00),
('25136', '2015-11-12', 176.00),
('25136', '2016-06-09', 179.00),
('25136', '2016-06-11', 177.00),
('25136', '2016-06-13', 175.00),
('25136', '2016-06-16', 179.00),
('25136', '2016-06-18', 177.00),
('25137', '2013-10-25', 218.50),
('25137', '2015-12-23', 226.00),
('25137', '2016-02-18', 224.00),
('25137', '2016-02-25', 224.00),
('25137', '2016-09-17', 225.00),
('25137', '2016-09-19', 223.00),
('25137', '2016-09-22', 227.00),
('25137', '2016-09-24', 225.00),
('25137', '2016-09-26', 223.00),
('25138', '2013-10-25', 160.00),
('25138', '2015-08-20', 166.50),
('25138', '2015-08-27', 166.50),
('25138', '2015-10-22', 164.50),
('25138', '2016-05-16', 163.50),
('25138', '2016-05-19', 160.50),
('25138', '2016-05-21', 165.50),
('25138', '2016-05-23', 163.50),
('25138', '2016-05-26', 160.50),
('25154', '2013-10-25', 264.50),
('25154', '2015-10-31', 270.00),
('25154', '2015-11-10', 270.00),
('25154', '2015-11-12', 275.00),
('25154', '2015-11-14', 273.00),
('25154', '2016-02-04', 276.00),
('25154', '2016-02-18', 276.00),
('25154', '2016-04-06', 274.00),
('25154', '2016-04-20', 274.00),
('32055', '2013-10-25', 125.50),
('32055', '2015-03-25', 124.50),
('32055', '2015-04-01', 127.50),
('32055', '2015-05-27', 129.50),
('32055', '2015-12-24', 125.50),
('32055', '2015-12-26', 130.50),
('32055', '2015-12-28', 128.50),
('32055', '2015-12-31', 125.50),
('32055', '2016-01-02', 126.50),
('32067', '2013-12-20', 91.00),
('32067', '2014-10-17', 91.50),
('32067', '2014-12-19', 89.50),
('32067', '2015-07-09', 92.50),
('32067', '2015-07-23', 92.50),
('32067', '2016-07-11', 90.50),
('32067', '2016-07-13', 88.50),
('32067', '2016-07-25', 90.50),
('32067', '2016-07-27', 88.50),
('32069', '2013-10-25', 148.50),
('32069', '2015-07-08', 151.00),
('32069', '2015-08-27', 153.00),
('32069', '2015-09-24', 149.00),
('32069', '2016-03-21', 152.00),
('32069', '2016-04-02', 150.00),
('32069', '2016-04-14', 152.00),
('32069', '2016-04-18', 148.00),
('32069', '2016-04-30', 150.00),
('32191', '2013-10-25', 385.50),
('32191', '2015-10-07', 397.00),
('32191', '2016-04-29', 396.00),
('32191', '2016-05-01', 396.00),
('32191', '2016-05-04', 400.00),
('32191', '2016-05-06', 398.00),
('32191', '2016-05-08', 396.00),
('32191', '2016-08-05', 399.00),
('32191', '2016-09-30', 402.00),
('32610', '2013-10-25', 102.50),
('32610', '2014-12-18', 105.50),
('32610', '2015-02-13', 103.50),
('32610', '2015-02-20', 103.50),
('32610', '2015-09-17', 106.50),
('32610', '2015-09-24', 106.50),
('32610', '2016-09-14', 102.50),
('32610', '2016-09-19', 104.50),
('32610', '2016-09-21', 102.50),
('33044', '2012-05-15', 9.50),
('33044', '2012-05-22', 9.50),
('33044', '2012-07-17', 14.50),
('33044', '2012-07-24', 14.50),
('33044', '2013-02-21', 10.50),
('33044', '2014-02-16', 8.50),
('33044', '2014-02-23', 8.50),
('33044', '2015-02-18', 13.50),
('33045', '2012-07-05', 14.50),
('33045', '2012-08-31', 16.50),
('33045', '2012-09-07', 12.50),
('33045', '2013-04-04', 15.50),
('33045', '2013-04-11', 15.50),
('33045', '2014-04-06', 13.50),
('33045', '2015-04-01', 11.50),
('33045', '2015-04-08', 11.50),
('33046', '2012-06-01', 15.00),
('33046', '2012-06-08', 15.00),
('33046', '2012-08-03', 13.00),
('33046', '2013-02-28', 9.00),
('33046', '2013-03-07', 9.00),
('33046', '2014-03-02', 14.00),
('33046', '2015-02-25', 12.00),
('33046', '2015-03-04', 12.00),
('33047', '2012-06-22', 15.00),
('33047', '2012-08-10', 13.00),
('33047', '2012-08-24', 13.00),
('33047', '2013-03-14', 16.00),
('33047', '2013-03-28', 16.00),
('33047', '2014-03-16', 14.00),
('33047', '2014-03-30', 14.00),
('33047', '2015-03-18', 12.00),
('35911', '2012-04-18', 6.50),
('35911', '2012-05-01', 9.50),
('35911', '2012-06-20', 11.50),
('35911', '2013-01-24', 7.50),
('35911', '2014-01-12', 5.50),
('35911', '2014-01-26', 5.50),
('35911', '2015-01-14', 10.50),
('35911', '2015-01-28', 10.50),
('35912', '2012-04-25', 5.50),
('35912', '2012-06-13', 10.50),
('35912', '2012-06-27', 10.50),
('35912', '2013-01-17', 6.50),
('35912', '2013-01-31', 6.50),
('35912', '2014-01-19', 11.50),
('35912', '2014-02-02', 7.50),
('35912', '2015-01-21', 9.50),
('37710', '2013-04-03', 31.00),
('37710', '2013-06-05', 29.00),
('37710', '2013-12-26', 29.00),
('37710', '2014-01-09', 32.00),
('37710', '2014-12-28', 34.00),
('37710', '2015-01-11', 30.00),
('37710', '2015-12-30', 32.00),
('37710', '2016-01-13', 35.00),
('37720', '2013-09-06', 39.00),
('37720', '2013-11-01', 37.00),
('37720', '2014-05-29', 37.00),
('37720', '2014-06-19', 40.00),
('37720', '2015-05-24', 42.00),
('37720', '2015-06-14', 38.00),
('37720', '2016-05-19', 40.00),
('37720', '2016-06-09', 36.00),
('37725', '2013-05-21', 34.00),
('37725', '2013-05-28', 34.00),
('37725', '2013-07-23', 32.00),
('37725', '2014-02-20', 35.00),
('37725', '2014-02-27', 35.00),
('37725', '2015-02-22', 33.00),
('37725', '2015-03-01', 33.00),
('37725', '2016-02-24', 31.00),
('37730', '2012-09-07', 23.50),
('37730', '2012-10-26', 18.50),
('37730', '2012-11-09', 21.50),
('37730', '2013-05-30', 21.50),
('37730', '2013-06-13', 17.50),
('37730', '2014-06-01', 22.50),
('37730', '2014-06-15', 22.50),
('37730', '2015-06-03', 20.50),
('37731', '2013-02-22', 28.00),
('37731', '2013-04-10', 26.00),
('37731', '2013-04-24', 26.00),
('37731', '2013-11-14', 29.00),
('37731', '2013-11-28', 29.00),
('37731', '2014-11-16', 27.00),
('37731', '2014-11-30', 27.00),
('37731', '2015-11-18', 25.00),
('37732', '2012-12-06', 26.00),
('37732', '2012-12-20', 26.00),
('37732', '2013-02-08', 24.00),
('37732', '2013-02-22', 24.00),
('37732', '2013-09-12', 27.00),
('37732', '2013-09-26', 27.00),
('37732', '2014-09-14', 25.00),
('37732', '2015-09-16', 23.00),
('41020', '2014-10-10', 91.50),
('41020', '2014-10-24', 91.50),
('41020', '2014-12-12', 89.50),
('41020', '2014-12-26', 89.50),
('41020', '2015-07-16', 92.50),
('41020', '2015-07-30', 92.50),
('41020', '2016-07-18', 90.50),
('41020', '2016-07-20', 88.50),
('41096', '2013-10-25', 110.50),
('41096', '2015-01-09', 114.00),
('41096', '2015-01-23', 114.00),
('41096', '2015-03-11', 112.00),
('41096', '2015-03-25', 112.00),
('41096', '2015-10-05', 111.00),
('41096', '2015-10-15', 115.00),
('41096', '2015-10-17', 113.00),
('41096', '2015-10-19', 111.00),
('41097', '2013-10-25', 137.00),
('41097', '2015-05-12', 137.50),
('41097', '2015-06-30', 139.50),
('41097', '2015-07-28', 142.50),
('41097', '2016-01-25', 138.50),
('41097', '2016-02-06', 136.50),
('41097', '2016-02-18', 138.50),
('41097', '2016-02-22', 141.50),
('41097', '2016-03-05', 137.50),
('41098', '2013-10-25', 80.00),
('41098', '2014-08-15', 81.00),
('41098', '2014-10-03', 79.00),
('41098', '2014-10-31', 79.00),
('41098', '2015-04-23', 80.00),
('41098', '2015-05-21', 82.00),
('41098', '2016-04-27', 83.00),
('41098', '2016-05-09', 80.00),
('41098', '2016-05-25', 78.00),
('42613', '2013-10-25', 102.50),
('42613', '2014-11-28', 102.00),
('42613', '2015-01-23', 100.00),
('42613', '2015-08-20', 103.00),
('42613', '2015-09-10', 106.00),
('42613', '2016-08-10', 106.00),
('42613', '2016-08-15', 101.00),
('42613', '2016-08-31', 106.00),
('42613', '2016-09-05', 104.00),
('42615', '2013-10-25', 102.50),
('42615', '2014-11-21', 100.00),
('42615', '2014-12-11', 103.00),
('42615', '2015-01-16', 105.00),
('42615', '2015-02-06', 101.00),
('42615', '2015-08-13', 101.00),
('42615', '2015-09-03', 104.00),
('42615', '2016-08-24', 104.00),
('42615', '2016-08-29', 106.00),
('42626', '2013-12-20', 135.50),
('42626', '2015-04-08', 137.50),
('42626', '2015-06-03', 135.50),
('42626', '2015-06-10', 135.50),
('42626', '2016-01-04', 141.50),
('42626', '2016-01-07', 138.50),
('42626', '2016-01-09', 136.50),
('42626', '2016-01-11', 141.50),
('42626', '2016-01-14', 138.50),
('42929', '2013-10-25', 80.00),
('42929', '2014-07-24', 82.00),
('42929', '2014-08-22', 77.00),
('42929', '2014-10-10', 82.00),
('42929', '2015-04-30', 83.00),
('42929', '2015-05-28', 78.00),
('42929', '2016-05-04', 81.00),
('42929', '2016-05-16', 83.00),
('42929', '2016-06-01', 77.00),
('42933', '2014-03-19', 69.50),
('42933', '2014-05-07', 67.50),
('42933', '2014-05-21', 67.50),
('42933', '2014-12-11', 63.50),
('42933', '2014-12-25', 63.50),
('42933', '2015-12-13', 68.50),
('42933', '2015-12-15', 66.50),
('42933', '2015-12-27', 68.50),
('42934', '2014-03-12', 68.50),
('42934', '2014-03-26', 68.50),
('42934', '2014-05-14', 66.50),
('42934', '2014-05-28', 66.50),
('42934', '2014-12-18', 69.50),
('42934', '2015-12-08', 65.50),
('42934', '2015-12-20', 67.50),
('42934', '2015-12-22', 65.50),
('42939', '2014-10-31', 91.00),
('42939', '2014-11-07', 94.00),
('42939', '2015-01-02', 92.00),
('42939', '2015-01-09', 92.00),
('42939', '2015-08-06', 95.00),
('42939', '2016-08-01', 93.00),
('42939', '2016-08-03', 91.00),
('42939', '2016-08-08', 93.00),
('42941', '2014-05-13', 69.00),
('42941', '2014-07-01', 67.00),
('42941', '2014-08-01', 67.00),
('42941', '2015-01-22', 67.00),
('42941', '2015-02-19', 70.00),
('42941', '2016-01-26', 70.00),
('42941', '2016-02-07', 68.00),
('42941', '2016-02-23', 66.00),
('42945', '2014-07-10', 78.50),
('42945', '2014-07-17', 78.50),
('42945', '2014-09-12', 76.50),
('42945', '2014-09-19', 76.50),
('42945', '2015-04-16', 79.50),
('42945', '2016-04-11', 77.50),
('42945', '2016-04-13', 75.50),
('42945', '2016-04-18', 77.50),
('43000', '2015-10-07', 534.00),
('43000', '2015-10-14', 534.00),
('43000', '2015-12-09', 539.00),
('43000', '2016-07-06', 535.00),
('43000', '2016-07-08', 540.00),
('43000', '2016-07-10', 538.00),
('43000', '2016-07-13', 535.00),
('43000', '2016-07-15', 540.00),
('43014', '2013-10-25', 357.00),
('43014', '2016-04-17', 370.00),
('43014', '2016-04-20', 367.00),
('43014', '2016-04-22', 372.00),
('43014', '2016-04-24', 370.00),
('43014', '2016-04-27', 367.00),
('43014', '2016-07-21', 366.00),
('43014', '2016-07-28', 366.00),
('43014', '2016-09-23', 371.00),
('43015', '2013-10-25', 276.00),
('43015', '2015-12-08', 287.00),
('43015', '2015-12-10', 285.00),
('43015', '2015-12-12', 283.00),
('43015', '2015-12-22', 287.00),
('43015', '2015-12-24', 285.00),
('43015', '2016-03-16', 286.00),
('43015', '2016-05-04', 284.00),
('43015', '2016-05-18', 284.00),
('44939', '2015-01-16', 114.00),
('44939', '2015-03-18', 112.00),
('44939', '2015-10-08', 115.00),
('44939', '2015-10-10', 113.00),
('44939', '2015-10-12', 111.00),
('44939', '2015-10-22', 115.00),
('44939', '2015-10-24', 113.00),
('44939', '2015-10-26', 111.00),
('45101', '2014-01-10', 54.00),
('45101', '2014-03-12', 52.00),
('45101', '2014-10-02', 55.00),
('45101', '2014-10-16', 55.00),
('45101', '2015-10-04', 53.00),
('45101', '2015-10-06', 51.00),
('45101', '2015-10-18', 53.00),
('45101', '2015-10-20', 51.00),
('45105', '2013-10-04', 44.00),
('45105', '2013-10-11', 44.00),
('45105', '2013-12-06', 42.00),
('45105', '2013-12-13', 42.00),
('45105', '2014-07-10', 45.00),
('45105', '2015-07-05', 43.00),
('45105', '2015-07-12', 43.00),
('45105', '2016-07-07', 41.00),
('45923', '2013-08-30', 37.00),
('45923', '2013-09-20', 40.00),
('45923', '2013-10-25', 42.00),
('45923', '2013-11-15', 38.00),
('45923', '2014-05-22', 38.00),
('45923', '2014-06-12', 41.00),
('45923', '2015-06-07', 39.00),
('45923', '2016-06-02', 37.00),
('45935', '2012-07-26', 13.50),
('45935', '2012-08-03', 15.50),
('45935', '2012-09-28', 18.50),
('45935', '2013-04-25', 14.50),
('45935', '2013-05-02', 16.50),
('45935', '2014-04-27', 19.50),
('45935', '2015-04-22', 17.50),
('45935', '2015-04-29', 17.50),
('46702', '2013-10-25', 68.50),
('46702', '2014-06-13', 67.50),
('46702', '2014-08-08', 65.50),
('46702', '2014-08-15', 65.50),
('46702', '2015-03-12', 68.50),
('46702', '2016-03-07', 66.50),
('46702', '2016-03-09', 71.50),
('46702', '2016-03-14', 66.50),
('46702', '2016-03-16', 71.50),
('46706', '2013-01-11', 21.50),
('46706', '2013-03-06', 26.50),
('46706', '2013-03-27', 26.50),
('46706', '2013-10-03', 22.50),
('46706', '2013-10-24', 22.50),
('46706', '2013-10-25', 26.00),
('46706', '2014-09-28', 25.50),
('46706', '2014-10-19', 27.50),
('46706', '2015-10-14', 25.50),
('46738', '2013-08-02', 39.00),
('46738', '2013-09-27', 35.00),
('46738', '2013-10-04', 37.00),
('46738', '2013-12-20', 39.00),
('46738', '2014-05-01', 40.00),
('46738', '2014-05-08', 40.00),
('46738', '2015-05-03', 38.00),
('46738', '2016-04-28', 34.00),
('46738', '2016-05-05', 36.00),
('46741', '2012-04-04', 4.00),
('46741', '2012-04-11', 4.00),
('46741', '2012-06-06', 9.00),
('46741', '2013-01-03', 5.00),
('46741', '2013-01-10', 5.00),
('46741', '2013-10-25', 10.00),
('46741', '2014-01-05', 10.00),
('46741', '2015-01-01', 7.00),
('46741', '2015-01-07', 8.00),
('46745', '2013-09-27', 38.50),
('46745', '2013-10-25', 41.50),
('46745', '2013-11-22', 43.50),
('46745', '2013-11-29', 43.50),
('46745', '2014-06-26', 39.50),
('46745', '2014-07-03', 41.50),
('46745', '2015-06-28', 37.50),
('46745', '2016-06-23', 42.50),
('46745', '2016-06-30', 42.50),
('47903', '2012-08-24', 11209.00),
('47903', '2012-10-19', 11214.00),
('47903', '2012-10-26', 11214.00),
('47903', '2013-05-23', 11210.00),
('47903', '2013-05-30', 11210.00),
('47903', '2013-10-25', 10765.00),
('47903', '2014-05-25', 11208.00),
('47903', '2015-05-20', 11213.00),
('47903', '2015-05-27', 11213.00),
('49916', '2012-11-09', 24.00),
('49916', '2013-01-04', 22.00),
('49916', '2013-08-01', 25.00),
('49916', '2013-08-22', 25.00),
('49916', '2013-10-25', 24.00),
('49916', '2014-07-27', 20.00),
('49916', '2014-08-17', 23.00),
('49916', '2015-07-22', 25.00),
('49916', '2015-08-12', 21.00),
('49917', '2012-11-30', 23.50),
('49917', '2013-01-25', 21.50),
('49917', '2013-02-01', 24.50),
('49917', '2013-08-29', 24.50),
('49917', '2013-10-25', 24.00),
('49917', '2014-08-24', 22.50),
('49917', '2014-08-31', 22.50),
('49917', '2015-08-26', 20.50),
('49917', '2015-09-02', 23.50),
('49919', '2014-02-21', 56.50),
('49919', '2014-04-16', 54.50),
('49919', '2014-04-23', 54.50),
('49919', '2014-11-20', 57.50),
('49919', '2015-11-15', 55.50),
('49919', '2015-11-17', 53.50),
('49919', '2015-11-22', 55.50),
('49919', '2015-11-24', 53.50),
('49921', '2016-02-20', 354.00),
('49921', '2016-02-23', 351.00),
('49921', '2016-02-25', 356.00),
('49921', '2016-02-27', 354.00),
('49921', '2016-03-02', 351.00),
('49921', '2016-05-24', 357.00),
('49921', '2016-06-03', 357.00),
('49921', '2016-07-26', 355.00),
('55112', '2014-02-02', 595.50),
('55112', '2015-02-04', 593.50),
('55112', '2015-10-28', 597.50),
('55112', '2015-12-16', 595.50),
('55112', '2015-12-30', 595.50),
('55112', '2016-07-20', 598.50),
('55112', '2016-07-22', 596.50),
('55112', '2016-07-24', 594.50),
('55129', '2013-10-25', 148.50),
('55129', '2015-07-15', 149.00),
('55129', '2015-09-03', 154.00),
('55129', '2015-10-01', 149.00),
('55129', '2016-03-24', 154.00),
('55129', '2016-03-28', 150.00),
('55129', '2016-04-09', 148.00),
('55129', '2016-04-21', 150.00),
('55129', '2016-04-25', 153.00),
('55130', '2013-10-25', 286.50),
('55130', '2016-01-07', 293.50),
('55130', '2016-01-09', 298.50),
('55130', '2016-01-12', 295.50),
('55130', '2016-01-14', 293.50),
('55130', '2016-01-16', 298.50),
('55130', '2016-04-13', 294.50),
('55130', '2016-06-08', 292.50),
('55130', '2016-06-15', 292.50),
('55550', '2012-07-19', 1555.50),
('55550', '2012-07-26', 1555.50),
('55550', '2012-09-21', 1553.50),
('55550', '2013-04-18', 1556.50),
('55550', '2013-04-25', 1556.50),
('55550', '2013-10-25', 1496.50),
('55550', '2014-04-20', 1554.50),
('55550', '2015-04-15', 1552.50),
('55550', '2015-04-22', 1552.50),
('58028', '2013-10-25', 137.50),
('58028', '2015-05-19', 139.50),
('58028', '2015-07-07', 137.50),
('58028', '2015-08-06', 138.50),
('58028', '2016-01-28', 137.50),
('58028', '2016-02-01', 136.50),
('58028', '2016-02-13', 138.50),
('58028', '2016-02-25', 140.50),
('58028', '2016-02-28', 136.50),
('59915', '2012-07-25', 19.00),
('59915', '2012-11-02', 21.00),
('59915', '2012-11-23', 21.00),
('59915', '2012-12-28', 23.00),
('59915', '2013-01-18', 19.00),
('59915', '2013-08-15', 22.00),
('59915', '2013-10-25', 24.00),
('59915', '2014-08-10', 20.00),
('59915', '2015-08-05', 25.00),
('64509', '2013-10-25', 137.00),
('64509', '2015-04-15', 137.00),
('64509', '2015-04-22', 137.00),
('64509', '2015-06-17', 142.00),
('64509', '2015-06-24', 142.00),
('64509', '2016-01-16', 136.00),
('64509', '2016-01-18', 141.00),
('64509', '2016-01-21', 138.00),
('64509', '2016-01-23', 136.00),
('64510', '2013-10-25', 148.50),
('64510', '2015-06-25', 152.00),
('64510', '2015-07-22', 148.00),
('64510', '2015-09-10', 153.00),
('64510', '2016-03-31', 153.00),
('64510', '2016-04-04', 152.00),
('64510', '2016-04-16', 154.00),
('64510', '2016-04-28', 149.00),
('64510', '2016-05-02', 154.00),
('64511', '2013-10-25', 218.00),
('64511', '2015-12-09', 226.50),
('64511', '2015-12-16', 226.50),
('64511', '2016-02-11', 224.50),
('64511', '2016-09-05', 223.50),
('64511', '2016-09-08', 227.50),
('64511', '2016-09-10', 225.50),
('64511', '2016-09-12', 223.50),
('64511', '2016-09-15', 227.50),
('64550', '2013-10-25', 120.50),
('64550', '2015-03-04', 126.00),
('64550', '2015-03-11', 126.00),
('64550', '2015-05-06', 124.00),
('64550', '2015-11-30', 121.00),
('64550', '2015-12-03', 120.00),
('64550', '2015-12-05', 125.00),
('64550', '2015-12-07', 123.00),
('64550', '2015-12-10', 120.00),
('64551', '2013-10-25', 114.00),
('64551', '2015-01-30', 112.00),
('64551', '2015-02-06', 115.00),
('64551', '2015-04-01', 113.00),
('64551', '2015-10-29', 113.00),
('64551', '2015-10-31', 118.00),
('64551', '2015-11-02', 112.00),
('64551', '2015-11-05', 116.00),
('64551', '2015-11-07', 114.00),
('64552', '2013-10-25', 264.50),
('64552', '2015-11-03', 275.00),
('64552', '2015-11-05', 273.00),
('64552', '2015-11-07', 271.00),
('64552', '2015-11-17', 275.00),
('64552', '2015-11-19', 273.00),
('64552', '2015-11-21', 271.00),
('64552', '2016-02-11', 274.00),
('64552', '2016-04-13', 272.00),
('65032', '2012-05-01', 595.50),
('65032', '2012-07-03', 593.50),
('65032', '2013-02-07', 596.50),
('65032', '2013-10-25', 574.50),
('65032', '2015-10-21', 596.50),
('65032', '2015-12-23', 594.50),
('65032', '2016-07-17', 593.50),
('65032', '2016-07-27', 597.50),
('65032', '2016-07-29', 595.50),
('65033', '2012-05-22', 1040.00),
('65033', '2012-06-01', 1040.00),
('65033', '2012-07-24', 1038.00),
('65033', '2013-02-21', 1041.00),
('65033', '2013-02-28', 1041.00),
('65033', '2013-10-25', 1002.00),
('65033', '2014-02-23', 1039.00),
('65033', '2015-02-18', 1044.00),
('65033', '2015-02-25', 1044.00),
('65034', '2012-08-31', 15000.00),
('65034', '2012-09-07', 14996.00),
('65034', '2012-11-02', 14994.00),
('65034', '2012-11-09', 14994.00),
('65034', '2013-06-06', 14997.00),
('65034', '2013-10-25', 14400.00),
('65034', '2014-06-01', 14995.00),
('65034', '2014-06-08', 14995.00),
('65034', '2015-06-03', 15000.00),
('65060', '2013-10-25', 44.50),
('65060', '2013-11-22', 43.50),
('65060', '2014-01-10', 41.50),
('65060', '2014-02-07', 44.50),
('65060', '2014-07-31', 41.50),
('65060', '2014-08-28', 44.50),
('65060', '2015-08-16', 42.50),
('65060', '2016-08-04', 40.50),
('65060', '2016-09-01', 43.50),
('65070', '2013-10-25', 114.50),
('65070', '2015-02-20', 114.50),
('65070', '2015-04-08', 112.50),
('65070', '2015-04-22', 112.50),
('65070', '2015-11-12', 115.50),
('65070', '2015-11-14', 113.50),
('65070', '2015-11-16', 118.50),
('65070', '2015-11-26', 115.50),
('65070', '2015-11-28', 113.50),
('65080', '2013-10-25', 459.50),
('65080', '2015-11-04', 473.00),
('65080', '2015-11-18', 473.00),
('65080', '2016-06-08', 476.00),
('65080', '2016-06-10', 474.00),
('65080', '2016-06-12', 472.00),
('65080', '2016-06-22', 476.00),
('65080', '2016-09-02', 475.00),
('65080', '2016-09-16', 475.00),
('65081', '2013-10-25', 107.00),
('65081', '2014-12-25', 106.00),
('65081', '2015-01-02', 108.00),
('65081', '2015-02-27', 111.00),
('65081', '2015-03-04', 106.00),
('65081', '2015-10-01', 109.00),
('65081', '2015-10-03', 107.00),
('65081', '2016-09-26', 112.00),
('65081', '2016-09-28', 110.00),
('65082', '2013-10-25', 167.00),
('65082', '2015-09-03', 168.00),
('65082', '2015-10-29', 170.00),
('65082', '2015-11-05', 173.00),
('65082', '2016-05-28', 171.00),
('65082', '2016-05-30', 169.00),
('65082', '2016-06-02', 169.00),
('65082', '2016-06-04', 174.00),
('65082', '2016-06-06', 172.00),
('65122', '2012-07-05', 1552.00),
('65122', '2012-08-24', 1554.00),
('65122', '2012-09-07', 1557.00),
('65122', '2013-03-28', 1557.00),
('65122', '2013-04-11', 1553.00),
('65122', '2013-10-25', 1496.50),
('65122', '2014-03-30', 1555.00),
('65122', '2014-04-13', 1558.00),
('65122', '2015-04-01', 1556.00),
('65142', '2013-10-25', 89.00),
('65142', '2014-09-19', 88.00),
('65142', '2014-09-26', 88.00),
('65142', '2014-11-21', 93.00),
('65142', '2015-06-18', 89.00),
('65142', '2015-06-25', 89.00),
('65142', '2016-06-15', 92.00),
('65142', '2016-06-20', 87.00),
('65142', '2016-06-22', 92.00),
('65143', '2014-09-05', 77.50),
('65143', '2014-09-12', 77.50),
('65143', '2014-11-07', 82.50),
('65143', '2014-11-14', 82.50),
('65143', '2015-06-11', 78.50),
('65143', '2016-06-06', 83.50),
('65143', '2016-06-08', 81.50),
('65143', '2016-06-13', 83.50),
('65147', '2015-10-01', 232.50),
('65147', '2015-10-06', 234.50),
('65147', '2015-10-17', 237.50),
('65147', '2015-10-22', 232.50),
('65147', '2015-10-27', 234.50),
('65147', '2016-01-14', 233.50),
('65147', '2016-03-09', 238.50),
('65147', '2016-03-30', 238.50),
('65190', '2015-09-24', 188.50),
('65190', '2015-11-19', 186.50),
('65190', '2015-11-26', 186.50),
('65190', '2016-06-20', 185.50),
('65190', '2016-06-23', 189.50),
('65190', '2016-06-25', 187.50),
('65190', '2016-06-27', 185.50),
('65190', '2016-06-30', 189.50),
('65191', '2012-08-17', 20.00),
('65191', '2012-08-24', 20.00),
('65191', '2012-10-19', 18.00),
('65191', '2013-05-16', 21.00),
('65191', '2013-05-23', 21.00),
('65191', '2014-05-18', 19.00),
('65191', '2014-05-25', 19.00),
('65191', '2015-05-20', 17.00),
('65247', '2014-06-20', 69.00),
('65247', '2014-06-27', 69.00),
('65247', '2014-08-22', 74.00),
('65247', '2015-03-19', 70.00),
('65247', '2015-03-26', 70.00),
('65247', '2016-03-21', 75.00),
('65247', '2016-03-23', 73.00),
('65247', '2016-03-28', 75.00),
('71912', '2013-03-27', 35.00),
('71912', '2013-04-10', 31.00),
('71912', '2013-05-29', 33.00),
('71912', '2013-06-12', 29.00),
('71912', '2014-01-02', 32.00),
('71912', '2014-01-16', 32.00),
('71912', '2015-01-04', 30.00),
('71912', '2016-01-06', 35.00),
('72777', '2015-07-01', 148.00),
('72777', '2015-07-29', 148.00),
('72777', '2015-09-17', 153.00),
('72777', '2016-03-26', 151.00),
('72777', '2016-04-07', 149.00),
('72777', '2016-04-11', 152.00),
('72777', '2016-04-23', 154.00),
('72777', '2016-05-05', 151.00),
('72942', '2013-04-30', 30.50),
('72942', '2013-06-26', 35.50),
('72942', '2013-07-16', 31.50),
('72942', '2014-01-23', 31.50),
('72942', '2014-02-13', 34.50),
('72942', '2015-01-18', 29.50),
('72942', '2015-02-08', 32.50),
('72942', '2016-02-03', 30.50),
('72943', '2013-04-24', 29.50),
('72943', '2013-05-14', 32.50),
('72943', '2013-06-19', 34.50),
('72943', '2013-07-09', 30.50),
('72943', '2014-02-06', 33.50),
('72943', '2015-02-01', 31.50),
('72943', '2016-01-27', 33.50),
('72943', '2016-02-17', 29.50),
('72944', '2013-08-23', 36.00),
('72944', '2013-09-13', 39.00),
('72944', '2013-11-08', 37.00),
('72944', '2014-06-05', 40.00),
('72944', '2015-05-31', 42.00),
('72944', '2015-06-21', 38.00),
('72944', '2016-05-26', 40.00),
('72944', '2016-06-16', 36.00),
('76032', '2013-10-25', 321.00),
('76032', '2016-01-30', 334.50),
('76032', '2016-02-02', 334.50),
('76032', '2016-02-04', 332.50),
('76032', '2016-02-06', 330.50),
('76032', '2016-02-09', 334.50),
('76032', '2016-05-03', 333.50),
('76032', '2016-06-29', 328.50),
('76032', '2016-07-05', 331.50),
('77033', '2013-10-25', 344.00),
('77033', '2016-03-04', 356.00),
('77033', '2016-03-09', 358.00),
('77033', '2016-03-20', 354.00),
('77033', '2016-03-25', 356.00),
('77033', '2016-03-30', 358.00),
('77033', '2016-06-17', 357.00),
('77033', '2016-08-12', 355.00),
('77033', '2016-09-02', 358.00),
('77036', '2013-10-25', 344.00),
('77036', '2016-03-13', 358.00),
('77036', '2016-03-18', 353.00),
('77036', '2016-03-23', 355.00),
('77036', '2016-04-03', 354.00),
('77036', '2016-06-10', 354.00),
('77036', '2016-06-30', 354.00),
('77036', '2016-08-05', 352.00),
('77036', '2016-08-26', 352.00),
('77038', '2013-10-25', 459.50),
('77038', '2015-11-11', 478.00),
('77038', '2016-06-03', 472.00),
('77038', '2016-06-05', 477.00),
('77038', '2016-06-15', 474.00),
('77038', '2016-06-17', 472.00),
('77038', '2016-06-19', 477.00),
('77038', '2016-09-09', 473.00),
('77038', '2016-09-23', 473.00),
('77249', '2012-06-29', 1553.00),
('77249', '2012-07-12', 1556.00),
('77249', '2012-08-31', 1558.00),
('77249', '2012-09-14', 1554.00),
('77249', '2013-04-04', 1557.00),
('77249', '2013-10-25', 1496.00),
('77249', '2014-04-06', 1555.00),
('77249', '2015-03-25', 1557.00),
('77249', '2015-04-08', 1553.00),
('77251', '2012-05-08', 658.00),
('77251', '2012-05-15', 658.00),
('77251', '2012-07-10', 656.00),
('77251', '2012-07-17', 656.00),
('77251', '2013-02-14', 652.00),
('77251', '2013-10-25', 632.00),
('77251', '2014-02-09', 657.00),
('77251', '2014-02-16', 657.00),
('77251', '2015-02-11', 655.00),
('77252', '2013-03-20', 28.50),
('77252', '2013-05-15', 33.50),
('77252', '2013-05-22', 33.50),
('77252', '2013-10-25', 33.50),
('77252', '2013-12-19', 29.50),
('77252', '2014-12-14', 34.50),
('77252', '2014-12-21', 34.50),
('77252', '2015-12-16', 32.50),
('77252', '2015-12-23', 32.50),
('77276', '2012-08-03', 4552.00),
('77276', '2012-09-28', 4555.00),
('77276', '2012-10-05', 4557.00),
('77276', '2013-05-02', 4553.00),
('77276', '2014-04-27', 4556.00),
('77276', '2014-05-04', 4558.00),
('77276', '2015-04-29', 4554.00),
('77276', '2015-05-06', 4556.00),
('77277', '2016-03-06', 355.00),
('77277', '2016-03-11', 357.00),
('77277', '2016-03-16', 352.00),
('77277', '2016-03-27', 355.00),
('77277', '2016-04-01', 353.00),
('77277', '2016-04-06', 355.00),
('77277', '2016-06-24', 358.00),
('77277', '2016-08-19', 356.00),
('78029', '2015-04-29', 141.50),
('78029', '2015-05-26', 137.50),
('78029', '2015-07-14', 142.50),
('78029', '2016-02-04', 138.50),
('78029', '2016-02-08', 141.50),
('78029', '2016-02-20', 136.50),
('78029', '2016-03-03', 139.50),
('78029', '2016-03-07', 142.50),
('80032', '2015-08-06', 154.50),
('80032', '2015-08-13', 154.50),
('80032', '2015-10-08', 152.50),
('80032', '2015-10-15', 152.50),
('80032', '2016-05-07', 153.50),
('80032', '2016-05-09', 151.50),
('80032', '2016-05-12', 148.50),
('80032', '2016-05-14', 153.50),
('80082', '2015-02-13', 117.50),
('80082', '2015-02-27', 117.50),
('80082', '2015-04-15', 115.50),
('80082', '2015-04-29', 115.50),
('80082', '2015-11-09', 114.50),
('80082', '2015-11-19', 118.50),
('80082', '2015-11-21', 116.50),
('80082', '2015-11-23', 114.50),
('80088', '2015-11-05', 207.00),
('80088', '2015-11-12', 207.00),
('80088', '2016-01-07', 212.00),
('80088', '2016-08-04', 208.00),
('80088', '2016-08-06', 213.00),
('80088', '2016-08-08', 211.00),
('80088', '2016-08-11', 208.00),
('80088', '2016-08-13', 213.00),
('80692', '2013-07-18', 39.50),
('80692', '2013-09-06', 37.50),
('80692', '2013-09-20', 37.50),
('80692', '2013-10-25', 38.00),
('80692', '2014-04-10', 33.50),
('80692', '2014-04-24', 33.50),
('80692', '2015-04-12', 38.50),
('80692', '2015-04-26', 38.50),
('80692', '2016-04-14', 36.50),
('81007', '2013-10-25', 59.50),
('81007', '2014-02-28', 59.50),
('81007', '2014-03-05', 61.50),
('81007', '2014-04-30', 57.50),
('81007', '2014-11-27', 60.50),
('81007', '2014-12-04', 62.50),
('81007', '2015-11-29', 58.50),
('81007', '2015-12-01', 58.50),
('81007', '2015-12-06', 60.50),
('82090', '2013-02-15', 28.00),
('82090', '2013-02-28', 28.00),
('82090', '2013-04-17', 26.00),
('82090', '2013-05-01', 28.00),
('82090', '2013-10-25', 28.50),
('82090', '2013-11-21', 29.00),
('82090', '2014-11-23', 27.00),
('82090', '2015-11-11', 25.00),
('82090', '2015-11-25', 25.00),
('82092', '2012-07-12', 17.00),
('82092', '2012-07-19', 17.00),
('82092', '2012-09-14', 15.00),
('82092', '2012-09-21', 15.00),
('82092', '2013-04-18', 18.00),
('82092', '2013-10-25', 17.00),
('82092', '2014-04-13', 16.00),
('82092', '2014-04-20', 16.00),
('82092', '2015-04-15', 14.00),
('82093', '2012-09-21', 20.00),
('82093', '2012-09-28', 20.00),
('82093', '2012-11-23', 18.00),
('82093', '2013-06-20', 21.00),
('82093', '2013-06-27', 21.00),
('82093', '2013-10-25', 23.00),
('82093', '2014-06-22', 19.00),
('82093', '2015-06-17', 24.00),
('82093', '2015-06-24', 24.00),
('82095', '2012-08-31', 21.50),
('82095', '2012-09-14', 17.50),
('82095', '2012-11-02', 22.50),
('82095', '2012-11-16', 22.50),
('82095', '2013-06-06', 18.50),
('82095', '2013-10-25', 22.00),
('82095', '2014-06-08', 23.50),
('82095', '2015-05-27', 18.50),
('82095', '2015-06-10', 21.50),
('82096', '2013-01-04', 23.50),
('82096', '2013-01-25', 23.50),
('82096', '2013-02-28', 26.50),
('82096', '2013-03-20', 21.50),
('82096', '2013-10-17', 24.50),
('82096', '2013-10-25', 26.50),
('82096', '2014-10-12', 22.50),
('82096', '2015-10-07', 27.50),
('82096', '2015-10-28', 27.50),
('83013', '2013-10-18', 42.00),
('83013', '2013-10-25', 44.00),
('83013', '2013-12-20', 40.00),
('83013', '2014-07-17', 43.00),
('83013', '2014-07-24', 43.00),
('83013', '2015-07-19', 41.00),
('83013', '2016-07-14', 46.00),
('83013', '2016-07-21', 46.00),
('90106', '2013-06-14', 36.00),
('90106', '2013-07-04', 32.00),
('90106', '2013-08-09', 34.00),
('90106', '2013-08-30', 34.00),
('90106', '2013-10-25', 36.50),
('90106', '2014-03-06', 37.00),
('90106', '2014-03-27', 37.00),
('90106', '2015-03-22', 35.00),
('90106', '2016-03-17', 33.00),
('90109', '2013-08-09', 40.50),
('90109', '2013-08-16', 40.50),
('90109', '2013-10-11', 38.50),
('90109', '2013-10-18', 38.50),
('90109', '2013-10-25', 39.00),
('90109', '2014-05-15', 34.50),
('90109', '2015-05-10', 39.50),
('90109', '2015-05-17', 39.50),
('90109', '2016-05-12', 37.50),
('90116', '2013-10-25', 48.00),
('90116', '2013-12-12', 47.00),
('90116', '2013-12-19', 47.00),
('90116', '2014-02-14', 45.00),
('90116', '2014-09-11', 48.00),
('90116', '2014-09-18', 48.00),
('90116', '2015-09-13', 46.00),
('90116', '2016-09-08', 44.00),
('90116', '2016-09-15', 44.00),
('90164', '2013-10-25', 75.00),
('90164', '2014-07-03', 75.50),
('90164', '2014-08-29', 70.50),
('90164', '2014-09-05', 73.50),
('90164', '2015-04-02', 69.50),
('90164', '2015-04-09', 69.50),
('90164', '2015-07-12', 72.50),
('90164', '2016-03-30', 69.50),
('90164', '2016-04-04', 74.50),
('90164', '2016-04-06', 72.50),
('90192', '2013-10-25', 67.50),
('90192', '2014-04-09', 64.50),
('90192', '2014-06-11', 69.50),
('90192', '2015-01-01', 65.50),
('90192', '2015-01-15', 65.50),
('90192', '2016-01-03', 70.50),
('90192', '2016-01-05', 68.50),
('90192', '2016-01-17', 70.50),
('90192', '2016-01-19', 68.50),
('90208', '2013-10-25', 68.50),
('90208', '2014-04-23', 70.00),
('90208', '2014-05-20', 66.00),
('90208', '2014-07-08', 71.00),
('90208', '2015-01-29', 71.00),
('90208', '2015-02-26', 67.00),
('90208', '2016-02-02', 70.00),
('90208', '2016-02-14', 65.00),
('90208', '2016-03-02', 70.00),
('90209', '2013-10-25', 68.50),
('90209', '2014-04-30', 69.00),
('90209', '2014-05-27', 65.00),
('90209', '2014-07-15', 70.00),
('90209', '2015-02-05', 66.00),
('90209', '2015-03-05', 66.00),
('90209', '2016-01-24', 68.00),
('90209', '2016-02-09', 69.00),
('90209', '2016-02-21', 71.00),
('90212', '2013-10-25', 68.00),
('90212', '2014-05-06', 69.00),
('90212', '2014-06-06', 69.00),
('90212', '2014-06-25', 71.00),
('90212', '2014-07-22', 67.00),
('90212', '2015-02-12', 70.00),
('90212', '2016-01-31', 65.00),
('90212', '2016-02-16', 66.00),
('90212', '2016-02-28', 68.00),
('90510', '2013-10-25', 413.00),
('90510', '2015-10-21', 430.50),
('90510', '2015-10-28', 430.50),
('90510', '2016-05-22', 429.50),
('90510', '2016-05-25', 426.50),
('90510', '2016-05-27', 424.50),
('90510', '2016-05-29', 429.50),
('90510', '2016-06-01', 429.50),
('90510', '2016-08-26', 425.50),
('90521', '2013-10-25', 137.50),
('90521', '2015-05-05', 140.50),
('90521', '2015-06-04', 141.50),
('90521', '2015-07-21', 138.50),
('90521', '2016-01-30', 136.50),
('90521', '2016-02-11', 141.50),
('90521', '2016-02-15', 137.50),
('90521', '2016-02-27', 139.50),
('90521', '2016-03-10', 142.50),
('90531', '2013-10-25', 80.50),
('90531', '2014-08-01', 82.00),
('90531', '2014-08-29', 82.00),
('90531', '2014-10-17', 80.00),
('90531', '2015-05-07', 83.00),
('90531', '2015-06-04', 79.00),
('90531', '2016-04-25', 79.00),
('90531', '2016-05-11', 79.00),
('90531', '2016-05-23', 81.00),
('90545', '2013-10-25', 276.50),
('90545', '2015-12-05', 283.00),
('90545', '2015-12-15', 287.00),
('90545', '2015-12-17', 285.00),
('90545', '2015-12-19', 283.00),
('90545', '2016-03-09', 286.00),
('90545', '2016-03-23', 286.00),
('90545', '2016-05-11', 284.00),
('90545', '2016-05-25', 284.00),
('90693', '2014-01-03', 53.00),
('90693', '2014-01-17', 53.00),
('90693', '2014-03-05', 51.00),
('90693', '2014-03-19', 51.00),
('90693', '2014-10-09', 54.00),
('90693', '2014-10-23', 54.00),
('90693', '2015-10-11', 52.00),
('90693', '2015-10-13', 57.00),
('90737', '2013-10-25', 339.50),
('90737', '2016-02-11', 354.00),
('90737', '2016-02-13', 352.00),
('90737', '2016-02-16', 349.00),
('90737', '2016-02-18', 354.00),
('90737', '2016-05-10', 348.00),
('90737', '2016-05-17', 348.00),
('90737', '2016-07-12', 353.00),
('90737', '2016-07-19', 353.00),
('91008', '2013-10-25', 91.00),
('91008', '2014-10-03', 90.00),
('91008', '2014-11-28', 93.00),
('91008', '2014-12-05', 88.00),
('91008', '2015-07-02', 91.00),
('91008', '2016-06-27', 94.00),
('91008', '2016-06-29', 92.00),
('91008', '2016-07-04', 89.00),
('91008', '2016-07-06', 94.00),
('92606', '2013-12-20', 102.50),
('92606', '2014-11-14', 103.00),
('92606', '2014-12-04', 106.00),
('92606', '2015-01-30', 101.00),
('92606', '2015-08-27', 104.00),
('92606', '2016-08-17', 100.00),
('92606', '2016-08-22', 102.00),
('92606', '2016-09-07', 103.00),
('92606', '2016-09-12', 105.00);



--
-- Dataark for tabell Ansatt
--

INSERT INTO Ansatt (AnsNr, Fornavn, Etternavn, Adresse, PostNr, Fødselsdato, Kjønn, Stilling, Årslønn) VALUES
(1, 'Georg', 'Barth', 'Kringsjågrenda 3F', '3841', '1978-10-20', 'M', 'Lagerleder', 526000.00),
(2, 'Gunnlaug', 'Angeltveit', 'Langmyrgrenda 9', '3800', '1965-03-29', 'K', 'Markedssjef', 559300.00),
(3, 'Morgan', 'Dalland', 'Jansbergveien 19', '3830', '1970-01-10', 'M', 'Innkjøper', 583000.00),
(6, 'Vilde', 'Aksnes', 'Minister Ditleffs vei 44', '3810', '1973-10-11', 'K', 'Databaseadministrator', 602800.00),
(7, 'Henriette', 'Brobakken', 'Stubberud Sognsvann 1', '3800', '1967-10-01', 'K', 'Daglig leder', 725000.00),
(8, 'Synøve', 'Bakketun', 'Vassøyveien 7', '3840', '1981-05-15', 'K', 'Kundebehandler', 450500.00),
(9, 'Ragnvald', 'Allum', 'Utsikten 4', '3812', '1988-03-07', 'M', 'Kundebehandler', 421500.00),
(11, 'Oliver', 'Abrahamsen', 'Tarjei Vesaas'''' vei 3A', '3812', '1985-01-20', 'M', 'Lagermedarbeider', 406000.00),
(13, 'Oda', 'Cappelen', 'Norheimskneiken 12', '3800', '1987-02-28', 'K', 'Produktutvikler', 567900.00),
(16, 'Andrine', 'Ebbesen', 'Kristianias gate 9', '3800', '1984-12-27', 'K', 'Regnskapssekretær', 462900.00),
(17, 'Karl Anton', 'Hoff', 'Furustia 3', '3840', '1993-08-03', 'M', 'Kundebehandler', 410700.00),
(18, 'Johanna', 'Li', 'Krogsteinveien 101A', '3841', '1992-05-17', 'K', 'Kundebehandler', 416200.00);



--
-- Dataark for tabell Kunde
--

INSERT INTO Kunde (KNr, Fornavn, Etternavn, Adresse, PostNr) VALUES
(5002, 'Paal', 'Aass', 'Lindemans gate79', '1711'),
(5007, 'Joakim', 'Laursen', 'Thomas Heftyes gate 39', '0015'),
(5009, 'Laurits', 'Eckhoff', 'Solheimgata 81', '0654'),
(5011, 'Åshild', 'Sætran', 'Erling Skjalgssons gate 56', '3750'),
(5022, 'Torgrim', 'Østbø', 'Hafrsfjordgata 11', '3925'),
(5025, 'Malvin', 'Khan', 'Halvdan Svartes gate 7', '1326'),
(5028, 'Sidsel', 'Gulli', 'Kristinelundveien 34', '4297'),
(5039, 'Katrine', 'Eilertsen', 'Ingar Nilsens vei 12C', '7003'),
(5042, 'Skjalg', 'Tengesdal', 'Nobels gate 17', '8310'),
(5043, 'Gunn Iren', 'Ånestad', 'Ottar Birtings gate 9', '7200'),
(5049, 'Khalid', 'Rue', 'Observatorie Terrasse 1', '6401'),
(5071, 'Jann', 'Skjelvik', 'Munkedamsveien 51A', '5570'),
(5079, 'Ine', 'Kraft', 'Thomles gate 8', '3340'),
(5081, 'Valter', 'Grimsmo', 'Lassons gate 32', '5802'),
(5082, 'Alexandra', 'Saleh', 'Leiv Eirikssons gate 74', '8300'),
(5087, 'Maj', 'Elton', 'Bjørn Farmanns gate 119A', '8380'),
(5091, 'Agnethe', 'Wessel', 'Gardeveien 38', '8883'),
(5092, 'Erland', 'Trøan', 'Gydas vei 55', '2201'),
(5093, 'Morten', 'Lindland', 'Harald Hårfagres gate 141', '3400'),
(5102, 'Kaja', 'Høvik', 'Hammerstads gate 3E', '5600'),
(5119, 'Thale', 'Evenrud', 'Kirkeveien 5', '1201'),
(5122, 'Connie', 'Volden', 'Valkyriegata 19A', '1701'),
(5129, 'Arne', 'Reinertsen', 'Valkyrieplassen', '0501'),
(5138, 'Ranveig', 'Gjertsen', 'Henrik Wergelands Allé 47', '0901'),
(5139, 'Mariann', 'Enger', 'Krebs gate 12', '3300'),
(5144, 'Asle', 'Hornnes', 'Hegermanns gate 3', '0201'),
(5162, 'Ole-Jørgen', 'Molteberg', 'Hegermanns plass 4C', '3201'),
(5172, 'Aasta', 'Garvik', 'Kyrre Grepps gate 19', '8300'),
(5188, 'Jorid', 'Marcussen', 'Haarklous plass 23C', '9001'),
(5201, 'Aleksandra', 'Vaksdal', 'Edvard Griegs Allé 12', '0952'),
(5208, 'Fatima', 'Hildre', 'Nordkappgata 15', '3901'),
(5209, 'Emilie', 'Fotland', 'Sigurd Lies gate 19', '7200'),
(5219, 'Ayse', 'Sellevold', 'Lilleborggata 28', '8820'),
(5237, 'Magnhild', 'Helgestad', 'Åsengata 6', '6201'),
(5238, 'Inger-Lise', 'Nerdal', 'Erika Nissens gate 3', '2910'),
(5239, 'Mustafa', 'Falck', 'Lammers'''' gate 8B', '6320'),
(5250, 'Tormod', 'Furset', 'Kyrre Grepps gate 81', '9321'),
(5251, 'Maren', 'Stephansen', 'Fjellhus Allé 129', '7730'),
(5256, 'Sol', 'Fauske', 'Caspar Storms vei 21', '2880'),
(5267, 'Birthe', 'Nydal', 'Duggveien 30', '3387'),
(5310, 'Ole', 'Haugom', 'Agmund Bolts vei 145', '9925'),
(5316, 'Åsa', 'Folgerø', 'Klosterheimveien 6C', '0330'),
(5321, 'Sivert', 'Ose', 'Harald Halvorsens vei 17', '0208'),
(5322, 'Lisa', 'Fjeldstad', 'Fyrstikkbakken 5D', '0201'),
(5328, 'Anne-Britt', 'Sneve', 'Johan Evjes vei 41', '0330'),
(5353, 'Gjermund', 'Hansson', 'Grinda 2', '4020'),
(5354, 'David', 'Astrup', 'Bjørndalsbrotet 21', '1892'),
(5355, 'Evelyn', 'Langaas', 'Aldersheimbakken 6', '3243'),
(5356, 'Ole-jørgen', 'Kongshaug', 'Ruskeneshaugen 57', '2943'),
(5357, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '5072'),
(5358, 'Brian', 'Holte', 'Nedberget 49', '0764'),
(5359, 'Klara', 'Brække', 'Fanavegen 40', '1763'),
(5360, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '3044'),
(5361, 'Klara', 'Brække', 'Fanavegen 40', '4645'),
(5362, 'Ada', 'Fiske', 'Hesthaugvegen 36', '3790'),
(5363, 'Wanja', 'Nordhaug', 'Vestre Murallmenningen 14', '1605'),
(5364, 'Jakob', 'Mundal', 'Tollbugata 53', '0988'),
(5365, 'Brian', 'Holte', 'Nedberget 49', '4004'),
(5366, 'Johny', 'Jonassen', 'Nøttveitvegen 35', '1155'),
(5367, 'Thore', 'Hauan', 'Lindealléen 39', '4586'),
(5368, 'Sven', 'Dammen', 'Apotekarvegen 43', '0801'),
(5369, 'Jesper', 'Førre', 'Jomfrustien 161', '5445'),
(5370, 'Maud', 'Mellingen', 'Sætrefjellet 50', '0565'),
(5371, 'Mohamed', 'Bremseth', 'Engevikvegen 7', '5035'),
(5372, 'Tony', 'Lauritzen', 'Skjenlien 1', '4803'),
(5373, 'Lina', 'Buljo', 'Finnemanns plass 56', '1255'),
(5374, 'Trine-lise', 'Nilssen', 'Vaskerelven 64', '1892'),
(5375, 'Oddbjørn', 'Brunstad', 'Fagertunvegen 29', '4174'),
(5376, 'Chris', 'Fiksdal', 'Helmers vei 25', '0877'),
(5377, 'Veslemøy', 'Nordbø', 'Vesthagen 6', '3044'),
(5378, 'Gjert', 'Forland', 'Hylkjeneset 69', '3243'),
(5379, 'Wanja', 'Nordhaug', 'Vestre Murallmenningen 14', '2025'),
(5380, 'Brian', 'Holte', 'Nedberget 49', '3044'),
(5381, 'Ingmar', 'Morken', 'Thomasstien 41', '2943'),
(5382, 'Adam', 'Loe', 'St. Halvards vei 22A', '1763'),
(5383, 'Sigvart', 'Christophersen', 'Fortunbakkane 23', '0901'),
(5384, 'Kaare', 'Gloppen', 'Kippersmauet 35', '3893'),
(5385, 'David', 'Astrup', 'Bjørndalsbrotet 21', '1389'),
(5386, 'Mariann', 'Mathiassen', 'Sveiarhaugen 26', '3800'),
(5387, 'Dagny', 'Kvamme', 'Sandviksleitet 24', '0764'),
(5388, 'Hallstein', 'Håkonsen', 'Nordre Gommershaugen 45', '0764'),
(5389, 'Jakob', 'Mundal', 'Tollbugata 53', '3044'),
(5390, 'Stephanie', 'Eng', 'Gullstølslien 12', '0032'),
(5391, 'Gorm', 'Milde', 'Søren van der Weldes veg 71', '2607'),
(5392, 'Agnes', 'Johannessen', 'Nylandsveien 26', '5258'),
(5393, 'Tom-erik', 'Drange', 'Fæsteråsen 67', '3044'),
(5394, 'Jakob', 'Mundal', 'Tollbugata 53', '2309'),
(5395, 'Ismail', 'Furu', 'Jens Rolfsens gate 47', '4174'),
(5396, 'Mathilde', 'Hessen', 'Midtunstien 54', '3885'),
(5397, 'Ismail', 'Furu', 'Bakkevegen 47', '5282'),
(5398, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '5845'),
(5399, 'Evelyn', 'Langaas', 'Balders veg 63', '0764'),
(5400, 'Adam', 'Loe', 'St. Halvards vei 22', '5202'),
(5401, 'Jarand', 'Mydland', 'Tordenskjolds gate 57', '3484'),
(5402, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '2607'),
(5403, 'Abdirahman', 'Lindahl', 'Solbakksvingen 27', '0602'),
(5404, 'Gøril', 'Bjørke', 'Barliveien 29', '2309'),
(5405, 'Gjert', 'Forland', 'Hylkjeneset 69', '0270'),
(5406, 'Carsten', 'Askildsen', 'Bjørgebrekken 9', '3044'),
(5407, 'Ismail', 'Furu', 'Bendixens vei 47', '3790'),
(5408, 'Agnar', 'Engelsen', 'Gårdsvegen 21', '5232'),
(5409, 'Tom-erik', 'Drange', 'Fæsteråsen 67', '3199'),
(5410, 'Maren', 'Martens', 'Sukkerhusgaten 18D', '2943'),
(5411, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '0988'),
(5412, 'Veslemøy', 'Nordbø', 'Vesthagen 26', '0988'),
(5413, 'Bjørnar', 'Holsen', 'Nattlandsveien 43', '3209'),
(5414, 'Brian', 'Holte', 'Nedberget 49', '3790'),
(5415, 'Sebastian', 'Ofstad', 'Zander Kaaes gate 13', '2943'),
(5416, 'Dagny', 'Kvamme', 'Sandviksleitet 24', '1286'),
(5417, 'Brian', 'Holte', 'Nedberget 49', '0988'),
(5418, 'Adam', 'Loe', 'Bjørkåsen 22', '1763'),
(5419, 'Edny', 'Kvaal', 'Sejersteds park 40', '0122'),
(5420, 'Christiane', 'Gjerdrum', 'Kaptein Amlands vei 18', '3750'),
(5421, 'Celine', 'Ramberg', 'Øvregaten 4', '3893'),
(5422, 'Tony', 'Lauritzen', 'Skjenlien 1', '6057'),
(5423, 'Lucas', 'Kirkeby', 'Petedalsheia 71', '3044'),
(5424, 'Nikolai', 'Knarvik', 'Rognehaugen 41', '4742'),
(5425, 'Trine-lise', 'Nilssen', 'Vaskerelven 64', '4056'),
(5426, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '4004'),
(5427, 'Gjert', 'Forland', 'Hylkjeneset 67', '3126'),
(5428, 'Per-arne', 'Guttormsen', 'Krohnåsvegen 37', '6057'),
(5429, 'Mohamed', 'Bremseth', 'Engevikvegen 7B', '5859'),
(5430, 'Steven', 'Oma', 'Øvre Bjørkåsen 33', '3790'),
(5431, 'Eystein', 'Bakker', 'Borgermester Platous gate 49', '3790'),
(5432, 'Karla', 'Hauglid', 'Loddefjordveien 48', '1158'),
(5433, 'Thea', 'Høvik', 'Nordhordlandsvegen 34', '5501'),
(5434, 'Rene', 'Bø', 'Fjøsangerveien 71', '1892'),
(5435, 'Marvin', 'Kjær', 'Professor Keysers gate 11', '4150'),
(5436, 'Marvin', 'Brattli', 'Elvebakken 60', '3126'),
(5437, 'Gjert', 'Forland', 'Hylkjeneset 29', '1389'),
(5438, 'Christer', 'Fimreite', 'Henrik Jægers vei 27', '3044'),
(5439, 'Målfrid', 'Drage', 'Fæstergrenden 64', '4742'),
(5440, 'Ole-jørgen', 'Kongshaug', 'Ruskeneshaugen 57', '1892'),
(5441, 'Sven', 'Dammen', 'Frieda Fasmers vei 43', '2808'),
(5442, 'Oddlaug', 'Hognestad', 'Myrdalshovden 20', '0122'),
(5443, 'Ulf', 'Hegge', 'Lyngberget 59', '5859'),
(5444, 'Oddlaug', 'Hognestad', 'Myrdalshovden 20', '0122'),
(5445, 'Søren', 'Hasle', 'Lilandsvegen 29', '4586'),
(5446, 'Evelyn', 'Langaas', 'Blåbærvegen 6A', '3243'),
(5447, 'Jacob', 'Bjerk', 'Christian Michelsens gate 55', '0584'),
(5448, 'Jakob', 'Mundal', 'Tollbugata 53', '3790'),
(5449, 'Ailin', 'Fjellvang', 'Hjortlandsvegen 52', '4993'),
(5450, 'Gøril', 'Bjørke', 'Bugården 2', '1414'),
(5451, 'Mathilde', 'Hessen', 'Midtunstien 54', '3484'),
(5452, 'Adam', 'Lone', 'St. Olavs vei 1', '0587'),
(5453, 'Oddvin', 'Kolnes', 'Ross-smauet 21', '3691'),
(5454, 'Jone', 'Myrhaug', 'Trangesmauet 1', '1747'),
(5455, 'Celine', 'Ramberg', 'Øvregaten 4', '2011'),
(5456, 'Evelyn', 'Langaas', 'C. J. Hambros vei 6', '0122'),
(5457, 'Oddvin', 'Kolnes', 'Ross-smauet 51', '5598'),
(5458, 'Andres', 'Hjelm', 'Morvikbotn 1', '0025'),
(5459, 'Jone', 'Myrhaug', 'Trangesmauet 1', '5445'),
(5460, 'Thore', 'Hauan', 'Lindealléen 39', '2302'),
(5461, 'Marvin', 'Brattli', 'Elvebakken 67', '2808'),
(5462, 'Villy', 'Lian', 'Skytterveien 24', '3044'),
(5463, 'Veslemøy', 'Nordbø', 'Vesthagen 6', '3044'),
(5464, 'Wanja', 'Nordhaug', 'Vestre Murallmenningen 14', '4150'),
(5466, 'David', 'Astrup', 'Bjørndalsbrotet 21', '4032'),
(5467, 'Oddlaug', 'Hognestad', 'Myrdalshovden 20', '0122'),
(5468, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '3371'),
(5469, 'Elias', 'Husabø', 'Neshaugen 69', '3471'),
(5470, 'Jone', 'Myrhaug', 'Trangesmauet 1', '2011'),
(5471, 'Ole-jørgen', 'Kongshaug', 'Ruskeneshaugen 57', '4265'),
(5472, 'Jørund', 'Gjelsten', 'Kalihaugen 11', '5598'),
(5473, 'Gøril', 'Bjørke', 'Dokkeboder 21', '2309'),
(5474, 'Joakim', 'Garnes', 'Jonsterhaugskiftet 67', '2025'),
(5475, 'Oddbjørn', 'Brunstad', 'Fagertunvegen 29', '1286'),
(5476, 'Gøril', 'Bjørke', 'Dynevoll 2', '4004'),
(5477, 'Målfrid', 'Drage', 'Fæstergrenden 64', '5903'),
(5478, 'Elias', 'Husabø', 'Neshaugen 69', '4586'),
(5479, 'Ada', 'Jørstad', 'Oldernesveien 50', '0455'),
(5480, 'Tatiana', 'Høie', 'Nordeidstølen 28', '0587'),
(5481, 'Stephanie', 'Eng', 'Gullstølslien 12', '4896'),
(5482, 'Carsten', 'Askildsen', 'Bjørgebrekken 9', '3044'),
(5483, 'Evelyn', 'Langaas', 'Erdalsvegen 6F', '0764'),
(5484, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '5845'),
(5485, 'Torje', 'Ottesen', 'Øvre Titlestad 13', '2607'),
(5486, 'Wanja', 'Nordhaug', 'Vestre Murallmenningen 14', '1605'),
(5488, 'Veslemøy', 'Nordbø', 'Vesthagen 6', '3044'),
(5489, 'Emilie', 'Grude', 'Klostersmauet 74', '2825'),
(5490, 'Evelyn', 'Langaas', 'Elgvegenn 6', '0764'),
(5491, 'Dagny', 'Kvamme', 'Sandviksleitet 24', '0764'),
(5492, 'Evelyn', 'Langaas', 'Fabrikkgaten 56', '0764'),
(5493, 'Olve', 'Gundersen', 'Kringlebotn 25', '3683'),
(5494, 'Emilie', 'Grude', 'Klostersmauet 74', '2825'),
(5495, 'Agnar', 'Engelsen', 'Gårdsvegen 21', '5859'),
(5496, 'Ole-jørgen', 'Kongshaug', 'Ruskeneshaugen 57', '2943'),
(5497, 'Stephen', 'Olsvik', 'Øvre alle 31', '3471'),
(5498, 'Veslemøy', 'Nordbø', 'Vesthagen 46', '3790'),
(5499, 'Ismail', 'Furu', 'JensRolfsens gate 47', '5035'),
(5500, 'Evelyn', 'Langaas', 'Skipanesvegen 4A', '0764'),
(5501, 'Villy', 'Lian', 'Skytterveien 24', '3790'),
(5502, 'Karla', 'Hauglid', 'Loddefjordveien 48', '4150'),
(5503, 'Jakob', 'Mundal', 'Tollbugata 53', '3044'),
(5504, 'Villy', 'Lian', 'Skytterveien 24', '3790'),
(5505, 'Ada', 'Fiske', 'Hesthaugvegen 36', '0764'),
(5506, 'Fatma', 'Grønnevik', 'Kollåsen 74', '0579'),
(5507, 'Jarand', 'Mydland', 'Tordenskjolds gate 57', '4742'),
(5508, 'Carsten', 'Askildsen', 'Bjørgebrekken 9', '0760'),
(5509, 'Torje', 'Ottesen', 'Fiolveien 1', '4586'),
(5510, 'Ingmar', 'Bhatti', 'Bønesheien 45', '5035'),
(5511, 'Trine-lise', 'Nilssen', 'Vaskerelven 64', '0270'),
(5512, 'Ali', 'Lunden', 'Starefoss-svingen 15', '5859'),
(5513, 'Målfrid', 'Drage', 'Fæstergrenden 64', '1767'),
(5514, 'Ingmar', 'Bhatti', 'Bønesheien 45', '2015'),
(5515, 'Mathis', 'Bratvold', 'Elvegaten 69', '5035'),
(5516, 'Ada', 'Fiske', 'Hesthaugvegen 36', '3044'),
(5517, 'Olve', 'Gundersen', 'Kringlebotn 25', '6398'),
(5518, 'Ali', 'Lunden', 'Starefoss-svingen 15', '2808'),
(5519, 'Asgeir', 'Alvær', 'Balders veg 23', '5260'),
(5520, 'Mathilde', 'Hessen', 'Midtunstien 54', '4742'),
(5521, 'Madelen', 'Mahmood', 'Straumeveien 2', '4398'),
(5522, 'Odvar', 'Bryhn', 'Fanafjellsvegen 35', '4523'),
(5523, 'Sven', 'Dammen', 'Fosswinckels gate 43', '5258'),
(5524, 'Veslemøy', 'Nordbø', 'Vesthagen 7', '3044'),
(5525, 'Mimmi', 'Dirdal', 'Furubotn 56', '3044'),
(5526, 'Villy', 'Lian', 'Skytterveien 24', '3790'),
(5527, 'Alex', 'Akselsen', 'Arnoldus Reimers'''' gate 24', '5859'),
(5528, 'Ingmar', 'Morken', 'Thomasstien 41C', '1719'),
(5529, 'Jakob', 'Mundal', 'Tollbugata 53', '3790'),
(5530, 'Amina', 'Alexandersen', 'Asylplassen 2', '3790'),
(5531, 'Ismail', 'Furu', 'Glasskaret 47', '0988'),
(5532, 'Gøril', 'Bjørke', 'Gjøas vei 87', '4174'),
(5533, 'Ian', 'Berre', 'Bøkestien 39', '0602'),
(5534, 'Abdi', 'Ekeberg', 'Grendatunvegen 53', '0584'),
(5535, 'Oddlaug', 'Hognestad', 'Myrdalshovden 20', '0122'),
(5536, 'Adam', 'Hestad', 'Midtunvegen 55', '2943'),
(5537, 'Søren', 'Hasle', 'Lilandsvegen 29', '3044'),
(5538, 'Torje', 'Ottesen', 'Øvre titlestad 1', '3893'),
(5539, 'Marvin', 'Brattli', 'Elvebakken 67', '4586'),
(5540, 'Villy', 'Lian', 'Skytterveien 24', '3044'),
(5541, 'Adrian', 'Elvestad', 'Grøvlesvingen 5', '5859'),
(5542, 'Maren', 'Martens', 'Sukkerhusgaten 18', '2847'),
(5543, 'Ronnie', 'Hall', 'Kvitura 59', '3151'),
(5544, 'Oddlaug', 'Hognestad', 'Myrdalshovden 20', '1892'),
(5545, 'May-Britt', 'Hestnes', 'Minde allé 58', '1581'),
(5546, 'Odvar', 'Kolstad', 'Rotvollen 53', '5614'),
(5547, 'Carsten', 'Askildsen', 'Bjørgebrekken 9', '4322'),
(5548, 'Marvin', 'Brattli', 'Elvebakken 67', '5035'),
(5549, 'David', 'Astrup', 'Bjørndalsbrotet 21', '2302'),
(5550, 'Jakob', 'Mundal', 'Tollbugata 53', '3790'),
(5551, 'Edny', 'Kvaal', 'Sejersteds park 40', '4596'),
(5552, 'Evelyn', 'Langaas', 'Gåsestien 134', '1892'),
(5553, 'Kristen', 'Gjøsund', 'Kiplelien 31', '5260'),
(5554, 'Noah', 'Nordlund', 'Vestre solheia 21', '4808'),
(5555, 'Ada', 'Fiske', 'Hesthaugvegen 36', '5282'),
(5556, 'Søren', 'Hasle', 'Lilandsvegen 29', '2206'),
(5557, 'Ingmar', 'Morken', 'Thomasstien 41', '1719'),
(5558, 'Venke', 'Nordang', 'Verftstrappen 2', '3216'),
(5559, 'Mimmi', 'Dirdal', 'Furubotn 56', '2825'),
(5560, 'Marlen', 'Hepsø', 'Merkurvegen 42', '4276'),
(5561, 'Karla', 'Hauglid', 'Loddefjordveien 48', '0025'),
(5562, 'Elias', 'Husabø', 'Neshaugen 69', '6212'),
(5563, 'Svenn', 'Langen', 'Sjømarkvegen 63', '3800'),
(5564, 'Agathe', 'Johnstad', 'Nøttveitlia 34', '5232'),
(5565, 'Olve', 'Gundersen', 'Kringlebotn 25', '1892'),
(5566, 'Ingve', 'Moseng', 'Tipphaugen 45', '0025'),
(5567, 'Alex', 'Lunde', 'Starefossbakken 21', '2607'),
(5568, 'Kaj', 'Mælen', 'Trosteveien 19', '5035'),
(5569, 'Ali', 'Lunden', 'Starefoss-svingen 15', '0565'),
(5570, 'Stephanie', 'Eng', 'Gullstølslien 12', '4398'),
(5571, 'Celine', 'Kruse', 'Sanddalsvegen 10D', '1617'),
(5572, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '3221'),
(5573, 'Paul', 'Gustavson', 'Krohnengssmauet 35', '5859'),
(5574, 'Trine-lise', 'Nilssen', 'Vaskerelven 64B', '1892'),
(5575, 'Gøril', 'Bjørke', 'Liheia 25', '4004'),
(5576, 'Paul', 'Gustavson', 'Krohnengssmauet 35', '0025'),
(5577, 'Karla', 'Hauglid', 'Loddefjordveien 48', '0122'),
(5578, 'Laura', 'Løset', 'Storetveitvegen 52', '2851'),
(5579, 'Anne-Kari', 'Kjelstad', 'Professor Arentz'''' gate 8', '2020'),
(5580, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '1892'),
(5581, 'Mohamed', 'Bremseth', 'Engevikvegen 7', '5035'),
(5582, 'Kristen', 'Gjøsund', 'Kiplelien 31', '5260'),
(5583, 'Marvin', 'Brattli', 'Elvebakken 67', '5258'),
(5584, 'Simon', 'Claussen', 'Forvasshaugen 25', '2334'),
(5585, 'Amalie', 'Albrigtsen', 'Askøyveien 27', '5258'),
(5586, 'Elias', 'Husabø', 'Neshaugen 69', '5202'),
(5587, 'Gøril', 'Bjørke', 'Jordbærstedet', '5202'),
(5588, 'Olve', 'Gundersen', 'Kringlebotn 25', '1539'),
(5589, 'Søren', 'Opedal', 'Øvre gyldenprisveien 45', '3885'),
(5590, 'Thore', 'Hauan', 'Lindealléen 39', '1605'),
(5591, 'Idar', 'Frøyland', 'Janahaugen 37', '3199'),
(5592, 'Jørund', 'Gjelsten', 'Kalihaugen 11', '5859'),
(5593, 'Trine-lise', 'Nilssen', 'Vaskerelven 64', '4993'),
(5594, 'Marvin', 'Brattli', 'Elvebakken 67', '0122'),
(5595, 'Bjørnar', 'Holsen', 'Nattlandsveien 43', '3885'),
(5596, 'Mikkel', 'Kleiveland', 'Ravns gate 23', '1284'),
(5597, 'Lucas', 'Kirkeby', 'Petedalsheia 71', '3044'),
(5598, 'Ian', 'Berre', 'Bøkestien 39', '5630'),
(5599, 'Karla', 'Hauglid', 'Loddefjordveien 48', '3243'),
(5600, 'Brian', 'Holte', 'Nedberget 49', '0988'),
(5601, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '0988'),
(5602, 'Ronnie', 'Hall', 'Kvitura 59', '1747'),
(5603, 'Ingmar', 'Bhatti', 'Bønesheien 45A', '3044'),
(5604, 'Adam', 'Loe', 'St. Halvards vei 22', '0452'),
(5605, 'Adam', 'Loe', 'St. Halvards vei 22', '2007'),
(5606, 'Ole-jørgen', 'Kongshaug', 'Ruskeneshaugen 57', '2943'),
(5607, 'Amina', 'Alexandersen', 'Kipo', '5141'),
(5608, 'Evelyn', 'Langaas', 'Skipsgata 4', '4174'),
(5609, 'Sebastian', 'Kvia', 'Seimshovden 35', '3199'),
(5610, 'Dagny', 'Kvamme', 'Sandviksleitet 24', '0025'),
(5611, 'Trine-lise', 'Nilssen', 'Vaskerelven 64', '1605'),
(5612, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '0971'),
(5613, 'Ismail', 'Furu', 'Koengen 47', '5457'),
(5614, 'Dagny', 'Kvamme', 'Sandviksleitet 24', '4004'),
(5615, 'Jofrid', 'Lorentzen', 'Stabburvegen 4', '2015'),
(5616, 'Adam', 'Hestad', 'Midtunvegen 55', '0579'),
(5618, 'Karla', 'Hauglid', 'Loddefjordveien 48', '3126'),
(5619, 'Nikolai', 'Brudvik', 'Fagerbakkvegen 23E', '3750'),
(5620, 'Ørjan', 'Lilleberg', 'Slåtthauglia 9', '1401'),
(5621, 'Elias', 'Husabø', 'Neshaugen 99', '4742'),
(5622, 'Heine', 'Ibrahim', 'Nordre skogveien 57', '6398'),
(5623, 'Gjert', 'Forland', 'Hylkjeneset 101', '2206'),
(5624, 'Ronnie', 'Hall', 'Kvitura 59', '0452'),
(5625, 'Carsten', 'Askildsen', 'Bjørgebrekken 9', '5258'),
(5626, 'David', 'Astrup', 'Bjørndalsbrotet 21', '3893'),
(5627, 'Gitte', 'Grøstad', 'Kong oscars gate 8', '4993'),
(5628, 'Carsten', 'Askildsen', 'Bjørgebrekken 9', '0452'),
(5629, 'Markus', 'Bratlie', 'Elsters gate 65', '4586'),
(5630, 'Thea', 'Høvik', 'Nordhordlandsvegen 34', '1215'),
(5631, 'Noah', 'Grønvik', 'Kolåshøyen 5', '5614'),
(5632, 'Trine-lise', 'Nilssen', 'Vaskerelven 64', '3126'),
(5633, 'Karla', 'Hauglid', 'Loddefjordveien 48', '1158'),
(5634, 'Trine-lise', 'Nilssen', 'Vaskerelven 64', '3126'),
(5635, 'Lucas', 'Kirkeby', 'Petedalsheia 71', '4004'),
(5636, 'Hildegunn', 'Liland', 'Slottsgaten 8', '5072'),
(5637, 'Mathilde', 'Hessen', 'Midtunstien 54', '5202'),
(5638, 'Trine-lise', 'Nilssen', 'Vaskerelven 64', '3484'),
(5639, 'Celine', 'Ramberg', 'Øvregaten 4B', '3893'),
(5640, 'May-britt', 'Hestnes', 'Minde allé 58', '3893'),
(5641, 'Mimmi', 'Dirdal', 'Furubotn 56', '2607'),
(5642, 'Gøril', 'Bjørke', 'Krabbedalen 2', '1610'),
(5643, 'Ian', 'Berre', 'Bøkestien 39', '3965'),
(5644, 'Ada', 'Fiske', 'Hesthaugvegen 36', '0764'),
(5645, 'Ali', 'Lunden', 'Starefoss-svingen 15', '2808'),
(5646, 'Kaj', 'Mælen', 'Trosteveien 13', '6057'),
(5647, 'Målfrid', 'Drage', 'Fæstergrenden 64', '3885'),
(5648, 'Mathilde', 'Hessen', 'Midtunstien 54', '1605'),
(5649, 'Oddlaug', 'Hognestad', 'Myrdalshovden 20', '6013'),
(5650, 'Brian', 'Holte', 'Nedberget 49', '0988'),
(5651, 'Nicholas', 'Broch', 'Ervikveien 15', '3576'),
(5652, 'Noah', 'Grønvik', 'Kolåshøyen 5A', '4715'),
(5653, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '4004'),
(5654, 'Johny', 'Jonassen', 'Nøttveitvegen 35', '3484'),
(5655, 'Anders', 'Jansen', 'Forvasshaugen 25', '1536'),
(5656, 'Alex', 'Lunde', 'Starefossbakken 13', '1064'),
(5657, 'Brian', 'Holte', 'Nedberget 49', '0452'),
(5658, 'Johny', 'Jonassen', 'Nøttveitvegen 35', '5614'),
(5659, 'Thore', 'Hauan', 'Lindealléen 39', '2851'),
(5660, 'Joakim', 'Garnes', 'Jonsterhaugskiftet 67', '3484'),
(5661, 'Kaj', 'Mælen', 'Trosteveien 13', '3676'),
(5662, 'Karla', 'Hauglid', 'Loddefjordveien 48', '4671'),
(5663, 'Gjert', 'Forland', 'Hylkjeneset 72', '5859'),
(5664, 'Evelyn', 'Langaas', 'Lokes veg 6', '0764'),
(5665, 'Hallstein', 'Håkonsen', 'Londalen 45', '1892'),
(5666, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '5445'),
(5667, 'Evelyn', 'Langaas', 'Lyderhorn 6C', '0444'),
(5668, 'Ulla', 'Iden', 'Nordre Skuteviksveien 58', '4150'),
(5669, 'Søren', 'Opedal', 'Øvre Gyldenprisveien 45', '3885'),
(5670, 'Søren', 'Devik', 'Lyngberget', '4586'),
(5671, 'Mikkel', 'Nordal', 'Verftssmauet 1', '4523'),
(5672, 'Carl', 'Ferstad', 'Helldalslia 19', '5501'),
(5673, 'Tony', 'Lauritzen', 'Skjenlien 1', '3885'),
(5674, 'Gøril', 'Bjørke', 'Midtunlia', '3044'),
(5675, 'Amina', 'Alexandersen', 'Neptuns vei 101', '3044'),
(5676, 'Gitte', 'Grøstad', 'Kong Oscars gate 8', '4322'),
(5677, 'Mohamed', 'Bremseth', 'Engevikvegen 7', '5035'),
(5678, 'Lucas', 'Kirkeby', 'Petedalsheia 71', '3790'),
(5679, 'Eystein', 'Huynh', 'Nils Hertzbergs gate 9', '3151'),
(5680, 'David', 'Astrup', 'Bjørndalsbrotet 21', '0444'),
(5681, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '0988'),
(5682, 'Ada', 'Fiske', 'Hesthaugvegen 36', '3790'),
(5683, 'Mariam', 'Mathiassen', 'Sveiarhaugen 26', '3790'),
(5684, 'Mimmi', 'Dirdal', 'Furubotn 56', '3790'),
(5685, 'Tobias', 'Haugerud', 'Litleholten 45A', '1535'),
(5686, 'Oddlaug', 'Hognestad', 'Myrdalshovden 20', '0122'),
(5687, 'Bengt', 'Hollund', 'Mølleveien 31', '0801'),
(5688, 'Mohamed', 'Bremseth', 'Engevikvegen 7', '5258'),
(5689, 'Gøril', 'Bjørke', 'Dokkeboder 2', '2309'),
(5690, 'Mikkel', 'Kleiveland', 'Ravns gate 23', '2847'),
(5691, 'Karla', 'Hauglid', 'Loddefjordveien 48', '6029'),
(5692, 'Joakim', 'Bjørgen', 'Danckert Krohns gate 71', '5010'),
(5693, 'Olve', 'Nornes', 'Vinjes gate 41', '2607'),
(5694, 'Brian', 'Holte', 'Nedberget 49', '2309'),
(5695, 'Asgeir', 'Hoftun', 'Myravegen 19', '3285'),
(5696, 'Brage', 'Arntsen', 'Bernhard Meyers vei 24', '0250'),
(5698, 'Kaare', 'Gloppen', 'Kippersmauet 35', '5859'),
(5699, 'Trine-lise', 'Nilssen', 'Vaskerelven 64', '3484'),
(5700, 'Abdullahi', 'Hellem', 'Margaretastredet 21', '2074'),
(5701, 'Gjert', 'Forland', 'Hylkjeneset 69', '3606'),
(5702, 'Benedicte', 'Furulund', 'Joachim Frieles gate 50', '2015'),
(5703, 'Kaj', 'Mælen', 'Trosteveien 13', '2808'),
(5704, 'Veslemøy', 'Nordbø', 'Vesthagen 6', '4174'),
(5705, 'Gøril', 'Bjørke', 'Oldernesveien 2A', '2851'),
(5706, 'Brian', 'Holte', 'Nedberget 49', '1730'),
(5707, 'Tom-erik', 'Drange', 'Fæsteråsen 67', '0406'),
(5708, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '0764'),
(5709, 'Hallstein', 'Håkonsen', 'Nordre Gommershaugen 45', '4696'),
(5710, 'Gøril', 'Bjørke', 'Persenbakken 2', '3199'),
(5711, 'Evelyn', 'Langaas', 'Pinnelien 6', '0764'),
(5712, 'Mehmet', 'Nome', 'Venåsen 71', '3676'),
(5713, 'Emilie', 'Grude', 'Klostersmauet 74', '4645'),
(5714, 'Olve', 'Gundersen', 'Kringlebotn 25', '3965'),
(5715, 'Elias', 'Husabø', 'Neshaugen 69', '1763'),
(5716, 'Marvin', 'Brattli', 'Elvebakken 67', '4265'),
(5717, 'Eystein', 'Huynh', 'Nils Hertzbergs gate 9', '0214'),
(5718, 'Ulla', 'Iden', 'Nordre Skuteviksveien 58', '5401'),
(5719, 'Stephanie', 'Eng', 'Gullstølslien 12', '4671'),
(5720, 'Ismail', 'Furu', 'Jens Rolfsens gate 47', '3790'),
(5721, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '0764'),
(5722, 'Ada', 'Fiske', 'Hesthaugvegen 36B', '3790'),
(5723, 'Dagny', 'Kvamme', 'Sandviksleitet 24', '2607'),
(5724, 'Idar', 'Frøyland', 'Janahaugen 37', '6062'),
(5725, 'Aina', 'Nygren', 'Von der Ohes vei 50', '0032'),
(5726, 'Veslemøy', 'Nordbø', 'Vesthagen 6', '3044'),
(5727, 'Wanja', 'Nordhaug', 'Vestre Murallmenningen 14', '0025'),
(5728, 'Agnar', 'Engelsen', 'Gårdsvegen 21', '5859'),
(5729, 'Frithjof', 'Bastiansen', 'Brattlandsvegen 61', '3044'),
(5730, 'Brian', 'Holte', 'Nedberget 49', '0764'),
(5731, 'Dagny', 'Kvamme', 'Sandviksleitet 24', '0764'),
(5732, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '0764'),
(5734, 'Amina', 'Alexandersen', 'Plytten', '0988'),
(5735, 'Ada', 'Fiske', 'Hesthaugvegen 36', '3044'),
(5736, 'Veslemøy', 'Nordbø', 'Vesthagen 8', '4174'),
(5737, 'Sebastian', 'Ofstad', 'Zander Kaaes gate 13', '2943'),
(5738, 'Marvin', 'Brattli', 'Elvebakken 67F', '3471'),
(5739, 'Svenn', 'Langen', 'Sjømarkvegen 63', '1610'),
(5740, 'Ørjan', 'Helberg', 'Løtveitveien 9', '3790'),
(5741, 'Eigil', 'Fjelde', 'Hillerenveien 43', '4586'),
(5742, 'Steven', 'Oma', 'Øvre bjørkåsen 33', '3044'),
(5743, 'Idar', 'Mongstad', 'Tertnesgrenden 37', '3209'),
(5744, 'Mehmet', 'Nome', 'Venåsen 71', '2223'),
(5745, 'Noah', 'Grønvik', 'Kolåshøyen 5', '4586'),
(5746, 'Veslemøy', 'Nordbø', 'Vesthagen 1', '0988'),
(5747, 'Adrian', 'Elvestad', 'Grøvlesvingen 5', '5035'),
(5748, 'Sven', 'Dammen', 'Frieda Fasmers vei 43', '3044'),
(5749, 'Paul', 'Gustavson', 'Krohnengssmauet 35', '3507'),
(5750, 'Thea', 'Høvik', 'Nordhordlandsvegen 34', '1763'),
(5751, 'Carsten', 'Askildsen', 'Bjørgebrekken 9', '4322'),
(5752, 'Bengt', 'Hollund', 'Mølleveien 31', '4688'),
(5753, 'Villy', 'Lian', 'Skytterveien 24', '3044'),
(5754, 'Ismail', 'Furu', 'Jens Rolfsens gate 47', '2808'),
(5755, 'Veslemøy', 'Nordbø', 'Nordilia', '3044'),
(5756, 'Susanne', 'Natland', 'Tverrgaten 24F', '0764'),
(5757, 'Markus', 'Bratlie', 'Elsters gate 65', '5445'),
(5758, 'Mohammed', 'Nordby', 'Vestgårdvegen 5', '1255'),
(5759, 'Adam', 'Loe', 'St. Halvards vei 22', '3885'),
(5760, 'David', 'Astrup', 'Bjørndalsbrotet 21', '2607'),
(5761, 'Evelyn', 'Langaas', 'Reinane', '0764'),
(5762, 'Oddbjørn', 'Brunstad', 'Fagertunvegen 29', '1763'),
(5763, 'Hilmar', 'Bergstrøm', 'Bursflata 31', '0764'),
(5764, 'Ørjan', 'Helberg', 'Løtveitveien 9', '0255'),
(5765, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '1610'),
(5766, 'Ole-jørgen', 'Kongshaug', 'Ruskeneshaugen 57', '2943'),
(5767, 'Evelyn', 'Langaas', 'Klarhei 4', '1286'),
(5768, 'Bjørnar', 'Holsen', 'Nattlandsveien 43', '3885'),
(5769, 'Emil', 'Fjellestad', 'Hjellestadvegen 49', '4645'),
(5770, 'Ismail', 'Furu', 'JensRolfsens gate 47', '3209'),
(5771, 'Eystein', 'Huynh', 'Nils Hertzbergs gate 9', '0602'),
(5772, 'Veslemøy', 'Nordbø', 'Vesthagen 6', '3044'),
(5773, 'Hallstein', 'Håkonsen', 'Råtun', '4696'),
(5774, 'Ottar', 'Bue', 'Feråsvegen 51E', '3216'),
(5775, 'Elias', 'Husabø', 'Neshaugen 69', '6057'),
(5776, 'Fanny', 'Betten', 'Bønesberget 44', '3126'),
(5777, 'Mikkel', 'Kleiveland', 'Ravns gate 23', '2847'),
(5778, 'Flemming', 'Mellum', 'Sætrevegen 51', '0760'),
(5779, 'Emilie', 'Grude', 'Klostersmauet 74', '5282'),
(5780, 'Evelyn', 'Langaas', 'Jordbotn 9', '1286'),
(5781, 'Brian', 'Holte', 'Nedberget 49', '0988'),
(5782, 'Andres', 'Hjelm', 'Morvikbotn 1', '0025'),
(5783, 'Kaj', 'Mælen', 'Trosteveien 13', '2808'),
(5784, 'Gjert', 'Forland', 'Hylkjeneset 69', '1389'),
(5785, 'Hulda', 'Blakstad', 'Edvard Griegs vei 26', '0760'),
(5786, 'Eystein', 'Bakker', 'Borgermester Platous gate 49', '4523'),
(5787, 'Maren', 'Martens', 'Sukkerhusgaten 18', '2943'),
(5788, 'Adam', 'Loe', 'St. Halvards vei 22', '3681'),
(5789, 'Gjert', 'Forland', 'Hylkjeneset 69', '0270'),
(5790, 'Joakim', 'Johnsen', 'Nøstebodene 31', '6057'),
(5791, 'Celine', 'Ramberg', 'Øvregaten 4', '1539'),
(5792, 'Ann-kristin', 'Anthonsen', 'Bellgården 15', '6029'),
(5793, 'Adam', 'Loe', 'St. Halvards vei 22D', '3606'),
(5794, 'Veslemøy', 'Nordbø', 'Vesthagen 6', '1286'),
(5795, 'Lucas', 'Kirkeby', 'Petedalsheia 71', '1539'),
(5796, 'Fanny', 'Betten', 'Bønesberget 44', '0122'),
(5797, 'Agnar', 'Engelsen', 'Gårdsvegen 21', '4696'),
(5798, 'Stephanie', 'Eng', 'Gullstølslien 12', '4671'),
(5799, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '1892'),
(5800, 'Evelyn', 'Langaas', 'Skipanesvegen 6', '0764'),
(5801, 'Ian', 'Irgens', 'Nordåshøgda 73', '3209'),
(5802, 'Sven', 'Dammen', 'Frieda Fasmers vei 43', '6057'),
(5803, 'Brian', 'Holte', 'Nedberget 49', '2825'),
(5804, 'Ismail', 'Furu', 'Jens Rolfsens gate 47D', '4004'),
(5805, 'Jane', 'Brandtzæg', 'Elgvegen 58', '1286'),
(5806, 'Brian', 'Holte', 'Nedberget 49', '2309'),
(5807, 'Abdirahman', 'Lindahl', 'Solbakksvingen 27', '4276'),
(5808, 'Johny', 'Jonassen', 'Nøttveitvegen 35', '5859'),
(5809, 'Søren', 'Hasle', 'Lilandsvegen 29', '5859'),
(5810, 'Hilmar', 'Bergstrøm', 'Bursflata 31', '2302'),
(5811, 'Olve', 'Gundersen', 'Kringlebotn 25', '0270'),
(5812, 'Abdirahman', 'Lindahl', 'Solbakksvingen 27', '4276'),
(5813, 'Amina', 'Alexandersen', 'Asylplassen 2', '3199'),
(5814, 'Bengt', 'Hollund', 'Mølleveien 31', '0801'),
(5815, 'Gøril', 'Bjørke', 'Skjoldlia', '3681'),
(5816, 'Joakim', 'Bjørgen', 'Danckert Krohns gate 71', '3606'),
(5817, 'Abdullah', 'Endal', 'Gullfjellsvegen 9', '5282'),
(5818, 'Lucas', 'Kirkeby', 'Petedalsheia 71', '3790'),
(5819, 'Eystein', 'Bakker', 'Borgermester Platous gate 49', '3790'),
(5820, 'Elias', 'Husabø', 'Neshaugen 69', '4742'),
(5821, 'Birgitte', 'Garshol', 'Jonsvollsgaten 68A', '5912'),
(5822, 'Gøril', 'Bjørke', 'Svineryggen', '3681'),
(5823, 'Ailin', 'Fjellvang', 'Hjortlandsvegen 52', '3681'),
(5824, 'Erland', 'Hussain', 'Nesttunkollen 1', '0171');



--
-- Dataark for tabell Ordre
--

INSERT INTO `Ordre` (`OrdreNr`, `OrdreDato`, `SendtDato`, `BetaltDato`, `KNr`) VALUES
(20505, '2015-08-20', '2015-08-25', '2015-09-14', 5022),
(20506, '2015-08-20', '2015-08-22', '2015-09-07', 5009),
(20507, '2015-08-20', '2015-08-25', '2015-09-14', 5188),
(20508, '2015-08-20', '2015-08-22', '2015-09-07', 5039),
(20509, '2015-08-20', '2015-08-25', '2015-09-14', 5082),
(20510, '2015-08-20', '2015-08-22', '2015-09-07', 5256),
(20511, '2015-08-20', '2015-08-25', '2015-09-14', 5129),
(20512, '2015-08-20', '2015-08-22', '2015-09-07', 5353),
(20513, '2015-08-20', '2015-08-25', '2015-09-14', 5353),
(20514, '2015-08-20', '2015-08-22', '2013-09-07', 5091),
(20515, '2015-08-20', '2015-08-25', '2015-09-14', 5256),
(20516, '2015-08-20', '2015-08-22', '2015-09-07', 5237),
(20517, '2015-08-20', '2015-08-25', '2015-09-14', 5042),
(20518, '2015-08-20', '2015-08-22', '2015-09-07', 5188),
(20519, '2015-08-20', '2015-08-25', '2015-09-14', 5353),
(20520, '2015-08-20', '2015-08-22', '2015-09-07', 5237),
(20521, '2015-08-20', '2015-08-25', '2015-09-14', 5316),
(20522, '2015-08-20', '2015-08-22', '2015-09-07', 5316),
(20523, '2015-03-08', '2015-03-12', '2015-03-23', 5002),
(20524, '2015-04-08', '2015-04-12', '2015-04-23', 5007),
(20525, '2015-04-08', '2015-04-12', '2015-04-23', 5009),
(20526, '2015-04-09', '2015-04-13', '2015-04-24', 5011),
(20527, '2015-04-09', '2015-04-13', '2015-04-24', 5022),
(20528, '2015-04-09', '2015-04-13', '2015-04-24', 5025),
(20529, '2015-04-10', '2015-04-14', '2015-04-25', 5028),
(20530, '2015-04-10', '2015-04-14', '2015-04-25', 5039),
(20531, '2015-04-10', '2015-04-14', '2015-04-25', 5042),
(20532, '2015-04-11', '2015-04-15', '2015-04-26', 5043),
(20533, '2015-04-11', '2015-04-15', '2015-04-26', 5049),
(20534, '2015-04-11', '2015-04-15', '2015-04-26', 5071),
(20535, '2015-05-12', '2015-05-16', '2015-05-27', 5079),
(20536, '2015-05-12', '2015-05-16', '2015-05-27', 5081),
(20537, '2015-05-12', '2015-05-16', '2015-05-27', 5082),
(20538, '2015-05-13', '2015-05-17', '2015-05-28', 5087),
(20539, '2015-05-13', '2015-05-17', '2015-05-28', 5091),
(20540, '2015-05-13', '2015-05-17', '2015-05-28', 5092),
(20541, '2015-05-14', '2015-05-18', '2015-05-29', 5093),
(20542, '2015-06-14', '2015-06-18', '2015-06-29', 5102),
(20543, '2015-06-14', '2015-06-18', '2015-06-29', 5119),
(20544, '2015-06-15', '2015-06-20', '2015-07-01', 5574),
(20545, '2015-06-15', '2015-06-20', '2015-07-01', 5575),
(20546, '2015-06-15', '2015-06-20', '2015-07-01', 5576),
(20547, '2015-06-16', '2015-06-21', '2015-07-02', 5577),
(20548, '2015-06-16', '2015-06-21', '2015-07-02', 5578),
(20549, '2015-06-16', '2015-06-21', '2015-07-02', 5579),
(20550, '2015-06-17', '2015-06-22', '2015-07-03', 5580),
(20551, '2015-06-17', '2015-06-22', '2015-07-03', 5581),
(20552, '2015-09-17', '2015-09-22', '2015-10-03', 5582),
(20553, '2015-09-18', '2015-09-23', '2015-10-04', 5583),
(20554, '2015-09-18', '2015-09-23', '2015-10-04', 5584),
(20555, '2015-09-18', '2015-09-23', '2015-10-04', 5585),
(20556, '2015-09-19', '2015-09-24', '2015-10-05', 5586),
(20557, '2015-09-19', '2015-09-24', '2015-10-05', 5587),
(20558, '2015-09-19', '2015-09-24', '2015-10-05', 5139),
(20559, '2015-09-20', '2015-09-25', '2015-10-06', 5144),
(20560, '2015-09-20', '2015-09-25', '2015-10-06', 5162),
(20561, '2015-02-20', '2015-02-25', '2015-03-07', 5172),
(20562, '2015-02-21', '2015-02-26', '2015-03-08', 5237),
(20563, '2015-02-21', '2015-02-26', '2015-03-08', 5238),
(20564, '2015-02-21', '2015-02-26', '2015-03-08', 5239),
(20565, '2015-02-22', '2015-02-27', '2015-03-09', 5250),
(20566, '2015-02-22', '2015-02-27', '2015-03-09', 5251),
(20567, '2015-04-22', '2015-04-27', '2015-05-08', 5256),
(20568, '2015-04-23', '2015-04-28', '2015-05-09', 5267),
(20569, '2015-04-23', '2015-04-28', '2015-05-09', 5310),
(20570, '2015-04-23', '2015-04-28', '2015-05-09', 5316),
(20571, '2015-04-24', '2015-04-29', '2015-05-10', 5321),
(20572, '2015-04-24', '2015-04-29', '2015-05-10', 5322),
(20573, '2015-04-24', '2015-04-29', '2015-05-10', 5328),
(20574, '2015-04-25', '2015-05-01', '2015-05-12', 5353),
(20575, '2015-04-25', '2015-05-01', '2015-05-12', 5354),
(20576, '2015-04-25', '2015-05-01', '2015-05-12', 5355),
(20577, '2015-04-26', '2015-05-02', '2015-05-13', 5356),
(20578, '2015-04-26', '2015-05-02', '2015-05-13', 5432),
(20579, '2015-05-26', '2015-06-01', '2015-06-12', 5433),
(20580, '2015-05-27', '2015-06-02', '2015-06-13', 5434),
(20581, '2015-05-27', '2015-06-02', '2015-06-13', 5435),
(20582, '2015-05-27', '2015-06-02', '2015-06-13', 5445),
(20583, '2015-05-28', '2015-06-03', '2015-06-14', 5477),
(20584, '2015-05-28', '2015-06-03', '2015-06-14', 5322),
(20585, '2015-05-28', '2015-06-03', '2015-06-14', 5328),
(20586, '2015-05-29', '2015-06-04', '2015-06-15', 5353),
(20587, '2015-05-29', '2015-06-04', '2015-06-15', 5354),
(20588, '2015-05-29', '2015-06-04', '2015-06-15', 5438),
(20589, '2015-05-30', '2015-06-05', '2015-06-16', 5439),
(20590, '2015-05-30', '2015-06-05', '2015-06-16', 5440),
(20591, '2015-05-30', '2015-06-05', '2015-06-16', 5441),
(20592, '2015-05-31', '2015-06-06', '2015-06-17', 5442),
(20593, '2015-05-31', '2015-06-06', '2015-06-17', 5443),
(20594, '2015-05-31', '2015-06-06', '2015-06-17', 5444),
(20595, '2015-06-01', '2015-06-07', '2015-06-18', 5445),
(20596, '2015-02-01', '2015-02-07', '2015-02-18', 5477),
(20597, '2015-02-01', '2015-02-07', '2015-02-18', 5478),
(20598, '2015-02-02', '2015-02-08', '2015-02-19', 5479),
(20599, '2015-02-02', '2015-02-08', '2015-02-19', 5480),
(20600, '2014-12-31', '2015-01-03', '2015-01-14', 5481),
(20601, '2014-12-31', '2015-01-03', '2015-01-14', 5482),
(20602, '2015-01-01', '2015-01-04', '2015-01-15', 5483),
(20603, '2015-01-01', '2015-01-04', '2015-01-15', 5484),
(20604, '2015-01-01', '2015-01-04', '2015-01-15', 5485),
(20605, '2015-01-02', '2015-01-05', '2015-01-16', 5486),
(20606, '2015-01-02', '2015-01-05', '2015-01-16', 5488),
(20607, '2015-01-02', '2015-01-05', '2015-01-16', 5489),
(20608, '2015-01-03', '2015-01-06', '2015-01-17', 5385),
(20609, '2015-01-03', '2015-01-06', '2015-01-17', 5386),
(20610, '2015-01-03', '2015-01-06', '2015-01-17', 5387),
(20611, '2015-01-04', '2015-01-07', '2015-01-18', 5388),
(20612, '2015-01-04', '2015-01-07', '2015-01-18', 5389),
(20613, '2015-01-04', '2015-01-07', '2015-01-18', 5390),
(20614, '2015-01-05', '2015-01-09', '2015-01-20', 5391),
(20615, '2015-01-05', '2015-01-09', '2015-01-20', 5392),
(20616, '2015-01-05', '2015-01-09', '2015-01-20', 5393),
(20617, '2015-01-06', '2015-01-10', '2015-01-21', 5394),
(20618, '2015-01-06', '2015-01-10', '2015-01-21', 5395),
(20619, '2015-01-06', '2015-01-10', '2015-01-21', 5353),
(20620, '2015-01-07', '2015-01-11', '2015-01-22', 5354),
(20621, '2015-01-07', '2015-01-11', '2015-01-22', 5355),
(20622, '2015-01-07', '2015-01-11', '2015-01-22', 5356),
(20623, '2015-01-08', '2015-01-12', '2015-01-23', 5357),
(20624, '2015-01-08', '2015-01-12', '2015-01-23', 5358),
(20625, '2015-01-08', '2015-01-12', '2015-01-23', 5359),
(20626, '2015-01-09', '2015-01-13', '2015-01-24', 5360),
(20627, '2015-01-09', '2015-01-13', '2015-01-24', 5361),
(20628, '2015-01-09', '2015-01-13', '2015-01-24', 5362),
(20629, '2015-01-10', '2015-01-14', '2015-01-25', 5363),
(20630, '2015-01-10', '2015-01-14', '2015-01-25', 5364),
(20631, '2015-01-10', '2015-01-14', '2015-01-25', 5365),
(20632, '2015-01-11', '2015-01-15', '2015-01-26', 5366),
(20633, '2015-01-11', '2015-01-15', '2015-01-26', 5367),
(20634, '2015-01-11', '2015-01-15', '2015-01-26', 5368),
(20635, '2015-01-12', '2015-01-16', '2015-01-27', 5369),
(20636, '2015-01-12', '2015-01-16', '2015-01-27', 5370),
(20637, '2015-01-12', '2015-01-16', '2015-01-27', 5371),
(20638, '2015-01-13', '2015-01-17', '2015-01-28', 5426),
(20639, '2015-01-13', '2015-01-17', '2015-01-28', 5427),
(20640, '2015-01-13', '2015-01-17', '2015-01-28', 5428),
(20641, '2015-01-14', '2015-01-18', '2015-01-29', 5429),
(20642, '2015-01-14', '2015-01-18', '2015-01-29', 5430),
(20643, '2015-01-14', '2015-01-18', '2015-01-29', 5431),
(20644, '2015-01-15', '2015-01-20', '2015-01-31', 5432),
(20645, '2015-01-15', '2015-01-20', '2015-01-31', 5433),
(20646, '2015-01-15', '2015-01-20', '2015-01-31', 5434),
(20647, '2015-01-16', '2015-01-21', '2015-02-01', 5381),
(20648, '2015-01-16', '2015-01-21', '2015-02-01', 5382),
(20649, '2015-01-16', '2015-01-21', '2015-02-01', 5383),
(20650, '2015-01-17', '2015-01-22', '2015-02-02', 5384),
(20651, '2015-01-17', '2015-01-22', '2015-02-02', 5385),
(20652, '2015-01-17', '2015-01-22', '2015-02-02', 5386),
(20653, '2015-01-18', '2015-01-23', '2015-02-03', 5449),
(20654, '2015-01-18', '2015-01-23', '2015-02-03', 5450),
(20655, '2015-01-18', '2015-01-23', '2015-02-03', 5451),
(20656, '2015-01-19', '2015-01-24', '2015-02-04', 5452),
(20657, '2015-01-19', '2015-01-24', '2015-02-04', 5453),
(20658, '2015-01-19', '2015-01-24', '2015-02-04', 5454),
(20659, '2015-01-20', '2015-01-25', '2015-02-05', 5455),
(20660, '2015-01-20', '2015-01-25', '2015-02-05', 5456),
(20661, '2015-01-20', '2015-01-25', '2015-02-05', 5457),
(20662, '2015-01-21', '2015-01-26', '2015-02-06', 5458),
(20663, '2015-01-21', '2015-01-26', '2015-02-06', 5459),
(20664, '2015-01-21', '2015-01-26', '2015-02-06', 5460),
(20665, '2015-01-22', '2015-01-27', '2015-02-07', 5461),
(20666, '2015-01-22', '2015-01-27', '2015-02-07', 5466),
(20667, '2015-01-22', '2015-01-27', '2015-02-07', 5467),
(20668, '2015-01-23', '2015-01-28', '2015-02-08', 5468),
(20669, '2015-01-23', '2015-01-28', '2015-02-08', 5469),
(20670, '2015-01-23', '2015-01-28', '2015-02-08', 5470),
(20671, '2015-01-24', '2015-01-29', '2015-02-09', 5471),
(20672, '2015-01-24', '2015-01-29', '2015-02-09', 5472),
(20673, '2015-01-24', '2015-01-29', '2015-02-09', 5473),
(20674, '2015-01-25', '2015-01-31', '2015-02-11', 5474),
(20675, '2015-01-25', '2015-01-31', '2015-02-11', 5475),
(20676, '2015-01-25', '2015-01-31', '2015-02-11', 5476),
(20677, '2015-01-26', '2015-02-01', '2015-02-12', 5392),
(20678, '2015-01-26', '2015-02-01', '2015-02-12', 5393),
(20679, '2015-01-26', '2015-02-01', '2015-02-12', 5394),
(20680, '2015-01-27', '2015-02-02', '2015-02-13', 5395),
(20681, '2015-01-27', '2015-02-02', '2015-02-13', 5396),
(20682, '2015-01-27', '2015-02-02', '2015-02-13', 5397),
(20683, '2015-01-28', '2015-02-03', '2015-02-14', 5398),
(20684, '2015-01-28', '2015-02-03', '2015-02-14', 5399),
(20685, '2015-01-28', '2015-02-03', '2015-02-14', 5400),
(20686, '2015-01-29', '2015-02-04', '2015-02-15', 5401),
(20687, '2015-01-29', '2015-02-04', '2015-02-15', 5402),
(20688, '2015-01-29', '2015-02-04', '2015-02-15', 5403),
(20689, '2015-01-30', '2015-02-05', '2015-02-16', 5404),
(20690, '2015-01-30', '2015-02-05', '2015-02-16', 5405),
(20691, '2015-01-30', '2015-02-05', '2015-02-16', 5406),
(20692, '2015-01-31', '2015-02-06', '2015-02-17', 5407),
(20693, '2015-01-31', '2015-02-06', '2015-02-17', 5408),
(20694, '2015-01-31', '2015-02-06', '2015-02-17', 5409),
(20695, '2015-02-01', '2015-02-07', '2015-02-18', 5410),
(20696, '2015-02-01', '2015-02-07', '2015-02-18', 5411),
(20697, '2015-02-01', '2015-02-07', '2015-02-18', 5412),
(20698, '2015-02-02', '2015-02-08', '2015-02-19', 5413),
(20699, '2015-02-02', '2015-02-08', '2015-02-19', 5414),
(20700, '2014-12-31', '2015-01-03', '2015-01-14', 5415),
(20701, '2014-12-31', '2015-01-03', '2015-01-14', 5416),
(20702, '2015-01-01', '2015-01-04', '2015-01-15', 5417),
(20703, '2015-01-01', '2015-01-04', '2015-01-15', 5418),
(20704, '2015-01-01', '2015-01-04', '2015-01-15', 5419),
(20705, '2015-01-02', '2015-01-05', '2015-01-16', 5420),
(20706, '2015-01-02', '2015-01-05', '2015-01-16', 5421),
(20707, '2015-01-02', '2015-01-05', '2015-01-16', 5422),
(20708, '2015-01-03', '2015-01-06', '2015-01-17', 5423),
(20709, '2015-01-03', '2015-01-06', '2015-01-17', 5424),
(20710, '2015-01-03', '2015-01-06', '2015-01-17', 5499),
(20711, '2015-01-04', '2015-01-07', '2015-01-18', 5500),
(20712, '2015-01-04', '2015-01-07', '2015-01-18', 5501),
(20713, '2015-01-04', '2015-01-07', '2015-01-18', 5502),
(20714, '2015-01-05', '2015-01-09', '2015-01-20', 5503),
(20715, '2015-01-05', '2015-01-09', '2015-01-20', 5504),
(20716, '2015-01-05', '2015-01-09', '2015-01-20', 5505),
(20717, '2015-01-06', '2015-01-10', '2015-01-21', 5506),
(20718, '2015-01-06', '2015-01-10', '2015-01-21', 5507),
(20719, '2015-01-06', '2015-01-10', '2015-01-21', 5508),
(20720, '2015-01-07', '2015-01-11', '2015-01-22', 5509),
(20721, '2015-01-07', '2015-01-11', '2015-01-22', 5510),
(20722, '2015-01-07', '2015-01-11', '2015-01-22', 5511),
(20723, '2015-01-08', '2015-01-12', '2015-01-23', 5456),
(20724, '2015-01-08', '2015-01-12', '2015-01-23', 5457),
(20725, '2015-01-08', '2015-01-12', '2015-01-23', 5458),
(20726, '2015-01-09', '2015-01-13', '2015-01-24', 5459),
(20727, '2015-01-09', '2015-01-13', '2015-01-24', 5460),
(20728, '2015-01-09', '2015-01-13', '2015-01-24', 5461),
(20729, '2015-01-10', '2015-01-14', '2015-01-25', 5462),
(20730, '2015-01-10', '2015-01-14', '2015-01-25', 5463),
(20731, '2015-01-10', '2015-01-14', '2015-01-25', 5464),
(20732, '2015-01-11', '2015-01-15', '2015-01-26', 5549),
(20733, '2015-01-11', '2015-01-15', '2015-01-26', 5550),
(20734, '2015-01-11', '2015-01-15', '2015-01-26', 5551),
(20735, '2015-01-12', '2015-01-16', '2015-01-27', 5552),
(20736, '2015-01-12', '2015-01-16', '2015-01-27', 5553),
(20737, '2015-01-12', '2015-01-16', '2015-01-27', 5554),
(20738, '2015-01-13', '2015-01-17', '2015-01-28', 5555),
(20739, '2015-01-13', '2015-01-17', '2015-01-28', 5556),
(20740, '2015-01-13', '2015-01-17', '2015-01-28', 5557),
(20741, '2015-01-14', '2015-01-18', '2015-01-29', 5558),
(20742, '2015-01-14', '2015-01-18', '2015-01-29', 5559),
(20743, '2015-01-14', '2015-01-18', '2015-01-29', 5560),
(20744, '2015-01-15', '2015-01-20', '2015-01-31', 5561),
(20745, '2015-01-15', '2015-01-20', '2015-01-31', 5562),
(20746, '2015-01-15', '2015-01-20', '2015-01-31', 5563),
(20747, '2015-01-16', '2015-01-21', '2015-02-01', 5564),
(20748, '2015-01-16', '2015-01-21', '2015-02-01', 5565),
(20749, '2015-01-16', '2015-01-21', '2015-02-01', 5566),
(20750, '2015-01-17', '2015-01-22', '2015-02-02', 5567),
(20751, '2015-01-17', '2015-01-22', '2015-02-02', 5568),
(20752, '2015-01-17', '2015-01-22', '2015-02-02', 5569),
(20753, '2015-01-18', '2015-01-23', '2015-02-03', 5570),
(20754, '2015-01-18', '2015-01-23', '2015-02-03', 5571),
(20755, '2015-01-18', '2015-01-23', '2015-02-03', 5572),
(20756, '2015-01-19', '2015-01-24', '2015-02-04', 5569),
(20757, '2015-01-19', '2015-01-24', '2015-02-04', 5570),
(20758, '2015-01-19', '2015-01-24', '2015-02-04', 5571),
(20759, '2015-01-20', '2015-01-25', '2015-02-05', 5572),
(20760, '2015-01-20', '2015-01-25', '2015-02-05', 5573),
(20761, '2015-01-20', '2015-01-25', '2015-02-05', 5574),
(20762, '2015-01-21', '2015-01-26', '2015-02-06', 5575),
(20763, '2015-01-21', '2015-01-26', '2015-02-06', 5576),
(20764, '2015-01-21', '2015-01-26', '2015-02-06', 5577),
(20765, '2015-01-22', '2015-01-27', '2015-02-07', 5578),
(20766, '2015-01-22', '2015-01-27', '2015-02-07', 5579),
(20767, '2015-01-22', '2015-01-27', '2015-02-07', 5580),
(20768, '2015-01-23', '2015-01-28', '2015-02-08', 5550),
(20769, '2015-01-23', '2015-01-28', '2015-02-08', 5551),
(20770, '2015-01-23', '2015-01-28', '2015-02-08', 5552),
(20771, '2015-01-24', '2015-01-29', '2015-02-09', 5553),
(20772, '2015-01-24', '2015-01-29', '2015-02-09', 5554),
(20773, '2015-01-24', '2015-01-29', '2015-02-09', 5555),
(20774, '2015-01-25', '2015-01-31', '2015-02-11', 5587),
(20775, '2015-02-25', '2015-03-02', '2015-03-13', 5588),
(20776, '2015-02-25', '2015-03-02', '2015-03-13', 5589),
(20777, '2015-02-26', '2015-03-03', '2015-03-14', 5590),
(20778, '2015-02-26', '2015-03-03', '2015-03-14', 5591),
(20779, '2015-02-26', '2015-03-03', '2015-03-14', 5592),
(20780, '2015-02-27', '2015-03-04', '2015-03-15', 5593),
(20781, '2015-02-27', '2015-03-04', '2015-03-15', 5594),
(20782, '2015-02-27', '2015-03-04', '2015-03-15', 5595),
(20783, '2015-02-28', '2015-03-05', '2015-03-16', 5596),
(20784, '2015-02-28', '2015-03-05', '2015-03-16', 5597),
(20785, '2015-02-28', '2015-03-05', '2015-03-16', 5598),
(20786, '2015-02-28', '2015-03-06', '2015-03-17', 5599),
(20787, '2015-02-28', '2015-03-06', '2015-03-17', 5600),
(20788, '2015-02-28', '2015-03-06', '2015-03-17', 5701),
(20789, '2015-03-01', '2015-03-07', '2015-03-18', 5702),
(20790, '2015-03-01', '2015-03-07', '2015-03-18', 5703),
(20791, '2015-03-01', '2015-03-07', '2015-03-18', 5704),
(20792, '2015-03-02', '2015-03-08', '2015-03-19', 5705),
(20793, '2015-03-02', '2015-03-08', '2015-03-19', 5706),
(20794, '2015-03-02', '2015-03-08', '2015-03-19', 5707),
(20795, '2015-03-03', '2015-03-09', '2015-03-20', 5708),
(20796, '2015-03-03', '2015-03-09', '2015-03-20', 5709),
(20797, '2015-03-03', '2015-03-09', '2015-03-20', 5710),
(20798, '2015-03-04', '2015-03-10', '2015-03-21', 5711),
(20799, '2015-03-04', '2015-03-10', '2015-03-21', 5712),
(20800, '2015-01-31', '2015-02-03', '2015-02-14', 5713),
(20801, '2015-01-31', '2015-02-03', '2015-02-14', 5714),
(20802, '2015-02-01', '2015-02-04', '2015-02-15', 5715),
(20803, '2015-02-01', '2015-02-04', '2015-02-15', 5716),
(20804, '2015-02-01', '2015-02-04', '2015-02-15', 5717),
(20805, '2015-02-02', '2015-02-05', '2015-02-16', 5718),
(20806, '2015-02-02', '2015-02-05', '2015-02-16', 5719),
(20807, '2015-02-02', '2015-02-05', '2015-02-16', 5525),
(20808, '2015-02-03', '2015-02-06', '2015-02-17', 5526),
(20809, '2015-02-03', '2015-02-06', '2015-02-17', 5527),
(20810, '2015-02-03', '2015-02-06', '2015-02-17', 5528),
(20811, '2015-02-04', '2015-02-07', '2015-02-18', 5529),
(20812, '2015-02-04', '2015-02-07', '2015-02-18', 5530),
(20813, '2015-02-04', '2015-02-07', '2015-02-18', 5531),
(20814, '2015-02-05', '2015-02-09', '2015-02-20', 5532),
(20815, '2015-02-05', '2015-02-09', '2015-02-20', 5533),
(20816, '2015-02-05', '2015-02-09', '2015-02-20', 5534),
(20817, '2015-02-06', '2015-02-10', '2015-02-21', 5535),
(20818, '2015-02-06', '2015-02-10', '2015-02-21', 5536),
(20819, '2015-02-06', '2015-02-10', '2015-02-21', 5537),
(20820, '2015-02-07', '2015-02-11', '2015-02-22', 5538),
(20821, '2015-02-07', '2015-02-11', '2015-02-22', 5539),
(20822, '2015-02-07', '2015-02-11', '2015-02-22', 5540),
(20823, '2015-02-08', '2015-02-12', '2015-02-23', 5606),
(20824, '2015-02-08', '2015-02-12', '2015-02-23', 5607),
(20825, '2015-02-08', '2015-02-12', '2015-02-23', 5608),
(20826, '2015-02-09', '2015-02-13', '2015-02-24', 5609),
(20827, '2015-02-09', '2015-02-13', '2015-02-24', 5610),
(20828, '2015-02-09', '2015-02-13', '2015-02-24', 5611),
(20829, '2015-02-10', '2015-02-14', '2015-02-25', 5612),
(20830, '2015-02-10', '2015-02-14', '2015-02-25', 5613),
(20831, '2015-02-10', '2015-02-14', '2015-02-25', 5614),
(20832, '2015-02-11', '2015-02-15', '2015-02-26', 5615),
(20833, '2015-02-11', '2015-02-15', '2015-02-26', 5616),
(20834, '2015-02-11', '2015-02-15', '2015-02-26', 5618),
(20835, '2015-02-12', '2015-02-16', '2015-02-27', 5619),
(20836, '2015-02-12', '2015-02-16', '2015-02-27', 5620),
(20837, '2015-02-12', '2015-02-16', '2015-02-27', 5525),
(20838, '2015-02-13', '2015-02-17', '2015-02-28', 5526),
(20839, '2015-02-13', '2015-02-17', '2015-02-28', 5527),
(20840, '2015-02-13', '2015-02-17', '2015-02-28', 5528),
(20841, '2015-02-14', '2015-02-18', '2015-02-28', 5529),
(20842, '2015-02-14', '2015-02-18', '2015-02-28', 5530),
(20843, '2015-02-14', '2015-02-18', '2015-02-28', 5531),
(20844, '2015-02-15', '2015-02-20', '2015-03-02', 5532),
(20845, '2015-02-15', '2015-02-20', '2015-03-02', 5533),
(20846, '2015-02-15', '2015-02-20', '2015-03-02', 5534),
(20847, '2015-02-16', '2015-02-21', '2015-03-03', 5535),
(20848, '2015-02-16', '2015-02-21', '2015-03-03', 5536),
(20849, '2015-02-16', '2015-02-21', '2015-03-03', 5537),
(20850, '2015-02-17', '2015-02-22', '2015-03-04', 5538),
(20851, '2015-02-17', '2015-02-22', '2015-03-04', 5539),
(20852, '2015-02-17', '2015-02-22', '2015-03-04', 5540),
(20853, '2015-02-18', '2015-02-23', '2015-03-05', 5752),
(20854, '2015-02-18', '2015-02-23', '2015-03-05', 5753),
(20855, '2015-02-18', '2015-02-23', '2015-03-05', 5754),
(20856, '2015-02-19', '2015-02-24', '2015-03-06', 5755),
(20857, '2015-02-19', '2015-02-24', '2015-03-06', 5756),
(20858, '2015-02-19', '2015-02-24', '2015-03-06', 5757),
(20859, '2015-02-20', '2015-02-25', '2015-03-07', 5758),
(20860, '2015-02-20', '2015-02-25', '2015-03-07', 5759),
(20861, '2015-02-20', '2015-02-25', '2015-03-07', 5760),
(20862, '2015-02-21', '2015-02-26', '2015-03-08', 5761),
(20863, '2015-02-21', '2015-02-26', '2015-03-08', 5762),
(20864, '2015-02-21', '2015-02-26', '2015-03-08', 5763),
(20865, '2015-02-22', '2015-02-27', '2015-03-09', 5764),
(20866, '2015-02-22', '2015-02-27', '2015-03-09', 5665),
(20867, '2015-02-22', '2015-02-27', '2015-03-09', 5666),
(20868, '2015-02-23', '2015-02-28', '2015-03-10', 5667),
(20869, '2015-02-23', '2015-02-28', '2015-03-10', 5668),
(20870, '2015-02-23', '2015-02-28', '2015-03-10', 5669),
(20871, '2015-02-24', '2015-02-28', '2015-03-11', 5670),
(20872, '2015-02-24', '2015-02-28', '2015-03-11', 5671),
(20873, '2015-02-24', '2015-02-28', '2015-03-11', 5672),
(20874, '2015-02-25', '2015-03-02', '2015-03-13', 5673),
(20875, '2015-02-25', '2015-03-02', '2015-03-13', 5674),
(20876, '2015-02-25', '2015-03-02', '2015-03-13', 5675),
(20877, '2015-02-26', '2015-03-03', '2015-03-14', 5795),
(20878, '2015-02-26', '2015-03-03', '2015-03-14', 5796),
(20879, '2015-02-26', '2015-03-03', '2015-03-14', 5797),
(20880, '2015-02-27', '2015-03-04', '2015-03-15', 5798),
(20881, '2015-02-27', '2015-03-04', '2015-03-15', 5799),
(20882, '2015-02-27', '2015-03-04', '2015-03-15', 5800),
(20883, '2015-02-28', '2015-03-05', '2015-03-16', 5801),
(20884, '2015-02-28', '2015-03-05', '2015-03-16', 5802),
(20885, '2015-02-28', '2015-03-05', '2015-03-16', 5803),
(20886, '2015-02-28', '2015-03-06', '2015-03-17', 5804),
(20887, '2015-02-28', '2015-03-06', '2015-03-17', 5805),
(20888, '2015-02-28', '2015-03-06', '2015-03-17', 5806),
(20889, '2015-03-01', '2015-03-07', '2015-03-18', 5807),
(20890, '2015-03-01', '2015-03-07', '2015-03-18', 5808),
(20891, '2015-03-01', '2015-03-07', '2015-03-18', 5809),
(20892, '2015-03-02', '2015-03-08', '2015-03-19', 5810),
(20893, '2015-03-02', '2015-03-08', '2015-03-19', 5811),
(20894, '2015-03-02', '2015-03-08', '2015-03-19', 5812),
(20895, '2015-03-03', '2015-03-09', '2015-03-20', 5813),
(20896, '2015-03-03', '2015-03-09', '2015-03-20', 5626),
(20897, '2015-03-03', '2015-03-09', '2015-03-20', 5627),
(20898, '2015-03-04', '2015-03-10', '2015-03-21', 5628),
(20899, '2015-03-04', '2015-03-10', '2015-03-21', 5629),
(20900, '2015-01-31', '2015-02-03', '2015-02-14', 5630),
(20901, '2015-01-31', '2015-02-03', '2015-02-14', 5631),
(20902, '2015-02-01', '2015-02-04', '2015-02-15', 5632),
(20903, '2015-02-01', '2015-02-04', '2015-02-15', 5633),
(20904, '2015-02-01', '2015-02-04', '2015-02-15', 5634),
(20905, '2015-02-02', '2015-02-05', '2015-02-16', 5635),
(20906, '2015-02-02', '2015-02-05', '2015-02-16', 5636),
(20907, '2015-02-02', '2015-02-05', '2015-02-16', 5637),
(20908, '2015-02-03', '2015-02-06', '2015-02-17', 5638),
(20909, '2015-02-03', '2015-02-06', '2015-02-17', 5639),
(20910, '2015-02-03', '2015-02-06', '2015-02-17', 5640),
(20911, '2015-02-04', '2015-02-07', '2015-02-18', 5641),
(20912, '2015-02-04', '2015-02-07', '2015-02-18', 5642),
(20913, '2015-02-04', '2015-02-07', '2015-02-18', 5643),
(20914, '2015-02-05', '2015-02-09', '2015-02-20', 5644),
(20915, '2015-02-05', '2015-02-09', '2015-02-20', 5645),
(20916, '2015-02-05', '2015-02-09', '2015-02-20', 5646),
(20917, '2015-02-06', '2015-02-10', '2015-02-21', 5647),
(20918, '2015-02-06', '2015-02-10', '2015-02-21', 5648),
(20919, '2015-02-06', '2015-02-10', '2015-02-21', 5649),
(20920, '2015-02-07', '2015-02-11', '2015-02-22', 5650),
(20921, '2015-02-07', '2015-02-11', '2015-02-22', 5651),
(20922, '2015-02-07', '2015-02-11', '2015-02-22', 5652),
(20923, '2015-02-08', '2015-02-12', '2015-02-23', 5653),
(20924, '2015-02-08', '2015-02-12', '2015-02-23', 5654),
(20925, '2015-02-08', '2015-02-12', '2015-02-23', 5655),
(20926, '2015-02-09', '2015-02-13', '2015-02-24', 5656),
(20927, '2015-02-09', '2015-02-13', '2015-02-24', 5657),
(20928, '2015-02-09', '2015-02-13', '2015-02-24', 5658),
(20929, '2015-02-10', '2015-02-14', '2015-02-25', 5659),
(20930, '2015-02-10', '2015-02-14', '2015-02-25', 5660),
(20931, '2015-02-10', '2015-02-14', '2015-02-25', 5661),
(20932, '2015-02-11', '2015-02-15', '2015-02-26', 5662),
(20933, '2015-02-11', '2015-02-15', '2015-02-26', 5663),
(20934, '2015-02-11', '2015-02-15', '2015-02-26', 5664),
(20935, '2015-02-12', '2015-02-16', '2015-02-27', 5665),
(20936, '2015-02-12', '2015-02-16', '2015-02-27', 5666),
(20937, '2015-02-12', '2015-02-16', '2015-02-27', 5667),
(20938, '2015-02-13', '2015-02-17', '2015-02-28', 5668),
(20939, '2015-02-13', '2015-02-17', '2015-02-28', 5669),
(20940, '2015-02-13', '2015-02-17', '2015-02-28', 5670),
(20941, '2015-02-14', '2015-02-18', '2015-02-28', 5671),
(20942, '2015-02-14', '2015-02-18', '2015-02-28', 5672),
(20943, '2015-02-14', '2015-02-18', '2015-02-28', 5673),
(20944, '2015-02-15', '2015-02-20', '2015-03-02', 5674),
(20945, '2015-02-15', '2015-02-20', '2015-03-02', 5675),
(20946, '2015-02-15', '2015-02-20', '2015-03-02', 5676),
(20947, '2015-02-16', '2015-02-21', '2015-03-03', 5734),
(20948, '2015-02-16', '2015-02-21', '2015-03-03', 5735),
(20949, '2015-02-16', '2015-02-21', '2015-03-03', 5736),
(20950, '2015-02-17', '2015-02-22', '2015-03-04', 5737),
(20951, '2015-02-17', '2015-02-22', '2015-03-04', 5738),
(20952, '2015-02-17', '2015-02-22', '2015-03-04', 5739),
(20953, '2015-02-18', '2015-02-23', '2015-03-05', 5683),
(20954, '2015-02-18', '2015-02-23', '2015-03-05', 5684),
(20955, '2015-03-18', '2015-03-23', '2015-04-03', 5685),
(20956, '2015-03-19', '2015-03-24', '2015-04-04', 5686),
(20957, '2015-03-19', '2015-03-24', '2015-04-04', 5687),
(20958, '2015-03-19', '2015-03-24', '2015-04-04', 5688),
(20959, '2015-03-20', '2015-03-25', '2015-04-05', 5780),
(20960, '2015-03-20', '2015-03-25', '2015-04-05', 5781),
(20961, '2015-03-20', '2015-03-25', '2015-04-05', 5782),
(20962, '2015-03-21', '2015-03-26', '2015-04-06', 5783),
(20963, '2015-03-21', '2015-03-26', '2015-04-06', 5784),
(20964, '2015-03-21', '2015-03-26', '2015-04-06', 5785),
(20965, '2015-03-22', '2015-03-27', '2015-04-07', 5786),
(20966, '2015-03-22', '2015-03-27', '2015-04-07', 5787),
(20967, '2015-03-22', '2015-03-27', '2015-04-07', 5788),
(20968, '2015-03-23', '2015-03-28', '2015-04-08', 5789),
(20969, '2015-03-23', '2015-03-28', '2015-04-08', 5700),
(20970, '2015-03-23', '2015-03-28', '2015-04-08', 5814),
(20971, '2015-03-24', '2015-03-29', '2015-04-09', 5815),
(20972, '2015-03-24', '2015-03-29', '2015-04-09', 5816),
(20973, '2015-03-24', '2015-03-29', '2015-04-09', 5817),
(20974, '2015-03-25', '2015-03-31', '2015-04-11', 5818),
(20975, '2015-03-25', '2015-03-31', '2015-04-11', 5819),
(20976, '2015-03-25', '2015-03-31', '2015-04-11', 5820),
(20977, '2015-03-26', '2015-04-01', '2015-04-12', 5821),
(20978, '2015-03-26', '2015-04-01', '2015-04-12', 5822),
(20979, '2015-03-26', '2015-04-01', '2015-04-12', 5632),
(20980, '2015-03-27', '2015-04-02', '2015-04-13', 5633),
(20981, '2015-03-27', '2015-04-02', '2015-04-13', 5634),
(20982, '2015-03-27', '2015-04-02', '2015-04-13', 5635),
(20983, '2015-03-28', '2015-04-03', '2015-04-14', 5636),
(20984, '2015-03-28', '2015-04-03', '2015-04-14', 5637),
(20985, '2015-03-28', '2015-04-03', '2015-04-14', 5638),
(20986, '2015-03-29', '2015-04-04', '2015-04-15', 5639),
(20987, '2015-03-29', '2015-04-04', '2015-04-15', 5640),
(20988, '2015-03-29', '2015-04-04', '2015-04-15', 5641),
(20989, '2015-03-30', '2015-04-05', '2015-04-16', 5642),
(20990, '2015-03-30', '2015-04-05', '2015-04-16', 5643),
(20991, '2015-03-30', '2015-04-05', '2015-04-16', 5775),
(20992, '2015-03-31', '2015-04-06', '2015-04-17', 5773),
(20993, '2015-03-31', '2015-04-06', '2015-04-17', 5774),
(20994, '2015-03-31', '2015-04-06', '2015-04-17', 5775),
(20995, '2015-04-01', '2015-04-07', '2015-04-18', 5776),
(20996, '2015-04-01', '2015-04-07', '2015-04-18', 5780),
(20997, '2015-04-01', '2015-04-07', '2015-04-18', 5781),
(20998, '2015-04-02', '2015-04-08', '2015-04-19', 5782),
(20999, '2015-04-02', '2015-04-08', '2015-04-19', 5783),
(21000, '2015-02-28', '2015-03-03', '2015-03-14', 5784),
(21001, '2015-02-28', '2015-03-03', '2015-03-14', 5785),
(21002, '2015-03-01', '2015-03-04', '2015-03-15', 5786),
(21003, '2015-03-01', '2015-03-04', '2015-03-15', 5787),
(21004, '2015-03-01', '2015-03-04', '2015-03-15', 5788),
(21005, '2015-03-02', '2015-03-05', '2015-03-16', 5789),
(21006, '2015-03-02', '2015-03-05', '2015-03-16', 5731),
(21007, '2015-03-02', '2015-03-05', '2015-03-16', 5732),
(21008, '2015-03-03', '2015-03-06', '2015-03-17', 5734),
(21009, '2015-03-03', '2015-03-06', '2015-03-17', 5735),
(21010, '2015-03-03', '2015-03-06', '2015-03-17', 5736),
(21011, '2015-03-04', '2015-03-07', '2015-03-18', 5737),
(21012, '2015-03-04', '2015-03-07', '2015-03-18', 5738),
(21013, '2015-03-04', '2015-03-07', '2015-03-18', 5739),
(21014, '2015-03-05', '2015-03-09', '2015-03-20', 5740),
(21015, '2015-03-05', '2015-03-09', '2015-03-20', 5741),
(21016, '2015-03-05', '2015-03-09', '2015-03-20', 5742),
(21017, '2015-03-06', '2015-03-10', '2015-03-21', 5743),
(21018, '2015-03-06', '2015-03-10', '2015-03-21', 5744),
(21019, '2015-03-06', '2015-03-10', '2015-03-21', 5519),
(21020, '2015-03-07', '2015-03-11', '2015-03-22', 5520),
(21021, '2015-03-07', '2015-03-11', '2015-03-22', 5521),
(21022, '2015-03-07', '2015-03-11', '2015-03-22', 5522),
(21023, '2015-03-08', '2015-03-12', '2015-03-23', 5523),
(21024, '2015-03-08', '2015-03-12', '2015-03-23', 5524),
(21025, '2015-03-08', '2015-03-12', '2015-03-23', 5525),
(21026, '2015-03-09', '2015-03-13', '2015-03-24', 5526),
(21027, '2015-03-09', '2015-03-13', '2015-03-24', 5527),
(21028, '2015-03-09', '2015-03-13', '2015-03-24', 5528),
(21029, '2015-03-10', '2015-03-14', '2015-03-25', 5529),
(21030, '2015-03-10', '2015-03-14', '2015-03-25', 5530),
(21031, '2015-03-10', '2015-03-14', '2015-03-25', 5531),
(21032, '2015-03-11', '2015-03-15', '2015-03-26', 5532),
(21033, '2015-03-11', '2015-03-15', '2015-03-26', 5533),
(21034, '2015-03-11', '2015-03-15', '2015-03-26', 5534),
(21035, '2015-03-12', '2015-03-16', '2015-03-27', 5535),
(21036, '2015-03-12', '2015-03-16', '2015-03-27', 5536),
(21037, '2015-03-12', '2015-03-16', '2015-03-27', 5007),
(21038, '2015-03-13', '2015-03-17', '2015-03-28', 5002),
(21039, '2015-03-13', '2015-03-17', '2015-03-28', 5007),
(21040, '2015-03-13', '2015-03-17', '2015-03-28', 5009),
(21041, '2015-03-14', '2015-03-18', '2015-03-29', 5011),
(21042, '2015-03-14', '2015-03-18', '2015-03-29', 5022),
(21043, '2015-03-14', '2015-03-18', '2015-03-29', 5025),
(21044, '2015-03-15', '2015-03-20', '2015-03-31', 5028),
(21045, '2015-03-15', '2015-03-20', '2015-03-31', 5039),
(21046, '2015-03-15', '2015-03-20', '2015-03-31', 5042),
(21047, '2015-03-16', '2015-03-21', '2015-04-01', 5043),
(21048, '2015-03-16', '2015-03-21', '2015-04-01', 5049),
(21049, '2015-03-16', '2015-03-21', '2015-04-01', 5071),
(21050, '2015-03-17', '2015-03-22', '2015-04-02', 5079),
(21051, '2015-03-17', '2015-03-22', '2015-04-02', 5081),
(21052, '2015-03-17', '2015-03-22', '2015-04-02', 5082),
(21053, '2015-03-18', '2015-03-23', '2015-04-03', 5087),
(21054, '2015-03-18', '2015-03-23', '2015-04-03', 5091),
(21055, '2015-03-18', '2015-03-23', '2015-04-03', 5092),
(21056, '2015-03-19', '2015-03-24', '2015-04-04', 5093),
(21057, '2015-03-19', '2015-03-24', '2015-04-04', 5102),
(21058, '2015-03-19', '2015-03-24', '2015-04-04', 5119),
(21059, '2015-03-20', '2015-03-25', '2015-04-05', 5574),
(21060, '2015-03-20', '2015-03-25', '2015-04-05', 5575),
(21061, '2015-03-20', '2015-03-25', '2015-04-05', 5576),
(21062, '2015-03-21', '2015-03-26', '2015-04-06', 5577),
(21063, '2015-03-21', '2015-03-26', '2015-04-06', 5578),
(21064, '2015-03-21', '2015-03-26', '2015-04-06', 5579),
(21065, '2015-03-22', '2015-03-27', '2015-04-07', 5580),
(21066, '2015-03-22', '2015-03-27', '2015-04-07', 5581),
(21067, '2015-03-22', '2015-03-27', '2015-04-07', 5582),
(21068, '2015-03-23', '2015-03-28', '2015-04-08', 5583),
(21069, '2015-03-23', '2015-03-28', '2015-04-08', 5584),
(21070, '2015-03-23', '2015-03-28', '2015-04-08', 5585),
(21071, '2015-03-24', '2015-03-29', '2015-04-09', 5586),
(21072, '2015-03-24', '2015-03-29', '2015-04-09', 5587),
(21073, '2015-03-24', '2015-03-29', '2015-04-09', 5139),
(21074, '2015-03-25', '2015-03-31', '2015-04-11', 5144),
(21075, '2015-03-25', '2015-03-31', '2015-04-11', 5162),
(21076, '2015-03-25', '2015-03-31', '2015-04-11', 5172),
(21077, '2015-03-26', '2015-04-01', '2015-04-12', 5237),
(21078, '2015-03-26', '2015-04-01', '2015-04-12', 5238),
(21079, '2015-03-26', '2015-04-01', '2015-04-12', 5239),
(21080, '2015-03-27', '2015-04-02', '2015-04-13', 5250),
(21081, '2015-03-27', '2015-04-02', '2015-04-13', 5251),
(21082, '2015-03-27', '2015-04-02', '2015-04-13', 5256),
(21083, '2015-03-28', '2015-04-03', '2015-04-14', 5267),
(21084, '2015-03-28', '2015-04-03', '2015-04-14', 5310),
(21085, '2015-03-28', '2015-04-03', '2015-04-14', 5316),
(21086, '2015-03-29', '2015-04-04', '2015-04-15', 5321),
(21087, '2015-03-29', '2015-04-04', '2015-04-15', 5322),
(21088, '2015-03-29', '2015-04-04', '2015-04-15', 5328),
(21089, '2015-03-30', '2015-04-05', '2015-04-16', 5353),
(21090, '2015-03-30', '2015-04-05', '2015-04-16', 5354),
(21091, '2015-03-30', '2015-04-05', '2015-04-16', 5355),
(21092, '2015-03-31', '2015-04-06', '2015-04-17', 5356),
(21093, '2015-03-31', '2015-04-06', '2015-04-17', 5432),
(21094, '2015-03-31', '2015-04-06', '2015-04-17', 5433),
(21095, '2015-04-01', '2015-04-07', '2015-04-18', 5434),
(21096, '2015-04-01', '2015-04-07', '2015-04-18', 5435),
(21097, '2015-04-01', '2015-04-07', '2015-04-18', 5445),
(21098, '2015-04-02', '2015-04-08', '2015-04-19', 5477),
(21099, '2015-04-02', '2015-04-08', '2015-04-19', 5322),
(21100, '2015-02-28', '2015-03-03', '2015-03-14', 5328),
(21101, '2015-02-28', '2015-03-03', '2015-03-14', 5353),
(21102, '2015-03-01', '2015-03-04', '2015-03-15', 5354),
(21103, '2015-03-01', '2015-03-04', '2015-03-15', 5438),
(21104, '2015-03-01', '2015-03-04', '2015-03-15', 5439),
(21105, '2015-03-02', '2015-03-05', '2015-03-16', 5440),
(21106, '2015-03-02', '2015-03-05', '2015-03-16', 5441),
(21107, '2015-03-02', '2015-03-05', '2015-03-16', 5442),
(21108, '2015-03-03', '2015-03-06', '2015-03-17', 5443),
(21109, '2015-03-03', '2015-03-06', '2015-03-17', 5444),
(21110, '2015-03-03', '2015-03-06', '2015-03-17', 5445),
(21111, '2015-03-04', '2015-03-07', '2015-03-18', 5477),
(21112, '2015-03-04', '2015-03-07', '2015-03-18', 5478),
(21113, '2015-03-04', '2015-03-07', '2015-03-18', 5479),
(21114, '2015-03-05', '2015-03-09', '2015-03-20', 5480),
(21115, '2015-03-05', '2015-03-09', '2015-03-20', 5481),
(21116, '2015-03-05', '2015-03-09', '2015-03-20', 5482),
(21117, '2015-03-06', '2015-03-10', '2015-03-21', 5483),
(21118, '2015-03-06', '2015-03-10', '2015-03-21', 5484),
(21119, '2015-03-06', '2015-03-10', '2015-03-21', 5485),
(21120, '2015-03-07', '2015-03-11', '2015-03-22', 5486),
(21121, '2015-03-07', '2015-03-11', '2015-03-22', 5488),
(21122, '2015-03-07', '2015-03-11', '2015-03-22', 5489),
(21123, '2015-03-08', '2015-03-12', '2015-03-23', 5385),
(21124, '2015-03-08', '2015-03-12', '2015-03-23', 5386),
(21125, '2015-03-08', '2015-03-12', '2015-03-23', 5387),
(21126, '2015-03-09', '2015-03-13', '2015-03-24', 5388),
(21127, '2015-03-09', '2015-03-13', '2015-03-24', 5389),
(21128, '2015-03-09', '2015-03-13', '2015-03-24', 5390),
(21129, '2015-03-10', '2015-03-14', '2015-03-25', 5391),
(21130, '2015-03-10', '2015-03-14', '2015-03-25', 5392),
(21131, '2015-03-10', '2015-03-14', '2015-03-25', 5393),
(21132, '2015-03-11', '2015-03-15', '2015-03-26', 5394),
(21133, '2015-03-11', '2015-03-15', '2015-03-26', 5395),
(21134, '2015-03-11', '2015-03-15', '2015-03-26', 5353),
(21135, '2015-04-12', '2015-04-16', '2015-04-27', 5354),
(21136, '2015-04-12', '2015-04-16', '2015-04-27', 5355),
(21137, '2015-04-12', '2015-04-16', '2015-04-27', 5356),
(21138, '2015-04-13', '2015-04-17', '2015-04-28', 5357),
(21139, '2015-04-13', '2015-04-17', '2015-04-28', 5358),
(21140, '2015-04-13', '2015-04-17', '2015-04-28', 5359),
(21141, '2015-04-14', '2015-04-18', '2015-04-29', 5360),
(21142, '2015-04-14', '2015-04-18', '2015-04-29', 5361),
(21143, '2015-04-14', '2015-04-18', '2015-04-29', 5362),
(21144, '2015-04-15', '2015-04-20', '2015-05-01', 5363),
(21145, '2015-04-15', '2015-04-20', '2015-05-01', 5364),
(21146, '2015-04-15', '2015-04-20', '2015-05-01', 5365),
(21147, '2015-04-16', '2015-04-21', '2015-05-02', 5366),
(21148, '2015-04-16', '2015-04-21', '2015-05-02', 5367),
(21149, '2015-04-16', '2015-04-21', '2015-05-02', 5368),
(21150, '2015-04-17', '2015-04-22', '2015-05-03', 5369),
(21151, '2015-04-17', '2015-04-22', '2015-05-03', 5370),
(21152, '2015-04-17', '2015-04-22', '2015-05-03', 5371),
(21153, '2015-04-18', '2015-04-23', '2015-05-04', 5426),
(21154, '2015-04-18', '2015-04-23', '2015-05-04', 5427),
(21155, '2015-04-18', '2015-04-23', '2015-05-04', 5428),
(21156, '2015-04-19', '2015-04-24', '2015-05-05', 5429),
(21157, '2015-04-19', '2015-04-24', '2015-05-05', 5430),
(21158, '2015-04-19', '2015-04-24', '2015-05-05', 5431),
(21159, '2015-04-20', '2015-04-25', '2015-05-06', 5432),
(21160, '2015-04-20', '2015-04-25', '2015-05-06', 5433),
(21161, '2015-04-20', '2015-04-25', '2015-05-06', 5434),
(21162, '2015-04-21', '2015-04-26', '2015-05-07', 5381),
(21163, '2015-04-21', '2015-04-26', '2015-05-07', 5382),
(21164, '2015-04-21', '2015-04-26', '2015-05-07', 5383),
(21165, '2015-04-22', '2015-04-27', '2015-05-08', 5384),
(21166, '2015-04-22', '2015-04-27', '2015-05-08', 5385),
(21167, '2015-04-22', '2015-04-27', '2015-05-08', 5386),
(21168, '2015-04-23', '2015-04-28', '2015-05-09', 5449),
(21169, '2015-04-23', '2015-04-28', '2015-05-09', 5450),
(21170, '2015-04-23', '2015-04-28', '2015-05-09', 5451),
(21171, '2015-04-24', '2015-04-29', '2015-05-10', 5452),
(21172, '2015-04-24', '2015-04-29', '2015-05-10', 5453),
(21173, '2015-04-24', '2015-04-29', '2015-05-10', 5454),
(21174, '2015-04-25', '2015-05-01', '2015-05-12', 5455),
(21175, '2015-04-25', '2015-05-01', '2015-05-12', 5456),
(21176, '2015-04-25', '2015-05-01', '2015-05-12', 5457),
(21177, '2015-04-26', '2015-05-02', '2015-05-13', 5458),
(21178, '2015-04-26', '2015-05-02', '2015-05-13', 5459),
(21179, '2015-04-26', '2015-05-02', '2015-05-13', 5460),
(21180, '2015-04-27', '2015-05-03', '2015-05-14', 5461),
(21181, '2015-04-27', '2015-05-03', '2015-05-14', 5466),
(21182, '2015-04-27', '2015-05-03', '2015-05-14', 5467),
(21183, '2015-04-28', '2015-05-04', '2015-05-15', 5468),
(21184, '2015-04-28', '2015-05-04', '2015-05-15', 5469),
(21185, '2015-04-28', '2015-05-04', '2015-05-15', 5470),
(21186, '2015-04-29', '2015-05-05', '2015-05-16', 5471),
(21187, '2015-04-29', '2015-05-05', '2015-05-16', 5472),
(21188, '2015-04-29', '2015-05-05', '2015-05-16', 5473),
(21189, '2015-04-30', '2015-05-06', '2015-05-17', 5474),
(21190, '2015-04-30', '2015-05-06', '2015-05-17', 5475),
(21191, '2015-04-30', '2015-05-06', '2015-05-17', 5476),
(21192, '2015-05-01', '2015-05-07', '2015-05-18', 5392),
(21193, '2015-05-01', '2015-05-07', '2015-05-18', 5393),
(21194, '2015-05-01', '2015-05-07', '2015-05-18', 5394),
(21195, '2015-05-02', '2015-05-08', '2015-05-19', 5395),
(21196, '2015-05-02', '2015-05-08', '2015-05-19', 5396),
(21197, '2015-05-02', '2015-05-08', '2015-05-19', 5397),
(21198, '2015-05-03', '2015-05-09', '2015-05-20', 5398),
(21199, '2015-05-03', '2015-05-09', '2015-05-20', 5399),
(21200, '2015-03-31', '2015-04-03', '2015-04-14', 5400),
(21201, '2015-03-31', '2015-04-03', '2015-04-14', 5401),
(21202, '2015-04-01', '2015-04-04', '2015-04-15', 5402),
(21203, '2015-04-01', '2015-04-04', '2015-04-15', 5403),
(21204, '2015-04-01', '2015-04-04', '2015-04-15', 5404),
(21205, '2015-04-02', '2015-04-05', '2015-04-16', 5405),
(21206, '2015-04-02', '2015-04-05', '2015-04-16', 5406),
(21207, '2015-04-02', '2015-04-05', '2015-04-16', 5407),
(21208, '2015-04-03', '2015-04-06', '2015-04-17', 5408),
(21209, '2015-04-03', '2015-04-06', '2015-04-17', 5409),
(21210, '2015-04-03', '2015-04-06', '2015-04-17', 5410),
(21211, '2015-04-04', '2015-04-07', '2015-04-18', 5411),
(21212, '2015-04-04', '2015-04-07', '2015-04-18', 5412),
(21213, '2015-04-04', '2015-04-07', '2015-04-18', 5413),
(21214, '2015-04-05', '2015-04-09', '2015-04-20', 5414),
(21215, '2015-04-05', '2015-04-09', '2015-04-20', 5415),
(21216, '2015-04-05', '2015-04-09', '2015-04-20', 5416),
(21217, '2015-04-06', '2015-04-10', '2015-04-21', 5417),
(21218, '2015-04-06', '2015-04-10', '2015-04-21', 5418),
(21219, '2015-04-06', '2015-04-10', '2015-04-21', 5419),
(21220, '2015-04-07', '2015-04-11', '2015-04-22', 5420),
(21221, '2015-04-07', '2015-04-11', '2015-04-22', 5421),
(21222, '2015-04-07', '2015-04-11', '2015-04-22', 5422),
(21223, '2015-04-08', '2015-04-12', '2015-04-23', 5423),
(21224, '2015-04-08', '2015-04-12', '2015-04-23', 5424),
(21225, '2015-04-08', '2015-04-12', '2015-04-23', 5499),
(21226, '2015-04-09', '2015-04-13', '2015-04-24', 5500),
(21227, '2015-04-09', '2015-04-13', '2015-04-24', 5501),
(21228, '2015-04-09', '2015-04-13', '2015-04-24', 5502),
(21229, '2015-04-10', '2015-04-14', '2015-04-25', 5503),
(21230, '2015-04-10', '2015-04-14', '2015-04-25', 5504),
(21231, '2015-04-10', '2015-04-14', '2015-04-25', 5505),
(21232, '2015-04-11', '2015-04-15', '2015-04-26', 5506),
(21233, '2015-04-11', '2015-04-15', '2015-04-26', 5507),
(21234, '2015-04-11', '2015-04-15', '2015-04-26', 5508),
(21235, '2015-04-12', '2015-04-16', '2015-04-27', 5509),
(21236, '2015-04-12', '2015-04-16', '2015-04-27', 5510),
(21237, '2015-04-12', '2015-04-16', '2015-04-27', 5511),
(21238, '2015-04-13', '2015-04-17', '2015-04-28', 5456),
(21239, '2015-04-13', '2015-04-17', '2015-04-28', 5457),
(21240, '2015-04-13', '2015-04-17', '2015-04-28', 5458),
(21241, '2015-04-14', '2015-04-18', '2015-04-29', 5459),
(21242, '2015-04-14', '2015-04-18', '2015-04-29', 5460),
(21243, '2015-04-14', '2015-04-18', '2015-04-29', 5461),
(21244, '2015-04-15', '2015-04-20', '2015-05-01', 5462),
(21245, '2015-04-15', '2015-04-20', '2015-05-01', 5463),
(21246, '2015-04-15', '2015-04-20', '2015-05-01', 5464),
(21247, '2015-04-16', '2015-04-21', '2015-05-02', 5549),
(21248, '2015-04-16', '2015-04-21', '2015-05-02', 5550),
(21249, '2015-04-16', '2015-04-21', '2015-05-02', 5551),
(21250, '2015-04-17', '2015-04-22', '2015-05-03', 5552),
(21251, '2015-04-17', '2015-04-22', '2015-05-03', 5553),
(21252, '2015-04-17', '2015-04-22', '2015-05-03', 5554),
(21253, '2015-04-18', '2015-04-23', '2015-05-04', 5555),
(21254, '2015-04-18', '2015-04-23', '2015-05-04', 5556),
(21255, '2015-04-18', '2015-04-23', '2015-05-04', 5557),
(21256, '2015-04-19', '2015-04-24', '2015-05-05', 5558),
(21257, '2015-04-19', '2015-04-24', '2015-05-05', 5559),
(21258, '2015-04-19', '2015-04-24', '2015-05-05', 5560),
(21259, '2015-04-20', '2015-04-25', '2015-05-06', 5561),
(21260, '2015-04-20', '2015-04-25', '2015-05-06', 5562),
(21261, '2015-04-20', '2015-04-25', '2015-05-06', 5563),
(21262, '2015-04-21', '2015-04-26', '2015-05-07', 5564),
(21263, '2015-04-21', '2015-04-26', '2015-05-07', 5565),
(21264, '2015-04-21', '2015-04-26', '2015-05-07', 5566),
(21265, '2015-04-22', '2015-04-27', '2015-05-08', 5567),
(21266, '2015-04-22', '2015-04-27', '2015-05-08', 5568),
(21267, '2015-04-22', '2015-04-27', '2015-05-08', 5569),
(21268, '2015-04-23', '2015-04-28', '2015-05-09', 5570),
(21269, '2015-04-23', '2015-04-28', '2015-05-09', 5571),
(21270, '2015-04-23', '2015-04-28', '2015-05-09', 5572),
(21271, '2015-04-24', '2015-04-29', '2015-05-10', 5569),
(21272, '2015-04-24', '2015-04-29', '2015-05-10', 5570),
(21273, '2015-04-24', '2015-04-29', '2015-05-10', 5571),
(21274, '2015-04-25', '2015-05-01', '2015-05-12', 5572),
(21275, '2015-04-25', '2015-05-01', '2015-05-12', 5573),
(21276, '2015-04-25', '2015-05-01', '2015-05-12', 5574),
(21277, '2015-04-26', '2015-05-02', '2015-05-13', 5575),
(21278, '2015-04-26', '2015-05-02', '2015-05-13', 5576),
(21279, '2015-04-26', '2015-05-02', '2015-05-13', 5577),
(21280, '2015-04-27', '2015-05-03', '2015-05-14', 5578),
(21281, '2015-04-27', '2015-05-03', '2015-05-14', 5579),
(21282, '2015-04-27', '2015-05-03', '2015-05-14', 5580),
(21283, '2015-04-28', '2015-05-04', '2015-05-15', 5550),
(21284, '2015-04-28', '2015-05-04', '2015-05-15', 5551),
(21285, '2015-04-28', '2015-05-04', '2015-05-15', 5552),
(21286, '2015-04-29', '2015-05-05', '2015-05-16', 5553),
(21287, '2015-04-29', '2015-05-05', '2015-05-16', 5554),
(21288, '2015-04-29', '2015-05-05', '2015-05-16', 5555),
(21289, '2015-04-30', '2015-05-06', '2015-05-17', 5587),
(21290, '2015-04-30', '2015-05-06', '2015-05-17', 5588),
(21291, '2015-04-30', '2015-05-06', '2015-05-17', 5589),
(21292, '2015-05-01', '2015-05-07', '2015-05-18', 5590),
(21293, '2015-05-01', '2015-05-07', '2015-05-18', 5591),
(21294, '2015-05-01', '2015-05-07', '2015-05-18', 5592),
(21295, '2015-05-02', '2015-05-08', '2015-05-19', 5593),
(21296, '2015-05-02', '2015-05-08', '2015-05-19', 5594),
(21297, '2015-05-02', '2015-05-08', '2015-05-19', 5595),
(21298, '2015-05-03', '2015-05-09', '2015-05-20', 5596),
(21299, '2015-05-03', '2015-05-09', '2015-05-20', 5597),
(21300, '2015-03-31', '2015-04-03', '2015-04-14', 5598),
(21301, '2015-03-31', '2015-04-03', '2015-04-14', 5599),
(21302, '2015-04-01', '2015-04-04', '2015-04-15', 5600),
(21303, '2015-04-01', '2015-04-04', '2015-04-15', 5701),
(21304, '2015-04-01', '2015-04-04', '2015-04-15', 5702),
(21305, '2015-04-02', '2015-04-05', '2015-04-16', 5703),
(21306, '2015-04-02', '2015-04-05', '2015-04-16', 5704),
(21307, '2015-04-02', '2015-04-05', '2015-04-16', 5705),
(21308, '2015-04-03', '2015-04-06', '2015-04-17', 5706),
(21309, '2015-04-03', '2015-04-06', '2015-04-17', 5707),
(21310, '2015-04-03', '2015-04-06', '2015-04-17', 5708),
(21311, '2015-04-04', '2015-04-07', '2015-04-18', 5709),
(21312, '2015-04-04', '2015-04-07', '2015-04-18', 5710),
(21313, '2015-04-04', '2015-04-07', '2015-04-18', 5711),
(21314, '2015-04-05', '2015-04-09', '2015-04-20', 5712),
(21315, '2015-05-05', '2015-05-09', '2015-05-20', 5713),
(21316, '2015-05-05', '2015-05-09', '2015-05-20', 5714),
(21317, '2015-05-06', '2015-05-10', '2015-05-21', 5715),
(21318, '2015-05-06', '2015-05-10', '2015-05-21', 5716),
(21319, '2015-05-06', '2015-05-10', '2015-05-21', 5717),
(21320, '2015-05-07', '2015-05-11', '2015-05-22', 5718),
(21321, '2015-05-07', '2015-05-11', '2015-05-22', 5719),
(21322, '2015-05-07', '2015-05-11', '2015-05-22', 5525),
(21323, '2015-05-08', '2015-05-12', '2015-05-23', 5526),
(21324, '2015-05-08', '2015-05-12', '2015-05-23', 5527),
(21325, '2015-05-08', '2015-05-12', '2015-05-23', 5528),
(21326, '2015-05-09', '2015-05-13', '2015-05-24', 5529),
(21327, '2015-05-09', '2015-05-13', '2015-05-24', 5530),
(21328, '2015-05-09', '2015-05-13', '2015-05-24', 5531),
(21329, '2015-05-10', '2015-05-14', '2015-05-25', 5532),
(21330, '2015-05-10', '2015-05-14', '2015-05-25', 5533),
(21331, '2015-05-10', '2015-05-14', '2015-05-25', 5534),
(21332, '2015-05-11', '2015-05-15', '2015-05-26', 5535),
(21333, '2015-05-11', '2015-05-15', '2015-05-26', 5536),
(21334, '2015-05-11', '2015-05-15', '2015-05-26', 5537),
(21335, '2015-05-12', '2015-05-16', '2015-05-27', 5538),
(21336, '2015-05-12', '2015-05-16', '2015-05-27', 5539),
(21337, '2015-05-12', '2015-05-16', '2015-05-27', 5540),
(21338, '2015-05-13', '2015-05-17', '2015-05-28', 5606),
(21339, '2015-05-13', '2015-05-17', '2015-05-28', 5607),
(21340, '2015-05-13', '2015-05-17', '2015-05-28', 5608),
(21341, '2015-05-14', '2015-05-18', '2015-05-29', 5609),
(21342, '2015-05-14', '2015-05-18', '2015-05-29', 5610),
(21343, '2015-05-14', '2015-05-18', '2015-05-29', 5611),
(21344, '2015-05-15', '2015-05-20', '2015-05-31', 5612),
(21345, '2015-05-15', '2015-05-20', '2015-05-31', 5613),
(21346, '2015-05-15', '2015-05-20', '2015-05-31', 5614),
(21347, '2015-05-16', '2015-05-21', '2015-06-01', 5615),
(21348, '2015-05-16', '2015-05-21', '2015-06-01', 5616),
(21349, '2015-05-16', '2015-05-21', '2015-06-01', 5618),
(21350, '2015-05-17', '2015-05-22', '2015-06-02', 5619),
(21351, '2015-05-17', '2015-05-22', '2015-06-02', 5620),
(21352, '2015-05-17', '2015-05-22', '2015-06-02', 5525),
(21353, '2015-05-18', '2015-05-23', '2015-06-03', 5526),
(21354, '2015-05-18', '2015-05-23', '2015-06-03', 5527),
(21355, '2015-05-18', '2015-05-23', '2015-06-03', 5528),
(21356, '2015-05-19', '2015-05-24', '2015-06-04', 5529),
(21357, '2015-05-19', '2015-05-24', '2015-06-04', 5530),
(21358, '2015-05-19', '2015-05-24', '2015-06-04', 5531),
(21359, '2015-05-20', '2015-05-25', '2015-06-05', 5532),
(21360, '2015-05-20', '2015-05-25', '2015-06-05', 5533),
(21361, '2015-05-20', '2015-05-25', '2015-06-05', 5534),
(21362, '2015-05-21', '2015-05-26', '2015-06-06', 5535),
(21363, '2015-05-21', '2015-05-26', '2015-06-06', 5536),
(21364, '2015-05-21', '2015-05-26', '2015-06-06', 5537),
(21365, '2015-05-22', '2015-05-27', '2015-06-07', 5538),
(21366, '2015-05-22', '2015-05-27', '2015-06-07', 5539),
(21367, '2015-05-22', '2015-05-27', '2015-06-07', 5540),
(21368, '2015-05-23', '2015-05-28', '2015-06-08', 5752),
(21369, '2015-05-23', '2015-05-28', '2015-06-08', 5753),
(21370, '2015-05-23', '2015-05-28', '2015-06-08', 5754),
(21371, '2015-05-24', '2015-05-29', '2015-06-09', 5755),
(21372, '2015-05-24', '2015-05-29', '2015-06-09', 5756),
(21373, '2015-05-24', '2015-05-29', '2015-06-09', 5757),
(21374, '2015-05-25', '2015-05-31', '2015-06-11', 5758),
(21375, '2015-05-25', '2015-05-31', '2015-06-11', 5759),
(21376, '2015-05-25', '2015-05-31', '2015-06-11', 5760),
(21377, '2015-05-26', '2015-06-01', '2015-06-12', 5761),
(21378, '2015-05-26', '2015-06-01', '2015-06-12', 5762),
(21379, '2015-05-26', '2015-06-01', '2015-06-12', 5763),
(21380, '2015-05-27', '2015-06-02', '2015-06-13', 5764),
(21381, '2015-05-27', '2015-06-02', '2015-06-13', 5665),
(21382, '2015-05-27', '2015-06-02', '2015-06-13', 5666),
(21383, '2015-05-28', '2015-06-03', '2015-06-14', 5667),
(21384, '2015-05-28', '2015-06-03', '2015-06-14', 5668),
(21385, '2015-05-28', '2015-06-03', '2015-06-14', 5669),
(21386, '2015-05-29', '2015-06-04', '2015-06-15', 5670),
(21387, '2015-05-29', '2015-06-04', '2015-06-15', 5671),
(21388, '2015-05-29', '2015-06-04', '2015-06-15', 5672),
(21389, '2015-05-30', '2015-06-05', '2015-06-16', 5673),
(21390, '2015-05-30', '2015-06-05', '2015-06-16', 5674),
(21391, '2015-05-30', '2015-06-05', '2015-06-16', 5675),
(21392, '2015-05-31', '2015-06-06', '2015-06-17', 5795),
(21393, '2015-05-31', '2015-06-06', '2015-06-17', 5796),
(21394, '2015-05-31', '2015-06-06', '2015-06-17', 5797),
(21395, '2015-06-01', '2015-06-07', '2015-06-18', 5798),
(21396, '2015-06-01', '2015-06-07', '2015-06-18', 5799),
(21397, '2015-06-01', '2015-06-07', '2015-06-18', 5800),
(21398, '2015-06-02', '2015-06-08', '2015-06-19', 5801),
(21399, '2015-06-02', '2015-06-08', '2015-06-19', 5802),
(21400, '2015-04-30', '2015-05-03', '2015-05-14', 5803),
(21401, '2015-04-30', '2015-05-03', '2015-05-14', 5804),
(21402, '2015-05-01', '2015-05-04', '2015-05-15', 5805),
(21403, '2015-05-01', '2015-05-04', '2015-05-15', 5806),
(21404, '2015-05-01', '2015-05-04', '2015-05-15', 5807),
(21405, '2015-05-02', '2015-05-05', '2015-05-16', 5808),
(21406, '2015-05-02', '2015-05-05', '2015-05-16', 5809),
(21407, '2015-05-02', '2015-05-05', '2015-05-16', 5810),
(21408, '2015-05-03', '2015-05-06', '2015-05-17', 5811),
(21409, '2015-05-03', '2015-05-06', '2015-05-17', 5812),
(21410, '2015-05-03', '2015-05-06', '2015-05-17', 5813),
(21411, '2015-05-04', '2015-05-07', '2015-05-18', 5626);
INSERT INTO `Ordre` (`OrdreNr`, `OrdreDato`, `SendtDato`, `BetaltDato`, `KNr`) VALUES
(21412, '2015-05-04', '2015-05-07', '2015-05-18', 5627),
(21413, '2015-05-04', '2015-05-07', '2015-05-18', 5628),
(21414, '2015-05-05', '2015-05-09', '2015-05-20', 5629),
(21415, '2015-05-05', '2015-05-09', '2015-05-20', 5630),
(21416, '2015-05-05', '2015-05-09', '2015-05-20', 5631),
(21417, '2015-05-06', '2015-05-10', '2015-05-21', 5632),
(21418, '2015-05-06', '2015-05-10', '2015-05-21', 5633),
(21419, '2015-05-06', '2015-05-10', '2015-05-21', 5634),
(21420, '2015-05-07', '2015-05-11', '2015-05-22', 5635),
(21421, '2015-05-07', '2015-05-11', '2015-05-22', 5636),
(21422, '2015-05-07', '2015-05-11', '2015-05-22', 5637),
(21423, '2015-05-08', '2015-05-12', '2015-05-23', 5638),
(21424, '2015-05-08', '2015-05-12', '2015-05-23', 5639),
(21425, '2015-05-08', '2015-05-12', '2015-05-23', 5640),
(21426, '2015-05-09', '2015-05-13', '2015-05-24', 5641),
(21427, '2015-05-09', '2015-05-13', '2015-05-24', 5642),
(21428, '2015-05-09', '2015-05-13', '2015-05-24', 5643),
(21429, '2015-05-10', '2015-05-14', '2015-05-25', 5644),
(21430, '2015-05-10', '2015-05-14', '2015-05-25', 5645),
(21431, '2015-05-10', '2015-05-14', '2015-05-25', 5646),
(21432, '2015-05-11', '2015-05-15', '2015-05-26', 5647),
(21433, '2015-05-11', '2015-05-15', '2015-05-26', 5648),
(21434, '2015-05-11', '2015-05-15', '2015-05-26', 5649),
(21435, '2015-05-12', '2015-05-16', '2015-05-27', 5650),
(21436, '2015-05-12', '2015-05-16', '2015-05-27', 5651),
(21437, '2015-05-12', '2015-05-16', '2015-05-27', 5652),
(21438, '2015-05-13', '2015-05-17', '2015-05-28', 5653),
(21439, '2015-05-13', '2015-05-17', '2015-05-28', 5654),
(21440, '2015-05-13', '2015-05-17', '2015-05-28', 5655),
(21441, '2015-05-14', '2015-05-18', '2015-05-29', 5656),
(21442, '2015-05-14', '2015-05-18', '2015-05-29', 5657),
(21443, '2015-05-14', '2015-05-18', '2015-05-29', 5658),
(21444, '2015-05-15', '2015-05-20', '2015-05-31', 5659),
(21445, '2015-05-15', '2015-05-20', '2015-05-31', 5660),
(21446, '2015-05-15', '2015-05-20', '2015-05-31', 5661),
(21447, '2015-05-16', '2015-05-21', '2015-06-01', 5662),
(21448, '2015-05-16', '2015-05-21', '2015-06-01', 5663),
(21449, '2015-05-16', '2015-05-21', '2015-06-01', 5664),
(21450, '2015-05-17', '2015-05-22', '2015-06-02', 5665),
(21451, '2015-05-17', '2015-05-22', '2015-06-02', 5666),
(21452, '2015-05-17', '2015-05-22', '2015-06-02', 5667),
(21453, '2015-05-18', '2015-05-23', '2015-06-03', 5668),
(21454, '2015-05-18', '2015-05-23', '2015-06-03', 5669),
(21455, '2015-05-18', '2015-05-23', '2015-06-03', 5670),
(21456, '2015-05-19', '2015-05-24', '2015-06-04', 5671),
(21457, '2015-05-19', '2015-05-24', '2015-06-04', 5672),
(21458, '2015-05-19', '2015-05-24', '2015-06-04', 5673),
(21459, '2015-05-20', '2015-05-25', '2015-06-05', 5674),
(21460, '2015-05-20', '2015-05-25', '2015-06-05', 5675),
(21461, '2015-05-20', '2015-05-25', '2015-06-05', 5676),
(21462, '2015-05-21', '2015-05-26', '2015-06-06', 5734),
(21463, '2015-05-21', '2015-05-26', '2015-06-06', 5735),
(21464, '2015-05-21', '2015-05-26', '2015-06-06', 5736),
(21465, '2015-05-22', '2015-05-27', '2015-06-07', 5737),
(21466, '2015-05-22', '2015-05-27', '2015-06-07', 5738),
(21467, '2015-05-22', '2015-05-27', '2015-06-07', 5739),
(21468, '2015-05-23', '2015-05-28', '2015-06-08', 5683),
(21469, '2015-05-23', '2015-05-28', '2015-06-08', 5684),
(21470, '2015-05-23', '2015-05-28', '2015-06-08', 5685),
(21471, '2015-05-24', '2015-05-29', '2015-06-09', 5686),
(21472, '2015-05-24', '2015-05-29', '2015-06-09', 5687),
(21473, '2015-05-24', '2015-05-29', '2015-06-09', 5688),
(21474, '2015-05-25', '2015-05-31', '2015-06-11', 5780),
(21475, '2015-05-25', '2015-05-31', '2015-06-11', 5781),
(21476, '2015-05-25', '2015-05-31', '2015-06-11', 5782),
(21477, '2015-05-26', '2015-06-01', '2015-06-12', 5783),
(21478, '2015-05-26', '2015-06-01', '2015-06-12', 5784),
(21479, '2015-05-26', '2015-06-01', '2015-06-12', 5785),
(21480, '2015-05-27', '2015-06-02', '2015-06-13', 5786),
(21481, '2015-05-27', '2015-06-02', '2015-06-13', 5787),
(21482, '2015-05-27', '2015-06-02', '2015-06-13', 5788),
(21483, '2015-05-28', '2015-06-03', '2015-06-14', 5789),
(21484, '2015-05-28', '2015-06-03', '2015-06-14', 5700),
(21485, '2015-05-28', '2015-06-03', '2015-06-14', 5814),
(21486, '2015-05-29', '2015-06-04', '2015-06-15', 5815),
(21487, '2015-05-29', '2015-06-04', '2015-06-15', 5816),
(21488, '2015-05-29', '2015-06-04', '2015-06-15', 5817),
(21489, '2015-05-30', '2015-06-05', '2015-06-16', 5818),
(21490, '2015-05-30', '2015-06-05', '2015-06-16', 5819),
(21491, '2015-05-30', '2015-06-05', '2015-06-16', 5820),
(21492, '2015-05-31', '2015-06-06', '2015-06-17', 5821),
(21493, '2015-05-31', '2015-06-06', '2015-06-17', 5822),
(21494, '2015-05-31', '2015-06-06', '2015-06-17', 5632),
(21495, '2015-07-02', '2015-07-08', '2015-07-19', 5633),
(21496, '2015-07-02', '2015-07-08', '2015-07-19', 5634),
(21497, '2015-07-02', '2015-07-08', '2015-07-19', 5635),
(21498, '2015-07-03', '2015-07-09', '2015-07-20', 5636),
(21499, '2015-07-03', '2015-07-09', '2015-07-20', 5637),
(21500, '2015-05-31', '2015-06-03', '2015-06-14', 5638),
(21501, '2015-05-31', '2015-06-03', '2015-06-14', 5639),
(21502, '2015-06-01', '2015-06-04', '2015-06-15', 5640),
(21503, '2015-06-01', '2015-06-04', '2015-06-15', 5641),
(21504, '2015-06-01', '2015-06-04', '2015-06-15', 5642),
(21505, '2015-06-02', '2015-06-05', '2015-06-16', 5643),
(21506, '2015-06-02', '2015-06-05', '2015-06-16', 5775),
(21507, '2015-06-02', '2015-06-05', '2015-06-16', 5773),
(21508, '2015-06-03', '2015-06-06', '2015-06-17', 5774),
(21509, '2015-06-03', '2015-06-06', '2015-06-17', 5775),
(21510, '2015-06-03', '2015-06-06', '2015-06-17', 5776),
(21511, '2015-06-04', '2015-06-07', '2015-06-18', 5780),
(21512, '2015-06-04', '2015-06-07', '2015-06-18', 5781),
(21513, '2015-06-04', '2015-06-07', '2015-06-18', 5782),
(21514, '2015-06-05', '2015-06-09', '2015-06-20', 5783),
(21515, '2015-06-05', '2015-06-09', '2015-06-20', 5784),
(21516, '2015-06-05', '2015-06-09', '2015-06-20', 5785),
(21517, '2015-06-06', '2015-06-10', '2015-06-21', 5786),
(21518, '2015-06-06', '2015-06-10', '2015-06-21', 5787),
(21519, '2015-06-06', '2015-06-10', '2015-06-21', 5788),
(21520, '2015-06-07', '2015-06-11', '2015-06-22', 5789),
(21521, '2015-06-07', '2015-06-11', '2015-06-22', 5731),
(21522, '2015-06-07', '2015-06-11', '2015-06-22', 5732),
(21523, '2015-06-08', '2015-06-12', '2015-06-23', 5734),
(21524, '2015-06-08', '2015-06-12', '2015-06-23', 5735),
(21525, '2015-06-08', '2015-06-12', '2015-06-23', 5736),
(21526, '2015-06-09', '2015-06-13', '2015-06-24', 5737),
(21527, '2015-06-09', '2015-06-13', '2015-06-24', 5738),
(21528, '2015-06-09', '2015-06-13', '2015-06-24', 5739),
(21529, '2015-06-10', '2015-06-14', '2015-06-25', 5740),
(21530, '2015-06-10', '2015-06-14', '2015-06-25', 5741),
(21531, '2015-06-10', '2015-06-14', '2015-06-25', 5742),
(21532, '2015-06-11', '2015-06-15', '2015-06-26', 5743),
(21533, '2015-06-11', '2015-06-15', '2015-06-26', 5744),
(21534, '2015-06-11', '2015-06-15', '2015-06-26', 5519),
(21535, '2015-06-12', '2015-06-16', '2015-06-27', 5520),
(21536, '2015-06-12', '2015-06-16', '2015-06-27', 5521),
(21537, '2015-06-12', '2015-06-16', '2015-06-27', 5522),
(21538, '2015-06-13', '2015-06-17', '2015-06-28', 5523),
(21539, '2015-06-13', '2015-06-17', '2015-06-28', 5524),
(21540, '2015-06-13', '2015-06-17', '2015-06-28', 5525),
(21541, '2015-06-14', '2015-06-18', '2015-06-29', 5526),
(21542, '2015-06-14', '2015-06-18', '2015-06-29', 5527),
(21543, '2015-06-14', '2015-06-18', '2015-06-29', 5528),
(21544, '2015-06-15', '2015-06-20', '2015-07-01', 5529),
(21545, '2015-06-15', '2015-06-20', '2015-07-01', 5530),
(21546, '2015-06-15', '2015-06-20', '2015-07-01', 5531),
(21547, '2015-06-16', '2015-06-21', '2015-07-02', 5532),
(21548, '2015-06-16', '2015-06-21', '2015-07-02', 5533),
(21549, '2015-06-16', '2015-06-21', '2015-07-02', 5534),
(21550, '2015-06-17', '2015-06-22', '2015-07-03', 5535),
(21551, '2015-06-17', '2015-06-22', '2015-07-03', 5536),
(21552, '2015-06-17', '2015-06-22', '2015-07-03', 5007),
(21553, '2015-06-18', '2015-06-23', '2015-07-04', 5002),
(21554, '2015-06-18', '2015-06-23', '2015-07-04', 5007),
(21555, '2015-06-18', '2015-06-23', '2015-07-04', 5009),
(21556, '2015-06-19', '2015-06-24', '2015-07-05', 5011),
(21557, '2015-06-19', '2015-06-24', '2015-07-05', 5022),
(21558, '2015-06-19', '2015-06-24', '2015-07-05', 5025),
(21559, '2015-06-20', '2015-06-25', '2015-07-06', 5028),
(21560, '2015-06-20', '2015-06-25', '2015-07-06', 5039),
(21561, '2015-06-20', '2015-06-25', '2015-07-06', 5042),
(21562, '2015-06-21', '2015-06-26', '2015-07-07', 5043),
(21563, '2015-06-21', '2015-06-26', '2015-07-07', 5049),
(21564, '2015-06-21', '2015-06-26', '2015-07-07', 5071),
(21565, '2015-06-22', '2015-06-27', '2015-07-08', 5079),
(21566, '2015-06-22', '2015-06-27', '2015-07-08', 5081),
(21567, '2015-06-22', '2015-06-27', '2015-07-08', 5082),
(21568, '2015-06-23', '2015-06-28', '2015-07-09', 5087),
(21569, '2015-06-23', '2015-06-28', '2015-07-09', 5091),
(21570, '2015-06-23', '2015-06-28', '2015-07-09', 5092),
(21571, '2015-06-24', '2015-06-29', '2015-07-10', 5093),
(21572, '2015-06-24', '2015-06-29', '2015-07-10', 5102),
(21573, '2015-06-24', '2015-06-29', '2015-07-10', 5119),
(21574, '2015-06-25', '2015-07-01', '2015-07-12', 5574),
(21575, '2015-06-25', '2015-07-01', '2015-07-12', 5575),
(21576, '2015-06-25', '2015-07-01', '2015-07-12', 5576),
(21577, '2015-06-26', '2015-07-02', '2015-07-13', 5577),
(21578, '2015-06-26', '2015-07-02', '2015-07-13', 5578),
(21579, '2015-06-26', '2015-07-02', '2015-07-13', 5579),
(21580, '2015-06-27', '2015-07-03', '2015-07-14', 5580),
(21581, '2015-06-27', '2015-07-03', '2015-07-14', 5581),
(21582, '2015-06-27', '2015-07-03', '2015-07-14', 5582),
(21583, '2015-06-28', '2015-07-04', '2015-07-15', 5583),
(21584, '2015-06-28', '2015-07-04', '2015-07-15', 5584),
(21585, '2015-06-28', '2015-07-04', '2015-07-15', 5585),
(21586, '2015-06-29', '2015-07-05', '2015-07-16', 5586),
(21587, '2015-06-29', '2015-07-05', '2015-07-16', 5587),
(21588, '2015-06-29', '2015-07-05', '2015-07-16', 5139),
(21589, '2015-06-30', '2015-07-06', '2015-07-17', 5144),
(21590, '2015-06-30', '2015-07-06', '2015-07-17', 5162),
(21591, '2015-06-30', '2015-07-06', '2015-07-17', 5172),
(21592, '2015-07-01', '2015-07-07', '2015-07-18', 5237),
(21593, '2015-07-01', '2015-07-07', '2015-07-18', 5238),
(21594, '2015-07-01', '2015-07-07', '2015-07-18', 5239),
(21595, '2015-07-02', '2015-07-08', '2015-07-19', 5250),
(21596, '2015-07-02', '2015-07-08', '2015-07-19', 5251),
(21597, '2015-07-02', '2015-07-08', '2015-07-19', 5256),
(21598, '2015-07-03', '2015-07-09', '2015-07-20', 5267),
(21599, '2015-07-03', '2015-07-09', '2015-07-20', 5310),
(21600, '2015-05-31', '2015-06-03', '2015-06-14', 5316),
(21601, '2015-05-31', '2015-06-03', '2015-06-14', 5321),
(21602, '2015-06-01', '2015-06-04', '2015-06-15', 5322),
(21603, '2015-06-01', '2015-06-04', '2015-06-15', 5328),
(21604, '2015-06-01', '2015-06-04', '2015-06-15', 5353),
(21605, '2015-06-02', '2015-06-05', '2015-06-16', 5354),
(21606, '2015-06-02', '2015-06-05', '2015-06-16', 5355),
(21607, '2015-06-02', '2015-06-05', '2015-06-16', 5356),
(21608, '2015-06-03', '2015-06-06', '2015-06-17', 5432),
(21609, '2015-06-03', '2015-06-06', '2015-06-17', 5433),
(21610, '2015-06-03', '2015-06-06', '2015-06-17', 5434),
(21611, '2015-06-04', '2015-06-07', '2015-06-18', 5435),
(21612, '2015-06-04', '2015-06-07', '2015-06-18', 5445),
(21613, '2015-06-04', '2015-06-07', '2015-06-18', 5477),
(21614, '2015-06-05', '2015-06-09', '2015-06-20', 5322),
(21615, '2015-06-05', '2015-06-09', '2015-06-20', 5328),
(21616, '2015-06-05', '2015-06-09', '2015-06-20', 5353),
(21617, '2015-06-06', '2015-06-10', '2015-06-21', 5354),
(21618, '2015-06-06', '2015-06-10', '2015-06-21', 5438),
(21619, '2015-06-06', '2015-06-10', '2015-06-21', 5439),
(21620, '2015-06-07', '2015-06-11', '2015-06-22', 5440),
(21621, '2015-06-07', '2015-06-11', '2015-06-22', 5441),
(21622, '2015-06-07', '2015-06-11', '2015-06-22', 5442),
(21623, '2015-06-08', '2015-06-12', '2015-06-23', 5443),
(21624, '2015-06-08', '2015-06-12', '2015-06-23', 5444),
(21625, '2015-06-08', '2015-06-12', '2015-06-23', 5445),
(21626, '2015-06-09', '2015-06-13', '2015-06-24', 5477),
(21627, '2015-06-09', '2015-06-13', '2015-06-24', 5478),
(21628, '2015-06-09', '2015-06-13', '2015-06-24', 5479),
(21629, '2015-06-10', '2015-06-14', '2015-06-25', 5480),
(21630, '2015-06-10', '2015-06-14', '2015-06-25', 5481),
(21631, '2015-06-10', '2015-06-14', '2015-06-25', 5482),
(21632, '2015-06-11', '2015-06-15', '2015-06-26', 5483),
(21633, '2015-06-11', '2015-06-15', '2015-06-26', 5484),
(21634, '2015-06-11', '2015-06-15', '2015-06-26', 5485),
(21635, '2015-06-12', '2015-06-16', '2015-06-27', 5486),
(21636, '2015-06-12', '2015-06-16', '2015-06-27', 5488),
(21637, '2015-06-12', '2015-06-16', '2015-06-27', 5489),
(21638, '2015-06-13', '2015-06-17', '2015-06-28', 5385),
(21639, '2015-06-13', '2015-06-17', '2015-06-28', 5386),
(21640, '2015-06-13', '2015-06-17', '2015-06-28', 5387),
(21641, '2015-06-14', '2015-06-18', '2015-06-29', 5388),
(21642, '2015-06-14', '2015-06-18', '2015-06-29', 5389),
(21643, '2015-06-14', '2015-06-18', '2015-06-29', 5390),
(21644, '2015-06-15', '2015-06-20', '2015-07-01', 5391),
(21645, '2015-06-15', '2015-06-20', '2015-07-01', 5392),
(21646, '2015-06-15', '2015-06-20', '2015-07-01', 5393),
(21647, '2015-06-16', '2015-06-21', '2015-07-02', 5394),
(21648, '2015-06-16', '2015-06-21', '2015-07-02', 5395),
(21649, '2015-06-16', '2015-06-21', '2015-07-02', 5353),
(21650, '2015-06-17', '2015-06-22', '2015-07-03', 5354),
(21651, '2015-06-17', '2015-06-22', '2015-07-03', 5355),
(21652, '2015-06-17', '2015-06-22', '2015-07-03', 5356),
(21653, '2015-06-18', '2015-06-23', '2015-07-04', 5357),
(21654, '2015-06-18', '2015-06-23', '2015-07-04', 5358),
(21655, '2015-06-18', '2015-06-23', '2015-07-04', 5359),
(21656, '2015-06-19', '2015-06-24', '2015-07-05', 5360),
(21657, '2015-06-19', '2015-06-24', '2015-07-05', 5361),
(21658, '2015-06-19', '2015-06-24', '2015-07-05', 5362),
(21659, '2015-06-20', '2015-06-25', '2015-07-06', 5363),
(21660, '2015-06-20', '2015-06-25', '2015-07-06', 5364),
(21661, '2015-06-20', '2015-06-25', '2015-07-06', 5365),
(21662, '2015-06-21', '2015-06-26', '2015-07-07', 5366),
(21663, '2015-06-21', '2015-06-26', '2015-07-07', 5367),
(21664, '2015-06-21', '2015-06-26', '2015-07-07', 5368),
(21665, '2015-06-22', '2015-06-27', '2015-07-08', 5369),
(21666, '2015-06-22', '2015-06-27', '2015-07-08', 5370),
(21667, '2015-06-22', '2015-06-27', '2015-07-08', 5371),
(21668, '2015-06-23', '2015-06-28', '2015-07-09', 5426),
(21669, '2015-06-23', '2015-06-28', '2015-07-09', 5427),
(21670, '2015-06-23', '2015-06-28', '2015-07-09', 5428),
(21671, '2015-06-24', '2015-06-29', '2015-07-10', 5429),
(21672, '2015-06-24', '2015-06-29', '2015-07-10', 5430),
(21673, '2015-06-24', '2015-06-29', '2015-07-10', 5431),
(21674, '2015-06-25', '2015-07-01', '2015-07-12', 5432),
(21675, '2015-07-25', '2015-07-31', '2015-08-11', 5433),
(21676, '2015-07-25', '2015-07-31', '2015-08-11', 5434),
(21677, '2015-07-26', '2015-08-01', '2015-08-12', 5381),
(21678, '2015-07-26', '2015-08-01', '2015-08-12', 5382),
(21679, '2015-07-26', '2015-08-01', '2015-08-12', 5383),
(21680, '2015-07-27', '2015-08-02', '2015-08-13', 5384),
(21681, '2015-07-27', '2015-08-02', '2015-08-13', 5385),
(21682, '2015-07-27', '2015-08-02', '2015-08-13', 5386),
(21683, '2015-07-28', '2015-08-03', '2015-08-14', 5449),
(21684, '2015-07-28', '2015-08-03', '2015-08-14', 5450),
(21685, '2015-07-28', '2015-08-03', '2015-08-14', 5451),
(21686, '2015-07-29', '2015-08-04', '2015-08-15', 5452),
(21687, '2015-07-29', '2015-08-04', '2015-08-15', 5453),
(21688, '2015-07-29', '2015-08-04', '2015-08-15', 5454),
(21689, '2015-07-30', '2015-08-05', '2015-08-16', 5455),
(21690, '2015-07-30', '2015-08-05', '2015-08-16', 5456),
(21691, '2015-07-30', '2015-08-05', '2015-08-16', 5457),
(21692, '2015-07-31', '2015-08-06', '2015-08-17', 5458),
(21693, '2015-07-31', '2015-08-06', '2015-08-17', 5459),
(21694, '2015-07-31', '2015-08-06', '2015-08-17', 5460),
(21695, '2015-08-01', '2015-08-07', '2015-08-18', 5461),
(21696, '2015-08-01', '2015-08-07', '2015-08-18', 5466),
(21697, '2015-08-01', '2015-08-07', '2015-08-18', 5467),
(21698, '2015-08-02', '2015-08-08', '2015-08-19', 5468),
(21699, '2015-08-02', '2015-08-08', '2015-08-19', 5469),
(21700, '2015-06-30', '2015-07-03', '2015-07-14', 5470),
(21701, '2015-06-30', '2015-07-03', '2015-07-14', 5471),
(21702, '2015-07-01', '2015-07-04', '2015-07-15', 5472),
(21703, '2015-07-01', '2015-07-04', '2015-07-15', 5473),
(21704, '2015-07-01', '2015-07-04', '2015-07-15', 5474),
(21705, '2015-07-02', '2015-07-05', '2015-07-16', 5475),
(21706, '2015-07-02', '2015-07-05', '2015-07-16', 5476),
(21707, '2015-07-02', '2015-07-05', '2015-07-16', 5392),
(21708, '2015-07-03', '2015-07-06', '2015-07-17', 5393),
(21709, '2015-07-03', '2015-07-06', '2015-07-17', 5394),
(21710, '2015-07-03', '2015-07-06', '2015-07-17', 5395),
(21711, '2015-07-04', '2015-07-07', '2015-07-18', 5396),
(21712, '2015-07-04', '2015-07-07', '2015-07-18', 5397),
(21713, '2015-07-04', '2015-07-07', '2015-07-18', 5398),
(21714, '2015-07-05', '2015-07-09', '2015-07-20', 5399),
(21715, '2015-07-05', '2015-07-09', '2015-07-20', 5400),
(21716, '2015-07-05', '2015-07-09', '2015-07-20', 5401),
(21717, '2015-07-06', '2015-07-10', '2015-07-21', 5402),
(21718, '2015-07-06', '2015-07-10', '2015-07-21', 5403),
(21719, '2015-07-06', '2015-07-10', '2015-07-21', 5404),
(21720, '2015-07-07', '2015-07-11', '2015-07-22', 5405),
(21721, '2015-07-07', '2015-07-11', '2015-07-22', 5406),
(21722, '2015-07-07', '2015-07-11', '2015-07-22', 5407),
(21723, '2015-07-08', '2015-07-12', '2015-07-23', 5408),
(21724, '2015-07-08', '2015-07-12', '2015-07-23', 5409),
(21725, '2015-07-08', '2015-07-12', '2015-07-23', 5410),
(21726, '2015-07-09', '2015-07-13', '2015-07-24', 5411),
(21727, '2015-07-09', '2015-07-13', '2015-07-24', 5412),
(21728, '2015-07-09', '2015-07-13', '2015-07-24', 5413),
(21729, '2015-07-10', '2015-07-14', '2015-07-25', 5414),
(21730, '2015-07-10', '2015-07-14', '2015-07-25', 5415),
(21731, '2015-07-10', '2015-07-14', '2015-07-25', 5416),
(21732, '2015-07-11', '2015-07-15', '2015-07-26', 5417),
(21733, '2015-07-11', '2015-07-15', '2015-07-26', 5418),
(21734, '2015-07-11', '2015-07-15', '2015-07-26', 5419),
(21735, '2015-07-12', '2015-07-16', '2015-07-27', 5420),
(21736, '2015-07-12', '2015-07-16', '2015-07-27', 5421),
(21737, '2015-07-12', '2015-07-16', '2015-07-27', 5422),
(21738, '2015-07-13', '2015-07-17', '2015-07-28', 5423),
(21739, '2015-07-13', '2015-07-17', '2015-07-28', 5424),
(21740, '2015-07-13', '2015-07-17', '2015-07-28', 5499),
(21741, '2015-07-14', '2015-07-18', '2015-07-29', 5500),
(21742, '2015-07-14', '2015-07-18', '2015-07-29', 5501),
(21743, '2015-07-14', '2015-07-18', '2015-07-29', 5502),
(21744, '2015-07-15', '2015-07-20', '2015-07-31', 5503),
(21745, '2015-07-15', '2015-07-20', '2015-07-31', 5504),
(21746, '2015-07-15', '2015-07-20', '2015-07-31', 5505),
(21747, '2015-07-16', '2015-07-21', '2015-08-01', 5506),
(21748, '2015-07-16', '2015-07-21', '2015-08-01', 5507),
(21749, '2015-07-16', '2015-07-21', '2015-08-01', 5508),
(21750, '2015-07-17', '2015-07-22', '2015-08-02', 5509),
(21751, '2015-07-17', '2015-07-22', '2015-08-02', 5510),
(21752, '2015-07-17', '2015-07-22', '2015-08-02', 5511),
(21753, '2015-07-18', '2015-07-23', '2015-08-03', 5456),
(21754, '2015-07-18', '2015-07-23', '2015-08-03', 5457),
(21755, '2015-07-18', '2015-07-23', '2015-08-03', 5458),
(21756, '2015-07-19', '2015-07-24', '2015-08-04', 5459),
(21757, '2015-07-19', '2015-07-24', '2015-08-04', 5460),
(21758, '2015-07-19', '2015-07-24', '2015-08-04', 5461),
(21759, '2015-07-20', '2015-07-25', '2015-08-05', 5462),
(21760, '2015-07-20', '2015-07-25', '2015-08-05', 5463),
(21761, '2015-07-20', '2015-07-25', '2015-08-05', 5464),
(21762, '2015-07-21', '2015-07-26', '2015-08-06', 5549),
(21763, '2015-07-21', '2015-07-26', '2015-08-06', 5550),
(21764, '2015-07-21', '2015-07-26', '2015-08-06', 5551),
(21765, '2015-07-22', '2015-07-27', '2015-08-07', 5552),
(21766, '2015-07-22', '2015-07-27', '2015-08-07', 5553),
(21767, '2015-07-22', '2015-07-27', '2015-08-07', 5554),
(21768, '2015-07-23', '2015-07-28', '2015-08-08', 5555),
(21769, '2015-07-23', '2015-07-28', '2015-08-08', 5556),
(21770, '2015-07-23', '2015-07-28', '2015-08-08', 5557),
(21771, '2015-07-24', '2015-07-29', '2015-08-09', 5558),
(21772, '2015-07-24', '2015-07-29', '2015-08-09', 5559),
(21773, '2015-07-24', '2015-07-29', '2015-08-09', 5560),
(21774, '2015-07-25', '2015-07-31', '2015-08-11', 5561),
(21775, '2015-07-25', '2015-07-31', '2015-08-11', 5562),
(21776, '2015-07-25', '2015-07-31', '2015-08-11', 5563),
(21777, '2015-07-26', '2015-08-01', '2015-08-12', 5564),
(21778, '2015-07-26', '2015-08-01', '2015-08-12', 5565),
(21779, '2015-07-26', '2015-08-01', '2015-08-12', 5566),
(21780, '2015-07-27', '2015-08-02', '2015-08-13', 5567),
(21781, '2015-07-27', '2015-08-02', '2015-08-13', 5568),
(21782, '2015-07-27', '2015-08-02', '2015-08-13', 5569),
(21783, '2015-07-28', '2015-08-03', '2015-08-14', 5570),
(21784, '2015-07-28', '2015-08-03', '2015-08-14', 5571),
(21785, '2015-07-28', '2015-08-03', '2015-08-14', 5572),
(21786, '2015-07-29', '2015-08-04', '2015-08-15', 5569),
(21787, '2015-07-29', '2015-08-04', '2015-08-15', 5570),
(21788, '2015-07-29', '2015-08-04', '2015-08-15', 5571),
(21789, '2015-07-30', '2015-08-05', '2015-08-16', 5572),
(21790, '2015-07-30', '2015-08-05', '2015-08-16', 5573),
(21791, '2015-07-30', '2015-08-05', '2015-08-16', 5574),
(21792, '2015-07-31', '2015-08-06', '2015-08-17', 5575),
(21793, '2015-07-31', '2015-08-06', '2015-08-17', 5576),
(21794, '2015-07-31', '2015-08-06', '2015-08-17', 5577),
(21795, '2015-08-01', '2015-08-07', '2015-08-18', 5578),
(21796, '2015-08-01', '2015-08-07', '2015-08-18', 5579),
(21797, '2015-08-01', '2015-08-07', '2015-08-18', 5580),
(21798, '2015-08-02', '2015-08-08', '2015-08-19', 5550),
(21799, '2015-08-02', '2015-08-08', '2015-08-19', 5551),
(21800, '2015-06-30', '2015-07-03', '2015-07-14', 5552),
(21801, '2015-06-30', '2015-07-03', '2015-07-14', 5553),
(21802, '2015-07-01', '2015-07-04', '2015-07-15', 5554),
(21803, '2015-07-01', '2015-07-04', '2015-07-15', 5555),
(21804, '2015-07-01', '2015-07-04', '2015-07-15', 5587),
(21805, '2015-07-02', '2015-07-05', '2015-07-16', 5588),
(21806, '2015-07-02', '2015-07-05', '2015-07-16', 5589),
(21807, '2015-07-02', '2015-07-05', '2015-07-16', 5590),
(21808, '2015-07-03', '2015-07-06', '2015-07-17', 5591),
(21809, '2015-07-03', '2015-07-06', '2015-07-17', 5592),
(21810, '2015-07-03', '2015-07-06', '2015-07-17', 5593),
(21811, '2015-07-04', '2015-07-07', '2015-07-18', 5594),
(21812, '2015-07-04', '2015-07-07', '2015-07-18', 5595),
(21813, '2015-07-04', '2015-07-07', '2015-07-18', 5596),
(21814, '2015-07-05', '2015-07-09', '2015-07-20', 5597),
(21815, '2015-07-05', '2015-07-09', '2015-07-20', 5598),
(21816, '2015-07-05', '2015-07-09', '2015-07-20', 5599),
(21817, '2015-07-06', '2015-07-10', '2015-07-21', 5600),
(21818, '2015-07-06', '2015-07-10', '2015-07-21', 5701),
(21819, '2015-07-06', '2015-07-10', '2015-07-21', 5702),
(21820, '2015-07-07', '2015-07-11', '2015-07-22', 5703),
(21821, '2015-07-07', '2015-07-11', '2015-07-22', 5704),
(21822, '2015-07-07', '2015-07-11', '2015-07-22', 5705),
(21823, '2015-07-08', '2015-07-12', '2015-07-23', 5706),
(21824, '2015-07-08', '2015-07-12', '2015-07-23', 5707),
(21825, '2015-07-08', '2015-07-12', '2015-07-23', 5708),
(21826, '2015-07-09', '2015-07-13', '2015-07-24', 5709),
(21827, '2015-07-09', '2015-07-13', '2015-07-24', 5710),
(21828, '2015-07-09', '2015-07-13', '2015-07-24', 5711),
(21829, '2015-07-10', '2015-07-14', '2015-07-25', 5712),
(21830, '2015-07-10', '2015-07-14', '2015-07-25', 5713),
(21831, '2015-07-10', '2015-07-14', '2015-07-25', 5714),
(21832, '2015-07-11', '2015-07-15', '2015-07-26', 5715),
(21833, '2015-07-11', '2015-07-15', '2015-07-26', 5716),
(21834, '2015-07-11', '2015-07-15', '2015-07-26', 5717),
(21835, '2015-07-12', '2015-07-16', '2015-07-27', 5718),
(21836, '2015-07-12', '2015-07-16', '2015-07-27', 5719),
(21837, '2015-07-12', '2015-07-16', '2015-07-27', 5525),
(21838, '2015-07-13', '2015-07-17', '2015-07-28', 5526),
(21839, '2015-07-13', '2015-07-17', '2015-07-28', 5527),
(21840, '2015-07-13', '2015-07-17', '2015-07-28', 5528),
(21841, '2015-07-14', '2015-07-18', '2015-07-29', 5529),
(21842, '2015-07-14', '2015-07-18', '2015-07-29', 5530),
(21843, '2015-07-14', '2015-07-18', '2015-07-29', 5531),
(21844, '2015-07-15', '2015-07-20', '2015-07-31', 5532),
(21845, '2015-07-15', '2015-07-20', '2015-07-31', 5533),
(21846, '2015-07-15', '2015-07-20', '2015-07-31', 5534),
(21847, '2015-07-16', '2015-07-21', '2015-08-01', 5535),
(21848, '2015-07-16', '2015-07-21', '2015-08-01', 5536),
(21849, '2015-07-16', '2015-07-21', '2015-08-01', 5537),
(21850, '2015-07-17', '2015-07-22', '2015-08-02', 5538),
(21851, '2015-07-17', '2015-07-22', '2015-08-02', 5539),
(21852, '2015-07-17', '2015-07-22', '2015-08-02', 5540),
(21853, '2015-07-18', '2015-07-23', '2015-08-03', 5606),
(21854, '2015-07-18', '2015-07-23', '2015-08-03', 5607),
(21855, '2015-08-18', '2015-08-23', '2015-09-03', 5608),
(21856, '2015-08-19', '2015-08-24', '2015-09-04', 5609),
(21857, '2015-08-19', '2015-08-24', '2015-09-04', 5610),
(21858, '2015-08-19', '2015-08-24', '2015-09-04', 5611),
(21859, '2015-08-20', '2015-08-25', '2015-09-05', 5612),
(21860, '2015-08-20', '2015-08-25', '2015-09-05', 5613),
(21861, '2015-08-20', '2015-08-25', '2015-09-05', 5614),
(21862, '2015-08-21', '2015-08-26', '2015-09-06', 5615),
(21863, '2015-08-21', '2015-08-26', '2015-09-06', 5616),
(21864, '2015-08-21', '2015-08-26', '2015-09-06', 5618),
(21865, '2015-08-22', '2015-08-27', '2015-09-07', 5619),
(21866, '2015-08-22', '2015-08-27', '2015-09-07', 5620),
(21867, '2015-08-22', '2015-08-27', '2015-09-07', 5525),
(21868, '2015-08-23', '2015-08-28', '2015-09-08', 5526),
(21869, '2015-08-23', '2015-08-28', '2015-09-08', 5527),
(21870, '2015-08-23', '2015-08-28', '2015-09-08', 5528),
(21871, '2015-08-24', '2015-08-29', '2015-09-09', 5529),
(21872, '2015-08-24', '2015-08-29', '2015-09-09', 5530),
(21873, '2015-08-24', '2015-08-29', '2015-09-09', 5531),
(21874, '2015-08-25', '2015-08-31', '2015-09-11', 5532),
(21875, '2015-08-25', '2015-08-31', '2015-09-11', 5533),
(21876, '2015-08-25', '2015-08-31', '2015-09-11', 5534),
(21877, '2015-08-26', '2015-09-01', '2015-09-12', 5535),
(21878, '2015-08-26', '2015-09-01', '2015-09-12', 5536),
(21879, '2015-08-26', '2015-09-01', '2015-09-12', 5537),
(21880, '2015-08-27', '2015-09-02', '2015-09-13', 5538),
(21881, '2015-08-27', '2015-09-02', '2015-09-13', 5539),
(21882, '2015-08-27', '2015-09-02', '2015-09-13', 5540),
(21883, '2015-08-28', '2015-09-03', '2015-09-14', 5752),
(21884, '2015-08-28', '2015-09-03', '2015-09-14', 5753),
(21885, '2015-08-28', '2015-09-03', '2015-09-14', 5754),
(21886, '2015-08-29', '2015-09-04', '2015-09-15', 5755),
(21887, '2015-08-29', '2015-09-04', '2015-09-15', 5756),
(21888, '2015-08-29', '2015-09-04', '2015-09-15', 5757),
(21889, '2015-08-30', '2015-09-05', '2015-09-16', 5758),
(21890, '2015-08-30', '2015-09-05', '2015-09-16', 5759),
(21891, '2015-08-30', '2015-09-05', '2015-09-16', 5760),
(21892, '2015-08-31', '2015-09-06', '2015-09-17', 5761),
(21893, '2015-08-31', '2015-09-06', '2015-09-17', 5762),
(21894, '2015-08-31', '2015-09-06', '2015-09-17', 5763),
(21895, '2015-09-01', '2015-09-07', '2015-09-18', 5764),
(21896, '2015-09-01', '2015-09-07', '2015-09-18', 5665),
(21897, '2015-09-01', '2015-09-07', '2015-09-18', 5666),
(21898, '2015-09-02', '2015-09-08', '2015-09-19', 5667),
(21899, '2015-09-02', '2015-09-08', '2015-09-19', 5668),
(21900, '2015-07-31', '2015-08-03', '2015-08-14', 5669),
(21901, '2015-07-31', '2015-08-03', '2015-08-14', 5670),
(21902, '2015-08-01', '2015-08-04', '2015-08-15', 5671),
(21903, '2015-08-01', '2015-08-04', '2015-08-15', 5672),
(21904, '2015-08-01', '2015-08-04', '2015-08-15', 5673),
(21905, '2015-08-02', '2015-08-05', '2015-08-16', 5674),
(21906, '2015-08-02', '2015-08-05', '2015-08-16', 5675),
(21907, '2015-08-02', '2015-08-05', '2015-08-16', 5795),
(21908, '2015-08-03', '2015-08-06', '2015-08-17', 5796),
(21909, '2015-08-03', '2015-08-06', '2015-08-17', 5797),
(21910, '2015-08-03', '2015-08-06', '2015-08-17', 5798),
(21911, '2015-08-04', '2015-08-07', '2015-08-18', 5799),
(21912, '2015-08-04', '2015-08-07', '2015-08-18', 5800),
(21913, '2015-08-04', '2015-08-07', '2015-08-18', 5801),
(21914, '2015-08-05', '2015-08-09', '2015-08-20', 5802),
(21915, '2015-08-05', '2015-08-09', '2015-08-20', 5803),
(21916, '2015-08-05', '2015-08-09', '2015-08-20', 5804),
(21917, '2015-08-06', '2015-08-10', '2015-08-21', 5805),
(21918, '2015-08-06', '2015-08-10', '2015-08-21', 5806),
(21919, '2015-08-06', '2015-08-10', '2015-08-21', 5807),
(21920, '2015-08-07', '2015-08-11', '2015-08-22', 5808),
(21921, '2015-08-07', '2015-08-11', '2015-08-22', 5809),
(21922, '2015-08-07', '2015-08-11', '2015-08-22', 5810),
(21923, '2015-08-08', '2015-08-12', '2015-08-23', 5811),
(21924, '2015-08-08', '2015-08-12', '2015-08-23', 5812),
(21925, '2015-08-08', '2015-08-12', '2015-08-23', 5813),
(21926, '2015-08-09', '2015-08-13', '2015-08-24', 5626),
(21927, '2015-08-09', '2015-08-13', '2015-08-24', 5627),
(21928, '2015-08-09', '2015-08-13', '2015-08-24', 5628),
(21929, '2015-08-10', '2015-08-14', '2015-08-25', 5629),
(21930, '2015-08-10', '2015-08-14', '2015-08-25', 5630),
(21931, '2015-08-10', '2015-08-14', '2015-08-25', 5631),
(21932, '2015-08-11', '2015-08-15', '2015-08-26', 5632),
(21933, '2015-08-11', '2015-08-15', '2015-08-26', 5633),
(21934, '2015-08-11', '2015-08-15', '2015-08-26', 5634),
(21935, '2015-08-12', '2015-08-16', '2015-08-27', 5635),
(21936, '2015-08-12', '2015-08-16', '2015-08-27', 5636),
(21937, '2015-08-12', '2015-08-16', '2015-08-27', 5637),
(21938, '2015-08-13', '2015-08-17', '2015-08-28', 5638),
(21939, '2015-08-13', '2015-08-17', '2015-08-28', 5639),
(21940, '2015-08-13', '2015-08-17', '2015-08-28', 5640),
(21941, '2015-08-14', '2015-08-18', '2015-08-29', 5641),
(21942, '2015-08-14', '2015-08-18', '2015-08-29', 5642),
(21943, '2015-08-14', '2015-08-18', '2015-08-29', 5643),
(21944, '2015-08-15', '2015-08-20', '2015-08-31', 5644),
(21945, '2015-08-15', '2015-08-20', '2015-08-31', 5645),
(21946, '2015-08-15', '2015-08-20', '2015-08-31', 5646),
(21947, '2015-08-16', '2015-08-21', '2015-09-01', 5647),
(21948, '2015-08-16', '2015-08-21', '2015-09-01', 5648),
(21949, '2015-08-16', '2015-08-21', '2015-09-01', 5649),
(21950, '2015-08-17', '2015-08-22', '2015-09-02', 5650),
(21951, '2015-08-17', '2015-08-22', '2015-09-02', 5651),
(21952, '2015-08-17', '2015-08-22', '2015-09-02', 5652),
(21953, '2015-08-18', '2015-08-23', '2015-09-03', 5653),
(21954, '2015-08-18', '2015-08-23', '2015-09-03', 5654),
(21955, '2015-08-18', '2015-08-23', '2015-09-03', 5655),
(21956, '2015-08-19', '2015-08-24', '2015-09-04', 5656),
(21957, '2015-08-19', '2015-08-24', '2015-09-04', 5657),
(21958, '2015-08-19', '2015-08-24', '2015-09-04', 5658),
(21959, '2015-08-20', '2015-08-25', '2015-09-05', 5659),
(21960, '2015-08-20', '2015-08-25', '2015-09-05', 5660),
(21961, '2015-08-20', '2015-08-25', '2015-09-05', 5661),
(21962, '2015-08-21', '2015-08-26', '2015-09-06', 5662),
(21963, '2015-08-21', '2015-08-26', '2015-09-06', 5663),
(21964, '2015-08-21', '2015-08-26', '2015-09-06', 5664),
(21965, '2015-08-22', '2015-08-27', '2015-09-07', 5665),
(21966, '2015-08-22', '2015-08-27', '2015-09-07', 5666),
(21967, '2015-08-22', '2015-08-27', '2015-09-07', 5667),
(21968, '2015-08-23', '2015-08-28', '2015-09-08', 5668),
(21969, '2015-08-23', '2015-08-28', '2015-09-08', 5669),
(21970, '2015-08-23', '2015-08-28', '2015-09-08', 5670),
(21971, '2015-08-24', '2015-08-29', '2015-09-09', 5671),
(21972, '2015-08-24', '2015-08-29', '2015-09-09', 5672),
(21973, '2015-08-24', '2015-08-29', '2015-09-09', 5673),
(21974, '2015-08-25', '2015-08-31', '2015-09-11', 5674),
(21975, '2015-08-25', '2015-08-31', '2015-09-11', 5675),
(21976, '2015-08-25', '2015-08-31', '2015-09-11', 5676),
(21977, '2015-08-26', '2015-09-01', '2015-09-12', 5734),
(21978, '2015-08-26', '2015-09-01', '2015-09-12', 5735),
(21979, '2015-08-26', '2015-09-01', '2015-09-12', 5736),
(21980, '2015-08-27', '2015-09-02', '2015-09-13', 5737),
(21981, '2015-08-27', '2015-09-02', '2015-09-13', 5738),
(21982, '2015-08-27', '2015-09-02', '2015-09-13', 5739),
(21983, '2015-08-28', '2015-09-03', '2015-09-14', 5683),
(21984, '2015-08-28', '2015-09-03', '2015-09-14', 5684),
(21985, '2015-08-28', '2015-09-03', '2015-09-14', 5685),
(21986, '2015-08-29', '2015-09-04', '2015-09-15', 5686),
(21987, '2015-08-29', '2015-09-04', '2015-09-15', 5687),
(21988, '2015-08-29', '2015-09-04', '2015-09-15', 5688),
(21989, '2015-08-30', '2015-09-05', '2015-09-16', 5780),
(21990, '2015-08-30', '2015-09-05', '2015-09-16', 5781),
(21991, '2015-08-30', '2015-09-05', '2015-09-16', 5782),
(21992, '2015-08-31', '2015-09-06', '2015-09-17', 5783),
(21993, '2015-08-31', '2015-09-06', '2015-09-17', 5784),
(21994, '2015-08-31', '2015-09-06', '2015-09-17', 5785),
(21995, '2015-09-01', '2015-09-07', '2015-09-18', 5786),
(21996, '2015-09-01', '2015-09-07', '2015-09-18', 5787),
(21997, '2015-09-01', '2015-09-07', '2015-09-18', 5788),
(21998, '2015-09-02', '2015-09-08', '2015-09-19', 5789),
(21999, '2015-09-02', '2015-09-08', '2015-09-19', 5700),
(22000, '2015-07-31', '2015-08-03', '2015-08-14', 5814),
(22001, '2015-07-31', '2015-08-03', '2015-08-14', 5815),
(22002, '2015-08-01', '2015-08-04', '2015-08-15', 5816),
(22003, '2015-08-01', '2015-08-04', '2015-08-15', 5817),
(22004, '2015-08-01', '2015-08-04', '2015-08-15', 5818),
(22005, '2015-08-02', '2015-08-05', '2015-08-16', 5819),
(22006, '2015-08-02', '2015-08-05', '2015-08-16', 5820),
(22007, '2015-08-02', '2015-08-05', '2015-08-16', 5821),
(22008, '2015-08-03', '2015-08-06', '2015-08-17', 5822),
(22009, '2015-08-03', '2015-08-06', '2015-08-17', 5632),
(22010, '2015-08-03', '2015-08-06', '2015-08-17', 5633),
(22011, '2015-08-04', '2015-08-07', '2015-08-18', 5634),
(22012, '2015-08-04', '2015-08-07', '2015-08-18', 5635),
(22013, '2015-08-04', '2015-08-07', '2015-08-18', 5636),
(22014, '2015-08-05', '2015-08-09', '2015-08-20', 5637),
(22015, '2015-08-05', '2015-08-09', '2015-08-20', 5638),
(22016, '2015-08-05', '2015-08-09', '2015-08-20', 5639),
(22017, '2015-08-06', '2015-08-10', '2015-08-21', 5640),
(22018, '2015-08-06', '2015-08-10', '2015-08-21', 5641),
(22019, '2015-08-06', '2015-08-10', '2015-08-21', 5642),
(22020, '2015-08-07', '2015-08-11', '2015-08-22', 5643),
(22021, '2015-08-07', '2015-08-11', '2015-08-22', 5775),
(22022, '2015-08-07', '2015-08-11', '2015-08-22', 5773),
(22023, '2015-08-08', '2015-08-12', '2015-08-23', 5774),
(22024, '2015-08-08', '2015-08-12', '2015-08-23', 5775),
(22025, '2015-08-08', '2015-08-12', '2015-08-23', 5776),
(22026, '2015-08-09', '2015-08-13', '2015-08-24', 5780),
(22027, '2015-08-09', '2015-08-13', '2015-08-24', 5781),
(22028, '2015-08-09', '2015-08-13', '2015-08-24', 5782),
(22029, '2015-08-10', '2015-08-14', '2015-08-25', 5783),
(22030, '2015-08-10', '2015-08-14', '2015-08-25', 5784),
(22031, '2015-08-10', '2015-08-14', '2015-08-25', 5785),
(22032, '2015-08-11', '2015-08-15', '2015-08-26', 5786),
(22033, '2015-08-11', '2015-08-15', '2015-08-26', 5787),
(22034, '2015-08-11', '2015-08-15', '2015-08-26', 5788),
(22035, '2015-09-12', '2015-09-16', '2015-09-27', 5789),
(22036, '2015-09-12', '2015-09-16', '2015-09-27', 5731),
(22037, '2015-09-12', '2015-09-16', '2015-09-27', 5732),
(22038, '2015-09-13', '2015-09-17', '2015-09-28', 5734),
(22039, '2015-09-13', '2015-09-17', '2015-09-28', 5735),
(22040, '2015-09-13', '2015-09-17', '2015-09-28', 5736),
(22041, '2015-09-14', '2015-09-18', '2015-09-29', 5737),
(22042, '2015-09-14', '2015-09-18', '2015-09-29', 5738),
(22043, '2015-09-14', '2015-09-18', '2015-09-29', 5739),
(22044, '2015-09-15', '2015-09-20', '2015-10-01', 5740),
(22045, '2015-09-15', '2015-09-20', '2015-10-01', 5741),
(22046, '2015-09-15', '2015-09-20', '2015-10-01', 5742),
(22047, '2015-09-16', '2015-09-21', '2015-10-02', 5743),
(22048, '2015-09-16', '2015-09-21', '2015-10-02', 5744),
(22049, '2015-09-16', '2015-09-21', '2015-10-02', 5519),
(22050, '2015-09-17', '2015-09-22', '2015-10-03', 5520),
(22051, '2015-09-17', '2015-09-22', '2015-10-03', 5521),
(22052, '2015-09-17', '2015-09-22', '2015-10-03', 5522),
(22053, '2015-09-18', '2015-09-23', '2015-10-04', 5523),
(22054, '2015-09-18', '2015-09-23', '2015-10-04', 5524),
(22055, '2015-09-18', '2015-09-23', '2015-10-04', 5525),
(22056, '2015-09-19', '2015-09-24', '2015-10-05', 5526),
(22057, '2015-09-19', '2015-09-24', '2015-10-05', 5527),
(22058, '2015-09-19', '2015-09-24', '2015-10-05', 5528),
(22059, '2015-09-20', '2015-09-25', '2015-10-06', 5529),
(22060, '2015-09-20', '2015-09-25', '2015-10-06', 5530),
(22061, '2015-09-20', '2015-09-25', '2015-10-06', 5531),
(22062, '2015-09-21', '2015-09-26', '2015-10-07', 5532),
(22063, '2015-09-21', '2015-09-26', '2015-10-07', 5533),
(22064, '2015-09-21', '2015-09-26', '2015-10-07', 5534),
(22065, '2015-09-22', '2015-09-27', '2015-10-08', 5535),
(22066, '2015-09-22', '2015-09-27', '2015-10-08', 5536),
(22067, '2015-09-22', '2015-09-27', '2015-10-08', 5007),
(22068, '2015-09-23', '2015-09-28', '2015-10-09', 5002),
(22069, '2015-09-23', '2015-09-28', '2015-10-09', 5007),
(22070, '2015-09-23', '2015-09-28', '2015-10-09', 5009),
(22071, '2015-09-24', '2015-09-29', '2015-10-10', 5011),
(22072, '2015-09-24', '2015-09-29', '2015-10-10', 5022),
(22073, '2015-09-24', '2015-09-29', '2015-10-10', 5025),
(22074, '2015-09-25', '2015-10-01', '2015-10-12', 5028),
(22075, '2015-09-25', '2015-10-01', '2015-10-12', 5039),
(22076, '2015-09-25', '2015-10-01', '2015-10-12', 5042),
(22077, '2015-09-26', '2015-10-02', '2015-10-13', 5043),
(22078, '2015-09-26', '2015-10-02', '2015-10-13', 5049),
(22079, '2015-09-26', '2015-10-02', '2015-10-13', 5071),
(22080, '2015-09-27', '2015-10-03', '2015-10-14', 5079),
(22081, '2015-09-27', '2015-10-03', '2015-10-14', 5081),
(22082, '2015-09-27', '2015-10-03', '2015-10-14', 5082),
(22083, '2015-09-28', '2015-10-04', '2015-10-15', 5087),
(22084, '2015-09-28', '2015-10-04', '2015-10-15', 5091),
(22085, '2015-09-28', '2015-10-04', '2015-10-15', 5092),
(22086, '2015-09-29', '2015-10-05', '2015-10-16', 5093),
(22087, '2015-09-29', '2015-10-05', '2015-10-16', 5102),
(22088, '2015-09-29', '2015-10-05', '2015-10-16', 5119),
(22089, '2015-09-30', '2015-10-06', '2015-10-17', 5574),
(22090, '2015-09-30', '2015-10-06', '2015-10-17', 5575),
(22091, '2015-09-30', '2015-10-06', '2015-10-17', 5576),
(22092, '2015-10-01', '2015-10-07', '2015-10-18', 5577),
(22093, '2015-10-01', '2015-10-07', '2015-10-18', 5578),
(22094, '2015-10-01', '2015-10-07', '2015-10-18', 5579),
(22095, '2015-10-02', '2015-10-08', '2015-10-19', 5580),
(22096, '2015-10-02', '2015-10-08', '2015-10-19', 5581),
(22097, '2015-10-02', '2015-10-08', '2015-10-19', 5582),
(22098, '2015-10-03', '2015-10-09', '2015-10-20', 5583),
(22099, '2015-10-03', '2015-10-09', '2015-10-20', 5584),
(22100, '2015-08-31', '2015-09-03', '2015-09-14', 5585),
(22101, '2015-08-31', '2015-09-03', '2015-09-14', 5586),
(22102, '2015-09-01', '2015-09-04', '2015-09-15', 5587),
(22103, '2015-09-01', '2015-09-04', '2015-09-15', 5139),
(22104, '2015-09-01', '2015-09-04', '2015-09-15', 5144),
(22105, '2015-09-02', '2015-09-05', '2015-09-16', 5162),
(22106, '2015-09-02', '2015-09-05', '2015-09-16', 5172),
(22107, '2015-09-02', '2015-09-05', '2015-09-16', 5237),
(22108, '2015-09-03', '2015-09-06', '2015-09-17', 5238),
(22109, '2015-09-03', '2015-09-06', '2015-09-17', 5239),
(22110, '2015-09-03', '2015-09-06', '2015-09-17', 5250),
(22111, '2015-09-04', '2015-09-07', '2015-09-18', 5251),
(22112, '2015-09-04', '2015-09-07', '2015-09-18', 5256),
(22113, '2015-09-04', '2015-09-07', '2015-09-18', 5267),
(22114, '2015-09-05', '2015-09-09', '2015-09-20', 5310),
(22115, '2015-09-05', '2015-09-09', '2015-09-20', 5316),
(22116, '2015-09-05', '2015-09-09', '2015-09-20', 5321),
(22117, '2015-09-06', '2015-09-10', '2015-09-21', 5322),
(22118, '2015-09-06', '2015-09-10', '2015-09-21', 5328),
(22119, '2015-09-06', '2015-09-10', '2015-09-21', 5353),
(22120, '2015-09-07', '2015-09-11', '2015-09-22', 5354),
(22121, '2015-09-07', '2015-09-11', '2015-09-22', 5355),
(22122, '2015-09-07', '2015-09-11', '2015-09-22', 5356),
(22123, '2015-09-08', '2015-09-12', '2015-09-23', 5432),
(22124, '2015-09-08', '2015-09-12', '2015-09-23', 5433),
(22125, '2015-09-08', '2015-09-12', '2015-09-23', 5434),
(22126, '2015-09-09', '2015-09-13', '2015-09-24', 5435),
(22127, '2015-09-09', '2015-09-13', '2015-09-24', 5445),
(22128, '2015-09-09', '2015-09-13', '2015-09-24', 5477),
(22129, '2015-09-10', '2015-09-14', '2015-09-25', 5322),
(22130, '2015-09-10', '2015-09-14', '2015-09-25', 5328),
(22131, '2015-09-10', '2015-09-14', '2015-09-25', 5353),
(22132, '2015-09-11', '2015-09-15', '2015-09-26', 5354),
(22133, '2015-09-11', '2015-09-15', '2015-09-26', 5438),
(22134, '2015-09-11', '2015-09-15', '2015-09-26', 5439),
(22135, '2015-09-12', '2015-09-16', '2015-09-27', 5440),
(22136, '2015-09-12', '2015-09-16', '2015-09-27', 5441),
(22137, '2015-09-12', '2015-09-16', '2015-09-27', 5442),
(22138, '2015-09-13', '2015-09-17', '2015-09-28', 5443),
(22139, '2015-09-13', '2015-09-17', '2015-09-28', 5444),
(22140, '2015-09-13', '2015-09-17', '2015-09-28', 5445),
(22141, '2015-09-14', '2015-09-18', '2015-09-29', 5477),
(22142, '2015-09-14', '2015-09-18', '2015-09-29', 5478),
(22143, '2015-09-14', '2015-09-18', '2015-09-29', 5479),
(22144, '2015-09-15', '2015-09-20', '2015-10-01', 5480),
(22145, '2015-09-15', '2015-09-20', '2015-10-01', 5481),
(22146, '2015-09-15', '2015-09-20', '2015-10-01', 5482),
(22147, '2015-09-16', '2015-09-21', '2015-10-02', 5483),
(22148, '2015-09-16', '2015-09-21', '2015-10-02', 5484),
(22149, '2015-09-16', '2015-09-21', '2015-10-02', 5485),
(22150, '2015-09-17', '2015-09-22', '2015-10-03', 5486),
(22151, '2015-09-17', '2015-09-22', '2015-10-03', 5488),
(22152, '2015-09-17', '2015-09-22', '2015-10-03', 5489),
(22153, '2015-09-18', '2015-09-23', '2015-10-04', 5385),
(22154, '2015-09-18', '2015-09-23', '2015-10-04', 5386),
(22155, '2015-09-18', '2015-09-23', '2015-10-04', 5387),
(22156, '2015-09-19', '2015-09-24', '2015-10-05', 5388),
(22157, '2015-09-19', '2015-09-24', '2015-10-05', 5389),
(22158, '2015-09-19', '2015-09-24', '2015-10-05', 5390),
(22159, '2015-09-20', '2015-09-25', '2015-10-06', 5391),
(22160, '2015-09-20', '2015-09-25', '2015-10-06', 5392),
(22161, '2015-09-20', '2015-09-25', '2015-10-06', 5393),
(22162, '2015-09-21', '2015-09-26', '2015-10-07', 5394),
(22163, '2015-09-21', '2015-09-26', '2015-10-07', 5395),
(22164, '2015-09-21', '2015-09-26', '2015-10-07', 5353),
(22165, '2015-09-22', '2015-09-27', '2015-10-08', 5354),
(22166, '2015-09-22', '2015-09-27', '2015-10-08', 5355),
(22167, '2015-09-22', '2015-09-27', '2015-10-08', 5356),
(22168, '2015-09-23', '2015-09-28', '2015-10-09', 5357),
(22169, '2015-09-23', '2015-09-28', '2015-10-09', 5358),
(22170, '2015-09-23', '2015-09-28', '2015-10-09', 5359),
(22171, '2015-09-24', '2015-09-29', '2015-10-10', 5360),
(22172, '2015-09-24', '2015-09-29', '2015-10-10', 5361),
(22173, '2015-09-24', '2015-09-29', '2015-10-10', 5362),
(22174, '2015-09-25', '2015-10-01', '2015-10-12', 5363),
(22175, '2015-09-25', '2015-10-01', '2015-10-12', 5364),
(22176, '2015-09-25', '2015-10-01', '2015-10-12', 5365),
(22177, '2015-09-26', '2015-10-02', '2015-10-13', 5366),
(22178, '2015-09-26', '2015-10-02', '2015-10-13', 5367),
(22179, '2015-09-26', '2015-10-02', '2015-10-13', 5368),
(22180, '2015-09-27', '2015-10-03', '2015-10-14', 5369),
(22181, '2015-09-27', '2015-10-03', '2015-10-14', 5370),
(22182, '2015-09-27', '2015-10-03', '2015-10-14', 5371),
(22183, '2015-09-28', '2015-10-04', '2015-10-15', 5426),
(22184, '2015-09-28', '2015-10-04', '2015-10-15', 5427),
(22185, '2015-09-28', '2015-10-04', '2015-10-15', 5428),
(22186, '2015-09-29', '2015-10-05', '2015-10-16', 5429),
(22187, '2015-09-29', '2015-10-05', '2015-10-16', 5430),
(22188, '2015-09-29', '2015-10-05', '2015-10-16', 5431),
(22189, '2015-09-30', '2015-10-06', '2015-10-17', 5432),
(22190, '2015-09-30', '2015-10-06', '2015-10-17', 5433),
(22191, '2015-09-30', '2015-10-06', '2015-10-17', 5434),
(22192, '2015-10-01', '2015-10-07', '2015-10-18', 5381),
(22193, '2015-10-01', '2015-10-07', '2015-10-18', 5382),
(22194, '2015-10-01', '2015-10-07', '2015-10-18', 5383),
(22195, '2015-10-02', '2015-10-08', '2015-10-19', 5384),
(22196, '2015-10-02', '2015-10-08', '2015-10-19', 5385),
(22197, '2015-10-02', '2015-10-08', '2015-10-19', 5386),
(22198, '2015-10-03', '2015-10-09', '2015-10-20', 5449),
(22199, '2015-10-03', '2015-10-09', '2015-10-20', 5450),
(22200, '2015-08-31', '2015-09-03', '2015-09-14', 5451),
(22201, '2015-08-31', '2015-09-03', '2015-09-14', 5452),
(22202, '2015-09-01', '2015-09-04', '2015-09-15', 5453),
(22203, '2015-09-01', '2015-09-04', '2015-09-15', 5454),
(22204, '2015-09-01', '2015-09-04', '2015-09-15', 5455),
(22205, '2015-09-02', '2015-09-05', '2015-09-16', 5456),
(22206, '2015-09-02', '2015-09-05', '2015-09-16', 5457),
(22207, '2015-09-02', '2015-09-05', '2015-09-16', 5458),
(22208, '2015-09-03', '2015-09-06', '2015-09-17', 5459),
(22209, '2015-09-03', '2015-09-06', '2015-09-17', 5460),
(22210, '2015-09-03', '2015-09-06', '2015-09-17', 5461),
(22211, '2015-09-04', '2015-09-07', '2015-09-18', 5466),
(22212, '2015-09-04', '2015-09-07', '2015-09-18', 5467),
(22213, '2015-09-04', '2015-09-07', '2015-09-18', 5468),
(22214, '2015-09-05', '2015-09-09', '2015-09-20', 5469),
(22215, '2015-10-05', '2015-10-09', '2015-10-20', 5470),
(22216, '2015-10-05', '2015-10-09', '2015-10-20', 5471),
(22217, '2015-10-06', '2015-10-10', '2015-10-21', 5472),
(22218, '2015-10-06', '2015-10-10', '2015-10-21', 5473),
(22219, '2015-10-06', '2015-10-10', '2015-10-21', 5474),
(22220, '2015-10-07', '2015-10-11', '2015-10-22', 5475),
(22221, '2015-10-07', '2015-10-11', '2015-10-22', 5476),
(22222, '2015-10-07', '2015-10-11', '2015-10-22', 5392),
(22223, '2015-10-08', '2015-10-12', '2015-10-23', 5393),
(22224, '2015-10-08', '2015-10-12', '2015-10-23', 5394),
(22225, '2015-10-08', '2015-10-12', '2015-10-23', 5395),
(22226, '2015-10-09', '2015-10-13', '2015-10-24', 5396),
(22227, '2015-10-09', '2015-10-13', '2015-10-24', 5397),
(22228, '2015-10-09', '2015-10-13', '2015-10-24', 5398),
(22229, '2015-10-10', '2015-10-14', '2015-10-25', 5399),
(22230, '2015-10-10', '2015-10-14', '2015-10-25', 5400),
(22231, '2015-10-10', '2015-10-14', '2015-10-25', 5401),
(22232, '2015-10-11', '2015-10-15', '2015-10-26', 5402),
(22233, '2015-10-11', '2015-10-15', '2015-10-26', 5403),
(22234, '2015-10-11', '2015-10-15', '2015-10-26', 5404),
(22235, '2015-10-12', '2015-10-16', '2015-10-27', 5405),
(22236, '2015-10-12', '2015-10-16', '2015-10-27', 5406),
(22237, '2015-10-12', '2015-10-16', '2015-10-27', 5407),
(22238, '2015-10-13', '2015-10-17', '2015-10-28', 5408),
(22239, '2015-10-13', '2015-10-17', '2015-10-28', 5409),
(22240, '2015-10-13', '2015-10-17', '2015-10-28', 5410),
(22241, '2015-10-14', '2015-10-18', '2015-10-29', 5411),
(22242, '2015-10-14', '2015-10-18', '2015-10-29', 5412),
(22243, '2015-10-14', '2015-10-18', '2015-10-29', 5413),
(22244, '2015-10-15', '2015-10-20', '2015-10-31', 5414),
(22245, '2015-10-15', '2015-10-20', '2015-10-31', 5415),
(22246, '2015-10-15', '2015-10-20', '2015-10-31', 5416),
(22247, '2015-10-16', '2015-10-21', '2015-11-01', 5417),
(22248, '2015-10-16', '2015-10-21', '2015-11-01', 5418),
(22249, '2015-10-16', '2015-10-21', '2015-11-01', 5419),
(22250, '2015-10-17', '2015-10-22', '2015-11-02', 5420),
(22251, '2015-10-17', '2015-10-22', '2015-11-02', 5421),
(22252, '2015-10-17', '2015-10-22', '2015-11-02', 5422),
(22253, '2015-10-18', '2015-10-23', '2015-11-03', 5423),
(22254, '2015-10-18', '2015-10-23', '2015-11-03', 5424),
(22255, '2015-10-18', '2015-10-23', '2015-11-03', 5499),
(22256, '2015-10-19', '2015-10-24', '2015-11-04', 5500),
(22257, '2015-10-19', '2015-10-24', '2015-11-04', 5501),
(22258, '2015-10-19', '2015-10-24', '2015-11-04', 5502),
(22259, '2015-10-20', '2015-10-25', '2015-11-05', 5503),
(22260, '2015-10-20', '2015-10-25', '2015-11-05', 5504),
(22261, '2015-10-20', '2015-10-25', '2015-11-05', 5505),
(22262, '2015-10-21', '2015-10-26', '2015-11-06', 5506),
(22263, '2015-10-21', '2015-10-26', '2015-11-06', 5507),
(22264, '2015-10-21', '2015-10-26', '2015-11-06', 5508),
(22265, '2015-10-22', '2015-10-27', '2015-11-07', 5509),
(22266, '2015-10-22', '2015-10-27', '2015-11-07', 5510),
(22267, '2015-10-22', '2015-10-27', '2015-11-07', 5511),
(22268, '2015-10-23', '2015-10-28', '2015-11-08', 5456),
(22269, '2015-10-23', '2015-10-28', '2015-11-08', 5457),
(22270, '2015-10-23', '2015-10-28', '2015-11-08', 5458),
(22271, '2015-10-24', '2015-10-29', '2015-11-09', 5459),
(22272, '2015-10-24', '2015-10-29', '2015-11-09', 5460),
(22273, '2015-10-24', '2015-10-29', '2015-11-09', 5461),
(22274, '2015-10-25', '2015-10-31', '2015-11-11', 5462),
(22275, '2015-10-25', '2015-10-31', '2015-11-11', 5463),
(22276, '2015-10-25', '2015-10-31', '2015-11-11', 5464),
(22277, '2015-10-26', '2015-11-01', '2015-11-12', 5549),
(22278, '2015-10-26', '2015-11-01', '2015-11-12', 5550),
(22279, '2015-10-26', '2015-11-01', '2015-11-12', 5551),
(22280, '2015-10-27', '2015-11-02', '2015-11-13', 5552),
(22281, '2015-10-27', '2015-11-02', '2015-11-13', 5553),
(22282, '2015-10-27', '2015-11-02', '2015-11-13', 5554),
(22283, '2015-10-28', '2015-11-03', '2015-11-14', 5555),
(22284, '2015-10-28', '2015-11-03', '2015-11-14', 5556),
(22285, '2015-10-28', '2015-11-03', '2015-11-14', 5557),
(22286, '2015-10-29', '2015-11-04', '2015-11-15', 5558),
(22287, '2015-10-29', '2015-11-04', '2015-11-15', 5559),
(22288, '2015-10-29', '2015-11-04', '2015-11-15', 5560),
(22289, '2015-10-30', '2015-11-05', '2015-11-16', 5561),
(22290, '2015-10-30', '2015-11-05', '2015-11-16', 5562),
(22291, '2015-10-30', '2015-11-05', '2015-11-16', 5563),
(22292, '2015-10-31', '2015-11-06', '2015-11-17', 5564),
(22293, '2015-10-31', '2015-11-06', '2015-11-17', 5565),
(22294, '2015-10-31', '2015-11-06', '2015-11-17', 5566),
(22295, '2015-11-01', '2015-11-07', '2015-11-18', 5567),
(22296, '2015-11-01', '2015-11-07', '2015-11-18', 5568),
(22297, '2015-11-01', '2015-11-07', '2015-11-18', 5569),
(22298, '2015-11-02', '2015-11-08', '2015-11-19', 5570),
(22299, '2015-11-02', '2015-11-08', '2015-11-19', 5571),
(22300, '2015-09-30', '2015-10-03', '2015-10-14', 5572),
(22301, '2015-09-30', '2015-10-03', '2015-10-14', 5569),
(22302, '2015-10-01', '2015-10-04', '2015-10-15', 5570),
(22303, '2015-10-01', '2015-10-04', '2015-10-15', 5571),
(22304, '2015-10-01', '2015-10-04', '2015-10-15', 5572),
(22305, '2015-10-02', '2015-10-05', '2015-10-16', 5573),
(22306, '2015-10-02', '2015-10-05', '2015-10-16', 5574),
(22307, '2015-10-02', '2015-10-05', '2015-10-16', 5575),
(22308, '2015-10-03', '2015-10-06', '2015-10-17', 5576),
(22309, '2015-10-03', '2015-10-06', '2015-10-17', 5577),
(22310, '2015-10-03', '2015-10-06', '2015-10-17', 5578),
(22311, '2015-10-04', '2015-10-07', '2015-10-18', 5579),
(22312, '2015-10-04', '2015-10-07', '2015-10-18', 5580),
(22313, '2015-10-04', '2015-10-07', '2015-10-18', 5550),
(22314, '2015-10-05', '2015-10-09', '2015-10-20', 5551),
(22315, '2015-10-05', '2015-10-09', '2015-10-20', 5552),
(22316, '2015-10-05', '2015-10-09', '2015-10-20', 5553),
(22317, '2015-10-06', '2015-10-10', '2015-10-21', 5554),
(22318, '2015-10-06', '2015-10-10', '2015-10-21', 5555);
INSERT INTO `Ordre` (`OrdreNr`, `OrdreDato`, `SendtDato`, `BetaltDato`, `KNr`) VALUES
(22319, '2015-10-06', '2015-10-10', '2015-10-21', 5587),
(22320, '2015-10-07', '2015-10-11', '2015-10-22', 5588),
(22321, '2015-10-07', '2015-10-11', '2015-10-22', 5589),
(22322, '2015-10-07', '2015-10-11', '2015-10-22', 5590),
(22323, '2015-10-08', '2015-10-12', '2015-10-23', 5591),
(22324, '2015-10-08', '2015-10-12', '2015-10-23', 5592),
(22325, '2015-10-08', '2015-10-12', '2015-10-23', 5593),
(22326, '2015-10-09', '2015-10-13', '2015-10-24', 5594),
(22327, '2015-10-09', '2015-10-13', '2015-10-24', 5595),
(22328, '2015-10-09', '2015-10-13', '2015-10-24', 5596),
(22329, '2015-10-10', '2015-10-14', '2015-10-25', 5597),
(22330, '2015-10-10', '2015-10-14', '2015-10-25', 5598),
(22331, '2015-10-10', '2015-10-14', '2015-10-25', 5599),
(22332, '2015-10-11', '2015-10-15', '2015-10-26', 5600),
(22333, '2015-10-11', '2015-10-15', '2015-10-26', 5701),
(22334, '2015-10-11', '2015-10-15', '2015-10-26', 5702),
(22335, '2015-10-12', '2015-10-16', '2015-10-27', 5703),
(22336, '2015-10-12', '2015-10-16', '2015-10-27', 5704),
(22337, '2015-10-12', '2015-10-16', '2015-10-27', 5705),
(22338, '2015-10-13', '2015-10-17', '2015-10-28', 5706),
(22339, '2015-10-13', '2015-10-17', '2015-10-28', 5707),
(22340, '2015-10-13', '2015-10-17', '2015-10-28', 5708),
(22341, '2015-10-14', '2015-10-18', '2015-10-29', 5709),
(22342, '2015-10-14', '2015-10-18', '2015-10-29', 5710),
(22343, '2015-10-14', '2015-10-18', '2015-10-29', 5711),
(22344, '2015-10-15', '2015-10-20', '2015-10-31', 5712),
(22345, '2015-10-15', '2015-10-20', '2015-10-31', 5713),
(22346, '2015-10-15', '2015-10-20', '2015-10-31', 5714),
(22347, '2015-10-16', '2015-10-21', '2015-11-01', 5715),
(22348, '2015-10-16', '2015-10-21', '2015-11-01', 5716),
(22349, '2015-10-16', '2015-10-21', '2015-11-01', 5717),
(22350, '2015-10-17', '2015-10-22', '2015-11-02', 5718),
(22351, '2015-10-17', '2015-10-22', '2015-11-02', 5719),
(22352, '2015-10-17', '2015-10-22', '2015-11-02', 5525),
(22353, '2015-10-18', '2015-10-23', '2015-11-03', 5526),
(22354, '2015-10-18', '2015-10-23', '2015-11-03', 5527),
(22355, '2015-10-18', '2015-10-23', '2015-11-03', 5528),
(22356, '2015-10-19', '2015-10-24', '2015-11-04', 5529),
(22357, '2015-10-19', '2015-10-24', '2015-11-04', 5530),
(22358, '2015-10-19', '2015-10-24', '2015-11-04', 5531),
(22359, '2015-10-20', '2015-10-25', '2015-11-05', 5532),
(22360, '2015-10-20', '2015-10-25', '2015-11-05', 5533),
(22361, '2015-10-20', '2015-10-25', '2015-11-05', 5534),
(22362, '2015-10-21', '2015-10-26', '2015-11-06', 5535),
(22363, '2015-10-21', '2015-10-26', '2015-11-06', 5536),
(22364, '2015-10-21', '2015-10-26', '2015-11-06', 5537),
(22365, '2015-10-22', '2015-10-27', '2015-11-07', 5538),
(22366, '2015-10-22', '2015-10-27', '2015-11-07', 5539),
(22367, '2015-10-22', '2015-10-27', '2015-11-07', 5540),
(22368, '2015-10-23', '2015-10-28', '2015-11-08', 5606),
(22369, '2015-10-23', '2015-10-28', '2015-11-08', 5607),
(22370, '2015-10-23', '2015-10-28', '2015-11-08', 5608),
(22371, '2015-10-24', '2015-10-29', '2015-11-09', 5609),
(22372, '2015-10-24', '2015-10-29', '2015-11-09', 5610),
(22373, '2015-10-24', '2015-10-29', '2015-11-09', 5611),
(22374, '2015-10-25', '2015-10-31', '2015-11-11', 5612),
(22375, '2015-10-25', '2015-10-31', '2015-11-11', 5613),
(22376, '2015-10-25', '2015-10-31', '2015-11-11', 5614),
(22377, '2015-10-26', '2015-11-01', '2015-11-12', 5615),
(22378, '2015-10-26', '2015-11-01', '2015-11-12', 5616),
(22379, '2015-10-26', '2015-11-01', '2015-11-12', 5618),
(22380, '2015-10-27', '2015-11-02', '2015-11-13', 5619),
(22381, '2015-10-27', '2015-11-02', '2015-11-13', 5620),
(22382, '2015-10-27', '2015-11-02', '2015-11-13', 5525),
(22383, '2015-10-28', '2015-11-03', '2015-11-14', 5526),
(22384, '2015-10-28', '2015-11-03', '2015-11-14', 5527),
(22385, '2015-10-28', '2015-11-03', '2015-11-14', 5528),
(22386, '2015-10-29', '2015-11-04', '2015-11-15', 5529),
(22387, '2015-10-29', '2015-11-04', '2015-11-15', 5530),
(22388, '2015-10-29', '2015-11-04', '2015-11-15', 5531),
(22389, '2015-10-30', '2015-11-05', '2015-11-16', 5532),
(22390, '2015-10-30', '2015-11-05', '2015-11-16', 5533),
(22391, '2015-10-30', '2015-11-05', '2015-11-16', 5534),
(22392, '2015-10-31', '2015-11-06', '2015-11-17', 5535),
(22393, '2015-10-31', '2015-11-06', '2015-11-17', 5536),
(22394, '2015-10-31', '2015-11-06', '2015-11-17', 5537),
(22395, '2015-12-02', '2015-12-08', '2015-12-19', 5538),
(22396, '2015-12-02', '2015-12-08', '2015-12-19', 5539),
(22397, '2015-12-02', '2015-12-08', '2015-12-19', 5540),
(22398, '2015-12-03', '2015-12-09', '2015-12-20', 5752),
(22399, '2015-12-03', '2015-12-09', '2015-12-20', 5753),
(22400, '2015-10-31', '2015-11-03', '2015-11-14', 5754),
(22401, '2015-10-31', '2015-11-03', '2015-11-14', 5755),
(22402, '2015-11-01', '2015-11-04', '2015-11-15', 5756),
(22403, '2015-11-01', '2015-11-04', '2015-11-15', 5757),
(22404, '2015-11-01', '2015-11-04', '2015-11-15', 5758),
(22405, '2015-11-02', '2015-11-05', '2015-11-16', 5759),
(22406, '2015-11-02', '2015-11-05', '2015-11-16', 5760),
(22407, '2015-11-02', '2015-11-05', '2015-11-16', 5761),
(22408, '2015-11-03', '2015-11-06', '2015-11-17', 5762),
(22409, '2015-11-03', '2015-11-06', '2015-11-17', 5763),
(22410, '2015-11-03', '2015-11-06', '2015-11-17', 5764),
(22411, '2015-11-04', '2015-11-07', '2015-11-18', 5665),
(22412, '2015-11-04', '2015-11-07', '2015-11-18', 5666),
(22413, '2015-11-04', '2015-11-07', '2015-11-18', 5667),
(22414, '2015-11-05', '2015-11-09', '2015-11-20', 5668),
(22415, '2015-11-05', '2015-11-09', '2015-11-20', 5669),
(22416, '2015-11-05', '2015-11-09', '2015-11-20', 5670),
(22417, '2015-11-06', '2015-11-10', '2015-11-21', 5671),
(22418, '2015-11-06', '2015-11-10', '2015-11-21', 5672),
(22419, '2015-11-06', '2015-11-10', '2015-11-21', 5673),
(22420, '2015-11-07', '2015-11-11', '2015-11-22', 5674),
(22421, '2015-11-07', '2015-11-11', '2015-11-22', 5675),
(22422, '2015-11-07', '2015-11-11', '2015-11-22', 5795),
(22423, '2015-11-08', '2015-11-12', '2015-11-23', 5796),
(22424, '2015-11-08', '2015-11-12', '2015-11-23', 5797),
(22425, '2015-11-08', '2015-11-12', '2015-11-23', 5798),
(22426, '2015-11-09', '2015-11-13', '2015-11-24', 5799),
(22427, '2015-11-09', '2015-11-13', '2015-11-24', 5800),
(22428, '2015-11-09', '2015-11-13', '2015-11-24', 5801),
(22429, '2015-11-10', '2015-11-14', '2015-11-25', 5802),
(22430, '2015-11-10', '2015-11-14', '2015-11-25', 5803),
(22431, '2015-11-10', '2015-11-14', '2015-11-25', 5804),
(22432, '2015-11-11', '2015-11-15', '2015-11-26', 5805),
(22433, '2015-11-11', '2015-11-15', '2015-11-26', 5806),
(22434, '2015-11-11', '2015-11-15', '2015-11-26', 5807),
(22435, '2015-11-12', '2015-11-16', '2015-11-27', 5808),
(22436, '2015-11-12', '2015-11-16', '2015-11-27', 5809),
(22437, '2015-11-12', '2015-11-16', '2015-11-27', 5810),
(22438, '2015-11-13', '2015-11-17', '2015-11-28', 5811),
(22439, '2015-11-13', '2015-11-17', '2015-11-28', 5812),
(22440, '2015-11-13', '2015-11-17', '2015-11-28', 5813),
(22441, '2015-11-14', '2015-11-18', '2015-11-29', 5626),
(22442, '2015-11-14', '2015-11-18', '2015-11-29', 5627),
(22443, '2015-11-14', '2015-11-18', '2015-11-29', 5628),
(22444, '2015-11-15', '2015-11-20', '2015-12-01', 5629),
(22445, '2015-11-15', '2015-11-20', '2015-12-01', 5630),
(22446, '2015-11-15', '2015-11-20', '2015-12-01', 5631),
(22447, '2015-11-16', '2015-11-21', '2015-12-02', 5632),
(22448, '2015-11-16', '2015-11-21', '2015-12-02', 5633),
(22449, '2015-11-16', '2015-11-21', '2015-12-02', 5634),
(22450, '2015-11-17', '2015-11-22', '2015-12-03', 5635),
(22451, '2015-11-17', '2015-11-22', '2015-12-03', 5636),
(22452, '2015-11-17', '2015-11-22', '2015-12-03', 5637),
(22453, '2015-11-18', '2015-11-23', '2015-12-04', 5638),
(22454, '2015-11-18', '2015-11-23', '2015-12-04', 5639),
(22455, '2015-11-18', '2015-11-23', '2015-12-04', 5640),
(22456, '2015-11-19', '2015-11-24', '2015-12-05', 5641),
(22457, '2015-11-19', '2015-11-24', '2015-12-05', 5642),
(22458, '2015-11-19', '2015-11-24', '2015-12-05', 5643),
(22459, '2015-11-20', '2015-11-25', '2015-12-06', 5644),
(22460, '2015-11-20', '2015-11-25', '2015-12-06', 5645),
(22461, '2015-11-20', '2015-11-25', '2015-12-06', 5646),
(22462, '2015-11-21', '2015-11-26', '2015-12-07', 5647),
(22463, '2015-11-21', '2015-11-26', '2015-12-07', 5648),
(22464, '2015-11-21', '2015-11-26', '2015-12-07', 5649),
(22465, '2015-11-22', '2015-11-27', '2015-12-08', 5650),
(22466, '2015-11-22', '2015-11-27', '2015-12-08', 5651),
(22467, '2015-11-22', '2015-11-27', '2015-12-08', 5652),
(22468, '2015-11-23', '2015-11-28', '2015-12-09', 5653),
(22469, '2015-11-23', '2015-11-28', '2015-12-09', 5654),
(22470, '2015-11-23', '2015-11-28', '2015-12-09', 5655),
(22471, '2015-11-24', '2015-11-29', '2015-12-10', 5656),
(22472, '2015-11-24', '2015-11-29', '2015-12-10', 5657),
(22473, '2015-11-24', '2015-11-29', '2015-12-10', 5658),
(22474, '2015-11-25', '2015-12-01', '2015-12-12', 5659),
(22475, '2015-11-25', '2015-12-01', '2015-12-12', 5660),
(22476, '2015-11-25', '2015-12-01', '2015-12-12', 5661),
(22477, '2015-11-26', '2015-12-02', '2015-12-13', 5662),
(22478, '2015-11-26', '2015-12-02', '2015-12-13', 5663),
(22479, '2015-11-26', '2015-12-02', '2015-12-13', 5664),
(22480, '2015-11-27', '2015-12-03', '2015-12-14', 5665),
(22481, '2015-11-27', '2015-12-03', '2015-12-14', 5666),
(22482, '2015-11-27', '2015-12-03', '2015-12-14', 5667),
(22483, '2015-11-28', '2015-12-04', '2015-12-15', 5668),
(22484, '2015-11-28', '2015-12-04', '2015-12-15', 5669),
(22485, '2015-11-28', '2015-12-04', '2015-12-15', 5670),
(22486, '2015-11-29', '2015-12-05', '2015-12-16', 5671),
(22487, '2015-11-29', '2015-12-05', '2015-12-16', 5672),
(22488, '2015-11-29', '2015-12-05', '2015-12-16', 5673),
(22489, '2015-11-30', '2015-12-06', '2015-12-17', 5674),
(22490, '2015-11-30', '2015-12-06', '2015-12-17', 5675),
(22491, '2015-11-30', '2015-12-06', '2015-12-17', 5676),
(22492, '2015-12-01', '2015-12-07', '2015-12-18', 5734),
(22493, '2015-12-01', '2015-12-07', '2015-12-18', 5735),
(22494, '2015-12-01', '2015-12-07', '2015-12-18', 5736),
(22495, '2015-12-02', '2015-12-08', '2015-12-19', 5737),
(22496, '2015-12-02', '2015-12-08', '2015-12-19', 5738),
(22497, '2015-12-02', '2015-12-08', '2015-12-19', 5739),
(22498, '2015-12-03', '2015-12-09', '2015-12-20', 5683),
(22499, '2015-12-03', '2015-12-09', '2015-12-20', 5684),
(22500, '2015-10-31', '2015-11-03', '2015-11-14', 5685),
(22501, '2015-10-31', '2015-11-03', '2015-11-14', 5686),
(22502, '2015-11-01', '2015-11-04', '2015-11-15', 5687),
(22503, '2015-11-01', '2015-11-04', '2015-11-15', 5688),
(22504, '2015-11-01', '2015-11-04', '2015-11-15', 5780),
(22505, '2015-11-02', '2015-11-05', '2015-11-16', 5781),
(22506, '2015-11-02', '2015-11-05', '2015-11-16', 5782),
(22507, '2015-11-02', '2015-11-05', '2015-11-16', 5783),
(22508, '2015-11-03', '2015-11-06', '2015-11-17', 5784),
(22509, '2015-11-03', '2015-11-06', '2015-11-17', 5785),
(22510, '2015-11-03', '2015-11-06', '2015-11-17', 5786),
(22511, '2015-11-04', '2015-11-07', '2015-11-18', 5787),
(22512, '2015-11-04', '2015-11-07', '2015-11-18', 5788),
(22513, '2015-11-04', '2015-11-07', '2015-11-18', 5789),
(22514, '2015-11-05', '2015-11-09', '2015-11-20', 5700),
(22515, '2015-11-05', '2015-11-09', '2015-11-20', 5814),
(22516, '2015-11-05', '2015-11-09', '2015-11-20', 5815),
(22517, '2015-11-06', '2015-11-10', '2015-11-21', 5816),
(22518, '2015-11-06', '2015-11-10', '2015-11-21', 5817),
(22519, '2015-11-06', '2015-11-10', '2015-11-21', 5818),
(22520, '2015-11-07', '2015-11-11', '2015-11-22', 5819),
(22521, '2015-11-07', '2015-11-11', '2015-11-22', 5820),
(22522, '2015-11-07', '2015-11-11', '2015-11-22', 5821),
(22523, '2015-11-08', '2015-11-12', '2015-11-23', 5822),
(22524, '2015-11-08', '2015-11-12', '2015-11-23', 5632),
(22525, '2015-11-08', '2015-11-12', '2015-11-23', 5633),
(22526, '2015-11-09', '2015-11-13', '2015-11-24', 5634),
(22527, '2015-11-09', '2015-11-13', '2015-11-24', 5635),
(22528, '2015-11-09', '2015-11-13', '2015-11-24', 5636),
(22529, '2015-11-10', '2015-11-14', '2015-11-25', 5637),
(22530, '2015-11-10', '2015-11-14', '2015-11-25', 5638),
(22531, '2015-11-10', '2015-11-14', '2015-11-25', 5639),
(22532, '2015-11-11', '2015-11-15', '2015-11-26', 5640),
(22533, '2015-11-11', '2015-11-15', '2015-11-26', 5641),
(22534, '2015-11-11', '2015-11-15', '2015-11-26', 5642),
(22535, '2015-11-12', '2015-11-16', '2015-11-27', 5643),
(22536, '2015-11-12', '2015-11-16', '2015-11-27', 5775),
(22537, '2015-11-12', '2015-11-16', '2015-11-27', 5773),
(22538, '2015-11-13', '2015-11-17', '2015-11-28', 5774),
(22539, '2015-11-13', '2015-11-17', '2015-11-28', 5775),
(22540, '2015-11-13', '2015-11-17', '2015-11-28', 5776),
(22541, '2015-11-14', '2015-11-18', '2015-11-29', 5780),
(22542, '2015-11-14', '2015-11-18', '2015-11-29', 5781),
(22543, '2015-11-14', '2015-11-18', '2015-11-29', 5782),
(22544, '2015-11-15', '2015-11-20', '2015-12-01', 5783),
(22545, '2015-11-15', '2015-11-20', '2015-12-01', 5784),
(22546, '2015-11-15', '2015-11-20', '2015-12-01', 5785),
(22547, '2015-11-16', '2015-11-21', '2015-12-02', 5786),
(22548, '2015-11-16', '2015-11-21', '2015-12-02', 5787),
(22549, '2015-11-16', '2015-11-21', '2015-12-02', 5788),
(22550, '2015-11-17', '2015-11-22', '2015-12-03', 5789),
(22551, '2015-11-17', '2015-11-22', '2015-12-03', 5731),
(22552, '2015-11-17', '2015-11-22', '2015-12-03', 5732),
(22553, '2015-11-18', '2015-11-23', '2015-12-04', 5734),
(22554, '2015-11-18', '2015-11-23', '2015-12-04', 5735),
(22555, '2015-11-18', '2015-11-23', '2015-12-04', 5736),
(22556, '2015-11-19', '2015-11-24', '2015-12-05', 5737),
(22557, '2015-11-19', '2015-11-24', '2015-12-05', 5738),
(22558, '2015-11-19', '2015-11-24', '2015-12-05', 5739),
(22559, '2015-11-20', '2015-11-25', '2015-12-06', 5740),
(22560, '2015-11-20', '2015-11-25', '2015-12-06', 5741),
(22561, '2015-11-20', '2015-11-25', '2015-12-06', 5519),
(22562, '2015-11-21', '2015-11-26', '2015-12-07', 5520),
(22563, '2015-11-21', '2015-11-26', '2015-12-07', 5521),
(22564, '2015-11-21', '2015-11-26', '2015-12-07', 5522),
(22565, '2015-11-22', '2015-11-27', '2015-12-08', 5523),
(22566, '2015-11-22', '2015-11-27', '2015-12-08', 5524),
(22567, '2015-11-22', '2015-11-27', '2015-12-08', 5525),
(22568, '2015-11-23', '2015-11-28', '2015-12-09', 5526),
(22569, '2015-11-23', '2015-11-28', '2015-12-09', 5527),
(22570, '2015-11-23', '2015-11-28', '2015-12-09', 5528),
(22571, '2015-11-24', '2015-11-29', '2015-12-10', 5529),
(22572, '2015-11-24', '2015-11-29', '2015-12-10', 5530),
(22573, '2015-11-24', '2015-11-29', '2015-12-10', 5531),
(22574, '2015-11-25', '2015-12-01', '2015-12-12', 5532),
(22575, '2015-12-25', '2015-12-31', '2016-01-11', 5533),
(22576, '2015-12-25', '2015-12-31', '2016-01-11', 5534),
(22577, '2015-12-26', '2016-01-01', '2016-01-12', 5535),
(22578, '2015-12-26', '2016-01-01', '2016-01-12', 5536),
(22579, '2015-12-26', '2016-01-01', '2016-01-12', 5007),
(22580, '2015-12-27', '2016-01-02', '2016-01-13', 5002),
(22581, '2015-12-27', '2016-01-02', '2016-01-13', 5007),
(22582, '2015-12-27', '2016-01-02', '2016-01-13', 5009),
(22583, '2015-12-28', '2016-01-03', '2016-01-14', 5011),
(22584, '2015-12-28', '2016-01-03', '2016-01-14', 5022),
(22585, '2015-12-28', '2016-01-03', '2016-01-14', 5025),
(22586, '2015-12-29', '2016-01-04', '2016-01-15', 5028),
(22587, '2015-12-29', '2016-01-04', '2016-01-15', 5039),
(22588, '2015-12-29', '2016-01-04', '2016-01-15', 5042),
(22589, '2015-12-30', '2016-01-05', '2016-01-16', 5043),
(22590, '2015-12-30', '2016-01-05', '2016-01-16', 5049),
(22591, '2015-12-30', '2016-01-05', '2016-01-16', 5071),
(22592, '2015-12-31', '2016-01-06', '2016-01-17', 5079),
(22593, '2015-12-31', '2016-01-06', '2016-01-17', 5081),
(22594, '2015-12-31', '2016-01-06', '2016-01-17', 5082),
(22595, '2016-01-01', '2016-01-07', '2016-01-18', 5087),
(22596, '2016-01-01', '2016-01-07', '2016-01-18', 5091),
(22597, '2016-01-01', '2016-01-07', '2016-01-18', 5092),
(22598, '2016-01-02', '2016-01-08', '2016-01-19', 5093),
(22599, '2016-01-02', '2016-01-08', '2016-01-19', 5102),
(22600, '2015-11-30', '2015-12-03', '2015-12-14', 5119),
(22601, '2015-11-30', '2015-12-03', '2015-12-14', 5574),
(22602, '2015-12-01', '2015-12-04', '2015-12-15', 5575),
(22603, '2015-12-01', '2015-12-04', '2015-12-15', 5576),
(22604, '2015-12-01', '2015-12-04', '2015-12-15', 5577),
(22605, '2015-12-02', '2015-12-05', '2015-12-16', 5578),
(22606, '2015-12-02', '2015-12-05', '2015-12-16', 5579),
(22607, '2015-12-02', '2015-12-05', '2015-12-16', 5580),
(22608, '2015-12-03', '2015-12-06', '2015-12-17', 5581),
(22609, '2015-12-03', '2015-12-06', '2015-12-17', 5582),
(22610, '2015-12-03', '2015-12-06', '2015-12-17', 5583),
(22611, '2015-12-04', '2015-12-07', '2015-12-18', 5584),
(22612, '2015-12-04', '2015-12-07', '2015-12-18', 5585),
(22613, '2015-12-04', '2015-12-07', '2015-12-18', 5586),
(22614, '2015-12-05', '2015-12-09', '2015-12-20', 5587),
(22615, '2015-12-05', '2015-12-09', '2015-12-20', 5139),
(22616, '2015-12-05', '2015-12-09', '2015-12-20', 5144),
(22617, '2015-12-06', '2015-12-10', '2015-12-21', 5162),
(22618, '2015-12-06', '2015-12-10', '2015-12-21', 5172),
(22619, '2015-12-06', '2015-12-10', '2015-12-21', 5237),
(22620, '2015-12-07', '2015-12-11', '2015-12-22', 5238),
(22621, '2015-12-07', '2015-12-11', '2015-12-22', 5239),
(22622, '2015-12-07', '2015-12-11', '2015-12-22', 5250),
(22623, '2015-12-08', '2015-12-12', '2015-12-23', 5251),
(22624, '2015-12-08', '2015-12-12', '2015-12-23', 5256),
(22625, '2015-12-08', '2015-12-12', '2015-12-23', 5267),
(22626, '2015-12-09', '2015-12-13', '2015-12-24', 5310),
(22627, '2015-12-09', '2015-12-13', '2015-12-24', 5316),
(22628, '2015-12-09', '2015-12-13', '2015-12-24', 5321),
(22629, '2015-12-10', '2015-12-14', '2015-12-25', 5322),
(22630, '2015-12-10', '2015-12-14', '2015-12-25', 5328),
(22631, '2015-12-10', '2015-12-14', '2015-12-25', 5353),
(22632, '2015-12-11', '2015-12-15', '2015-12-26', 5354),
(22633, '2015-12-11', '2015-12-15', '2015-12-26', 5355),
(22634, '2015-12-11', '2015-12-15', '2015-12-26', 5356),
(22635, '2015-12-12', '2015-12-16', '2015-12-27', 5432),
(22636, '2015-12-12', '2015-12-16', '2015-12-27', 5433),
(22637, '2015-12-12', '2015-12-16', '2015-12-27', 5434),
(22638, '2015-12-13', '2015-12-17', '2015-12-28', 5435),
(22639, '2015-12-13', '2015-12-17', '2015-12-28', 5445),
(22640, '2015-12-13', '2015-12-17', '2015-12-28', 5477),
(22641, '2015-12-14', '2015-12-18', '2015-12-29', 5322),
(22642, '2015-12-14', '2015-12-18', '2015-12-29', 5328),
(22643, '2015-12-14', '2015-12-18', '2015-12-29', 5353),
(22644, '2015-12-15', '2015-12-20', '2015-12-31', 5354),
(22645, '2015-12-15', '2015-12-20', '2015-12-31', 5438),
(22646, '2015-12-15', '2015-12-20', '2015-12-31', 5439),
(22647, '2015-12-16', '2015-12-21', '2016-01-01', 5440),
(22648, '2015-12-16', '2015-12-21', '2016-01-01', 5441),
(22649, '2015-12-16', '2015-12-21', '2016-01-01', 5442),
(22650, '2015-12-17', '2015-12-22', '2016-01-02', 5443),
(22651, '2015-12-17', '2015-12-22', '2016-01-02', 5444),
(22652, '2015-12-17', '2015-12-22', '2016-01-02', 5445),
(22653, '2015-12-18', '2015-12-23', '2016-01-03', 5477),
(22654, '2015-12-18', '2015-12-23', '2016-01-03', 5478),
(22655, '2015-12-18', '2015-12-23', '2016-01-03', 5479),
(22656, '2015-12-19', '2015-12-24', '2016-01-04', 5480),
(22657, '2015-12-19', '2015-12-24', '2016-01-04', 5481),
(22658, '2015-12-19', '2015-12-24', '2016-01-04', 5482),
(22659, '2015-12-20', '2015-12-25', '2016-01-05', 5483),
(22660, '2015-12-20', '2015-12-25', '2016-01-05', 5484),
(22661, '2015-12-20', '2015-12-25', '2016-01-05', 5485),
(22662, '2015-12-21', '2015-12-26', '2016-01-06', 5486),
(22663, '2015-12-21', '2015-12-26', '2016-01-06', 5488),
(22664, '2015-12-21', '2015-12-26', '2016-01-06', 5489),
(22665, '2015-12-22', '2015-12-27', '2016-01-07', 5385),
(22666, '2015-12-22', '2015-12-27', '2016-01-07', 5386),
(22667, '2015-12-22', '2015-12-27', '2016-01-07', 5387),
(22668, '2015-12-23', '2015-12-28', '2016-01-08', 5388),
(22669, '2015-12-23', '2015-12-28', '2016-01-08', 5389),
(22670, '2015-12-23', '2015-12-28', '2016-01-08', 5390),
(22671, '2015-12-24', '2015-12-29', '2016-01-09', 5391),
(22672, '2015-12-24', '2015-12-29', '2016-01-09', 5392),
(22673, '2015-12-24', '2015-12-29', '2016-01-09', 5393),
(22674, '2015-12-25', '2015-12-31', '2016-01-11', 5394),
(22675, '2015-12-25', '2015-12-31', '2016-01-11', 5395),
(22676, '2015-12-25', '2015-12-31', '2016-01-11', 5353),
(22677, '2015-12-26', '2016-01-01', '2016-01-12', 5354),
(22678, '2015-12-26', '2016-01-01', '2016-01-12', 5355),
(22679, '2015-12-26', '2016-01-01', '2016-01-12', 5356),
(22680, '2015-12-27', '2016-01-02', '2016-01-13', 5357),
(22681, '2015-12-27', '2016-01-02', '2016-01-13', 5358),
(22682, '2015-12-27', '2016-01-02', '2016-01-13', 5359),
(22683, '2015-12-28', '2016-01-03', '2016-01-14', 5360),
(22684, '2015-12-28', '2016-01-03', '2016-01-14', 5361),
(22685, '2015-12-28', '2016-01-03', '2016-01-14', 5362),
(22686, '2015-12-29', '2016-01-04', '2016-01-15', 5363),
(22687, '2015-12-29', '2016-01-04', '2016-01-15', 5364),
(22688, '2015-12-29', '2016-01-04', '2016-01-15', 5365),
(22689, '2015-12-30', '2016-01-05', '2016-01-16', 5366),
(22690, '2015-12-30', '2016-01-05', '2016-01-16', 5367),
(22691, '2015-12-30', '2016-01-05', '2016-01-16', 5368),
(22692, '2015-12-31', '2016-01-06', '2016-01-17', 5369),
(22693, '2015-12-31', '2016-01-06', '2016-01-17', 5370),
(22694, '2015-12-31', '2016-01-06', '2016-01-17', 5371),
(22695, '2016-01-01', '2016-01-07', '2016-01-18', 5426),
(22696, '2016-01-01', '2016-01-07', '2016-01-18', 5427);



--
-- Dataark for tabell Ordrelinje
--

INSERT INTO Ordrelinje(OrdreNr, VNr, PrisPrEnhet, Antall) VALUES
(20505, '10830', '29.90', 1),
(20505, '22055', '214.50', 1),
(20505, '41020', '94.50', 5),
(20505, '65060', '46.50', 1),
(20505, '77033', '109.50', 5),
(20506, '10830', '29.90', 1),
(20506, '22056', '130.00', 2),
(20506, '41096', '115.00', 1),
(20506, '44939', '57.60', 3),
(20506, '65070', '118.50', 2),
(20506, '65081', '109.50', 5),
(20507, '12088', '109.50', 5),
(20507, '21032', '57.60', 3),
(20507, '22165', '5400.00', 2),
(20507, '37710', '35.40', 2),
(20507, '41097', '142.50', 1),
(20507, '65080', '478.00', 5),
(20508, '22179', '1440.00', 2),
(20508, '33044', '109.50', 5),
(20508, '33045', '35.40', 2),
(20508, '41098', '83.00', 5),
(20508, '64509', '142.00', 5),
(20509, '10830', '29.90', 1),
(20509, '22870', '21.00', 5),
(20509, '42613', '106.00', 1),
(20509, '44939', '57.60', 3),
(20509, '64510', '154.00', 2),
(20509, '65081', '109.50', 5),
(20509, '65247', '35.40', 2),
(20510, '15211', '109.50', 5),
(20510, '25079', '334.00', 1),
(20510, '64511', '227.50', 3),
(20510, '65060', '46.50', 3),
(20511, '25121', '418.50', 5),
(20511, '42939', '95.00', 1),
(20511, '64511', '227.50', 2),
(20511, '64550', '126.00', 1),
(20511, '65070', '118.50', 1),
(20511, '65081', '109.50', 5),
(20512, '10830', '29.90', 1),
(20512, '25131', '1078.00', 3),
(20512, '42941', '71.00', 5),
(20512, '64550', '126.00', 5),
(20512, '64551', '118.00', 1),
(20512, '65080', '478.00', 1),
(20512, '65081', '109.50', 5),
(20513, '10830', '29.90', 1),
(20513, '15207', '109.50', 5),
(20513, '25136', '180.00', 2),
(20513, '42945', '81.50', 3),
(20513, '64509', '142.00', 1),
(20513, '64551', '118.00', 3),
(20513, '64552', '276.00', 5),
(20514, '25137', '228.00', 2),
(20514, '37710', '35.40', 2),
(20514, '42615', '109.50', 5),
(20514, '43000', '540.00', 2),
(20514, '64510', '154.00', 5),
(20514, '64552', '276.00', 1),
(20514, '65032', '598.50', 5),
(20515, '10830', '29.90', 1),
(20515, '25138', '166.50', 5),
(20515, '37710', '35.40', 2),
(20515, '43014', '372.00', 1),
(20515, '64511', '227.50', 5),
(20515, '65032', '598.50', 2),
(20515, '65033', '1044.00', 5),
(20515, '65081', '109.50', 5),
(20516, '25154', '276.00', 1),
(20516, '37710', '35.40', 2),
(20516, '43015', '288.00', 3),
(20516, '64550', '126.00', 1),
(20516, '65033', '1044.00', 3),
(20516, '65034', '15000.00', 5),
(20516, '65081', '109.50', 5),
(20517, '10830', '29.90', 1),
(20517, '21032', '57.60', 3),
(20517, '32055', '130.50', 2),
(20517, '37710', '35.40', 2),
(20517, '44939', '115.00', 3),
(20517, '64551', '118.00', 2),
(20517, '65034', '15000.00', 1),
(20517, '65060', '46.50', 2),
(20517, '65081', '109.50', 5),
(20518, '10830', '29.90', 1),
(20518, '21032', '57.60', 3),
(20518, '32067', '94.50', 2),
(20518, '37710', '35.40', 2),
(20518, '45101', '57.00', 1),
(20518, '64552', '276.00', 5),
(20518, '65060', '46.50', 1),
(20518, '65070', '118.50', 3),
(20518, '65081', '109.50', 5),
(20519, '10830', '29.90', 1),
(20519, '21032', '57.60', 3),
(20519, '32069', '154.00', 1),
(20519, '37710', '35.40', 2),
(20519, '49919', '58.50', 2),
(20519, '65032', '598.50', 5),
(20519, '65070', '118.50', 5),
(20519, '65080', '478.00', 5),
(20520, '10830', '29.90', 1),
(20520, '21032', '57.60', 3),
(20520, '32191', '402.00', 5),
(20520, '37710', '35.40', 2),
(20520, '49921', '357.00', 5),
(20520, '65033', '1044.00', 2),
(20520, '65080', '478.00', 2),
(20520, '65081', '109.50', 5),
(20521, '10830', '29.90', 1),
(20521, '21032', '57.60', 3),
(20521, '32610', '106.50', 5),
(20521, '55112', '598.50', 5),
(20521, '65034', '15000.00', 5),
(20521, '65081', '112.00', 5),
(20521, '65082', '174.00', 1),
(20522, '33044', '14.50', 1),
(20522, '37710', '35.40', 2),
(20522, '55129', '154.00', 2),
(20522, '65060', '46.50', 3),
(20522, '65081', '109.50', 5),
(20522, '65082', '174.00', 5),
(20522, '65122', '1558.00', 5),
(20523, '33045', '17.50', 2),
(20523, '65070', '118.50', 2),
(20523, '65142', '93.00', 5),
(20524, '33046', '15.00', 2),
(20524, '65080', '478.00', 5),
(20524, '65143', '83.50', 2),
(20525, '33047', '16.00', 1),
(20525, '65081', '112.00', 1),
(20525, '65147', '238.50', 2),
(20526, '35911', '11.50', 5),
(20526, '65082', '174.00', 2),
(20526, '65190', '190.50', 1),
(20527, '35912', '11.50', 1),
(20527, '65122', '1558.00', 1),
(20527, '65191', '23.00', 5),
(20528, '37710', '35.00', 5),
(20528, '65142', '93.00', 1),
(20528, '65247', '75.00', 3),
(20529, '25136', '180.00', 5),
(20529, '37720', '42.00', 2),
(20529, '71912', '35.00', 1),
(20530, '25137', '228.00', 1),
(20530, '37725', '36.00', 2),
(20530, '72777', '154.00', 5),
(20531, '25138', '166.50', 5),
(20531, '37730', '23.50', 1),
(20531, '72942', '35.50', 2),
(20532, '25154', '276.00', 1),
(20532, '37731', '30.00', 3),
(20532, '72943', '35.50', 9),
(20533, '32055', '130.50', 5),
(20533, '37732', '27.00', 1),
(20533, '72944', '42.00', 5),
(20534, '32067', '94.50', 1),
(20534, '41020', '94.50', 5),
(20534, '76032', '334.50', 2),
(20535, '32069', '154.00', 2),
(20535, '41096', '115.00', 2),
(20535, '77033', '358.00', 1),
(20536, '32191', '402.00', 1),
(20536, '41097', '142.50', 5),
(20536, '77036', '358.00', 5),
(20537, '25079', '334.00', 2),
(20537, '41098', '83.00', 1),
(20537, '77038', '478.00', 1),
(20538, '25121', '418.50', 2),
(20538, '42613', '106.00', 5),
(20538, '77249', '1558.00', 3),
(20539, '25131', '1078.00', 2),
(20539, '42615', '106.00', 2),
(20539, '77251', '658.00', 5),
(20540, '25136', '180.00', 2),
(20540, '42626', '141.50', 5),
(20540, '77252', '34.50', 2),
(20541, '25137', '228.00', 3),
(20541, '42929', '83.00', 5),
(20541, '77276', '4558.00', 1),
(20542, '25138', '166.50', 1),
(20542, '42933', '69.50', 10),
(20542, '77277', '358.00', 1),
(20543, '25154', '276.00', 5),
(20543, '42934', '69.50', 13),
(20543, '78029', '142.50', 2),
(20544, '32055', '130.50', 2),
(20544, '42939', '95.00', 5),
(20544, '80032', '154.50', 5),
(20545, '32067', '94.50', 2),
(20545, '42941', '71.00', 1),
(20545, '80082', '118.50', 5),
(20546, '32069', '154.00', 5),
(20546, '42945', '81.50', 5),
(20546, '77251', '658.00', 5),
(20547, '32191', '402.00', 3),
(20547, '43000', '540.00', 5),
(20547, '77252', '34.50', 5),
(20548, '32610', '106.50', 1),
(20548, '43014', '372.00', 3),
(20548, '77276', '4558.00', 5),
(20549, '43015', '288.00', 5),
(20549, '65060', '46.50', 2),
(20549, '77277', '358.00', 3),
(20550, '44939', '115.00', 5),
(20550, '65070', '118.50', 5),
(20550, '78029', '142.50', 5),
(20551, '45101', '57.00', 2),
(20551, '49919', '58.50', 2),
(20551, '65080', '478.00', 2),
(20552, '45105', '45.00', 5),
(20552, '49921', '357.00', 1),
(20552, '64509', '142.00', 3),
(20553, '45923', '42.00', 5),
(20553, '55112', '598.50', 1),
(20553, '64510', '154.00', 1),
(20554, '45935', '19.50', 4),
(20554, '55129', '154.00', 3),
(20554, '64511', '227.50', 1),
(20555, '46702', '71.50', 1),
(20555, '55130', '298.50', 5),
(20555, '64550', '126.00', 5),
(20556, '46706', '27.50', 5),
(20556, '55550', '1558.50', 2),
(20556, '64551', '118.00', 1),
(20557, '46738', '40.00', 3),
(20557, '58028', '142.50', 1),
(20557, '64552', '276.00', 2),
(20558, '46741', '10.00', 1),
(20558, '59915', '25.00', 7),
(20558, '65032', '598.50', 5),
(20559, '46745', '43.50', 5),
(20559, '64509', '142.00', 5),
(20559, '65033', '1044.00', 5),
(20560, '47903', '11214.00', 3),
(20560, '64510', '154.00', 2),
(20560, '65034', '15000.00', 2),
(20561, '49916', '25.00', 15),
(20561, '64511', '227.50', 3),
(20561, '65060', '46.50', 5),
(20562, '49917', '25.50', 2),
(20562, '64550', '126.00', 2),
(20562, '65070', '118.50', 1),
(20563, '49919', '58.50', 5),
(20563, '64551', '118.00', 3),
(20563, '65080', '478.00', 5),
(20564, '42615', '106.00', 5),
(20564, '49921', '357.00', 5),
(20564, '65081', '112.00', 3),
(20565, '42626', '141.50', 1),
(20565, '55112', '598.50', 1),
(20565, '65082', '174.00', 5),
(20566, '42929', '83.00', 1),
(20566, '55129', '154.00', 2),
(20566, '65122', '1558.00', 2),
(20567, '42933', '69.50', 3),
(20567, '55130', '298.50', 2),
(20567, '65142', '93.00', 3),
(20568, '42934', '69.50', 4),
(20568, '49916', '25.00', 5),
(20568, '55550', '1558.50', 5),
(20569, '49917', '25.50', 9),
(20569, '58028', '142.50', 2),
(20570, '49919', '58.50', 1),
(20570, '59915', '25.00', 2),
(20571, '49921', '357.00', 1),
(20571, '64509', '142.00', 5),
(20572, '55112', '598.50', 5),
(20572, '64510', '154.00', 5),
(20573, '55129', '154.00', 1),
(20573, '64511', '227.50', 2),
(20574, '55130', '298.50', 5),
(20574, '64550', '126.00', 5),
(20575, '55550', '1558.50', 1),
(20575, '64551', '118.00', 2),
(20576, '58028', '142.50', 5),
(20576, '64552', '276.00', 5),
(20577, '59915', '25.00', 9),
(20577, '65032', '598.50', 2),
(20578, '64509', '142.00', 3),
(20578, '65033', '1044.00', 2),
(20579, '64510', '154.00', 3),
(20579, '65034', '15000.00', 5),
(20580, '64511', '227.50', 5),
(20580, '65060', '46.50', 1),
(20581, '55130', '298.50', 1),
(20581, '64550', '126.00', 1),
(20581, '65070', '118.50', 5),
(20582, '55550', '1558.50', 5),
(20582, '64551', '118.00', 5),
(20582, '65080', '478.00', 2),
(20583, '42615', '106.00', 1),
(20583, '58028', '142.50', 2),
(20583, '65081', '112.00', 2),
(20584, '42626', '141.50', 5),
(20584, '59915', '25.00', 10),
(20584, '65082', '174.00', 1),
(20585, '42929', '83.00', 5),
(20585, '64509', '142.00', 2),
(20585, '65122', '1558.00', 5),
(20586, '42933', '69.50', 6),
(20586, '64510', '154.00', 2),
(20586, '65142', '93.00', 2),
(20587, '42934', '69.50', 8),
(20587, '64511', '227.50', 1),
(20587, '65143', '83.50', 5),
(20588, '42939', '95.00', 1),
(20588, '64550', '126.00', 2),
(20588, '65147', '238.50', 5),
(20589, '42941', '71.00', 3),
(20589, '64551', '118.00', 1),
(20589, '65190', '190.50', 3),
(20590, '42615', '106.00', 2),
(20590, '42945', '81.50', 2),
(20590, '65191', '23.00', 2),
(20591, '42626', '141.50', 1),
(20591, '43000', '540.00', 2),
(20591, '65247', '75.00', 2),
(20592, '42929', '83.00', 2),
(20592, '43014', '372.00', 2),
(20592, '71912', '35.00', 2),
(20593, '42933', '69.50', 2),
(20593, '43015', '288.00', 5),
(20593, '72777', '154.00', 5),
(20594, '42934', '69.50', 3),
(20594, '44939', '115.00', 1),
(20594, '72942', '35.50', 10),
(20595, '42939', '95.00', 5),
(20595, '45101', '57.00', 5),
(20595, '72943', '35.50', 13),
(20596, '42941', '71.00', 2),
(20596, '45105', '45.00', 5),
(20596, '72944', '42.00', 1),
(20597, '42945', '81.50', 5),
(20597, '45923', '42.00', 5),
(20597, '76032', '334.50', 2),
(20598, '43000', '540.00', 1),
(20598, '45935', '19.50', 6),
(20598, '77033', '358.00', 5),
(20599, '43014', '372.00', 5),
(20599, '46702', '71.50', 3),
(20599, '77036', '358.00', 5),
(20600, '43015', '288.00', 3),
(20600, '46706', '27.50', 3),
(20600, '77038', '478.00', 5),
(20601, '33047', '16.00', 3),
(20601, '44939', '115.00', 3),
(20601, '77249', '1558.00', 2),
(20602, '35911', '11.50', 3),
(20602, '45101', '57.00', 2),
(20602, '77251', '658.00', 1),
(20603, '35912', '11.50', 2),
(20603, '55550', '1558.50', 1),
(20603, '77252', '34.50', 1),
(20604, '37710', '35.00', 5),
(20604, '58028', '142.50', 5),
(20604, '77276', '4558.00', 1),
(20605, '37720', '42.00', 1),
(20605, '59915', '25.00', 13),
(20605, '77277', '358.00', 3),
(20606, '37725', '36.00', 5),
(20606, '64509', '142.00', 5),
(20606, '78029', '142.50', 1),
(20607, '37730', '23.50', 3),
(20607, '64510', '154.00', 1),
(20607, '80032', '154.50', 1),
(20608, '37731', '30.00', 2),
(20608, '64511', '227.50', 5),
(20608, '80082', '118.50', 1),
(20609, '10820', '46.50', 3),
(20609, '64550', '126.00', 5),
(20609, '80088', '213.00', 5),
(20610, '10822', '46.50', 2),
(20610, '64551', '118.00', 3),
(20610, '80692', '39.50', 1),
(20611, '10830', '57.50', 5),
(20611, '42615', '106.00', 5),
(20611, '81007', '62.50', 2),
(20612, '10835', '83.00', 5),
(20612, '42626', '141.50', 3),
(20612, '82090', '30.00', 5),
(20613, '10854', '39.50', 5),
(20613, '42929', '83.00', 1),
(20613, '82092', '18.00', 2),
(20614, '11630', '46.50', 5),
(20614, '42933', '69.50', 5),
(20614, '82093', '24.00', 2),
(20615, '12054', '358.50', 5),
(20615, '42934', '69.50', 2),
(20615, '82095', '23.50', 5),
(20616, '12055', '238.50', 5),
(20616, '42939', '95.00', 2),
(20616, '82096', '27.50', 2),
(20617, '12056', '191.50', 1),
(20617, '42941', '71.00', 1),
(20617, '83013', '46.00', 5),
(20618, '12088', '215.00', 2),
(20618, '42945', '81.50', 5),
(20618, '90106', '38.00', 3),
(20619, '12089', '144.00', 1),
(20619, '43000', '540.00', 3),
(20619, '90109', '40.50', 3),
(20620, '12090', '192.00', 1),
(20620, '43014', '372.00', 1),
(20620, '90116', '50.00', 3),
(20621, '12091', '286.50', 5),
(20621, '43015', '288.00', 2),
(20621, '90164', '75.50', 5),
(20622, '12092', '238.50', 1),
(20622, '44939', '115.00', 2),
(20622, '90192', '70.50', 5),
(20623, '13001', '38.00', 2),
(20623, '45101', '57.00', 5),
(20623, '90208', '71.00', 3),
(20624, '15207', '24.50', 2),
(20624, '45105', '45.00', 3),
(20624, '90209', '71.00', 2),
(20625, '15208', '24.50', 5),
(20625, '45923', '42.00', 5),
(20625, '90212', '71.00', 5),
(20626, '15211', '209.00', 3),
(20626, '45935', '19.50', 8),
(20626, '90510', '430.50', 1),
(20627, '15217', '32.00', 5),
(20627, '46702', '71.50', 2),
(20627, '90521', '142.50', 3),
(20628, '15559', '38.00', 2),
(20628, '46706', '27.50', 5),
(20628, '90531', '83.00', 2),
(20629, '20936', '25.00', 3),
(20629, '33047', '16.00', 2),
(20629, '90545', '288.00', 5),
(20630, '20980', '27.50', 2),
(20630, '35911', '11.50', 5),
(20630, '90693', '57.00', 1),
(20631, '10820', '46.50', 1),
(20631, '21032', '57.50', 5),
(20631, '35912', '11.50', 1),
(20632, '10822', '46.50', 5),
(20632, '21034', '504.00', 2),
(20632, '37710', '35.00', 2),
(20633, '10830', '57.50', 1),
(20633, '21037', '294.00', 3),
(20633, '37720', '42.00', 2),
(20634, '10835', '83.00', 5),
(20634, '21510', '35.50', 3),
(20634, '37725', '36.00', 1),
(20635, '10854', '39.50', 1),
(20635, '21514', '28.00', 1),
(20635, '37730', '23.50', 2),
(20636, '11630', '46.50', 1),
(20636, '21515', '27.00', 3),
(20636, '37731', '30.00', 2),
(20637, '12054', '358.50', 2),
(20637, '21517', '16.00', 5),
(20637, '37720', '42.00', 5),
(20638, '12055', '238.50', 5),
(20638, '21580', '13.50', 2),
(20638, '37725', '36.00', 1),
(20639, '12056', '191.50', 5),
(20639, '22002', '55.50', 5),
(20639, '33044', '14.50', 3),
(20640, '12088', '215.00', 1),
(20640, '22054', '70.50', 2),
(20640, '33045', '17.50', 5),
(20641, '12089', '144.00', 3),
(20641, '22055', '214.50', 3),
(20641, '33046', '15.00', 5),
(20642, '12090', '192.00', 3),
(20642, '22056', '130.00', 5),
(20642, '33047', '16.00', 1),
(20643, '12091', '286.50', 2),
(20643, '22165', '5400.00', 1),
(20643, '35911', '11.50', 3),
(20644, '12092', '238.50', 1),
(20644, '22179', '1440.00', 5),
(20644, '35912', '11.50', 2),
(20645, '13001', '38.00', 5),
(20645, '22870', '21.00', 1),
(20645, '37710', '35.00', 5),
(20646, '15207', '24.50', 2),
(20646, '25079', '334.00', 5),
(20646, '37720', '42.00', 1),
(20647, '15208', '24.50', 5),
(20647, '25121', '418.50', 5),
(20647, '37725', '36.00', 2),
(20648, '15211', '209.00', 2),
(20648, '25131', '1078.00', 5),
(20648, '37730', '23.50', 5),
(20649, '15217', '32.00', 1),
(20649, '25136', '180.00', 5),
(20649, '37731', '30.00', 1),
(20650, '15559', '38.00', 1),
(20650, '25137', '228.00', 5),
(20650, '37732', '27.00', 5),
(20651, '20936', '25.00', 4),
(20651, '25138', '166.50', 5),
(20651, '41020', '94.50', 5),
(20652, '20980', '27.50', 1),
(20652, '25154', '276.00', 1),
(20652, '41096', '115.00', 5),
(20653, '21032', '57.50', 5),
(20653, '32055', '130.50', 5),
(20653, '41097', '142.50', 2),
(20654, '21034', '504.00', 5),
(20654, '32067', '94.50', 2),
(20654, '41098', '83.00', 2),
(20655, '21037', '294.00', 2),
(20655, '32069', '154.00', 3),
(20655, '42613', '106.00', 2),
(20656, '21510', '35.50', 4),
(20656, '32191', '402.00', 5),
(20656, '65060', '46.50', 3),
(20657, '21514', '28.00', 2),
(20657, '32610', '106.50', 3),
(20657, '65070', '118.50', 5),
(20658, '21515', '27.00', 2),
(20658, '33044', '14.50', 2),
(20658, '65080', '478.00', 1),
(20659, '21517', '16.00', 5),
(20659, '33045', '17.50', 2),
(20659, '64509', '142.00', 2),
(20660, '21580', '13.50', 5),
(20660, '33046', '15.00', 2),
(20660, '64510', '154.00', 2),
(20661, '22002', '55.50', 1),
(20661, '33047', '16.00', 1),
(20662, '22054', '70.50', 5),
(20662, '35911', '11.50', 1),
(20663, '22055', '214.50', 5),
(20663, '35912', '11.50', 3),
(20664, '22056', '130.00', 1),
(20664, '37710', '35.00', 1),
(20665, '22165', '5400.00', 3),
(20665, '37720', '42.00', 2),
(20666, '22179', '1440.00', 1),
(20666, '37725', '36.00', 5),
(20667, '22870', '21.00', 2),
(20667, '37730', '23.50', 5),
(20668, '25079', '334.00', 2),
(20668, '37731', '30.00', 3),
(20669, '25121', '418.50', 1),
(20669, '37732', '27.00', 5),
(20670, '25131', '1078.00', 2),
(20670, '41020', '94.50', 5),
(20671, '25136', '180.00', 1),
(20671, '41096', '115.00', 1),
(20672, '25137', '228.00', 2),
(20672, '41097', '142.50', 2),
(20673, '25138', '166.50', 1),
(20673, '41098', '83.00', 5),
(20673, '65122', '1558.00', 1),
(20674, '25154', '276.00', 2),
(20674, '42613', '106.00', 5),
(20674, '65142', '93.00', 5),
(20675, '25136', '180.00', 3),
(20675, '32055', '130.50', 1),
(20675, '42615', '106.00', 1),
(20676, '25137', '228.00', 5),
(20676, '32067', '94.50', 1),
(20676, '42626', '141.50', 5),
(20677, '25138', '166.50', 5),
(20677, '32069', '154.00', 1),
(20677, '42929', '83.00', 1),
(20678, '25154', '276.00', 5),
(20678, '32191', '402.00', 5),
(20678, '42933', '69.50', 1),
(20679, '32055', '130.50', 1),
(20679, '32610', '106.50', 2),
(20679, '42934', '69.50', 3),
(20680, '32067', '94.50', 3),
(20680, '33044', '14.50', 5),
(20680, '42939', '95.00', 5),
(20681, '32069', '154.00', 3),
(20681, '33045', '17.50', 1),
(20681, '42941', '71.00', 1),
(20682, '32191', '402.00', 3),
(20682, '33046', '15.00', 5),
(20682, '42945', '81.50', 1),
(20683, '25079', '334.00', 5),
(20683, '33047', '16.00', 3),
(20683, '43000', '540.00', 5),
(20684, '25121', '418.50', 3),
(20684, '35911', '11.50', 2),
(20684, '43014', '372.00', 5),
(20685, '25131', '1078.00', 1),
(20685, '35912', '11.50', 5),
(20685, '43015', '288.00', 2),
(20686, '25136', '180.00', 2),
(20686, '37710', '35.00', 3),
(20686, '44939', '115.00', 5),
(20687, '25137', '228.00', 5),
(20687, '37720', '42.00', 5),
(20687, '45101', '57.00', 3),
(20688, '25138', '166.50', 2),
(20688, '37725', '36.00', 2),
(20688, '45105', '45.00', 2),
(20689, '25154', '276.00', 2),
(20689, '37730', '23.50', 1),
(20689, '45923', '42.00', 2),
(20690, '32055', '130.50', 5),
(20690, '37731', '30.00', 5),
(20690, '45935', '19.50', 2),
(20691, '32067', '94.50', 2),
(20691, '37732', '27.00', 5),
(20691, '46702', '71.50', 5),
(20692, '32069', '154.00', 2),
(20692, '41020', '94.50', 2),
(20692, '46706', '27.50', 3),
(20693, '32191', '402.00', 2),
(20693, '41096', '115.00', 1),
(20693, '46738', '40.00', 2),
(20694, '32610', '106.50', 5),
(20694, '41097', '142.50', 5),
(20694, '46741', '10.00', 5),
(20695, '41098', '83.00', 3),
(20695, '46745', '43.50', 1),
(20695, '65060', '46.50', 5),
(20696, '42613', '106.00', 3),
(20696, '47903', '11214.00', 2),
(20696, '65070', '118.50', 2),
(20697, '42615', '106.00', 2),
(20697, '49916', '25.00', 6),
(20697, '65080', '478.00', 3),
(20698, '42626', '141.50', 5),
(20698, '49917', '25.50', 10),
(20698, '64509', '142.00', 1),
(20699, '42929', '83.00', 2),
(20699, '49919', '58.50', 3),
(20699, '64510', '154.00', 5),
(20700, '42933', '69.50', 2),
(20700, '49921', '357.00', 3),
(20700, '64511', '227.50', 1),
(20701, '42934', '69.50', 2),
(20701, '55112', '598.50', 5),
(20701, '64550', '126.00', 2),
(20702, '42939', '95.00', 1),
(20702, '55129', '154.00', 1),
(20702, '64551', '118.00', 2),
(20703, '42941', '71.00', 3),
(20703, '55130', '298.50', 3),
(20703, '64552', '276.00', 5),
(20704, '42945', '81.50', 5),
(20704, '55550', '1558.50', 3),
(20704, '65032', '598.50', 1),
(20705, '43000', '540.00', 2),
(20705, '58028', '142.50', 1),
(20705, '65033', '1044.00', 1),
(20706, '43014', '372.00', 1),
(20706, '59915', '25.00', 8),
(20706, '65034', '15000.00', 1),
(20707, '43015', '288.00', 1),
(20707, '64509', '142.00', 3),
(20707, '65060', '46.50', 5),
(20708, '44939', '115.00', 3),
(20708, '64510', '154.00', 3),
(20708, '65070', '118.50', 5),
(20709, '45101', '57.00', 2),
(20709, '64511', '227.50', 3),
(20709, '65080', '478.00', 2),
(20710, '45105', '45.00', 5),
(20710, '64550', '126.00', 5),
(20710, '65081', '112.00', 1),
(20711, '45923', '42.00', 5),
(20711, '64551', '118.00', 5),
(20711, '65082', '174.00', 2),
(20712, '45935', '19.50', 3),
(20712, '64552', '276.00', 1),
(20712, '65122', '1558.00', 3),
(20713, '46702', '71.50', 1),
(20713, '65032', '598.50', 2),
(20713, '65142', '93.00', 1),
(20714, '46706', '27.50', 5),
(20714, '49916', '25.00', 2),
(20714, '65033', '1044.00', 3),
(20715, '46738', '40.00', 5),
(20715, '49917', '25.50', 13),
(20715, '65034', '15000.00', 2),
(20716, '46741', '10.00', 1),
(20716, '49919', '58.50', 2),
(20716, '65060', '46.50', 3),
(20717, '46745', '43.50', 5),
(20717, '49921', '357.00', 5),
(20717, '65070', '118.50', 1),
(20718, '47903', '11214.00', 2),
(20718, '55112', '598.50', 5),
(20718, '65080', '478.00', 2),
(20719, '49916', '25.00', 3),
(20719, '55129', '154.00', 2),
(20719, '65081', '112.00', 3),
(20720, '49917', '25.50', 3),
(20720, '55130', '298.50', 2),
(20720, '65082', '174.00', 5),
(20721, '49919', '58.50', 5),
(20721, '55550', '1558.50', 5),
(20721, '65122', '1558.00', 5),
(20722, '21514', '28.00', 5),
(20722, '32069', '154.00', 5),
(20722, '43000', '540.00', 5),
(20722, '49921', '357.00', 5),
(20722, '58028', '142.50', 3),
(20722, '65142', '93.00', 3),
(20723, '21515', '27.00', 1),
(20723, '32191', '402.00', 5),
(20723, '43014', '372.00', 3),
(20723, '55112', '598.50', 2),
(20723, '59915', '25.00', 5),
(20723, '65143', '83.50', 1),
(20724, '21517', '16.00', 5),
(20724, '25079', '334.00', 1),
(20724, '43015', '288.00', 3),
(20724, '55129', '154.00', 1),
(20724, '64509', '142.00', 5),
(20724, '65147', '238.50', 5),
(20725, '21580', '13.50', 1),
(20725, '25121', '418.50', 2),
(20725, '33044', '14.50', 1),
(20725, '44939', '115.00', 5),
(20725, '55130', '298.50', 2),
(20725, '64510', '154.00', 5),
(20725, '65190', '190.50', 2),
(20726, '22002', '55.50', 3),
(20726, '25131', '1078.00', 3),
(20726, '33045', '17.50', 3),
(20726, '45101', '57.00', 2),
(20726, '55550', '1558.50', 5),
(20726, '64511', '227.50', 5),
(20726, '65191', '23.00', 5),
(20727, '22054', '70.50', 1),
(20727, '25136', '180.00', 2),
(20727, '33046', '15.00', 2),
(20727, '45105', '45.00', 2),
(20727, '58028', '142.50', 2),
(20727, '64550', '126.00', 1),
(20727, '65247', '75.00', 5),
(20728, '22055', '214.50', 5),
(20728, '33047', '16.00', 5),
(20728, '45923', '42.00', 1),
(20728, '46745', '43.50', 1),
(20728, '59915', '25.00', 2),
(20728, '64551', '118.00', 1),
(20728, '71912', '35.00', 2),
(20729, '22056', '130.00', 3),
(20729, '35911', '11.50', 1),
(20729, '42615', '106.00', 2),
(20729, '45935', '19.50', 5),
(20729, '47903', '11214.00', 5),
(20729, '64509', '142.00', 2),
(20729, '72777', '154.00', 1),
(20730, '21580', '13.50', 5),
(20730, '22165', '5400.00', 2),
(20730, '35912', '11.50', 3),
(20730, '42626', '141.50', 3),
(20730, '46702', '71.50', 3),
(20730, '64510', '154.00', 3),
(20730, '72942', '35.50', 6),
(20731, '22002', '55.50', 2),
(20731, '22179', '1440.00', 3),
(20731, '37710', '35.00', 2),
(20731, '42929', '83.00', 2),
(20731, '46706', '27.50', 2),
(20731, '64511', '227.50', 5),
(20731, '72943', '35.50', 8),
(20732, '10820', '46.50', 2),
(20732, '22870', '21.00', 5),
(20732, '37720', '42.00', 3),
(20732, '42933', '69.50', 5),
(20732, '46738', '40.00', 1),
(20732, '64550', '126.00', 3),
(20732, '72944', '42.00', 2),
(20733, '10822', '46.50', 5),
(20733, '25079', '334.00', 3),
(20733, '37725', '36.00', 5),
(20733, '42934', '69.50', 1),
(20733, '46741', '10.00', 3),
(20733, '64551', '118.00', 5),
(20733, '76032', '334.50', 5),
(20734, '10830', '57.50', 1),
(20734, '25121', '418.50', 2),
(20734, '37730', '23.50', 5),
(20734, '42939', '95.00', 2),
(20734, '46745', '43.50', 5),
(20734, '64552', '276.00', 3),
(20734, '77033', '358.00', 2),
(20735, '10835', '83.00', 5),
(20735, '25131', '1078.00', 5),
(20735, '37731', '30.00', 2),
(20735, '42941', '71.00', 2),
(20735, '47903', '11214.00', 1),
(20735, '65032', '598.50', 5),
(20735, '77036', '358.00', 5),
(20736, '10854', '39.50', 5),
(20736, '25136', '180.00', 5),
(20736, '37732', '27.00', 5),
(20736, '42945', '81.50', 1),
(20736, '49916', '25.00', 1),
(20736, '65033', '1044.00', 5),
(20736, '77038', '478.00', 5),
(20737, '11630', '46.50', 2),
(20737, '25137', '228.00', 1),
(20737, '41020', '94.50', 5),
(20737, '43000', '540.00', 5),
(20737, '49917', '25.50', 4),
(20737, '65034', '15000.00', 5),
(20737, '77249', '1558.00', 2),
(20738, '12054', '358.50', 5),
(20738, '25138', '166.50', 5),
(20738, '41096', '115.00', 5),
(20738, '43014', '372.00', 5),
(20738, '49919', '58.50', 1),
(20738, '65060', '46.50', 1),
(20738, '77251', '658.00', 5),
(20739, '12055', '238.50', 2),
(20739, '25154', '276.00', 2),
(20739, '41097', '142.50', 5),
(20739, '43015', '288.00', 5),
(20739, '49921', '357.00', 3),
(20739, '65070', '118.50', 2),
(20739, '77252', '34.50', 3),
(20740, '41098', '83.00', 1),
(20740, '44939', '115.00', 3),
(20740, '65080', '478.00', 1),
(20740, '77276', '4558.00', 3),
(20741, '42613', '106.00', 5),
(20741, '45101', '57.00', 5),
(20741, '65081', '112.00', 2),
(20741, '77277', '358.00', 2),
(20742, '42615', '106.00', 1),
(20742, '45105', '45.00', 1),
(20742, '65082', '174.00', 2),
(20742, '78029', '142.50', 1),
(20743, '42626', '141.50', 2),
(20743, '45923', '42.00', 2),
(20743, '65122', '1558.00', 5),
(20743, '80032', '154.50', 3),
(20744, '45935', '19.50', 2),
(20744, '65142', '93.00', 2),
(20744, '80082', '118.50', 5),
(20745, '46702', '71.50', 2),
(20745, '65143', '83.50', 5),
(20745, '80088', '213.00', 1),
(20746, '46706', '27.50', 5),
(20746, '65147', '238.50', 5),
(20746, '80692', '39.50', 2),
(20747, '33047', '16.00', 3),
(20747, '65190', '190.50', 5),
(20747, '81007', '62.50', 5),
(20748, '35911', '11.50', 2),
(20748, '65191', '23.00', 1),
(20748, '82090', '30.00', 5),
(20749, '35912', '11.50', 5),
(20749, '65247', '75.00', 1),
(20749, '82092', '18.00', 5),
(20750, '37710', '35.00', 5),
(20750, '71912', '35.00', 1),
(20750, '82093', '24.00', 1),
(20751, '37720', '42.00', 5),
(20751, '72777', '154.00', 5),
(20751, '82095', '23.50', 1),
(20752, '37725', '36.00', 1),
(20752, '72942', '35.50', 2),
(20752, '82096', '27.50', 5),
(20753, '37730', '23.50', 5),
(20753, '72943', '35.50', 3),
(20753, '83013', '46.00', 5),
(20754, '37731', '30.00', 5),
(20754, '72944', '42.00', 1),
(20754, '90106', '38.00', 3),
(20755, '10820', '46.50', 3),
(20755, '76032', '334.50', 1),
(20755, '90109', '40.50', 2),
(20756, '10822', '46.50', 5),
(20756, '77033', '358.00', 1),
(20756, '90116', '50.00', 5),
(20757, '10830', '57.50', 5),
(20757, '77036', '358.00', 3),
(20757, '90164', '75.50', 1),
(20758, '10835', '83.00', 3),
(20758, '77038', '478.00', 3),
(20758, '90192', '70.50', 2),
(20759, '10854', '39.50', 5),
(20759, '77249', '1558.00', 5),
(20759, '90208', '71.00', 5),
(20760, '11630', '46.50', 2),
(20760, '77251', '658.00', 1),
(20760, '90209', '71.00', 1),
(20761, '12054', '358.50', 5),
(20761, '77252', '34.50', 2),
(20761, '90212', '71.00', 5),
(20762, '12055', '238.50', 1),
(20762, '77276', '4558.00', 5),
(20762, '90510', '430.50', 3),
(20763, '12056', '191.50', 2),
(20763, '77277', '358.00', 5),
(20763, '90521', '142.50', 3),
(20764, '12088', '215.00', 3),
(20764, '78029', '142.50', 2),
(20764, '90531', '83.00', 2),
(20765, '12089', '144.00', 2),
(20765, '80032', '154.50', 2),
(20765, '90545', '288.00', 2),
(20766, '12090', '192.00', 5),
(20766, '80082', '118.50', 2),
(20766, '90693', '57.00', 1),
(20767, '12091', '286.50', 5),
(20767, '80088', '213.00', 5),
(20767, '90737', '354.00', 1),
(20768, '12092', '238.50', 2),
(20768, '80692', '39.50', 1),
(20768, '91008', '94.00', 3),
(20769, '13001', '38.00', 2),
(20769, '81007', '62.50', 1),
(20769, '92606', '106.00', 3),
(20770, '15207', '24.50', 1),
(20770, '45101', '57.00', 3),
(20770, '82090', '30.00', 1),
(20771, '15208', '24.50', 3),
(20771, '55550', '1558.50', 3),
(20771, '82092', '18.00', 1),
(20772, '15211', '209.00', 5),
(20772, '58028', '142.50', 1),
(20772, '82093', '24.00', 3),
(20773, '15217', '32.00', 5),
(20773, '59915', '25.00', 3),
(20773, '82095', '23.50', 2),
(20774, '15559', '38.00', 5),
(20774, '64509', '142.00', 5),
(20774, '82096', '27.50', 1),
(20775, '20936', '25.00', 2),
(20775, '64510', '154.00', 5),
(20775, '83013', '46.00', 3),
(20776, '20980', '27.50', 5),
(20776, '64511', '227.50', 3),
(20776, '90106', '38.00', 1),
(20777, '21032', '57.50', 2),
(20777, '64550', '126.00', 2),
(20777, '90109', '40.50', 2),
(20778, '21034', '504.00', 2),
(20778, '64551', '118.00', 1),
(20778, '90116', '50.00', 5),
(20779, '21037', '294.00', 5),
(20779, '42615', '106.00', 2),
(20779, '90164', '75.50', 3),
(20780, '21510', '35.50', 5),
(20780, '42626', '141.50', 5),
(20780, '90192', '70.50', 5),
(20781, '42929', '83.00', 5),
(20781, '90208', '71.00', 1),
(20782, '12092', '238.50', 5),
(20782, '42933', '69.50', 3),
(20782, '90209', '71.00', 3),
(20783, '13001', '38.00', 3),
(20783, '42934', '69.50', 2),
(20783, '90212', '71.00', 5),
(20784, '15207', '24.50', 2),
(20784, '42939', '95.00', 5),
(20784, '90510', '430.50', 2),
(20785, '15208', '24.50', 2),
(20785, '42941', '71.00', 5),
(20785, '90521', '142.50', 3),
(20786, '15211', '209.00', 1),
(20786, '42945', '81.50', 5),
(20786, '90531', '83.00', 1),
(20787, '15217', '32.00', 1),
(20787, '43000', '540.00', 1),
(20787, '90545', '288.00', 5),
(20788, '15559', '38.00', 2),
(20788, '43014', '372.00', 5),
(20788, '90693', '57.00', 2),
(20789, '20936', '25.00', 2),
(20789, '43015', '288.00', 5),
(20789, '90737', '354.00', 5),
(20790, '20980', '27.50', 1),
(20790, '44939', '115.00', 2),
(20790, '91008', '94.00', 2),
(20791, '21032', '57.50', 5),
(20791, '45101', '57.00', 5),
(20791, '92606', '106.00', 5),
(20792, '10820', '46.50', 5),
(20792, '21034', '504.00', 5),
(20792, '45105', '45.00', 3),
(20793, '10822', '46.50', 5),
(20793, '45923', '42.00', 3),
(20794, '10830', '57.50', 1),
(20794, '45935', '19.50', 1),
(20795, '10835', '83.00', 3),
(20795, '46702', '71.50', 5),
(20796, '10854', '39.50', 2),
(20796, '46706', '27.50', 5),
(20797, '11630', '46.50', 1),
(20797, '33047', '16.00', 2),
(20798, '12054', '358.50', 1),
(20798, '35911', '11.50', 1),
(20799, '12055', '238.50', 2),
(20799, '32055', '130.50', 1),
(20799, '35912', '11.50', 5),
(20800, '12056', '191.50', 5),
(20800, '32067', '94.50', 1),
(20800, '37710', '35.00', 3),
(20801, '12088', '215.00', 5),
(20801, '32069', '154.00', 3),
(20801, '37720', '42.00', 2),
(20802, '12089', '144.00', 1),
(20802, '32191', '402.00', 2),
(20802, '37725', '35.00', 5),
(20803, '12090', '192.00', 5),
(20803, '32610', '106.50', 1),
(20803, '37730', '23.50', 5),
(20804, '12091', '286.50', 1),
(20804, '37731', '30.00', 5),
(20805, '12092', '238.50', 5),
(20805, '37720', '42.00', 5),
(20806, '13001', '38.00', 1),
(20806, '37725', '36.00', 3),
(20807, '15207', '24.50', 5),
(20807, '33044', '14.50', 3),
(20808, '15208', '24.50', 1),
(20808, '33045', '17.50', 5),
(20809, '15211', '209.00', 3),
(20809, '33046', '15.00', 1),
(20810, '15217', '32.00', 3),
(20810, '33047', '16.00', 5),
(20811, '15559', '38.00', 3),
(20811, '35911', '11.50', 1),
(20812, '20936', '25.00', 5),
(20812, '35912', '11.50', 3),
(20813, '20980', '27.50', 2),
(20813, '37710', '35.00', 2),
(20814, '21032', '57.50', 2),
(20814, '37720', '42.00', 1),
(20815, '21034', '504.00', 1),
(20815, '37725', '36.00', 2),
(20816, '37730', '23.50', 1),
(20817, '37731', '30.00', 1),
(20818, '37732', '27.00', 1),
(20819, '41020', '94.50', 3),
(20820, '41096', '115.00', 5),
(20821, '41097', '142.50', 2),
(20822, '41098', '83.00', 2),
(20823, '42613', '106.00', 1),
(20823, '42929', '83.00', 1),
(20824, '42933', '69.50', 5),
(20824, '65060', '46.50', 5),
(20825, '42934', '69.50', 1),
(20825, '65070', '118.50', 5),
(20826, '42939', '95.00', 2),
(20826, '65080', '478.00', 2),
(20827, '42941', '71.00', 3),
(20827, '64509', '142.00', 5),
(20828, '42945', '81.50', 2),
(20828, '64510', '154.00', 2),
(20829, '64511', '227.50', 2),
(20830, '64550', '126.00', 2),
(20831, '64551', '118.00', 3),
(20832, '25136', '180.00', 1),
(20832, '64552', '276.00', 2),
(20833, '25137', '228.00', 5),
(20833, '65032', '598.50', 1),
(20834, '25138', '166.50', 1),
(20834, '65033', '1044.00', 2),
(20835, '25154', '276.00', 5),
(20835, '65034', '15000.00', 2),
(20836, '32055', '130.50', 3),
(20836, '65060', '46.50', 1),
(20837, '32067', '94.50', 2),
(20837, '65070', '118.50', 1),
(20838, '32069', '154.00', 5),
(20838, '65080', '478.00', 5),
(20839, '32191', '402.00', 1),
(20839, '65081', '112.00', 5),
(20840, '32610', '106.50', 5),
(20840, '65082', '174.00', 5),
(20841, '33044', '14.50', 2),
(20841, '65122', '1558.00', 1),
(20842, '33045', '17.50', 2),
(20842, '65142', '93.00', 1),
(20843, '25136', '180.00', 3),
(20843, '33046', '15.00', 4),
(20844, '25137', '228.00', 1),
(20844, '33047', '16.00', 2),
(20845, '25138', '166.50', 2),
(20845, '35911', '11.50', 5),
(20846, '25154', '276.00', 1),
(20846, '35912', '11.50', 5),
(20847, '32055', '130.50', 5),
(20847, '37710', '35.00', 5),
(20847, '55112', '598.50', 3),
(20848, '32067', '94.50', 5),
(20848, '37720', '42.00', 3),
(20848, '55129', '154.00', 2),
(20849, '32069', '154.00', 1),
(20849, '37725', '36.00', 2),
(20849, '55130', '298.50', 5),
(20850, '32191', '402.00', 3),
(20850, '37730', '23.50', 2),
(20850, '55550', '1558.50', 2),
(20851, '25079', '334.00', 2),
(20851, '37731', '30.00', 5),
(20851, '58028', '142.50', 5),
(20852, '25121', '418.50', 5),
(20852, '37732', '27.00', 5),
(20852, '59915', '25.00', 1),
(20853, '25131', '1078.00', 2),
(20853, '41020', '94.50', 1),
(20853, '64509', '142.00', 1),
(20854, '25136', '180.00', 2),
(20854, '41096', '115.00', 2),
(20854, '64510', '154.00', 3),
(20855, '25137', '228.00', 5),
(20855, '41097', '142.50', 1),
(20855, '64511', '227.50', 5),
(20856, '25138', '166.50', 5),
(20856, '41098', '83.00', 3),
(20856, '64550', '126.00', 5),
(20857, '25154', '276.00', 3),
(20857, '42613', '106.00', 3),
(20857, '64551', '118.00', 5),
(20858, '32055', '130.50', 5),
(20858, '42615', '106.00', 2),
(20858, '64552', '276.00', 2),
(20859, '32067', '94.50', 3),
(20859, '42626', '141.50', 2),
(20859, '65032', '598.50', 2),
(20860, '32069', '154.00', 5),
(20860, '42929', '83.00', 2),
(20860, '65033', '1044.00', 5),
(20861, '32191', '402.00', 5),
(20861, '42933', '69.50', 3),
(20861, '65034', '15000.00', 5),
(20862, '32610', '106.50', 1),
(20862, '42934', '69.50', 2),
(20862, '65060', '46.50', 5),
(20863, '42939', '95.00', 5),
(20863, '65060', '46.50', 2),
(20863, '65070', '118.50', 3),
(20864, '42941', '71.00', 2),
(20864, '65070', '118.50', 2),
(20864, '65080', '478.00', 1),
(20865, '42945', '81.50', 5),
(20865, '65080', '478.00', 3),
(20865, '65081', '112.00', 1),
(20866, '43000', '540.00', 5),
(20866, '64509', '142.00', 5),
(20866, '65082', '174.00', 1),
(20867, '43014', '372.00', 3),
(20867, '64510', '154.00', 2),
(20867, '65122', '1558.00', 5),
(20868, '43015', '288.00', 1),
(20868, '64511', '227.50', 2),
(20868, '65142', '93.00', 3),
(20869, '44939', '115.00', 1),
(20869, '64550', '126.00', 1),
(20869, '65143', '83.50', 1),
(20870, '45101', '57.00', 1),
(20870, '64551', '118.00', 5),
(20870, '65147', '238.50', 1),
(20871, '45105', '45.00', 5),
(20871, '64552', '276.00', 5),
(20871, '65190', '190.50', 1),
(20872, '45923', '42.00', 2),
(20872, '65032', '598.50', 2),
(20872, '65191', '23.00', 3),
(20873, '45935', '19.50', 3),
(20873, '65033', '1044.00', 5),
(20873, '65247', '75.00', 3),
(20874, '46702', '71.50', 1),
(20874, '65034', '15000.00', 1),
(20874, '71912', '35.00', 1),
(20875, '46706', '27.50', 5),
(20875, '65060', '46.50', 5),
(20875, '72777', '154.00', 5),
(20876, '46738', '40.00', 5),
(20876, '65070', '118.50', 2),
(20876, '72942', '35.50', 2),
(20877, '46741', '10.00', 5),
(20877, '65080', '478.00', 2),
(20877, '72943', '35.50', 1),
(20878, '46745', '43.50', 2),
(20878, '65081', '112.00', 3),
(20878, '72944', '42.00', 1),
(20879, '47903', '11214.00', 3),
(20879, '65082', '174.00', 3),
(20879, '76032', '334.50', 3),
(20880, '49916', '25.00', 3),
(20880, '65122', '1558.00', 1),
(20880, '77033', '358.00', 2),
(20881, '49917', '25.50', 6),
(20881, '65142', '93.00', 2),
(20881, '77036', '358.00', 5),
(20882, '49916', '25.00', 2),
(20882, '49919', '58.50', 3),
(20882, '77038', '478.00', 1),
(20883, '49917', '25.50', 8),
(20883, '49921', '357.00', 2),
(20883, '77249', '1558.00', 5),
(20884, '49919', '58.50', 2),
(20884, '55112', '598.50', 5),
(20884, '77251', '658.00', 5),
(20885, '49921', '357.00', 5),
(20885, '55129', '154.00', 5),
(20885, '77252', '34.50', 5),
(20886, '55112', '598.50', 1),
(20886, '55130', '298.50', 1),
(20886, '77276', '4558.00', 5),
(20887, '55129', '154.00', 1),
(20887, '55550', '1558.50', 5),
(20887, '77277', '358.00', 5),
(20888, '55130', '298.50', 3),
(20888, '58028', '142.50', 2),
(20888, '78029', '142.50', 3),
(20889, '55550', '1558.50', 2),
(20889, '59915', '25.00', 5),
(20889, '80032', '154.50', 2),
(20890, '58028', '142.50', 5),
(20890, '64509', '142.00', 1),
(20890, '80082', '118.50', 5),
(20891, '59915', '25.00', 1),
(20891, '64510', '154.00', 5),
(20891, '80088', '213.00', 2),
(20892, '64509', '142.00', 5),
(20892, '64511', '227.50', 1),
(20892, '80692', '39.50', 5),
(20893, '64510', '154.00', 1),
(20893, '64550', '126.00', 3),
(20893, '81007', '62.50', 3),
(20894, '64511', '227.50', 3),
(20894, '64551', '118.00', 3),
(20894, '82090', '30.00', 2),
(20895, '64550', '126.00', 2),
(20895, '64552', '276.00', 1),
(20895, '82092', '18.00', 5),
(20896, '64551', '118.00', 2),
(20896, '65032', '598.50', 3),
(20896, '82093', '24.00', 2),
(20897, '42615', '106.00', 1),
(20897, '65033', '1044.00', 1),
(20897, '82095', '23.50', 5),
(20898, '42626', '141.50', 1),
(20898, '65034', '15000.00', 3),
(20898, '82096', '27.50', 1),
(20899, '42929', '83.00', 5),
(20899, '65060', '46.50', 1),
(20899, '83013', '46.00', 2),
(20900, '42933', '69.50', 1),
(20900, '65070', '118.50', 1),
(20900, '90106', '38.00', 2),
(20901, '42934', '69.50', 3),
(20901, '65080', '478.00', 3),
(20901, '90109', '40.50', 5),
(20902, '42939', '95.00', 1),
(20902, '65081', '112.00', 2),
(20902, '90116', '50.00', 3),
(20903, '42941', '71.00', 5),
(20903, '65082', '174.00', 2),
(20903, '90164', '75.50', 2),
(20904, '42945', '81.50', 1),
(20904, '65122', '1558.00', 2),
(20904, '90192', '70.50', 2),
(20905, '43000', '540.00', 1),
(20905, '65142', '93.00', 5),
(20905, '90208', '71.00', 2),
(20906, '43014', '372.00', 2),
(20906, '65143', '83.50', 3),
(20906, '90209', '71.00', 1),
(20907, '43015', '288.00', 5),
(20907, '65147', '238.50', 3),
(20907, '90212', '71.00', 3),
(20908, '44939', '115.00', 3),
(20908, '65190', '190.50', 3),
(20908, '90510', '430.50', 5),
(20909, '45101', '57.00', 3),
(20909, '65191', '23.00', 2),
(20909, '90521', '142.50', 1),
(20910, '45105', '45.00', 2),
(20910, '65247', '75.00', 2),
(20910, '90531', '83.00', 1),
(20911, '45923', '42.00', 3),
(20911, '71912', '35.00', 3),
(20911, '90545', '288.00', 1),
(20912, '45935', '19.50', 2),
(20912, '72777', '154.00', 5),
(20912, '90693', '57.00', 2),
(20913, '46702', '71.50', 5),
(20913, '72942', '35.50', 3),
(20913, '90737', '354.00', 1),
(20914, '46706', '27.50', 2),
(20914, '72943', '35.50', 2),
(20914, '91008', '94.00', 1),
(20915, '33047', '16.00', 1),
(20915, '72944', '42.00', 2),
(20915, '92606', '106.00', 3),
(20916, '25154', '276.00', 3),
(20916, '35911', '11.50', 3),
(20916, '76032', '334.50', 2),
(20917, '32055', '130.50', 3),
(20917, '35912', '11.50', 2),
(20917, '77033', '358.00', 1),
(20918, '32067', '94.50', 2),
(20918, '37710', '35.00', 2),
(20918, '77036', '358.00', 5),
(20919, '32069', '154.00', 2),
(20919, '37720', '42.00', 5),
(20919, '77038', '478.00', 2),
(20920, '32191', '402.00', 2),
(20920, '37725', '36.00', 5),
(20920, '77249', '1558.00', 5),
(20921, '25079', '334.00', 2),
(20921, '37730', '23.50', 2),
(20921, '77251', '658.00', 2),
(20922, '25121', '418.50', 1),
(20922, '37731', '30.00', 5),
(20922, '77252', '34.50', 1),
(20923, '10820', '46.50', 2),
(20923, '25131', '1078.00', 5),
(20923, '77276', '4558.00', 3),
(20924, '10822', '46.50', 5),
(20924, '25136', '180.00', 5),
(20924, '77277', '358.00', 1),
(20925, '10830', '57.50', 5),
(20925, '46745', '43.50', 5),
(20925, '78029', '142.50', 5),
(20926, '10835', '83.00', 3),
(20926, '47903', '11214.00', 2),
(20926, '80032', '154.50', 5),
(20927, '10854', '39.50', 2),
(20927, '22056', '130.00', 2),
(20927, '80082', '118.50', 3),
(20928, '11630', '46.50', 2),
(20928, '22165', '5400.00', 5),
(20928, '80088', '213.00', 5),
(20929, '12054', '358.50', 5),
(20929, '22179', '1440.00', 2),
(20929, '80692', '39.50', 5),
(20930, '12055', '238.50', 2),
(20930, '22870', '21.00', 2),
(20930, '81007', '62.50', 2),
(20931, '12056', '191.50', 1),
(20931, '25079', '334.00', 5),
(20931, '82090', '30.00', 1),
(20932, '12088', '215.00', 2),
(20932, '25121', '418.50', 3),
(20932, '82092', '18.00', 1),
(20933, '12089', '144.00', 3),
(20933, '25131', '1078.00', 5),
(20933, '82093', '24.00', 5),
(20934, '12090', '192.00', 3),
(20934, '25136', '180.00', 1),
(20934, '82095', '23.50', 5),
(20935, '12091', '286.50', 2),
(20935, '25137', '228.00', 2),
(20935, '82096', '27.50', 5),
(20936, '12092', '238.50', 2),
(20936, '25138', '166.50', 2),
(20936, '83013', '46.00', 5),
(20937, '13001', '38.00', 1),
(20937, '25154', '276.00', 2),
(20937, '90106', '38.00', 5),
(20938, '15207', '24.50', 2),
(20938, '32055', '130.50', 2),
(20938, '90109', '40.50', 1),
(20939, '15208', '24.50', 5),
(20939, '32067', '94.50', 1),
(20939, '90116', '50.00', 2),
(20940, '15211', '209.00', 2),
(20940, '90164', '75.50', 2),
(20941, '15217', '32.00', 5),
(20941, '90192', '70.50', 5),
(20942, '15559', '38.00', 3),
(20942, '90208', '71.00', 5),
(20943, '20936', '25.00', 3),
(20943, '90209', '71.00', 2),
(20944, '20980', '27.50', 2),
(20944, '21037', '294.00', 1),
(20944, '90212', '71.00', 5),
(20945, '21032', '57.50', 2),
(20945, '21510', '35.50', 2),
(20945, '90510', '430.50', 1),
(20946, '21034', '504.00', 3),
(20946, '21514', '28.00', 2),
(20946, '90521', '142.50', 1),
(20947, '21037', '294.00', 3),
(20947, '21515', '27.00', 2),
(20947, '90531', '83.00', 2),
(20948, '21510', '35.50', 5),
(20948, '21517', '16.00', 3),
(20948, '90545', '288.00', 5),
(20949, '21514', '28.00', 5),
(20949, '21580', '13.50', 1),
(20949, '90693', '57.00', 1),
(20950, '21515', '27.00', 5),
(20950, '22002', '55.50', 1),
(20950, '90737', '354.00', 5),
(20951, '21517', '16.00', 5),
(20951, '22054', '70.50', 1),
(20951, '91008', '94.00', 3),
(20952, '21580', '13.50', 3),
(20952, '22055', '214.50', 3),
(20952, '92606', '106.00', 2),
(20953, '22002', '55.50', 3),
(20953, '22056', '130.00', 1),
(20953, '45923', '42.00', 1),
(20954, '22054', '70.50', 3),
(20954, '22165', '5400.00', 1),
(20954, '45935', '19.50', 2),
(20955, '22055', '214.50', 2),
(20955, '22179', '1440.00', 5),
(20955, '46702', '71.50', 1),
(20956, '22056', '130.00', 3),
(20956, '22870', '21.00', 5),
(20956, '46706', '27.50', 5),
(20957, '22165', '5400.00', 3),
(20957, '25079', '334.00', 1),
(20957, '33047', '16.00', 2),
(20958, '12056', '191.50', 2),
(20958, '22179', '1440.00', 1),
(20958, '25121', '418.50', 2),
(20958, '35911', '11.50', 5),
(20959, '12088', '215.00', 5),
(20959, '22870', '21.00', 1),
(20959, '25131', '1078.00', 1),
(20959, '35912', '11.50', 2),
(20960, '12089', '144.00', 2),
(20960, '25079', '334.00', 3),
(20960, '37710', '35.00', 1),
(20961, '12090', '192.00', 2),
(20961, '25121', '418.50', 5),
(20961, '37720', '42.00', 3),
(20962, '12091', '286.50', 5),
(20962, '25131', '1078.00', 5),
(20962, '37725', '36.00', 1),
(20963, '12092', '238.50', 5),
(20963, '25136', '180.00', 3),
(20963, '37730', '23.50', 1),
(20964, '13001', '38.00', 2),
(20964, '25137', '228.00', 5),
(20964, '37731', '30.00', 2),
(20965, '10820', '46.50', 5),
(20965, '15207', '24.50', 1),
(20965, '25138', '166.50', 5),
(20966, '10822', '46.50', 1),
(20966, '15208', '24.50', 5),
(20966, '25154', '276.00', 1),
(20967, '10830', '57.50', 5),
(20967, '15211', '209.00', 1),
(20967, '32055', '130.50', 5),
(20968, '10835', '83.00', 5),
(20968, '15217', '32.00', 5),
(20968, '32067', '94.50', 3),
(20969, '10854', '39.50', 1),
(20969, '15559', '38.00', 5),
(20969, '32069', '154.00', 5),
(20970, '11630', '46.50', 3),
(20970, '20936', '25.00', 2),
(20970, '32191', '402.00', 5),
(20971, '12054', '358.50', 1),
(20971, '20980', '27.50', 1),
(20971, '32610', '106.50', 3),
(20972, '12055', '238.50', 1),
(20972, '21032', '57.50', 1),
(20972, '33044', '14.50', 1),
(20973, '12056', '191.50', 5),
(20973, '21034', '504.00', 2),
(20973, '33045', '17.50', 5),
(20974, '12088', '215.00', 5),
(20974, '21037', '294.00', 2),
(20974, '33046', '15.00', 7),
(20975, '12089', '144.00', 5),
(20975, '21510', '35.50', 1),
(20975, '33047', '16.00', 5),
(20976, '12090', '192.00', 5),
(20976, '21514', '28.00', 1),
(20976, '35911', '11.50', 1),
(20977, '12091', '286.50', 2),
(20977, '21515', '27.00', 1),
(20977, '35912', '11.50', 3),
(20978, '12092', '238.50', 3),
(20978, '21517', '16.00', 5),
(20978, '37710', '35.00', 3),
(20979, '13001', '38.00', 1),
(20979, '21580', '13.50', 5),
(20979, '37720', '42.00', 2),
(20980, '15207', '24.50', 1),
(20980, '22002', '55.50', 2),
(20980, '37725', '36.00', 3),
(20981, '15208', '24.50', 3),
(20981, '22054', '70.50', 2),
(20981, '37730', '23.50', 3),
(20982, '15211', '209.00', 3),
(20982, '22055', '214.50', 5),
(20982, '37731', '30.00', 2),
(20982, '90109', '40.50', 3),
(20983, '15217', '32.00', 3),
(20983, '22056', '130.00', 2),
(20983, '37732', '27.00', 2),
(20983, '90116', '50.00', 5),
(20984, '15559', '38.00', 5),
(20984, '22165', '5400.00', 2),
(20984, '41020', '94.50', 2),
(20984, '90164', '75.50', 5),
(20985, '20936', '25.00', 1),
(20985, '22179', '1440.00', 5),
(20985, '41096', '115.00', 5),
(20985, '90192', '70.50', 2),
(20986, '20980', '27.50', 3),
(20986, '22870', '21.00', 3),
(20986, '41097', '142.50', 3),
(20986, '90208', '71.00', 5),
(20987, '21032', '57.50', 3),
(20987, '25079', '334.00', 2),
(20987, '41098', '83.00', 1),
(20987, '90209', '71.00', 1),
(20988, '21034', '504.00', 2),
(20988, '25121', '418.50', 1),
(20988, '42613', '106.00', 5),
(20988, '90212', '71.00', 5),
(20989, '21037', '294.00', 5),
(20989, '25131', '1078.00', 1),
(20989, '42615', '106.00', 1),
(20989, '90510', '430.50', 3),
(20990, '21510', '35.50', 3),
(20990, '25136', '180.00', 2),
(20990, '42626', '141.50', 3),
(20990, '90521', '142.50', 5),
(20991, '21514', '28.00', 3),
(20991, '25137', '228.00', 1),
(20991, '42929', '83.00', 1),
(20991, '90531', '83.00', 5),
(20992, '21515', '27.00', 5),
(20992, '25138', '166.50', 1),
(20992, '42933', '69.50', 2),
(20992, '90545', '288.00', 2),
(20993, '21517', '16.00', 1),
(20993, '25154', '276.00', 3),
(20993, '42934', '69.50', 5),
(20993, '90693', '57.00', 3),
(20994, '21580', '13.50', 5),
(20994, '32055', '130.50', 2),
(20994, '42939', '95.00', 3),
(20994, '90737', '354.00', 2),
(20995, '22002', '55.50', 5),
(20995, '32067', '94.50', 5),
(20995, '42941', '71.00', 1),
(20995, '91008', '94.00', 2),
(20996, '22054', '70.50', 5),
(20996, '32069', '154.00', 1),
(20996, '42945', '81.50', 2),
(20996, '92606', '106.00', 3),
(20997, '22055', '214.50', 2),
(20997, '32191', '402.00', 5),
(20997, '43000', '540.00', 5),
(20997, '64550', '126.00', 5),
(20998, '22056', '130.00', 5),
(20998, '32610', '106.50', 5),
(20998, '43014', '372.00', 5),
(20998, '64551', '118.00', 5),
(20999, '22165', '5400.00', 5),
(20999, '33044', '14.50', 3),
(20999, '43015', '288.00', 5),
(20999, '64552', '276.00', 2),
(21000, '22179', '1440.00', 1),
(21000, '33045', '17.50', 5),
(21000, '44939', '115.00', 2),
(21000, '65032', '598.50', 2),
(21001, '33046', '15.00', 15),
(21001, '45101', '57.00', 2),
(21001, '65033', '1044.00', 5),
(21002, '33047', '16.00', 5),
(21002, '45105', '45.00', 5),
(21002, '65034', '15000.00', 2),
(21003, '35911', '11.50', 5),
(21003, '45923', '42.00', 5),
(21003, '65060', '46.50', 2),
(21004, '35912', '11.50', 2),
(21004, '45935', '19.50', 5),
(21004, '65070', '118.50', 2),
(21005, '37710', '35.00', 2),
(21005, '46702', '71.50', 3),
(21005, '65080', '478.00', 5),
(21006, '37720', '42.00', 1),
(21006, '46706', '27.50', 2),
(21006, '65081', '112.00', 5),
(21007, '37725', '36.00', 2),
(21007, '46738', '40.00', 1),
(21007, '65082', '174.00', 2),
(21008, '37730', '23.50', 2),
(21008, '46741', '10.00', 5),
(21008, '65122', '1558.00', 1),
(21009, '37731', '30.00', 1),
(21009, '46745', '43.50', 1),
(21009, '65142', '93.00', 1),
(21010, '37732', '27.00', 2),
(21010, '47903', '11214.00', 5),
(21010, '59915', '25.00', 3),
(21011, '41020', '94.50', 1),
(21011, '49916', '25.00', 2),
(21011, '64509', '142.00', 2),
(21011, '65034', '15000.00', 2),
(21012, '41096', '115.00', 5),
(21012, '49917', '25.50', 2),
(21012, '64510', '154.00', 2),
(21012, '65060', '46.50', 2),
(21013, '41097', '142.50', 5),
(21013, '49919', '58.50', 1),
(21013, '64511', '227.50', 5),
(21013, '65070', '118.50', 5),
(21014, '41098', '83.00', 3),
(21014, '49921', '357.00', 2),
(21014, '64550', '126.00', 1),
(21014, '65080', '478.00', 1),
(21015, '42613', '106.00', 2),
(21015, '55112', '598.50', 5),
(21015, '64551', '118.00', 2),
(21015, '65081', '112.00', 1),
(21016, '42615', '106.00', 5),
(21016, '55129', '154.00', 5),
(21016, '65082', '174.00', 5),
(21017, '33047', '16.00', 1),
(21017, '42626', '141.50', 5),
(21017, '55130', '298.50', 2),
(21017, '65122', '1558.00', 2),
(21018, '35911', '11.50', 5),
(21018, '42929', '83.00', 5),
(21018, '55550', '1558.50', 1),
(21019, '35912', '11.50', 5),
(21019, '42933', '69.50', 1),
(21019, '58028', '142.50', 3),
(21020, '37710', '35.00', 5),
(21020, '42934', '69.50', 2),
(21020, '59915', '25.00', 5),
(21021, '37720', '42.00', 5),
(21021, '42939', '95.00', 2),
(21021, '64509', '142.00', 5),
(21022, '37725', '36.00', 5),
(21022, '42941', '71.00', 5),
(21022, '64510', '154.00', 2),
(21023, '37730', '23.50', 2),
(21023, '42945', '81.50', 5),
(21023, '64511', '227.50', 2),
(21024, '37731', '30.00', 4),
(21024, '43000', '540.00', 2),
(21024, '64550', '126.00', 3),
(21025, '37732', '27.00', 5),
(21025, '43014', '372.00', 2),
(21025, '64551', '118.00', 1),
(21026, '41020', '94.50', 3),
(21026, '43015', '288.00', 1),
(21026, '64552', '276.00', 5),
(21027, '41096', '115.00', 5),
(21027, '44939', '115.00', 5),
(21027, '65032', '598.50', 1),
(21028, '41097', '142.50', 2),
(21028, '45101', '57.00', 5),
(21028, '65033', '1044.00', 1),
(21029, '41098', '83.00', 3),
(21029, '45105', '45.00', 5),
(21029, '65034', '15000.00', 5),
(21030, '42613', '106.00', 5),
(21030, '45923', '42.00', 1),
(21030, '65060', '46.50', 5),
(21031, '42615', '106.00', 1),
(21031, '45935', '19.50', 1),
(21031, '65070', '118.50', 1),
(21032, '42626', '141.50', 5),
(21032, '46702', '71.50', 5),
(21032, '65080', '478.00', 3),
(21033, '42929', '83.00', 2),
(21033, '46706', '27.50', 2),
(21033, '65081', '112.00', 5),
(21034, '33047', '16.00', 5),
(21034, '42933', '69.50', 1),
(21034, '46738', '40.00', 3),
(21034, '65082', '174.00', 1),
(21035, '35911', '11.50', 1),
(21035, '42934', '69.50', 5),
(21035, '46741', '10.00', 3),
(21035, '65122', '1558.00', 5),
(21036, '35912', '11.50', 5),
(21036, '42939', '95.00', 5),
(21036, '46745', '43.50', 2),
(21036, '65142', '93.00', 3),
(21037, '37710', '35.00', 1),
(21037, '42941', '71.00', 5),
(21037, '47903', '11214.00', 1),
(21037, '65143', '83.50', 5),
(21038, '37720', '42.00', 5),
(21038, '42945', '81.50', 5),
(21038, '49916', '25.00', 1),
(21038, '65147', '238.50', 2),
(21039, '10820', '46.50', 1),
(21039, '43000', '540.00', 1),
(21039, '49917', '25.50', 3),
(21039, '65190', '190.50', 2),
(21040, '10822', '46.50', 3),
(21040, '43014', '372.00', 3),
(21040, '49919', '58.50', 3),
(21040, '65191', '23.00', 2),
(21041, '10830', '57.50', 2),
(21041, '43015', '288.00', 5),
(21041, '49921', '357.00', 1),
(21041, '65247', '75.00', 5),
(21042, '10835', '83.00', 5),
(21042, '44939', '115.00', 1),
(21042, '55112', '598.50', 3),
(21042, '71912', '35.00', 3),
(21043, '10854', '39.50', 3),
(21043, '45101', '57.00', 3),
(21043, '55129', '154.00', 5),
(21043, '72777', '154.00', 1),
(21044, '11630', '46.50', 2),
(21044, '45105', '45.00', 5),
(21044, '55130', '298.50', 5),
(21044, '72942', '35.50', 2),
(21045, '12054', '358.50', 5),
(21045, '45923', '42.00', 5),
(21045, '55550', '1558.50', 3),
(21045, '72943', '35.50', 5),
(21046, '12055', '238.50', 5),
(21046, '45935', '19.50', 2),
(21046, '58028', '142.50', 5),
(21046, '72944', '42.00', 3),
(21047, '12056', '191.50', 2),
(21047, '46702', '71.50', 3),
(21047, '59915', '25.00', 3),
(21047, '76032', '334.50', 5),
(21048, '12088', '215.00', 1),
(21048, '46706', '27.50', 1),
(21048, '64509', '142.00', 1),
(21048, '77033', '358.00', 5),
(21049, '12089', '144.00', 1),
(21049, '46738', '40.00', 5),
(21049, '64510', '154.00', 3),
(21049, '77036', '358.00', 2),
(21050, '12090', '192.00', 2),
(21050, '46741', '10.00', 2),
(21050, '64511', '227.50', 5),
(21050, '77038', '478.00', 2),
(21051, '12091', '286.50', 5),
(21051, '46745', '43.50', 5),
(21051, '64550', '126.00', 2),
(21051, '77249', '1558.00', 2),
(21052, '12092', '238.50', 1),
(21052, '47903', '11214.00', 3),
(21052, '64551', '118.00', 3),
(21052, '77251', '658.00', 5),
(21053, '13001', '38.00', 1),
(21053, '49916', '25.00', 2),
(21053, '64552', '276.00', 1);
INSERT INTO Ordrelinje VALUES
(21053, '77252', '34.50', 3),
(21054, '15207', '24.50', 5),
(21054, '49917', '25.50', 5),
(21054, '65032', '598.50', 2),
(21054, '77276', '4558.00', 2),
(21055, '15208', '24.50', 5),
(21055, '49919', '58.50', 2),
(21055, '65033', '1044.00', 5),
(21055, '77277', '358.00', 5),
(21056, '15211', '209.00', 2),
(21056, '49921', '357.00', 3),
(21056, '78029', '142.50', 2),
(21057, '15217', '32.00', 2),
(21057, '55112', '598.50', 1),
(21057, '80032', '154.50', 1),
(21058, '15559', '38.00', 3),
(21058, '55129', '154.00', 2),
(21058, '80082', '118.50', 3),
(21059, '20936', '25.00', 5),
(21059, '55130', '298.50', 1),
(21059, '80088', '213.00', 1),
(21060, '20980', '27.50', 3),
(21060, '55550', '1558.50', 5),
(21060, '80692', '39.50', 2),
(21061, '21032', '57.50', 2),
(21061, '58028', '142.50', 1),
(21061, '81007', '62.50', 5),
(21062, '21034', '504.00', 5),
(21062, '59915', '25.00', 1),
(21062, '82090', '30.00', 7),
(21063, '21037', '294.00', 1),
(21063, '64509', '142.00', 2),
(21063, '65142', '93.00', 2),
(21063, '82092', '18.00', 3),
(21064, '21510', '35.50', 1),
(21064, '64510', '154.00', 2),
(21064, '65143', '83.50', 5),
(21064, '82093', '24.00', 1),
(21065, '21514', '28.00', 2),
(21065, '64511', '227.50', 5),
(21065, '65147', '238.50', 3),
(21065, '82095', '23.50', 5),
(21066, '21515', '27.00', 1),
(21066, '64550', '126.00', 1),
(21066, '65190', '190.50', 1),
(21066, '82096', '27.50', 2),
(21067, '21517', '16.00', 2),
(21067, '64551', '118.00', 5),
(21067, '65191', '23.00', 5),
(21067, '83013', '46.00', 2),
(21068, '21580', '13.50', 3),
(21068, '64552', '276.00', 3),
(21068, '65247', '75.00', 1),
(21068, '90106', '38.00', 5),
(21069, '22002', '55.50', 1),
(21069, '65032', '598.50', 3),
(21069, '71912', '35.00', 2),
(21069, '90109', '40.50', 2),
(21070, '22054', '70.50', 1),
(21070, '65033', '1044.00', 2),
(21070, '72777', '154.00', 5),
(21070, '90116', '50.00', 2),
(21071, '22055', '214.50', 1),
(21071, '65034', '15000.00', 1),
(21071, '72942', '35.50', 3),
(21071, '90164', '75.50', 1),
(21072, '65060', '46.50', 5),
(21072, '72943', '35.50', 2),
(21072, '90192', '70.50', 3),
(21073, '65070', '118.50', 2),
(21073, '72944', '42.00', 2),
(21073, '90208', '71.00', 1),
(21074, '65080', '478.00', 5),
(21074, '76032', '334.50', 1),
(21074, '90209', '71.00', 2),
(21075, '65081', '112.00', 1),
(21075, '77033', '358.00', 1),
(21075, '90212', '71.00', 5),
(21076, '65082', '174.00', 3),
(21076, '77036', '358.00', 2),
(21076, '90510', '430.50', 2),
(21077, '65122', '1558.00', 5),
(21077, '77038', '478.00', 1),
(21077, '90521', '142.50', 3),
(21078, '65142', '93.00', 5),
(21078, '77249', '1558.00', 1),
(21078, '90531', '83.00', 2),
(21079, '65143', '83.50', 3),
(21079, '77251', '658.00', 1),
(21079, '90545', '288.00', 2),
(21080, '65147', '238.50', 2),
(21080, '77252', '34.50', 2),
(21080, '90693', '57.00', 2),
(21081, '65190', '190.50', 3),
(21081, '77276', '4558.00', 5),
(21081, '90737', '354.00', 5),
(21082, '65191', '23.00', 1),
(21082, '77277', '358.00', 5),
(21082, '91008', '94.00', 5),
(21083, '65247', '75.00', 5),
(21083, '78029', '142.50', 5),
(21083, '92606', '106.00', 3),
(21084, '44939', '115.00', 5),
(21084, '71912', '35.00', 5),
(21084, '80032', '154.50', 3),
(21085, '45101', '57.00', 5),
(21085, '72777', '154.00', 1),
(21085, '80082', '118.50', 1),
(21086, '45105', '45.00', 1),
(21086, '72942', '35.50', 1),
(21086, '80088', '213.00', 2),
(21087, '45923', '42.00', 5),
(21087, '72943', '35.50', 3),
(21087, '80692', '39.50', 2),
(21088, '45935', '19.50', 5),
(21088, '72944', '42.00', 2),
(21088, '81007', '62.50', 1),
(21089, '46702', '71.50', 2),
(21089, '76032', '334.50', 3),
(21089, '82090', '30.00', 15),
(21090, '46706', '27.50', 5),
(21090, '77033', '358.00', 2),
(21090, '82092', '18.00', 5),
(21091, '33047', '16.00', 5),
(21091, '77036', '358.00', 5),
(21091, '82093', '24.00', 3),
(21092, '35911', '11.50', 1),
(21092, '77038', '478.00', 5),
(21092, '82095', '23.50', 1),
(21093, '35912', '11.50', 5),
(21093, '77249', '1558.00', 3),
(21093, '82096', '27.50', 1),
(21094, '37710', '35.00', 1),
(21094, '77251', '658.00', 2),
(21094, '83013', '46.00', 1),
(21095, '37720', '42.00', 1),
(21095, '77252', '34.50', 1),
(21095, '90106', '38.00', 5),
(21096, '37725', '35.00', 2),
(21096, '77276', '4558.00', 2),
(21097, '37730', '23.50', 3),
(21098, '37731', '30.00', 5),
(21099, '37720', '42.00', 3),
(21100, '37725', '36.00', 1),
(21101, '33044', '14.50', 2),
(21102, '33045', '17.50', 1),
(21103, '33046', '15.00', 5),
(21104, '33047', '16.00', 1),
(21105, '35911', '11.50', 2),
(21106, '35912', '11.50', 5),
(21107, '37710', '35.00', 5),
(21108, '37720', '42.00', 5),
(21109, '37725', '36.00', 3),
(21110, '37730', '23.50', 2),
(21111, '37731', '30.00', 2),
(21112, '37732', '27.00', 3),
(21113, '41020', '94.50', 2),
(21113, '90164', '75.50', 3),
(21114, '41096', '115.00', 2),
(21114, '90192', '70.50', 2),
(21115, '41097', '142.50', 2),
(21115, '90208', '71.00', 2),
(21116, '41098', '83.00', 1),
(21116, '90209', '71.00', 5),
(21117, '42613', '106.00', 5),
(21117, '90212', '71.00', 1),
(21118, '65060', '46.50', 1),
(21118, '90510', '430.50', 1),
(21119, '65070', '118.50', 3),
(21119, '90521', '142.50', 5),
(21120, '65080', '478.00', 1),
(21120, '90531', '83.00', 3),
(21121, '64509', '142.00', 5),
(21121, '90545', '288.00', 5),
(21122, '64510', '154.00', 3),
(21122, '90693', '57.00', 1),
(21123, '64511', '227.50', 1),
(21123, '90737', '354.00', 1),
(21124, '64550', '126.00', 3),
(21124, '91008', '94.00', 1),
(21125, '64551', '118.00', 2),
(21125, '92606', '106.00', 5),
(21126, '37725', '36.00', 2),
(21126, '64552', '276.00', 2),
(21127, '37730', '23.50', 5),
(21127, '65032', '598.50', 2),
(21128, '37731', '30.00', 9),
(21128, '65033', '1044.00', 5),
(21129, '37732', '27.00', 2),
(21129, '65034', '15000.00', 3),
(21130, '41020', '94.50', 5),
(21130, '65060', '46.50', 3),
(21131, '41096', '115.00', 5),
(21131, '65070', '118.50', 2),
(21132, '41097', '142.50', 5),
(21132, '65080', '478.00', 3),
(21133, '41098', '83.00', 5),
(21133, '65081', '112.00', 3),
(21134, '22870', '21.00', 2),
(21134, '42613', '106.00', 3),
(21134, '65082', '174.00', 2),
(21134, '77277', '358.00', 1),
(21135, '10820', '46.50', 2),
(21135, '25079', '334.00', 5),
(21135, '65122', '1558.00', 2),
(21135, '78029', '142.50', 1),
(21136, '10822', '46.50', 1),
(21136, '25121', '418.50', 3),
(21136, '65142', '93.00', 1),
(21136, '80032', '154.50', 2),
(21137, '10830', '57.50', 5),
(21137, '25131', '1078.00', 5),
(21137, '25136', '180.00', 1),
(21137, '80082', '118.50', 5),
(21138, '10835', '83.00', 2),
(21138, '25136', '180.00', 3),
(21138, '25137', '228.00', 2),
(21138, '80088', '213.00', 5),
(21139, '10854', '39.50', 1),
(21139, '25137', '228.00', 5),
(21139, '25138', '166.50', 3),
(21139, '80692', '39.50', 5),
(21140, '11630', '46.50', 3),
(21140, '25138', '166.50', 2),
(21140, '25154', '276.00', 5),
(21140, '81007', '62.50', 3),
(21141, '12054', '358.50', 2),
(21141, '25154', '276.00', 1),
(21141, '32055', '130.50', 1),
(21141, '82090', '30.00', 10),
(21142, '12055', '238.50', 2),
(21142, '32055', '130.50', 3),
(21142, '32067', '94.50', 1),
(21142, '82092', '18.00', 5),
(21143, '12056', '191.50', 5),
(21143, '32067', '94.50', 5),
(21143, '32069', '154.00', 2),
(21143, '82093', '24.00', 2),
(21144, '12088', '215.00', 5),
(21144, '32069', '154.00', 5),
(21144, '32191', '402.00', 1),
(21144, '82095', '23.50', 1),
(21145, '12089', '144.00', 3),
(21145, '25079', '334.00', 1),
(21145, '32191', '402.00', 5),
(21145, '82096', '27.50', 3),
(21146, '12090', '192.00', 1),
(21146, '25121', '418.50', 2),
(21146, '32610', '106.50', 5),
(21146, '83013', '46.00', 3),
(21147, '12091', '286.50', 1),
(21147, '25131', '1078.00', 2),
(21147, '33044', '14.50', 5),
(21147, '90106', '38.00', 3),
(21148, '12092', '238.50', 1),
(21148, '25136', '180.00', 2),
(21148, '33045', '17.50', 5),
(21148, '90109', '40.50', 5),
(21149, '13001', '38.00', 2),
(21149, '25137', '228.00', 2),
(21149, '33046', '15.00', 2),
(21149, '90116', '50.00', 1),
(21150, '15207', '24.50', 3),
(21150, '25138', '166.50', 2),
(21151, '15208', '24.50', 2),
(21151, '25154', '276.00', 5),
(21152, '15211', '209.00', 5),
(21152, '32055', '130.50', 5),
(21153, '15217', '32.00', 5),
(21153, '32067', '94.50', 1),
(21154, '15559', '38.00', 5),
(21154, '32069', '154.00', 1),
(21155, '20936', '25.00', 5),
(21155, '32191', '402.00', 1),
(21156, '20980', '27.50', 2),
(21156, '32610', '106.50', 3),
(21157, '21032', '57.50', 1),
(21157, '65060', '46.50', 2),
(21158, '21034', '504.00', 1),
(21158, '65070', '118.50', 1),
(21159, '21037', '294.00', 5),
(21159, '65080', '478.00', 5),
(21160, '21510', '35.50', 2),
(21160, '64509', '142.00', 2),
(21161, '21514', '28.00', 2),
(21161, '64510', '154.00', 3),
(21162, '21515', '27.00', 2),
(21162, '64511', '227.50', 5),
(21163, '21517', '16.00', 2),
(21163, '64550', '126.00', 2),
(21164, '21580', '13.50', 2),
(21164, '64551', '118.00', 5),
(21165, '22002', '55.50', 3),
(21165, '64552', '276.00', 1),
(21166, '22054', '70.50', 5),
(21166, '65032', '598.50', 5),
(21167, '22055', '214.50', 3),
(21167, '65033', '1044.00', 1),
(21168, '22056', '130.00', 1),
(21168, '65034', '15000.00', 2),
(21169, '22165', '5400.00', 1),
(21169, '65060', '46.50', 5),
(21170, '22179', '1440.00', 3),
(21170, '65070', '118.50', 3),
(21171, '22870', '21.00', 2),
(21171, '65080', '478.00', 5),
(21172, '25079', '334.00', 3),
(21172, '65081', '112.00', 5),
(21173, '25121', '418.50', 1),
(21173, '65082', '174.00', 5),
(21174, '25131', '1078.00', 5),
(21174, '65122', '1558.00', 2),
(21175, '25136', '180.00', 5),
(21175, '65142', '93.00', 5),
(21176, '25137', '228.00', 5),
(21176, '49916', '25.00', 1),
(21177, '25138', '166.50', 5),
(21177, '49917', '25.50', 2),
(21178, '25154', '276.00', 3),
(21178, '49919', '58.50', 5),
(21179, '32055', '130.50', 2),
(21179, '49921', '357.00', 5),
(21180, '32067', '94.50', 3),
(21180, '55112', '598.50', 1),
(21181, '32069', '154.00', 2),
(21181, '55129', '154.00', 1),
(21182, '32191', '402.00', 5),
(21182, '55130', '298.50', 3),
(21183, '32610', '106.50', 2),
(21183, '55550', '1558.50', 2),
(21184, '33044', '14.50', 1),
(21184, '58028', '142.50', 5),
(21185, '33045', '17.50', 1),
(21185, '59915', '25.00', 3),
(21186, '22056', '130.00', 3),
(21186, '33046', '15.00', 9),
(21186, '64509', '142.00', 5),
(21187, '22165', '5400.00', 5),
(21187, '33047', '16.00', 5),
(21187, '64510', '154.00', 3),
(21188, '22179', '1440.00', 5),
(21188, '35911', '11.50', 1),
(21188, '64511', '227.50', 1),
(21189, '22870', '21.00', 5),
(21189, '35912', '11.50', 2),
(21189, '64550', '126.00', 5),
(21190, '25079', '334.00', 2),
(21190, '37710', '35.00', 1),
(21190, '64551', '118.00', 5),
(21191, '25121', '418.50', 3),
(21191, '37720', '42.00', 2),
(21191, '42615', '106.00', 2),
(21192, '25131', '1078.00', 1),
(21192, '37725', '36.00', 1),
(21192, '42626', '141.50', 5),
(21193, '25136', '180.00', 1),
(21193, '37730', '23.50', 3),
(21193, '42929', '83.00', 5),
(21194, '25137', '228.00', 1),
(21194, '37731', '30.00', 13),
(21194, '42933', '69.50', 1),
(21195, '25138', '166.50', 1),
(21195, '37732', '27.00', 5),
(21195, '42934', '69.50', 3),
(21196, '25154', '276.00', 5),
(21196, '41020', '94.50', 5),
(21196, '42939', '95.00', 1),
(21197, '32055', '130.50', 5),
(21197, '41096', '115.00', 1),
(21197, '42941', '71.00', 3),
(21198, '12092', '238.50', 4),
(21198, '32067', '94.50', 5),
(21198, '33047', '16.00', 2),
(21198, '41097', '142.50', 1),
(21198, '42945', '81.50', 1),
(21198, '49919', '58.50', 1),
(21198, '80088', '213.00', 2),
(21199, '13001', '38.00', 2),
(21199, '32069', '154.00', 2),
(21199, '35911', '11.50', 5),
(21199, '41098', '83.00', 5),
(21199, '43000', '540.00', 2),
(21199, '49921', '357.00', 2),
(21199, '80692', '39.50', 2),
(21200, '15207', '24.50', 5),
(21200, '32191', '402.00', 2),
(21200, '35912', '11.50', 2),
(21200, '42613', '106.00', 5),
(21200, '43014', '372.00', 5),
(21200, '55112', '598.50', 3),
(21200, '81007', '62.50', 2),
(21201, '15208', '24.50', 2),
(21201, '32610', '106.50', 5),
(21201, '37710', '35.00', 3),
(21201, '42615', '106.00', 2),
(21201, '43015', '288.00', 1),
(21201, '55129', '154.00', 5),
(21201, '82090', '30.00', 3),
(21202, '15211', '209.00', 1),
(21202, '33044', '14.50', 3),
(21202, '37720', '42.00', 5),
(21202, '42626', '141.50', 1),
(21202, '44939', '115.00', 2),
(21202, '55130', '298.50', 2),
(21202, '82092', '18.00', 3),
(21203, '15217', '32.00', 2),
(21203, '33045', '17.50', 5),
(21203, '37725', '36.00', 3),
(21203, '42929', '83.00', 1),
(21203, '45101', '57.00', 5),
(21203, '55550', '1558.50', 5),
(21203, '82093', '24.00', 5),
(21204, '15559', '38.00', 1),
(21204, '33046', '15.00', 10),
(21204, '37730', '23.50', 1),
(21204, '42933', '69.50', 5),
(21204, '45105', '45.00', 5),
(21204, '58028', '142.50', 5),
(21204, '82095', '23.50', 2),
(21205, '20936', '25.00', 5),
(21205, '33047', '16.00', 5),
(21205, '37731', '30.00', 4),
(21205, '42934', '69.50', 5),
(21205, '45923', '42.00', 5),
(21205, '59915', '25.00', 5),
(21205, '82096', '27.50', 1),
(21206, '35911', '11.50', 5),
(21206, '42939', '95.00', 3),
(21206, '45935', '19.50', 1),
(21207, '35912', '11.50', 1),
(21207, '42941', '71.00', 2),
(21207, '46702', '71.50', 5),
(21208, '37710', '35.00', 5),
(21208, '42945', '81.50', 3),
(21208, '46706', '27.50', 3),
(21209, '33047', '16.00', 1),
(21209, '37720', '42.00', 1),
(21209, '43000', '540.00', 5),
(21210, '35911', '11.50', 3),
(21210, '37725', '36.00', 2),
(21210, '43014', '372.00', 2),
(21211, '35912', '11.50', 2),
(21211, '37730', '23.50', 3),
(21211, '43015', '288.00', 3),
(21212, '37710', '35.00', 5),
(21212, '37731', '30.00', 6),
(21212, '44939', '115.00', 5),
(21213, '37720', '42.00', 5),
(21213, '37732', '27.00', 1),
(21213, '45101', '57.00', 1),
(21214, '37725', '36.00', 5),
(21214, '41020', '94.50', 3),
(21214, '45105', '45.00', 2),
(21215, '37730', '23.50', 2),
(21215, '41096', '115.00', 2),
(21215, '45923', '42.00', 1),
(21216, '37731', '30.00', 8),
(21216, '41097', '142.50', 2),
(21216, '45935', '19.50', 3),
(21217, '10820', '46.50', 1),
(21217, '41098', '83.00', 5),
(21217, '46702', '71.50', 2),
(21218, '10822', '46.50', 3),
(21218, '42613', '106.00', 1),
(21218, '46706', '27.50', 2),
(21219, '10830', '57.50', 3),
(21219, '42615', '106.00', 3),
(21219, '46738', '40.00', 5),
(21220, '10835', '83.00', 1),
(21220, '42626', '141.50', 5),
(21220, '46741', '10.00', 5),
(21221, '10854', '39.50', 5),
(21221, '42929', '83.00', 5),
(21221, '46745', '43.50', 2),
(21222, '11630', '46.50', 2),
(21222, '42933', '69.50', 3),
(21222, '47903', '11214.00', 2),
(21223, '12054', '358.50', 5),
(21223, '42934', '69.50', 2),
(21223, '49916', '25.00', 3),
(21224, '12055', '238.50', 7),
(21224, '42939', '95.00', 2),
(21224, '49917', '25.50', 1),
(21225, '12056', '191.50', 1),
(21225, '42941', '71.00', 2),
(21225, '49919', '58.50', 3),
(21226, '12088', '215.00', 1),
(21226, '42945', '81.50', 2),
(21226, '49921', '357.00', 5),
(21227, '12089', '144.00', 2),
(21227, '43000', '540.00', 2),
(21227, '55112', '598.50', 2),
(21228, '12090', '192.00', 3),
(21228, '43014', '372.00', 5),
(21228, '55129', '154.00', 1),
(21229, '12091', '286.50', 3),
(21229, '43015', '288.00', 2),
(21229, '55130', '298.50', 1),
(21230, '12092', '238.50', 15),
(21230, '44939', '115.00', 5),
(21230, '55550', '1558.50', 5),
(21231, '13001', '38.00', 3),
(21231, '45101', '57.00', 3),
(21231, '58028', '142.50', 5),
(21232, '15207', '24.50', 1),
(21232, '45105', '45.00', 5),
(21232, '59915', '25.00', 2),
(21233, '15208', '24.50', 3),
(21233, '45923', '42.00', 5),
(21233, '64509', '142.00', 1),
(21234, '15211', '209.00', 3),
(21234, '45935', '19.50', 2),
(21234, '64510', '154.00', 3),
(21235, '15217', '32.00', 1),
(21235, '46702', '71.50', 1),
(21235, '64511', '227.50', 5),
(21236, '15559', '38.00', 5),
(21236, '46706', '27.50', 5),
(21236, '64550', '126.00', 1),
(21237, '20936', '25.00', 5),
(21237, '46738', '40.00', 3),
(21237, '64551', '118.00', 1),
(21238, '20980', '27.50', 1),
(21238, '46741', '10.00', 2),
(21238, '64552', '276.00', 5),
(21239, '21032', '57.50', 2),
(21239, '46745', '43.50', 5),
(21239, '65032', '598.50', 5),
(21240, '21034', '504.00', 3),
(21240, '47903', '11214.00', 1),
(21240, '65033', '1044.00', 2),
(21241, '21037', '294.00', 1),
(21241, '49916', '25.00', 2),
(21241, '65034', '15000.00', 5),
(21242, '21510', '35.50', 5),
(21242, '49917', '25.50', 3),
(21242, '65060', '46.50', 5),
(21243, '21514', '28.00', 5),
(21243, '65070', '118.50', 2),
(21244, '21515', '27.00', 3),
(21244, '65080', '478.00', 3),
(21245, '21517', '16.00', 3),
(21245, '65081', '112.00', 5),
(21246, '21580', '13.50', 5),
(21246, '65082', '174.00', 1),
(21247, '22002', '55.50', 2),
(21247, '65122', '1558.00', 5),
(21248, '22054', '70.50', 1),
(21248, '65142', '93.00', 1),
(21249, '22055', '214.50', 5),
(21249, '65143', '83.50', 2),
(21250, '22056', '130.00', 2),
(21250, '65147', '238.50', 5),
(21251, '22165', '5400.00', 1),
(21251, '64509', '142.00', 3),
(21251, '65190', '190.50', 2),
(21252, '22179', '1440.00', 5),
(21252, '64510', '154.00', 2),
(21252, '65191', '23.00', 3),
(21253, '22870', '21.00', 1),
(21253, '64511', '227.50', 2),
(21253, '65247', '75.00', 1),
(21254, '25079', '334.00', 1),
(21254, '64550', '126.00', 3),
(21254, '71912', '35.00', 3),
(21255, '25121', '418.50', 2),
(21255, '64551', '118.00', 5),
(21255, '72777', '154.00', 5),
(21256, '25131', '1078.00', 2),
(21256, '64552', '276.00', 3),
(21256, '72942', '35.50', 1),
(21257, '25136', '180.00', 3),
(21257, '65032', '598.50', 1),
(21257, '72943', '35.50', 3),
(21258, '25137', '228.00', 3),
(21258, '65033', '1044.00', 5),
(21258, '72944', '42.00', 2),
(21259, '25138', '166.50', 3),
(21259, '65034', '15000.00', 1),
(21259, '76032', '334.50', 2),
(21260, '25154', '276.00', 2),
(21260, '65060', '46.50', 1),
(21260, '77033', '358.00', 3),
(21261, '32055', '130.50', 5),
(21261, '65070', '118.50', 5),
(21261, '77036', '358.00', 2),
(21262, '32067', '94.50', 2),
(21262, '65080', '478.00', 2),
(21262, '77038', '478.00', 5),
(21263, '32069', '154.00', 1),
(21263, '65081', '112.00', 3),
(21263, '77249', '1558.00', 1),
(21264, '32191', '402.00', 5),
(21264, '65082', '174.00', 3),
(21264, '77251', '658.00', 5),
(21265, '32610', '106.50', 2),
(21265, '65122', '1558.00', 3),
(21265, '77252', '34.50', 3),
(21266, '33044', '14.50', 2),
(21266, '65142', '93.00', 3),
(21266, '77276', '4558.00', 1),
(21267, '33045', '17.50', 2),
(21267, '65143', '83.50', 5),
(21267, '77277', '358.00', 2),
(21268, '33046', '15.00', 13),
(21268, '65147', '238.50', 2),
(21268, '78029', '142.50', 1),
(21269, '33047', '16.00', 2),
(21269, '65190', '190.50', 5),
(21269, '80032', '154.50', 5),
(21270, '35911', '11.50', 2),
(21270, '65191', '23.00', 2),
(21270, '80082', '118.50', 1),
(21271, '35912', '11.50', 5),
(21271, '65247', '75.00', 3),
(21271, '80088', '213.00', 5),
(21272, '37710', '35.00', 5),
(21272, '71912', '35.00', 2),
(21272, '80692', '39.50', 1),
(21273, '37720', '42.00', 5),
(21273, '72777', '154.00', 5),
(21273, '81007', '62.50', 1),
(21274, '37725', '36.00', 1),
(21274, '72942', '35.50', 2),
(21274, '82090', '30.00', 2),
(21275, '37730', '23.50', 5),
(21275, '72943', '35.50', 5),
(21275, '82092', '18.00', 2),
(21276, '37731', '30.00', 3),
(21276, '72944', '42.00', 1),
(21276, '82093', '24.00', 1),
(21277, '37732', '27.00', 5),
(21277, '76032', '334.50', 1),
(21277, '82095', '23.50', 1),
(21278, '77033', '358.00', 5),
(21278, '82096', '27.50', 3),
(21279, '77036', '358.00', 1),
(21279, '83013', '46.00', 5),
(21280, '77038', '478.00', 2),
(21280, '90106', '38.00', 2),
(21281, '77249', '1558.00', 2),
(21281, '90109', '40.50', 1),
(21282, '77251', '658.00', 2),
(21282, '90116', '50.00', 3),
(21283, '77252', '34.50', 2),
(21283, '90164', '75.50', 2),
(21284, '77276', '4558.00', 3),
(21284, '90192', '70.50', 3),
(21285, '77277', '358.00', 3),
(21285, '90208', '71.00', 5),
(21286, '78029', '142.50', 2),
(21286, '90209', '71.00', 1),
(21287, '80032', '154.50', 1),
(21287, '90212', '71.00', 3),
(21288, '80082', '118.50', 5),
(21288, '90510', '430.50', 3),
(21289, '90521', '142.50', 5),
(21290, '90531', '83.00', 2),
(21291, '90545', '288.00', 2),
(21292, '90693', '57.00', 5),
(21293, '90737', '354.00', 2),
(21294, '91008', '94.00', 3),
(21295, '92606', '106.00', 5),
(21296, '65070', '118.50', 1),
(21297, '65080', '478.00', 1),
(21297, '83013', '46.00', 2),
(21298, '65081', '112.00', 2),
(21298, '90106', '38.00', 5),
(21299, '65082', '174.00', 2),
(21299, '90109', '40.50', 3),
(21300, '65122', '1558.00', 5),
(21300, '90116', '50.00', 5),
(21301, '65142', '93.00', 5),
(21301, '90164', '75.50', 5),
(21302, '49916', '25.00', 1),
(21302, '90192', '70.50', 2),
(21303, '49917', '25.50', 2),
(21303, '90208', '71.00', 2),
(21304, '49919', '58.50', 2),
(21304, '90209', '71.00', 5),
(21305, '90212', '71.00', 1),
(21306, '90510', '430.50', 2),
(21307, '90521', '142.50', 2),
(21308, '90531', '83.00', 5),
(21309, '90545', '288.00', 5),
(21310, '90693', '57.00', 5),
(21311, '90737', '354.00', 5),
(21312, '91008', '94.00', 2),
(21313, '58028', '142.50', 5),
(21313, '92606', '106.00', 2),
(21314, '21517', '16.00', 2),
(21314, '59915', '25.00', 3),
(21315, '21580', '13.50', 2),
(21315, '64509', '142.00', 2),
(21316, '22002', '55.50', 5),
(21316, '64510', '154.00', 1),
(21317, '10820', '46.50', 1),
(21317, '64511', '227.50', 5),
(21318, '10822', '46.50', 5),
(21318, '64550', '126.00', 2),
(21319, '10830', '57.50', 5),
(21319, '64551', '118.00', 1),
(21320, '10835', '83.00', 1),
(21320, '64552', '276.00', 5),
(21321, '10854', '39.50', 5),
(21321, '65032', '598.50', 5),
(21322, '11630', '46.50', 1),
(21322, '65033', '1044.00', 2),
(21323, '12054', '358.50', 1),
(21323, '65034', '15000.00', 3),
(21324, '12055', '238.50', 9),
(21324, '65060', '46.50', 3),
(21325, '12056', '191.50', 3),
(21325, '65070', '118.50', 3),
(21326, '12088', '215.00', 5),
(21326, '65080', '478.00', 3),
(21327, '12089', '144.00', 5),
(21327, '43015', '288.00', 1),
(21327, '65081', '112.00', 5),
(21328, '12090', '192.00', 5),
(21328, '44939', '115.00', 1),
(21328, '65082', '174.00', 1),
(21329, '12091', '286.50', 2),
(21329, '45101', '57.00', 3),
(21329, '65122', '1558.00', 1),
(21330, '45105', '45.00', 1),
(21330, '65142', '93.00', 5),
(21331, '45923', '42.00', 2),
(21331, '65143', '83.50', 2),
(21332, '45935', '19.50', 1),
(21332, '65147', '238.50', 10),
(21333, '46702', '71.50', 3),
(21333, '65190', '190.50', 1),
(21334, '46706', '27.50', 2),
(21334, '65191', '23.00', 5),
(21335, '33047', '16.00', 5),
(21335, '65247', '75.00', 5),
(21336, '35911', '11.50', 1),
(21336, '71912', '35.00', 2),
(21337, '35912', '11.50', 3),
(21337, '72777', '154.00', 3),
(21338, '20980', '27.50', 1),
(21338, '37710', '35.00', 1),
(21338, '72942', '35.50', 1),
(21339, '21032', '57.50', 1),
(21339, '37720', '42.00', 5),
(21339, '72943', '35.50', 5),
(21340, '21034', '504.00', 2),
(21340, '37725', '36.00', 3),
(21340, '72944', '42.00', 2),
(21341, '21037', '294.00', 3),
(21341, '37730', '23.50', 3),
(21341, '76032', '334.50', 3),
(21342, '21510', '35.50', 1),
(21342, '37731', '30.00', 5),
(21342, '77033', '358.00', 2),
(21343, '10820', '46.50', 5),
(21343, '21514', '28.00', 1),
(21343, '77036', '358.00', 5),
(21344, '10822', '46.50', 5),
(21344, '21515', '27.00', 5),
(21344, '77038', '478.00', 5),
(21345, '10830', '57.50', 3),
(21345, '21517', '16.00', 1),
(21345, '77249', '1558.00', 3),
(21346, '10835', '83.00', 2),
(21346, '21580', '13.50', 1),
(21346, '77251', '658.00', 5),
(21347, '10854', '39.50', 1),
(21347, '22002', '55.50', 1),
(21347, '77252', '34.50', 5),
(21348, '11630', '46.50', 3),
(21348, '22054', '70.50', 1),
(21348, '77276', '4558.00', 5),
(21349, '12054', '358.50', 2),
(21349, '22055', '214.50', 2),
(21349, '77277', '358.00', 1),
(21350, '12055', '238.50', 13),
(21350, '22056', '130.00', 5),
(21350, '78029', '142.50', 1),
(21351, '12056', '191.50', 2),
(21351, '22165', '5400.00', 3),
(21351, '80032', '154.50', 3),
(21352, '12088', '215.00', 2),
(21352, '22179', '1440.00', 3),
(21352, '80082', '118.50', 5),
(21353, '12089', '144.00', 1),
(21353, '22870', '21.00', 1),
(21353, '80088', '213.00', 1),
(21354, '12090', '192.00', 2),
(21354, '25079', '334.00', 3),
(21354, '80692', '39.50', 3),
(21355, '12091', '286.50', 2),
(21355, '25121', '418.50', 5),
(21355, '81007', '62.50', 3),
(21356, '12092', '238.50', 3),
(21356, '25131', '1078.00', 5),
(21356, '82090', '30.00', 2),
(21357, '13001', '38.00', 5),
(21357, '25136', '180.00', 2),
(21357, '82092', '18.00', 5),
(21358, '15207', '24.50', 5),
(21358, '25137', '228.00', 2),
(21358, '82093', '24.00', 5),
(21359, '15208', '24.50', 2),
(21359, '25138', '166.50', 2),
(21359, '82095', '23.50', 2),
(21360, '15211', '209.00', 2),
(21360, '25154', '276.00', 2),
(21360, '82096', '27.50', 4),
(21361, '15217', '32.00', 3),
(21361, '32055', '130.50', 1),
(21361, '83013', '46.00', 5),
(21362, '15559', '38.00', 1),
(21362, '32067', '94.50', 5),
(21362, '90106', '38.00', 5),
(21363, '20936', '25.00', 5),
(21363, '32069', '154.00', 5),
(21363, '90109', '40.50', 2),
(21364, '20980', '27.50', 7),
(21364, '32191', '402.00', 1),
(21364, '90116', '50.00', 2),
(21365, '21032', '57.50', 2),
(21365, '32610', '106.50', 1),
(21365, '90164', '75.50', 1),
(21366, '21034', '504.00', 5),
(21366, '33044', '14.50', 5),
(21366, '90192', '70.50', 3),
(21367, '21037', '294.00', 5),
(21367, '33045', '17.50', 5),
(21367, '90208', '71.00', 3),
(21368, '21510', '35.50', 3),
(21368, '33046', '15.00', 3),
(21368, '90209', '71.00', 2),
(21369, '21514', '28.00', 3),
(21369, '90212', '71.00', 1),
(21370, '21515', '27.00', 3),
(21370, '90510', '430.50', 5),
(21371, '21517', '16.00', 5),
(21371, '90521', '142.50', 3),
(21372, '21580', '13.50', 3),
(21372, '90531', '83.00', 5),
(21373, '22002', '55.50', 5),
(21373, '90545', '288.00', 3),
(21374, '22054', '70.50', 2),
(21374, '90693', '57.00', 2),
(21375, '22055', '214.50', 5),
(21375, '90737', '354.00', 2),
(21376, '22056', '130.00', 1),
(21376, '91008', '94.00', 5),
(21377, '22165', '5400.00', 5),
(21377, '37732', '27.00', 2),
(21377, '92606', '106.00', 5),
(21378, '10820', '46.50', 2),
(21378, '22179', '1440.00', 2),
(21378, '41020', '94.50', 2),
(21379, '10822', '46.50', 5),
(21379, '22870', '21.00', 3),
(21379, '41096', '115.00', 3),
(21380, '10830', '57.50', 1),
(21380, '25079', '334.00', 2),
(21380, '41097', '142.50', 2),
(21381, '10835', '83.00', 5),
(21381, '25121', '418.50', 1),
(21381, '41098', '83.00', 2),
(21382, '10854', '39.50', 5),
(21382, '25131', '1078.00', 2),
(21382, '42613', '106.00', 5),
(21383, '11630', '46.50', 2),
(21383, '25136', '180.00', 5),
(21383, '42615', '106.00', 1),
(21384, '12054', '358.50', 5),
(21384, '25137', '228.00', 2),
(21384, '42626', '141.50', 1),
(21385, '12055', '238.50', 4),
(21385, '25138', '166.50', 5),
(21385, '42929', '83.00', 1),
(21386, '12056', '191.50', 2),
(21386, '25154', '276.00', 1),
(21386, '42933', '69.50', 5),
(21387, '12088', '215.00', 5),
(21387, '32055', '130.50', 5),
(21387, '42934', '69.50', 2),
(21388, '12089', '144.00', 5),
(21388, '32067', '94.50', 1),
(21388, '42939', '95.00', 5),
(21389, '12090', '192.00', 5),
(21389, '32069', '154.00', 5),
(21389, '42941', '71.00', 3),
(21390, '12091', '286.50', 5),
(21390, '32191', '402.00', 2),
(21390, '42945', '81.50', 2),
(21391, '12092', '238.50', 6),
(21391, '32610', '106.50', 3),
(21391, '43000', '540.00', 5),
(21391, '49921', '357.00', 5),
(21392, '13001', '38.00', 1),
(21392, '33044', '14.50', 1),
(21392, '43014', '372.00', 5),
(21392, '55112', '598.50', 1),
(21393, '15207', '24.50', 5),
(21393, '33045', '17.50', 1),
(21393, '43015', '288.00', 2),
(21393, '55129', '154.00', 3),
(21394, '15208', '24.50', 5),
(21394, '33046', '15.00', 4),
(21394, '44939', '115.00', 2),
(21394, '55130', '298.50', 3),
(21395, '15211', '209.00', 5),
(21395, '33047', '16.00', 5),
(21395, '45101', '57.00', 5),
(21395, '55550', '1558.50', 1),
(21396, '15217', '32.00', 5),
(21396, '35911', '11.50', 2),
(21396, '45105', '45.00', 2),
(21396, '58028', '142.50', 2),
(21397, '15559', '38.00', 5),
(21397, '35912', '11.50', 5),
(21397, '45923', '42.00', 5),
(21397, '59915', '25.00', 2),
(21398, '20936', '25.00', 5),
(21398, '37710', '35.00', 3),
(21398, '45935', '19.50', 3),
(21398, '64509', '142.00', 2),
(21399, '20980', '27.50', 15),
(21399, '37720', '42.00', 1),
(21399, '46702', '71.50', 5),
(21399, '64510', '154.00', 2),
(21400, '21032', '57.50', 3),
(21400, '37725', '36.00', 2),
(21400, '46706', '27.50', 5),
(21400, '64511', '227.50', 1),
(21401, '21034', '504.00', 1),
(21401, '37730', '23.50', 5),
(21401, '46738', '40.00', 2),
(21401, '64550', '126.00', 5),
(21402, '21037', '294.00', 5),
(21402, '37731', '30.00', 1),
(21402, '41020', '94.50', 3),
(21402, '46741', '10.00', 1),
(21402, '64551', '118.00', 5),
(21402, '64552', '276.00', 3),
(21403, '21510', '35.50', 5),
(21403, '37732', '27.00', 5),
(21403, '41096', '115.00', 2),
(21403, '42615', '106.00', 5),
(21403, '46745', '43.50', 1),
(21403, '65032', '598.50', 3),
(21404, '21514', '28.00', 2),
(21404, '41020', '94.50', 5),
(21404, '41097', '142.50', 5),
(21404, '42626', '141.50', 5),
(21404, '47903', '11214.00', 3),
(21404, '65033', '1044.00', 5),
(21405, '21515', '27.00', 2),
(21405, '41096', '115.00', 5),
(21405, '41098', '83.00', 5),
(21405, '42929', '83.00', 1),
(21405, '49916', '25.00', 5),
(21405, '65034', '15000.00', 2),
(21406, '21517', '16.00', 3),
(21406, '41097', '142.50', 1),
(21406, '42613', '106.00', 1),
(21406, '42933', '69.50', 1),
(21406, '49917', '25.50', 2),
(21406, '65060', '46.50', 1),
(21407, '21580', '13.50', 5),
(21407, '41098', '83.00', 1),
(21407, '42615', '106.00', 5),
(21407, '42934', '69.50', 3),
(21407, '49919', '58.50', 5),
(21407, '65070', '118.50', 5),
(21408, '21515', '27.00', 1),
(21408, '22002', '55.50', 1),
(21408, '42613', '106.00', 2),
(21408, '42626', '141.50', 2),
(21408, '42939', '95.00', 1),
(21408, '49921', '357.00', 1),
(21408, '65080', '478.00', 2),
(21408, '82096', '27.50', 2),
(21409, '21517', '16.00', 2),
(21409, '22054', '70.50', 5),
(21409, '42615', '106.00', 5),
(21409, '42929', '83.00', 3),
(21409, '42941', '71.00', 2),
(21409, '55112', '598.50', 5),
(21409, '65081', '112.00', 2),
(21409, '83013', '46.00', 5),
(21410, '21580', '13.50', 2),
(21410, '22055', '214.50', 5),
(21410, '42626', '141.50', 5),
(21410, '42933', '69.50', 5),
(21410, '42945', '81.50', 5),
(21410, '55129', '154.00', 5),
(21410, '65082', '174.00', 3),
(21410, '90106', '38.00', 2),
(21411, '22002', '55.50', 3),
(21411, '22056', '130.00', 5),
(21411, '42929', '83.00', 5),
(21411, '42934', '69.50', 2),
(21411, '43000', '540.00', 1),
(21411, '55130', '298.50', 2),
(21411, '65122', '1558.00', 2),
(21411, '90109', '40.50', 1),
(21412, '22054', '70.50', 1),
(21412, '22165', '5400.00', 5),
(21412, '42933', '69.50', 5),
(21412, '42939', '95.00', 3),
(21412, '43014', '372.00', 1),
(21412, '55550', '1558.50', 5),
(21412, '65142', '93.00', 3),
(21412, '90116', '50.00', 5),
(21413, '22055', '214.50', 1),
(21413, '22179', '1440.00', 5),
(21413, '42934', '69.50', 5),
(21413, '42941', '71.00', 5),
(21413, '58028', '142.50', 3),
(21413, '65143', '83.50', 1),
(21413, '90164', '75.50', 3),
(21414, '22056', '130.00', 1),
(21414, '22870', '21.00', 2),
(21414, '42939', '95.00', 2),
(21414, '42945', '81.50', 1),
(21414, '59915', '25.00', 1),
(21414, '65147', '238.50', 8),
(21414, '90192', '70.50', 3),
(21415, '22165', '5400.00', 3),
(21415, '25079', '334.00', 5),
(21415, '42941', '71.00', 3),
(21415, '43000', '540.00', 3),
(21415, '64509', '142.00', 5),
(21415, '65190', '190.50', 3),
(21415, '90208', '71.00', 1),
(21416, '22179', '1440.00', 2),
(21416, '25121', '418.50', 3),
(21416, '42945', '81.50', 3),
(21416, '43014', '372.00', 5),
(21416, '64510', '154.00', 2),
(21416, '65191', '23.00', 1),
(21416, '90209', '71.00', 2),
(21417, '22870', '21.00', 5),
(21417, '25131', '1078.00', 5),
(21417, '43000', '540.00', 2),
(21417, '43015', '288.00', 5),
(21417, '64511', '227.50', 2),
(21417, '65247', '75.00', 5),
(21417, '90212', '71.00', 5),
(21418, '25079', '334.00', 1),
(21418, '25136', '180.00', 1),
(21418, '43014', '372.00', 1),
(21418, '44939', '115.00', 1),
(21418, '64550', '126.00', 1),
(21418, '71912', '35.00', 5),
(21418, '90510', '430.50', 1),
(21419, '25121', '418.50', 2),
(21419, '25137', '228.00', 5),
(21419, '43015', '288.00', 1),
(21419, '45101', '57.00', 2),
(21419, '64551', '118.00', 2),
(21419, '72777', '154.00', 1),
(21419, '90521', '142.50', 2),
(21420, '25131', '1078.00', 1),
(21420, '25138', '166.50', 1),
(21420, '44939', '115.00', 3),
(21420, '45105', '45.00', 5),
(21420, '64552', '276.00', 5),
(21420, '72942', '35.50', 5),
(21420, '90531', '83.00', 5),
(21421, '25136', '180.00', 5),
(21421, '25154', '276.00', 2),
(21421, '45101', '57.00', 1),
(21421, '45923', '42.00', 3),
(21421, '65032', '598.50', 5),
(21421, '72943', '35.50', 3),
(21421, '90545', '288.00', 3),
(21422, '32055', '130.50', 1),
(21422, '45105', '45.00', 2),
(21422, '45935', '19.50', 2),
(21422, '65033', '1044.00', 1),
(21422, '72944', '42.00', 2),
(21423, '32067', '94.50', 2),
(21423, '45923', '42.00', 2),
(21423, '46702', '71.50', 2),
(21423, '65034', '15000.00', 1),
(21423, '76032', '334.50', 2),
(21424, '32069', '154.00', 3),
(21424, '45935', '19.50', 5),
(21424, '46706', '27.50', 9),
(21424, '65060', '46.50', 3),
(21424, '77033', '358.00', 3),
(21425, '32191', '402.00', 5),
(21425, '46702', '71.50', 5),
(21425, '46738', '40.00', 5),
(21425, '65070', '118.50', 3),
(21425, '77036', '358.00', 2),
(21426, '32610', '106.50', 5),
(21426, '46706', '27.50', 10),
(21426, '46741', '10.00', 4),
(21426, '65080', '478.00', 5),
(21426, '77038', '478.00', 5),
(21427, '33044', '14.50', 5),
(21427, '46738', '40.00', 2),
(21427, '46745', '43.50', 3),
(21427, '65081', '112.00', 1),
(21427, '77249', '1558.00', 1),
(21428, '33045', '17.50', 2),
(21428, '46741', '10.00', 7),
(21428, '47903', '11214.00', 2),
(21428, '65082', '174.00', 2),
(21428, '77251', '658.00', 1),
(21429, '33046', '15.00', 6),
(21429, '46745', '43.50', 2),
(21429, '49916', '25.00', 5),
(21429, '65122', '1558.00', 3),
(21429, '77252', '34.50', 1),
(21430, '33047', '16.00', 5),
(21430, '47903', '11214.00', 5),
(21430, '49917', '25.50', 5),
(21430, '65142', '93.00', 2),
(21430, '77276', '4558.00', 2),
(21431, '35911', '11.50', 1),
(21431, '49916', '25.00', 1),
(21431, '49919', '58.50', 1),
(21431, '65143', '83.50', 3),
(21431, '77277', '358.00', 1),
(21432, '35912', '11.50', 3),
(21432, '49917', '25.50', 1),
(21432, '49921', '357.00', 5),
(21432, '65147', '238.50', 2),
(21432, '78029', '142.50', 5),
(21433, '37710', '35.00', 2),
(21433, '49919', '58.50', 5),
(21433, '55112', '598.50', 3),
(21433, '65190', '190.50', 2),
(21433, '80032', '154.50', 2),
(21434, '37720', '42.00', 5),
(21434, '49921', '357.00', 1),
(21434, '55129', '154.00', 5),
(21434, '65191', '23.00', 3),
(21434, '80082', '118.50', 2),
(21435, '37725', '36.00', 5),
(21435, '55112', '598.50', 2),
(21435, '55130', '298.50', 5),
(21435, '65247', '75.00', 3),
(21435, '80088', '213.00', 3),
(21436, '37730', '23.50', 1),
(21436, '55129', '154.00', 2),
(21436, '55550', '1558.50', 1),
(21436, '71912', '35.00', 5),
(21436, '80692', '39.50', 5),
(21437, '37731', '30.00', 3),
(21437, '55130', '298.50', 1),
(21437, '72777', '154.00', 5),
(21438, '37732', '27.00', 3),
(21438, '55550', '1558.50', 5),
(21438, '72942', '35.50', 2),
(21439, '41020', '94.50', 5),
(21439, '58028', '142.50', 1),
(21439, '72943', '35.50', 5),
(21440, '41096', '115.00', 2),
(21440, '59915', '25.00', 5),
(21440, '72944', '42.00', 1),
(21441, '41097', '142.50', 3),
(21441, '64509', '142.00', 1),
(21441, '76032', '334.50', 5),
(21442, '41098', '83.00', 3),
(21442, '64510', '154.00', 5),
(21442, '77033', '358.00', 3),
(21443, '42613', '106.00', 1),
(21443, '64511', '227.50', 5),
(21443, '77036', '358.00', 2),
(21444, '42615', '106.00', 2),
(21444, '64550', '126.00', 5),
(21444, '77038', '478.00', 1),
(21445, '42626', '141.50', 1),
(21445, '64551', '118.00', 5),
(21445, '77249', '1558.00', 2),
(21446, '42929', '83.00', 2),
(21446, '64552', '276.00', 5),
(21446, '77251', '658.00', 3),
(21447, '42933', '69.50', 1),
(21447, '77252', '34.50', 3),
(21448, '42934', '69.50', 5),
(21448, '77276', '4558.00', 5),
(21449, '42939', '95.00', 1),
(21449, '77277', '358.00', 5),
(21450, '42941', '71.00', 1),
(21450, '78029', '142.50', 2),
(21451, '42945', '81.50', 2),
(21451, '80032', '154.50', 1),
(21452, '43000', '540.00', 2),
(21452, '80082', '118.50', 5),
(21453, '43014', '372.00', 5),
(21453, '80088', '213.00', 2),
(21454, '43015', '288.00', 2),
(21454, '80692', '39.50', 3),
(21455, '44939', '115.00', 5),
(21455, '81007', '62.50', 2),
(21456, '45101', '57.00', 3),
(21456, '82090', '30.00', 2),
(21457, '45105', '45.00', 5),
(21457, '82092', '18.00', 2),
(21458, '45923', '42.00', 3),
(21458, '82093', '24.00', 1),
(21459, '45935', '19.50', 1),
(21459, '82095', '23.50', 5),
(21460, '46702', '71.50', 5),
(21461, '46706', '27.50', 13),
(21462, '46738', '40.00', 1),
(21463, '46741', '10.00', 15),
(21464, '46745', '43.50', 2),
(21465, '47903', '11214.00', 1),
(21466, '49916', '25.00', 2),
(21467, '49917', '25.50', 3),
(21468, '49919', '58.50', 1),
(21469, '49921', '357.00', 5),
(21469, '77036', '358.00', 1),
(21470, '55112', '598.50', 5),
(21470, '77038', '478.00', 5),
(21471, '55129', '154.00', 1),
(21471, '77249', '1558.00', 5),
(21472, '55130', '298.50', 3),
(21472, '77251', '658.00', 2),
(21473, '55550', '1558.50', 2),
(21473, '77252', '34.50', 2),
(21474, '58028', '142.50', 1),
(21474, '77276', '4558.00', 5),
(21474, '90693', '57.00', 5),
(21475, '59915', '25.00', 5),
(21475, '77277', '358.00', 3),
(21475, '90737', '354.00', 5),
(21476, '64509', '142.00', 3),
(21476, '78029', '142.50', 3),
(21476, '91008', '94.00', 1),
(21477, '64510', '154.00', 5),
(21477, '80032', '154.50', 3),
(21477, '92606', '106.00', 5),
(21478, '10820', '46.50', 5),
(21478, '64511', '227.50', 2),
(21478, '80082', '118.50', 2),
(21479, '10822', '46.50', 2),
(21479, '64550', '126.00', 1),
(21479, '80088', '213.00', 2),
(21480, '10830', '57.50', 2),
(21480, '64551', '118.00', 1),
(21480, '80692', '39.50', 2),
(21481, '10835', '83.00', 5),
(21481, '64552', '276.00', 5),
(21481, '81007', '62.50', 5),
(21482, '10854', '39.50', 5),
(21482, '65032', '598.50', 2),
(21482, '82090', '30.00', 2),
(21483, '11630', '46.50', 5),
(21483, '65033', '1044.00', 3),
(21483, '82092', '18.00', 1),
(21484, '12054', '358.50', 2),
(21484, '65034', '15000.00', 3),
(21484, '82093', '24.00', 3),
(21485, '12055', '238.50', 3),
(21485, '65060', '46.50', 5),
(21485, '82095', '23.50', 1),
(21486, '12056', '191.50', 5),
(21486, '65070', '118.50', 1),
(21486, '82096', '27.50', 3),
(21487, '12088', '215.00', 1),
(21487, '65080', '478.00', 1),
(21487, '83013', '46.00', 1),
(21488, '12089', '144.00', 1),
(21488, '65081', '112.00', 3),
(21488, '90106', '38.00', 2),
(21489, '12090', '192.00', 5),
(21489, '65082', '174.00', 5),
(21489, '90109', '40.50', 3),
(21490, '12091', '286.50', 1),
(21490, '65122', '1558.00', 1),
(21490, '90116', '50.00', 5),
(21491, '12092', '238.50', 5),
(21491, '65142', '93.00', 5),
(21491, '90164', '75.50', 2),
(21492, '13001', '38.00', 1),
(21492, '65143', '83.50', 5),
(21492, '90192', '70.50', 2),
(21493, '15207', '24.50', 1),
(21493, '65147', '238.50', 2),
(21493, '90208', '71.00', 5),
(21494, '15208', '24.50', 5),
(21494, '65190', '190.50', 5),
(21494, '90209', '71.00', 1),
(21495, '15211', '209.00', 1),
(21495, '65191', '23.00', 2),
(21495, '90212', '71.00', 3),
(21496, '15217', '32.00', 2),
(21496, '65247', '75.00', 2),
(21496, '90510', '430.50', 3),
(21497, '15559', '38.00', 4),
(21497, '71912', '35.00', 5),
(21497, '90521', '142.50', 2),
(21498, '20936', '25.00', 1),
(21498, '72777', '154.00', 1),
(21498, '90531', '83.00', 2),
(21499, '20980', '27.50', 4),
(21499, '72942', '35.50', 2),
(21499, '90545', '288.00', 1),
(21500, '21032', '57.50', 5),
(21500, '72943', '35.50', 1),
(21500, '90693', '57.00', 2),
(21501, '21034', '504.00', 3),
(21501, '72944', '42.00', 2),
(21501, '90737', '354.00', 1),
(21502, '21037', '294.00', 3),
(21502, '76032', '334.50', 1),
(21502, '91008', '94.00', 5),
(21503, '21510', '35.50', 3),
(21503, '77033', '358.00', 2),
(21503, '92606', '106.00', 2),
(21504, '21514', '28.00', 5),
(21504, '22165', '5400.00', 2),
(21504, '77036', '358.00', 5),
(21505, '22179', '1440.00', 1),
(21505, '77038', '478.00', 5),
(21506, '22870', '21.00', 1),
(21506, '77249', '1558.00', 3),
(21507, '25079', '334.00', 3),
(21507, '77251', '658.00', 2),
(21508, '25121', '418.50', 5),
(21508, '77252', '34.50', 5),
(21509, '25131', '1078.00', 3),
(21509, '77276', '4558.00', 1),
(21510, '25136', '180.00', 1),
(21510, '77277', '358.00', 1),
(21511, '25137', '228.00', 1),
(21511, '78029', '142.50', 5),
(21512, '25138', '166.50', 3),
(21512, '80032', '154.50', 2),
(21513, '25154', '276.00', 1),
(21513, '80082', '118.50', 3),
(21514, '32055', '130.50', 5),
(21514, '80088', '213.00', 5),
(21515, '32067', '94.50', 5),
(21515, '80692', '39.50', 2),
(21516, '32069', '154.00', 5),
(21516, '81007', '62.50', 1),
(21517, '32191', '402.00', 2),
(21517, '82090', '30.00', 5),
(21518, '25079', '334.00', 2),
(21518, '82092', '18.00', 3),
(21519, '25121', '418.50', 1),
(21519, '25137', '228.00', 3),
(21519, '82093', '24.00', 5),
(21520, '25131', '1078.00', 2),
(21520, '25138', '166.50', 2),
(21520, '82095', '23.50', 3),
(21521, '25136', '180.00', 3),
(21521, '25154', '276.00', 5),
(21521, '82096', '27.50', 6),
(21522, '32055', '130.50', 2),
(21522, '46745', '43.50', 5),
(21522, '83013', '46.00', 5),
(21523, '32067', '94.50', 1),
(21523, '47903', '11214.00', 3),
(21523, '90106', '38.00', 7),
(21524, '32069', '154.00', 2),
(21524, '49916', '25.00', 2),
(21524, '90109', '40.50', 2),
(21525, '32191', '402.00', 5),
(21525, '49917', '25.50', 2),
(21525, '90116', '50.00', 1),
(21526, '32610', '106.50', 2),
(21526, '49919', '58.50', 3),
(21526, '90164', '75.50', 1),
(21527, '33044', '14.50', 1),
(21527, '49921', '357.00', 2),
(21527, '90192', '70.50', 5),
(21528, '33045', '17.50', 5),
(21528, '55112', '598.50', 1),
(21528, '90208', '71.00', 5),
(21529, '10820', '46.50', 1),
(21529, '33046', '15.00', 8),
(21529, '90209', '71.00', 5),
(21530, '10822', '46.50', 5),
(21530, '33047', '16.00', 2),
(21530, '90212', '71.00', 3),
(21531, '10830', '57.50', 1),
(21531, '35911', '11.50', 2),
(21531, '90510', '430.50', 2),
(21532, '10835', '83.00', 1),
(21532, '35912', '11.50', 1),
(21532, '90521', '142.50', 1),
(21533, '10854', '39.50', 1),
(21533, '37710', '35.00', 1),
(21533, '90531', '83.00', 3),
(21534, '11630', '46.50', 1),
(21534, '37720', '42.00', 5),
(21535, '12054', '358.50', 5),
(21535, '37725', '36.00', 1),
(21536, '12055', '238.50', 1),
(21536, '37730', '23.50', 5),
(21537, '12056', '191.50', 1),
(21537, '37731', '30.00', 1),
(21538, '12088', '215.00', 2),
(21538, '37732', '27.00', 5),
(21539, '12089', '144.00', 3),
(21539, '41020', '94.50', 5),
(21540, '12090', '192.00', 1),
(21540, '41096', '115.00', 1),
(21541, '12091', '286.50', 3),
(21541, '41097', '142.50', 3),
(21542, '12092', '238.50', 3),
(21542, '41098', '83.00', 5),
(21543, '13001', '38.00', 15),
(21543, '42613', '106.00', 5),
(21544, '15207', '24.50', 1),
(21544, '42615', '106.00', 1),
(21545, '15208', '24.50', 5),
(21545, '42626', '141.50', 2),
(21546, '15211', '209.00', 5),
(21546, '42929', '83.00', 2),
(21547, '15217', '32.00', 5),
(21547, '42933', '69.50', 1),
(21548, '15559', '38.00', 5),
(21548, '42934', '69.50', 5),
(21549, '20936', '25.00', 5),
(21549, '42939', '95.00', 3),
(21550, '20980', '27.50', 8),
(21550, '42941', '71.00', 2),
(21551, '21032', '57.50', 3),
(21551, '42945', '81.50', 5),
(21552, '21034', '504.00', 2),
(21552, '43000', '540.00', 5),
(21552, '44939', '115.00', 3),
(21553, '21037', '294.00', 2),
(21553, '43014', '372.00', 2),
(21553, '45101', '57.00', 5),
(21554, '21510', '35.50', 5),
(21554, '43015', '288.00', 3),
(21554, '45105', '45.00', 1),
(21555, '21514', '28.00', 1),
(21555, '44939', '115.00', 2),
(21555, '45923', '42.00', 1),
(21556, '15207', '24.50', 2),
(21556, '21515', '27.00', 2),
(21556, '45101', '57.00', 5),
(21556, '45935', '19.50', 3),
(21557, '15208', '24.50', 5),
(21557, '21517', '16.00', 1),
(21557, '45105', '45.00', 3),
(21557, '46702', '71.50', 1),
(21558, '15211', '209.00', 1),
(21558, '21580', '13.50', 5),
(21558, '45923', '42.00', 3),
(21558, '46706', '27.50', 2),
(21559, '15217', '32.00', 5),
(21559, '22002', '55.50', 5),
(21559, '45935', '19.50', 2),
(21559, '46738', '40.00', 3),
(21560, '15559', '38.00', 2),
(21560, '22054', '70.50', 1),
(21560, '45101', '57.00', 1),
(21560, '46702', '71.50', 5),
(21561, '20936', '25.00', 2),
(21561, '22055', '214.50', 5),
(21561, '45105', '45.00', 2),
(21561, '46706', '27.50', 3),
(21562, '20980', '27.50', 5),
(21562, '22056', '130.00', 3),
(21562, '45923', '42.00', 2),
(21562, '46738', '40.00', 5),
(21563, '21032', '57.50', 2),
(21563, '22165', '5400.00', 5),
(21563, '45935', '19.50', 5),
(21563, '46741', '10.00', 5),
(21564, '21034', '504.00', 1),
(21564, '22179', '1440.00', 3),
(21564, '46702', '71.50', 1),
(21564, '46745', '43.50', 1),
(21565, '21037', '294.00', 5),
(21565, '22870', '21.00', 5),
(21565, '46706', '27.50', 2),
(21565, '47903', '11214.00', 2),
(21566, '21510', '35.50', 2),
(21566, '25079', '334.00', 5),
(21566, '46738', '40.00', 2),
(21566, '49916', '25.00', 5),
(21567, '21514', '28.00', 3),
(21567, '25121', '418.50', 5),
(21567, '46741', '10.00', 2),
(21567, '49917', '25.50', 5),
(21568, '21515', '27.00', 5),
(21568, '25131', '1078.00', 1),
(21568, '46745', '43.50', 3),
(21568, '49919', '58.50', 5),
(21569, '21517', '16.00', 3),
(21569, '25136', '180.00', 5),
(21569, '47903', '11214.00', 5),
(21569, '49921', '357.00', 5),
(21570, '21580', '13.50', 5),
(21570, '25137', '228.00', 2),
(21570, '49916', '25.00', 1),
(21570, '55112', '598.50', 3),
(21571, '22002', '55.50', 5),
(21571, '25138', '166.50', 1),
(21571, '49917', '25.50', 1),
(21571, '55129', '154.00', 5),
(21572, '22054', '70.50', 5),
(21572, '25154', '276.00', 1),
(21572, '49919', '58.50', 5),
(21572, '55130', '298.50', 2),
(21573, '22055', '214.50', 1),
(21573, '32055', '130.50', 5),
(21573, '55550', '1558.50', 5),
(21574, '22056', '130.00', 5),
(21574, '32067', '94.50', 1),
(21574, '58028', '142.50', 2),
(21575, '22165', '5400.00', 2),
(21575, '32069', '154.00', 1),
(21575, '59915', '25.00', 3),
(21576, '22179', '1440.00', 5),
(21576, '32191', '402.00', 1),
(21576, '64509', '142.00', 2),
(21577, '22870', '21.00', 1),
(21577, '32610', '106.50', 5),
(21577, '64510', '154.00', 2),
(21578, '25079', '334.00', 1),
(21578, '33044', '14.50', 3),
(21578, '64511', '227.50', 5),
(21579, '25121', '418.50', 1),
(21579, '33045', '17.50', 2),
(21579, '64550', '126.00', 3),
(21580, '25131', '1078.00', 4),
(21580, '33046', '15.00', 2),
(21580, '64551', '118.00', 2),
(21581, '25136', '180.00', 5),
(21581, '33047', '16.00', 5),
(21581, '64552', '276.00', 5),
(21582, '25137', '228.00', 5),
(21582, '35911', '11.50', 3),
(21582, '65032', '598.50', 5),
(21583, '25138', '166.50', 3),
(21583, '35912', '11.50', 2),
(21583, '65033', '1044.00', 2),
(21584, '25154', '276.00', 2),
(21584, '37710', '35.00', 5),
(21584, '65034', '15000.00', 2),
(21585, '32055', '130.50', 1),
(21585, '37720', '42.00', 1),
(21585, '65060', '46.50', 5),
(21586, '32067', '94.50', 5),
(21586, '37725', '36.00', 5),
(21586, '65070', '118.50', 5),
(21587, '32069', '154.00', 5),
(21587, '37730', '23.50', 5),
(21587, '65080', '478.00', 2),
(21588, '32191', '402.00', 1),
(21588, '37731', '30.00', 3),
(21588, '65081', '112.00', 5),
(21589, '32610', '106.50', 5),
(21589, '37732', '27.00', 5),
(21589, '65082', '174.00', 1),
(21590, '33044', '14.50', 5),
(21590, '41020', '94.50', 2),
(21590, '65122', '1558.00', 2),
(21591, '33045', '17.50', 5),
(21591, '41096', '115.00', 1),
(21591, '65142', '93.00', 2),
(21592, '33046', '15.00', 3),
(21592, '41097', '142.50', 5),
(21592, '65143', '83.50', 2),
(21593, '33047', '16.00', 2),
(21593, '41098', '83.00', 5),
(21593, '65147', '238.50', 2),
(21594, '35911', '11.50', 5),
(21594, '42613', '106.00', 3),
(21594, '65190', '190.50', 1),
(21595, '35912', '11.50', 1),
(21595, '42615', '106.00', 2),
(21595, '65191', '23.00', 1),
(21596, '37710', '35.00', 1),
(21596, '42626', '141.50', 5),
(21596, '65247', '75.00', 5),
(21597, '37720', '42.00', 3),
(21597, '42929', '83.00', 5),
(21597, '71912', '35.00', 5),
(21598, '37725', '36.00', 1),
(21598, '42933', '69.50', 2),
(21598, '72777', '154.00', 2),
(21599, '37730', '23.50', 3),
(21599, '42934', '69.50', 5),
(21599, '72942', '35.50', 5),
(21600, '37731', '30.00', 2),
(21600, '42939', '95.00', 2),
(21600, '72943', '35.50', 5),
(21601, '37732', '27.00', 1),
(21601, '42941', '71.00', 5),
(21601, '72944', '42.00', 2),
(21602, '41020', '94.50', 5),
(21602, '42945', '81.50', 1),
(21602, '76032', '334.50', 3),
(21603, '41096', '115.00', 3),
(21603, '43000', '540.00', 1),
(21603, '77033', '358.00', 5),
(21604, '41097', '142.50', 1),
(21604, '43014', '372.00', 5),
(21604, '77036', '358.00', 1),
(21605, '41098', '83.00', 1),
(21605, '43015', '288.00', 2),
(21605, '77038', '478.00', 5),
(21606, '42613', '106.00', 2),
(21606, '44939', '115.00', 2),
(21606, '77249', '1558.00', 5),
(21607, '42615', '106.00', 5),
(21607, '77251', '658.00', 5),
(21608, '42626', '141.50', 2),
(21608, '77252', '34.50', 1),
(21609, '42929', '83.00', 5),
(21609, '77276', '4558.00', 5),
(21610, '42933', '69.50', 1),
(21610, '77277', '358.00', 3),
(21611, '42934', '69.50', 2),
(21611, '78029', '142.50', 5),
(21612, '42939', '95.00', 5),
(21612, '80032', '154.50', 5),
(21613, '42941', '71.00', 2),
(21613, '80082', '118.50', 2),
(21613, '90545', '288.00', 5),
(21614, '42945', '81.50', 3),
(21614, '80088', '213.00', 1),
(21614, '90693', '57.00', 5),
(21615, '43000', '540.00', 3),
(21615, '80692', '39.50', 3),
(21615, '90737', '354.00', 3),
(21616, '43014', '372.00', 1),
(21616, '81007', '62.50', 3),
(21616, '91008', '94.00', 1),
(21617, '43015', '288.00', 1),
(21617, '82090', '30.00', 5),
(21617, '92606', '106.00', 1),
(21618, '44939', '115.00', 5),
(21618, '65122', '1558.00', 1),
(21618, '82092', '18.00', 5),
(21619, '45101', '57.00', 1),
(21619, '65142', '93.00', 1),
(21619, '82093', '24.00', 5),
(21620, '10820', '46.50', 2),
(21620, '45105', '45.00', 2),
(21620, '82095', '23.50', 2),
(21621, '10822', '46.50', 5),
(21621, '45923', '42.00', 5),
(21621, '82096', '27.50', 1),
(21622, '10830', '57.50', 5),
(21622, '45935', '19.50', 1),
(21622, '83013', '46.00', 1),
(21623, '10835', '83.00', 1),
(21623, '46702', '71.50', 5),
(21623, '90106', '38.00', 9),
(21624, '10854', '39.50', 5),
(21624, '46706', '27.50', 3),
(21624, '90109', '40.50', 5),
(21625, '11630', '46.50', 1),
(21625, '46738', '40.00', 5),
(21625, '90116', '50.00', 5),
(21626, '12054', '358.50', 1),
(21626, '46741', '10.00', 9),
(21626, '90164', '75.50', 3),
(21627, '12055', '238.50', 2),
(21627, '46745', '43.50', 2),
(21627, '90192', '70.50', 1),
(21628, '12056', '191.50', 3),
(21628, '47903', '11214.00', 1),
(21628, '90208', '71.00', 1),
(21629, '12088', '215.00', 5),
(21629, '49916', '25.00', 2),
(21629, '64511', '227.50', 1),
(21629, '90209', '71.00', 3),
(21630, '12089', '144.00', 5),
(21630, '49917', '25.50', 3),
(21630, '64550', '126.00', 5),
(21630, '90212', '71.00', 5),
(21631, '12090', '192.00', 5),
(21631, '49919', '58.50', 3),
(21631, '64551', '118.00', 5),
(21631, '90510', '430.50', 5),
(21632, '12091', '286.50', 2),
(21632, '49921', '357.00', 1),
(21632, '64552', '276.00', 5),
(21632, '90521', '142.50', 1),
(21633, '12092', '238.50', 5),
(21633, '55112', '598.50', 5),
(21633, '65032', '598.50', 2),
(21633, '90531', '83.00', 5),
(21634, '13001', '38.00', 10),
(21634, '55129', '154.00', 5),
(21634, '65033', '1044.00', 2),
(21634, '90545', '288.00', 3),
(21635, '55130', '298.50', 5),
(21635, '65034', '15000.00', 5),
(21635, '90693', '57.00', 5),
(21636, '55550', '1558.50', 1),
(21636, '65060', '46.50', 2),
(21636, '90737', '354.00', 2),
(21637, '58028', '142.50', 3),
(21637, '65070', '118.50', 5),
(21637, '91008', '94.00', 3),
(21638, '59915', '25.00', 2),
(21638, '65080', '478.00', 1),
(21638, '92606', '106.00', 3),
(21639, '64509', '142.00', 5),
(21639, '65032', '598.50', 5),
(21639, '65081', '112.00', 2),
(21640, '64510', '154.00', 1),
(21640, '65033', '1044.00', 5),
(21640, '65082', '174.00', 3),
(21641, '64511', '227.50', 3),
(21641, '65034', '15000.00', 1),
(21641, '65122', '1558.00', 5),
(21642, '64550', '126.00', 5),
(21642, '65060', '46.50', 5),
(21642, '65142', '93.00', 3),
(21643, '64551', '118.00', 2),
(21643, '65070', '118.50', 5),
(21643, '65143', '83.50', 5),
(21644, '64552', '276.00', 1),
(21644, '65080', '478.00', 2),
(21644, '65147', '238.50', 1),
(21645, '65032', '598.50', 1),
(21645, '65081', '112.00', 5),
(21645, '65190', '190.50', 5),
(21646, '65033', '1044.00', 1),
(21646, '65082', '174.00', 2),
(21646, '65191', '23.00', 3),
(21647, '65034', '15000.00', 3),
(21647, '65122', '1558.00', 1),
(21647, '65247', '75.00', 2),
(21648, '65060', '46.50', 2),
(21648, '65142', '93.00', 5),
(21648, '71912', '35.00', 2),
(21649, '10820', '46.50', 5),
(21649, '65070', '118.50', 1),
(21649, '72777', '154.00', 3),
(21650, '10822', '46.50', 1),
(21650, '65080', '478.00', 5),
(21650, '72942', '35.50', 1),
(21651, '10830', '57.50', 1),
(21651, '65081', '112.00', 5),
(21651, '72943', '35.50', 5),
(21652, '10835', '83.00', 2),
(21652, '65082', '174.00', 5),
(21652, '72944', '42.00', 1),
(21653, '10854', '39.50', 2);
INSERT INTO Ordrelinje VALUES
(21653, '65122', '1558.00', 3),
(21653, '76032', '334.50', 2),
(21654, '11630', '46.50', 3),
(21654, '65142', '93.00', 2),
(21654, '77033', '358.00', 5),
(21655, '12054', '358.50', 3),
(21655, '65143', '83.50', 5),
(21655, '77036', '358.00', 5),
(21656, '12055', '238.50', 3),
(21656, '65147', '238.50', 2),
(21656, '77038', '478.00', 2),
(21657, '12056', '191.50', 2),
(21657, '65190', '190.50', 1),
(21657, '77249', '1558.00', 5),
(21658, '12088', '215.00', 2),
(21658, '65191', '23.00', 2),
(21658, '77251', '658.00', 1),
(21659, '12089', '144.00', 5),
(21659, '65247', '75.00', 1),
(21659, '77252', '34.50', 5),
(21660, '12090', '192.00', 1),
(21660, '71912', '35.00', 5),
(21660, '77276', '4558.00', 1),
(21661, '12091', '286.50', 5),
(21661, '72777', '154.00', 2),
(21661, '77277', '358.00', 3),
(21662, '12092', '238.50', 5),
(21662, '72942', '35.50', 1),
(21662, '78029', '142.50', 5),
(21663, '13001', '38.00', 13),
(21663, '72943', '35.50', 5),
(21663, '80032', '154.50', 1),
(21664, '15207', '24.50', 1),
(21664, '72944', '42.00', 3),
(21664, '80082', '118.50', 5),
(21665, '15208', '24.50', 2),
(21665, '76032', '334.50', 5),
(21665, '80088', '213.00', 3),
(21666, '15211', '209.00', 3),
(21666, '77033', '358.00', 2),
(21666, '80692', '39.50', 5),
(21667, '15217', '32.00', 1),
(21667, '77036', '358.00', 5),
(21667, '81007', '62.50', 2),
(21668, '15559', '38.00', 3),
(21668, '77038', '478.00', 5),
(21668, '82090', '30.00', 1),
(21669, '20936', '25.00', 5),
(21669, '77249', '1558.00', 5),
(21669, '82092', '18.00', 2),
(21670, '20980', '27.50', 2),
(21670, '77251', '658.00', 3),
(21670, '82093', '24.00', 3),
(21671, '21032', '57.50', 5),
(21671, '77252', '34.50', 1),
(21671, '82095', '23.50', 5),
(21672, '21034', '504.00', 3),
(21672, '77276', '4558.00', 5),
(21672, '82096', '27.50', 2),
(21673, '21037', '294.00', 2),
(21673, '77277', '358.00', 2),
(21673, '83013', '46.00', 5),
(21674, '21510', '35.50', 2),
(21674, '78029', '142.50', 5),
(21674, '90106', '38.00', 4),
(21675, '21514', '28.00', 2),
(21675, '80032', '154.50', 3),
(21675, '90109', '40.50', 1),
(21676, '21515', '27.00', 5),
(21676, '80082', '118.50', 1),
(21676, '90116', '50.00', 1),
(21677, '21517', '16.00', 5),
(21677, '80088', '213.00', 2),
(21677, '90164', '75.50', 2),
(21678, '21580', '13.50', 1),
(21678, '80692', '39.50', 5),
(21678, '90192', '70.50', 3),
(21679, '22002', '55.50', 3),
(21679, '81007', '62.50', 5),
(21679, '90208', '71.00', 2),
(21680, '22054', '70.50', 5),
(21680, '82090', '30.00', 3),
(21680, '90209', '71.00', 5),
(21681, '22055', '214.50', 5),
(21681, '82092', '18.00', 5),
(21681, '90212', '71.00', 5),
(21682, '22056', '130.00', 5),
(21682, '82093', '24.00', 2),
(21682, '90510', '430.50', 1),
(21683, '22165', '5400.00', 1),
(21683, '82095', '23.50', 2),
(21683, '90521', '142.50', 3),
(21684, '22179', '1440.00', 2),
(21684, '82096', '27.50', 5),
(21684, '90531', '83.00', 5),
(21685, '22870', '21.00', 3),
(21685, '83013', '46.00', 2),
(21685, '90545', '288.00', 2),
(21686, '25079', '334.00', 5),
(21686, '90106', '38.00', 6),
(21686, '90693', '57.00', 2),
(21687, '25121', '418.50', 3),
(21687, '90109', '40.50', 3),
(21687, '90737', '354.00', 2),
(21688, '25131', '1078.00', 7),
(21688, '90116', '50.00', 5),
(21688, '91008', '94.00', 5),
(21689, '25136', '180.00', 3),
(21689, '90164', '75.50', 5),
(21689, '92606', '106.00', 2),
(21690, '25121', '418.50', 5),
(21690, '25137', '228.00', 1),
(21690, '90192', '70.50', 5),
(21691, '25131', '1078.00', 15),
(21691, '25138', '166.50', 2),
(21691, '90208', '71.00', 1),
(21692, '25136', '180.00', 2),
(21692, '25154', '276.00', 2),
(21692, '90209', '71.00', 5),
(21693, '32055', '130.50', 2),
(21693, '46745', '43.50', 5),
(21693, '90212', '71.00', 1),
(21694, '32067', '94.50', 1),
(21694, '47903', '11214.00', 5),
(21694, '90510', '430.50', 5),
(21695, '32069', '154.00', 2),
(21695, '49916', '25.00', 1),
(21695, '90521', '142.50', 2),
(21696, '32191', '402.00', 5),
(21696, '49917', '25.50', 2),
(21696, '90531', '83.00', 1),
(21697, '32610', '106.50', 1),
(21697, '49919', '58.50', 2),
(21697, '90545', '288.00', 5),
(21698, '33044', '14.50', 5),
(21698, '49921', '357.00', 2),
(21698, '90693', '57.00', 5),
(21699, '33045', '17.50', 1),
(21699, '55112', '598.50', 5),
(21699, '90737', '354.00', 5),
(21700, '33046', '15.00', 5),
(21700, '65060', '46.50', 2),
(21700, '91008', '94.00', 5),
(21701, '33047', '16.00', 5),
(21701, '65070', '118.50', 5),
(21701, '92606', '106.00', 5),
(21702, '22870', '21.00', 5),
(21702, '35911', '11.50', 3),
(21702, '65080', '478.00', 1),
(21703, '25079', '334.00', 1),
(21703, '35912', '11.50', 2),
(21703, '64509', '142.00', 1),
(21704, '25121', '418.50', 5),
(21704, '37710', '35.00', 1),
(21704, '64510', '154.00', 5),
(21705, '25131', '1078.00', 5),
(21705, '37720', '42.00', 2),
(21705, '64511', '227.50', 2),
(21706, '22055', '214.50', 2),
(21706, '37725', '36.00', 3),
(21706, '64550', '126.00', 3),
(21707, '22056', '130.00', 3),
(21707, '37730', '23.50', 1),
(21707, '64551', '118.00', 5),
(21708, '22165', '5400.00', 3),
(21708, '37731', '30.00', 2),
(21708, '64552', '276.00', 5),
(21709, '22179', '1440.00', 5),
(21709, '37732', '27.00', 1),
(21709, '65032', '598.50', 1),
(21710, '22870', '21.00', 5),
(21710, '41020', '94.50', 2),
(21710, '65033', '1044.00', 3),
(21711, '25079', '334.00', 3),
(21711, '41096', '115.00', 1),
(21711, '65034', '15000.00', 2),
(21712, '25121', '418.50', 3),
(21712, '41097', '142.50', 5),
(21712, '65060', '46.50', 2),
(21713, '25131', '1078.00', 2),
(21713, '41098', '83.00', 2),
(21713, '65070', '118.50', 2),
(21714, '25136', '180.00', 5),
(21714, '42613', '106.00', 1),
(21714, '65080', '478.00', 3),
(21715, '25137', '228.00', 3),
(21715, '42615', '106.00', 3),
(21715, '65081', '112.00', 1),
(21716, '25138', '166.50', 5),
(21716, '42626', '141.50', 5),
(21716, '65082', '174.00', 1),
(21717, '25154', '276.00', 2),
(21717, '42929', '83.00', 5),
(21717, '65122', '1558.00', 3),
(21718, '32055', '130.50', 5),
(21718, '42933', '69.50', 5),
(21718, '65142', '93.00', 5),
(21719, '10820', '46.50', 5),
(21719, '32067', '94.50', 5),
(21719, '42934', '69.50', 2),
(21720, '10822', '46.50', 1),
(21720, '32069', '154.00', 1),
(21720, '42939', '95.00', 1),
(21721, '10830', '57.50', 1),
(21721, '32191', '402.00', 1),
(21721, '42941', '71.00', 5),
(21722, '10835', '83.00', 2),
(21722, '25079', '334.00', 5),
(21722, '42945', '81.50', 2),
(21723, '10854', '39.50', 1),
(21723, '25121', '418.50', 2),
(21723, '43000', '540.00', 2),
(21724, '11630', '46.50', 3),
(21724, '25131', '1078.00', 9),
(21724, '43014', '372.00', 2),
(21725, '12054', '358.50', 2),
(21725, '25136', '180.00', 2),
(21725, '43015', '288.00', 1),
(21726, '12055', '238.50', 1),
(21726, '46745', '43.50', 1),
(21727, '12056', '191.50', 5),
(21727, '47903', '11214.00', 1),
(21728, '12088', '215.00', 5),
(21728, '49916', '25.00', 5),
(21729, '12089', '144.00', 3),
(21729, '49917', '25.50', 1),
(21730, '12090', '192.00', 5),
(21730, '49919', '58.50', 5),
(21731, '12091', '286.50', 1),
(21731, '49921', '357.00', 5),
(21732, '12092', '238.50', 3),
(21732, '55112', '598.50', 5),
(21733, '10820', '46.50', 2),
(21733, '13001', '38.00', 8),
(21734, '10822', '46.50', 5),
(21734, '15207', '24.50', 5),
(21734, '46741', '10.00', 10),
(21735, '10830', '57.50', 3),
(21735, '15208', '24.50', 2),
(21735, '46745', '43.50', 3),
(21736, '10835', '83.00', 5),
(21736, '15211', '209.00', 5),
(21736, '47903', '11214.00', 3),
(21737, '10854', '39.50', 5),
(21737, '15217', '32.00', 5),
(21737, '49916', '25.00', 2),
(21738, '11630', '46.50', 1),
(21738, '15559', '38.00', 2),
(21738, '49917', '25.50', 3),
(21739, '12054', '358.50', 2),
(21739, '20936', '25.00', 5),
(21739, '49919', '58.50', 2),
(21740, '12055', '238.50', 2),
(21740, '20980', '27.50', 1),
(21740, '49921', '357.00', 2),
(21741, '12056', '191.50', 1),
(21741, '21032', '57.50', 5),
(21741, '55112', '598.50', 2),
(21742, '12088', '215.00', 1),
(21742, '21034', '504.00', 2),
(21742, '55129', '154.00', 3),
(21743, '12089', '144.00', 2),
(21743, '21037', '294.00', 1),
(21743, '55130', '298.50', 1),
(21744, '12090', '192.00', 2),
(21744, '21510', '35.50', 5),
(21744, '55550', '1558.50', 2),
(21745, '12091', '286.50', 3),
(21745, '21514', '28.00', 1),
(21745, '58028', '142.50', 2),
(21746, '12092', '238.50', 1),
(21746, '21515', '27.00', 5),
(21746, '59915', '25.00', 1),
(21747, '13001', '38.00', 3),
(21747, '21517', '16.00', 1),
(21747, '64509', '142.00', 3),
(21748, '15207', '24.50', 5),
(21748, '21580', '13.50', 5),
(21748, '64510', '154.00', 2),
(21749, '15208', '24.50', 1),
(21749, '22002', '55.50', 2),
(21749, '64511', '227.50', 2),
(21750, '15211', '209.00', 5),
(21750, '22054', '70.50', 3),
(21750, '64550', '126.00', 2),
(21751, '15217', '32.00', 1),
(21751, '22055', '214.50', 5),
(21751, '45101', '57.00', 1),
(21751, '64551', '118.00', 1),
(21751, '65032', '598.50', 5),
(21752, '15559', '38.00', 5),
(21752, '22056', '130.00', 2),
(21752, '45105', '45.00', 5),
(21752, '64552', '276.00', 5),
(21752, '65033', '1044.00', 2),
(21753, '20936', '25.00', 3),
(21753, '22165', '5400.00', 5),
(21753, '45923', '42.00', 5),
(21753, '65032', '598.50', 1),
(21753, '65034', '15000.00', 5),
(21754, '20980', '27.50', 3),
(21754, '22179', '1440.00', 5),
(21754, '45935', '19.50', 5),
(21754, '65033', '1044.00', 5),
(21754, '65060', '46.50', 3),
(21755, '21032', '57.50', 5),
(21755, '22870', '21.00', 3),
(21755, '46702', '71.50', 2),
(21755, '65034', '15000.00', 1),
(21755, '65070', '118.50', 5),
(21756, '21034', '504.00', 5),
(21756, '25079', '334.00', 5),
(21756, '46706', '27.50', 2),
(21756, '65060', '46.50', 2),
(21756, '65080', '478.00', 2),
(21757, '21037', '294.00', 3),
(21757, '25121', '418.50', 5),
(21757, '46738', '40.00', 5),
(21757, '65070', '118.50', 1),
(21757, '65081', '112.00', 5),
(21758, '21510', '35.50', 1),
(21758, '25131', '1078.00', 10),
(21758, '46741', '10.00', 13),
(21758, '65080', '478.00', 2),
(21758, '65082', '174.00', 5),
(21759, '21514', '28.00', 3),
(21759, '25136', '180.00', 1),
(21759, '46745', '43.50', 2),
(21759, '65081', '112.00', 1),
(21759, '65122', '1558.00', 2),
(21760, '21515', '27.00', 2),
(21760, '25137', '228.00', 2),
(21760, '47903', '11214.00', 5),
(21760, '65082', '174.00', 1),
(21760, '65142', '93.00', 5),
(21761, '21517', '16.00', 5),
(21761, '25138', '166.50', 1),
(21761, '49916', '25.00', 2),
(21761, '65122', '1558.00', 5),
(21761, '65143', '83.50', 1),
(21762, '25154', '276.00', 1),
(21762, '49917', '25.50', 2),
(21762, '65142', '93.00', 1),
(21762, '65147', '238.50', 3),
(21763, '32055', '130.50', 2),
(21763, '49919', '58.50', 1),
(21763, '65143', '83.50', 5),
(21763, '65190', '190.50', 3),
(21764, '32067', '94.50', 2),
(21764, '49921', '357.00', 5),
(21764, '65147', '238.50', 2),
(21764, '65191', '23.00', 5),
(21765, '32069', '154.00', 5),
(21765, '55112', '598.50', 2),
(21765, '65190', '190.50', 5),
(21765, '65247', '75.00', 3),
(21766, '32191', '402.00', 3),
(21766, '55129', '154.00', 1),
(21766, '65191', '23.00', 1),
(21766, '71912', '35.00', 2),
(21767, '32610', '106.50', 5),
(21767, '55130', '298.50', 5),
(21767, '65247', '75.00', 5),
(21767, '72777', '154.00', 3),
(21768, '33044', '14.50', 3),
(21768, '55550', '1558.50', 5),
(21768, '71912', '35.00', 5),
(21768, '72942', '35.50', 2),
(21769, '33045', '17.50', 3),
(21769, '58028', '142.50', 1),
(21769, '72777', '154.00', 2),
(21769, '72943', '35.50', 5),
(21770, '33046', '15.00', 2),
(21770, '59915', '25.00', 2),
(21770, '72942', '35.50', 2),
(21770, '72944', '42.00', 1),
(21771, '33047', '16.00', 1),
(21771, '64509', '142.00', 2),
(21771, '72943', '35.50', 5),
(21771, '76032', '334.50', 1),
(21772, '35911', '11.50', 5),
(21772, '64510', '154.00', 1),
(21772, '72944', '42.00', 5),
(21772, '77033', '358.00', 1),
(21773, '35912', '11.50', 1),
(21773, '76032', '334.50', 5),
(21774, '37710', '35.00', 2),
(21774, '77033', '358.00', 3),
(21775, '37720', '42.00', 1),
(21775, '77036', '358.00', 5),
(21776, '37725', '36.00', 5),
(21776, '77038', '478.00', 5),
(21777, '37730', '23.50', 3),
(21777, '77249', '1558.00', 2),
(21778, '32067', '94.50', 5),
(21778, '37731', '30.00', 1),
(21778, '77251', '658.00', 2),
(21779, '32069', '154.00', 3),
(21779, '37732', '27.00', 5),
(21779, '77252', '34.50', 3),
(21780, '32191', '402.00', 5),
(21780, '41020', '94.50', 1),
(21780, '77276', '4558.00', 2),
(21781, '32610', '106.50', 1),
(21781, '41096', '115.00', 3),
(21781, '77277', '358.00', 2),
(21782, '33044', '14.50', 2),
(21782, '41097', '142.50', 5),
(21782, '78029', '142.50', 3),
(21783, '33045', '17.50', 2),
(21783, '41098', '83.00', 1),
(21783, '80032', '154.50', 2),
(21784, '33046', '15.00', 1),
(21784, '42613', '106.00', 2),
(21784, '80082', '118.50', 2),
(21785, '33047', '16.00', 5),
(21785, '42615', '106.00', 1),
(21785, '80088', '213.00', 5),
(21786, '35911', '11.50', 5),
(21786, '42626', '141.50', 1),
(21786, '80692', '39.50', 1),
(21787, '35912', '11.50', 1),
(21787, '42929', '83.00', 3),
(21787, '81007', '62.50', 1),
(21788, '37710', '35.00', 5),
(21788, '42933', '69.50', 5),
(21788, '82090', '30.00', 3),
(21789, '37720', '42.00', 3),
(21789, '42934', '69.50', 1),
(21789, '82092', '18.00', 5),
(21790, '37725', '36.00', 5),
(21790, '42939', '95.00', 3),
(21790, '82093', '24.00', 5),
(21791, '37730', '23.50', 2),
(21791, '42941', '71.00', 2),
(21791, '82095', '23.50', 5),
(21792, '37731', '30.00', 2),
(21792, '42945', '81.50', 1),
(21792, '82096', '27.50', 5),
(21793, '37732', '27.00', 1),
(21793, '43000', '540.00', 5),
(21793, '83013', '46.00', 5),
(21794, '41020', '94.50', 3),
(21794, '43014', '372.00', 5),
(21794, '90106', '38.00', 2),
(21795, '41096', '115.00', 2),
(21795, '43015', '288.00', 5),
(21795, '90109', '40.50', 2),
(21796, '41097', '142.50', 2),
(21796, '44939', '115.00', 5),
(21796, '90116', '50.00', 2),
(21797, '41098', '83.00', 2),
(21797, '45101', '57.00', 2),
(21797, '90164', '75.50', 1),
(21798, '42613', '106.00', 3),
(21798, '45105', '45.00', 1),
(21798, '90192', '70.50', 2),
(21799, '42615', '106.00', 2),
(21799, '45923', '42.00', 5),
(21799, '90208', '71.00', 5),
(21800, '42626', '141.50', 3),
(21800, '45935', '19.50', 1),
(21800, '90209', '71.00', 1),
(21801, '42929', '83.00', 2),
(21801, '46702', '71.50', 5),
(21801, '90212', '71.00', 2),
(21802, '42933', '69.50', 3),
(21802, '46706', '27.50', 1),
(21802, '90510', '430.50', 1),
(21803, '42934', '69.50', 2),
(21803, '46738', '40.00', 1),
(21803, '90521', '142.50', 5),
(21804, '42939', '95.00', 2),
(21804, '46741', '10.00', 3),
(21804, '90531', '83.00', 5),
(21805, '42941', '71.00', 5),
(21805, '46745', '43.50', 1),
(21805, '90545', '288.00', 1),
(21806, '42945', '81.50', 3),
(21806, '47903', '11214.00', 5),
(21806, '90693', '57.00', 5),
(21807, '43000', '540.00', 1),
(21807, '49916', '25.00', 5),
(21807, '90737', '354.00', 1),
(21808, '43014', '372.00', 2),
(21808, '49917', '25.50', 5),
(21808, '91008', '94.00', 3),
(21809, '43015', '288.00', 3),
(21809, '49919', '58.50', 3),
(21809, '92606', '106.00', 5),
(21810, '21515', '27.00', 2),
(21810, '44939', '115.00', 1),
(21810, '49921', '357.00', 1),
(21811, '21517', '16.00', 2),
(21811, '45101', '57.00', 2),
(21811, '55112', '598.50', 5),
(21812, '21580', '13.50', 1),
(21812, '45105', '45.00', 3),
(21812, '55129', '154.00', 2),
(21813, '22002', '55.50', 5),
(21813, '45923', '42.00', 5),
(21813, '55130', '298.50', 1),
(21814, '10820', '46.50', 1),
(21814, '45935', '19.50', 3),
(21814, '55550', '1558.50', 2),
(21815, '10822', '46.50', 3),
(21815, '46702', '71.50', 1),
(21815, '58028', '142.50', 5),
(21816, '10830', '57.50', 3),
(21816, '46706', '27.50', 3),
(21816, '59915', '25.00', 1),
(21817, '10835', '83.00', 1),
(21817, '46738', '40.00', 5),
(21817, '64509', '142.00', 1),
(21818, '10854', '39.50', 5),
(21818, '46741', '10.00', 4),
(21818, '64510', '154.00', 5),
(21819, '11630', '46.50', 2),
(21819, '46745', '43.50', 3),
(21819, '64511', '227.50', 5),
(21820, '12054', '358.50', 5),
(21820, '47903', '11214.00', 3),
(21820, '64550', '126.00', 5),
(21821, '12055', '238.50', 5),
(21821, '49916', '25.00', 3),
(21821, '64551', '118.00', 3),
(21822, '12056', '191.50', 3),
(21822, '49917', '25.50', 1),
(21823, '12088', '215.00', 3),
(21823, '49919', '58.50', 5),
(21824, '12089', '144.00', 5),
(21824, '49921', '357.00', 3),
(21825, '12090', '192.00', 5),
(21825, '55112', '598.50', 2),
(21826, '12091', '286.50', 2),
(21826, '55129', '154.00', 1),
(21827, '55130', '298.50', 3),
(21828, '55550', '1558.50', 5),
(21829, '58028', '142.50', 1),
(21830, '59915', '25.00', 2),
(21831, '64509', '142.00', 3),
(21832, '64510', '154.00', 3),
(21833, '64511', '227.50', 1),
(21834, '64550', '126.00', 2),
(21835, '64551', '118.00', 2),
(21836, '64552', '276.00', 3),
(21837, '65032', '598.50', 5),
(21838, '21037', '294.00', 5),
(21838, '65033', '1044.00', 1),
(21839, '21510', '35.50', 1),
(21839, '65034', '15000.00', 5),
(21840, '21514', '28.00', 2),
(21840, '65060', '46.50', 5),
(21841, '21515', '27.00', 5),
(21841, '65070', '118.50', 5),
(21842, '21517', '16.00', 5),
(21842, '65080', '478.00', 1),
(21843, '21580', '13.50', 5),
(21843, '65081', '112.00', 5),
(21844, '22002', '55.50', 2),
(21844, '65082', '174.00', 3),
(21845, '22054', '70.50', 5),
(21845, '65122', '1558.00', 1),
(21846, '22055', '214.50', 1),
(21846, '65142', '93.00', 5),
(21847, '22056', '130.00', 5),
(21847, '65143', '83.50', 1),
(21848, '22165', '5400.00', 2),
(21848, '65147', '238.50', 1),
(21849, '22179', '1440.00', 1),
(21849, '65190', '190.50', 5),
(21850, '22870', '21.00', 2),
(21850, '65191', '23.00', 3),
(21851, '25079', '334.00', 3),
(21851, '65247', '75.00', 2),
(21852, '25121', '418.50', 2),
(21852, '71912', '35.00', 1),
(21853, '25131', '1078.00', 13),
(21853, '72777', '154.00', 2),
(21854, '25136', '180.00', 3),
(21854, '72942', '35.50', 3),
(21855, '25137', '228.00', 1),
(21855, '72943', '35.50', 2),
(21856, '25138', '166.50', 3),
(21856, '72944', '42.00', 3),
(21857, '25154', '276.00', 2),
(21857, '76032', '334.50', 1),
(21857, '81007', '62.50', 5),
(21858, '32055', '130.50', 5),
(21858, '77033', '358.00', 5),
(21858, '82090', '30.00', 5),
(21859, '21580', '13.50', 2),
(21859, '32067', '94.50', 2),
(21859, '77036', '358.00', 5),
(21859, '82092', '18.00', 1),
(21860, '22002', '55.50', 1),
(21860, '32069', '154.00', 5),
(21860, '77038', '478.00', 3),
(21860, '82093', '24.00', 2),
(21861, '22054', '70.50', 2),
(21861, '32191', '402.00', 5),
(21861, '77249', '1558.00', 3),
(21861, '82095', '23.50', 5),
(21862, '22055', '214.50', 2),
(21862, '32610', '106.50', 5),
(21862, '77251', '658.00', 5),
(21862, '82096', '27.50', 2),
(21863, '22056', '130.00', 2),
(21863, '33044', '14.50', 5),
(21863, '77252', '34.50', 5),
(21863, '83013', '46.00', 1),
(21864, '22165', '5400.00', 5),
(21864, '33045', '17.50', 2),
(21864, '77276', '4558.00', 5),
(21864, '90106', '38.00', 1),
(21865, '22179', '1440.00', 5),
(21865, '33046', '15.00', 3),
(21865, '77277', '358.00', 1),
(21865, '90109', '40.50', 5),
(21866, '22870', '21.00', 5),
(21866, '33047', '16.00', 1),
(21866, '78029', '142.50', 5),
(21866, '90116', '50.00', 5),
(21867, '25079', '334.00', 2),
(21867, '35911', '11.50', 3),
(21867, '80032', '154.50', 5),
(21867, '90164', '75.50', 3),
(21868, '25121', '418.50', 1),
(21868, '35912', '11.50', 5),
(21868, '80082', '118.50', 2),
(21868, '90192', '70.50', 1),
(21869, '25131', '1078.00', 3),
(21869, '37710', '35.00', 3),
(21869, '80088', '213.00', 1),
(21869, '90208', '71.00', 2),
(21870, '25136', '180.00', 5),
(21870, '37720', '42.00', 2),
(21870, '80692', '39.50', 2),
(21870, '90209', '71.00', 5),
(21871, '25137', '228.00', 3),
(21871, '37725', '36.00', 3),
(21871, '81007', '62.50', 1),
(21871, '90212', '71.00', 1),
(21872, '25138', '166.50', 2),
(21872, '37730', '23.50', 5),
(21872, '82090', '30.00', 1),
(21872, '90510', '430.50', 3),
(21873, '25154', '276.00', 2),
(21873, '37731', '30.00', 3),
(21873, '82092', '18.00', 5),
(21873, '90521', '142.50', 1),
(21874, '32055', '130.50', 1),
(21874, '37732', '27.00', 2),
(21874, '82093', '24.00', 1),
(21874, '90531', '83.00', 3),
(21875, '41020', '94.50', 2),
(21875, '82095', '23.50', 1),
(21875, '90545', '288.00', 5),
(21876, '41096', '115.00', 5),
(21876, '82096', '27.50', 1),
(21876, '90693', '57.00', 5),
(21877, '41097', '142.50', 5),
(21877, '83013', '46.00', 2),
(21877, '90737', '354.00', 3),
(21878, '41098', '83.00', 2),
(21878, '90106', '38.00', 3),
(21878, '91008', '94.00', 2),
(21879, '42613', '106.00', 1),
(21879, '90109', '40.50', 1),
(21879, '92606', '106.00', 3),
(21880, '10820', '46.50', 1),
(21880, '42615', '106.00', 2),
(21880, '90116', '50.00', 1),
(21881, '10822', '46.50', 3),
(21881, '42626', '141.50', 2),
(21881, '90164', '75.50', 2),
(21882, '10830', '57.50', 2),
(21882, '42929', '83.00', 5),
(21882, '90192', '70.50', 3),
(21883, '10835', '83.00', 1),
(21883, '42933', '69.50', 2),
(21883, '90208', '71.00', 3),
(21884, '10854', '39.50', 5),
(21884, '42934', '69.50', 5),
(21884, '90209', '71.00', 2),
(21885, '11630', '46.50', 2),
(21885, '42939', '95.00', 5),
(21885, '90212', '71.00', 2),
(21886, '12054', '358.50', 1),
(21886, '42941', '71.00', 5),
(21886, '90510', '430.50', 5),
(21887, '12055', '238.50', 3),
(21887, '42945', '81.50', 2),
(21887, '90521', '142.50', 2),
(21888, '12056', '191.50', 2),
(21888, '43000', '540.00', 3),
(21888, '90531', '83.00', 3),
(21889, '12088', '215.00', 2),
(21889, '43014', '372.00', 5),
(21889, '90545', '288.00', 5),
(21890, '12089', '144.00', 2),
(21890, '43015', '288.00', 3),
(21890, '90693', '57.00', 1),
(21891, '12090', '192.00', 1),
(21891, '44939', '115.00', 1),
(21891, '90737', '354.00', 2),
(21892, '12091', '286.50', 1),
(21892, '45101', '57.00', 3),
(21892, '91008', '94.00', 5),
(21893, '12092', '238.50', 2),
(21893, '45105', '45.00', 2),
(21893, '92606', '106.00', 5),
(21894, '13001', '38.00', 2),
(21894, '45923', '42.00', 5),
(21894, '65070', '118.50', 5),
(21895, '15207', '24.50', 3),
(21895, '45935', '19.50', 5),
(21895, '65080', '478.00', 2),
(21896, '15208', '24.50', 2),
(21896, '46702', '71.50', 2),
(21896, '65081', '112.00', 2),
(21897, '15211', '209.00', 3),
(21897, '46706', '27.50', 3),
(21897, '65082', '174.00', 5),
(21898, '15217', '32.00', 5),
(21898, '46738', '40.00', 1),
(21898, '65122', '1558.00', 5),
(21899, '15559', '38.00', 2),
(21899, '46741', '10.00', 6),
(21899, '65142', '93.00', 1),
(21900, '20936', '25.00', 5),
(21900, '43000', '540.00', 2),
(21900, '46745', '43.50', 2),
(21901, '20980', '27.50', 2),
(21901, '43014', '372.00', 1),
(21901, '47903', '11214.00', 2),
(21902, '21032', '57.50', 5),
(21902, '43015', '288.00', 2),
(21902, '49916', '25.00', 1),
(21903, '21034', '504.00', 1),
(21903, '44939', '115.00', 3),
(21903, '49917', '25.50', 3),
(21904, '21037', '294.00', 2),
(21904, '45101', '57.00', 2),
(21904, '49919', '58.50', 2),
(21905, '21510', '35.50', 2),
(21905, '49919', '58.50', 5),
(21905, '49921', '357.00', 2),
(21906, '21514', '28.00', 5),
(21906, '49921', '357.00', 2),
(21906, '55112', '598.50', 1),
(21907, '21515', '27.00', 5),
(21907, '55112', '598.50', 3),
(21907, '55129', '154.00', 1),
(21908, '21517', '16.00', 2),
(21908, '55129', '154.00', 5),
(21908, '55130', '298.50', 5),
(21909, '21580', '13.50', 5),
(21909, '55130', '298.50', 5),
(21909, '55550', '1558.50', 1),
(21910, '22002', '55.50', 3),
(21910, '55550', '1558.50', 3),
(21910, '58028', '142.50', 5),
(21911, '22054', '70.50', 5),
(21911, '58028', '142.50', 1),
(21911, '59915', '25.00', 3),
(21912, '22055', '214.50', 5),
(21912, '59915', '25.00', 2),
(21912, '64509', '142.00', 2),
(21913, '22056', '130.00', 1),
(21913, '64509', '142.00', 5),
(21913, '64510', '154.00', 1),
(21914, '22165', '5400.00', 5),
(21914, '64510', '154.00', 3),
(21914, '64511', '227.50', 3),
(21915, '22179', '1440.00', 1),
(21915, '64511', '227.50', 2),
(21915, '64550', '126.00', 1),
(21916, '22870', '21.00', 2),
(21916, '64550', '126.00', 3),
(21916, '64551', '118.00', 2),
(21917, '25079', '334.00', 5),
(21917, '64551', '118.00', 5),
(21917, '64552', '276.00', 5),
(21918, '25121', '418.50', 3),
(21918, '42615', '106.00', 1),
(21918, '65032', '598.50', 2),
(21919, '25131', '1078.00', 4),
(21919, '42626', '141.50', 2),
(21919, '65033', '1044.00', 3),
(21920, '25136', '180.00', 2),
(21920, '42929', '83.00', 2),
(21920, '65034', '15000.00', 1),
(21921, '25137', '228.00', 2),
(21921, '42933', '69.50', 1),
(21921, '65060', '46.50', 5),
(21922, '25138', '166.50', 5),
(21922, '42934', '69.50', 5),
(21922, '65070', '118.50', 1),
(21923, '25154', '276.00', 1),
(21923, '42939', '95.00', 1),
(21923, '65080', '478.00', 5),
(21924, '32055', '130.50', 3),
(21924, '42941', '71.00', 1),
(21924, '65081', '112.00', 5),
(21925, '32067', '94.50', 5),
(21925, '42945', '81.50', 5),
(21925, '65082', '174.00', 5),
(21926, '32069', '154.00', 5),
(21926, '43000', '540.00', 1),
(21926, '65122', '1558.00', 2),
(21927, '32191', '402.00', 3),
(21927, '43014', '372.00', 3),
(21927, '65142', '93.00', 5),
(21928, '32610', '106.50', 2),
(21928, '43015', '288.00', 5),
(21928, '65143', '83.50', 5),
(21929, '33044', '14.50', 2),
(21929, '44939', '115.00', 5),
(21929, '65147', '238.50', 5),
(21930, '33045', '17.50', 5),
(21930, '45101', '57.00', 2),
(21930, '65190', '190.50', 3),
(21931, '33046', '15.00', 2),
(21931, '55550', '1558.50', 2),
(21931, '65191', '23.00', 2),
(21932, '33047', '16.00', 5),
(21932, '58028', '142.50', 2),
(21932, '65247', '75.00', 5),
(21933, '35911', '11.50', 5),
(21933, '59915', '25.00', 1),
(21933, '71912', '35.00', 2),
(21934, '35912', '11.50', 3),
(21934, '64509', '142.00', 1),
(21934, '72777', '154.00', 5),
(21935, '37710', '35.00', 2),
(21935, '64510', '154.00', 3),
(21935, '72942', '35.50', 5),
(21936, '37720', '42.00', 2),
(21936, '64511', '227.50', 5),
(21936, '72943', '35.50', 1),
(21937, '37725', '36.00', 2),
(21937, '64550', '126.00', 5),
(21937, '72944', '42.00', 1),
(21938, '37730', '23.50', 5),
(21938, '64551', '118.00', 1),
(21938, '76032', '334.50', 3),
(21939, '37731', '30.00', 2),
(21939, '42615', '106.00', 5),
(21939, '77033', '358.00', 5),
(21940, '37732', '27.00', 1),
(21940, '42626', '141.50', 5),
(21940, '77036', '358.00', 1),
(21941, '41020', '94.50', 1),
(21941, '77038', '478.00', 1),
(21942, '41096', '115.00', 5),
(21942, '77249', '1558.00', 5),
(21943, '41097', '142.50', 5),
(21943, '77251', '658.00', 1),
(21944, '41098', '83.00', 1),
(21944, '77252', '34.50', 5),
(21945, '42613', '106.00', 1),
(21945, '77276', '4558.00', 1),
(21946, '42615', '106.00', 3),
(21946, '77277', '358.00', 5),
(21947, '42626', '141.50', 1),
(21947, '78029', '142.50', 2),
(21948, '42929', '83.00', 3),
(21948, '80032', '154.50', 1),
(21949, '42933', '69.50', 1),
(21949, '80082', '118.50', 3),
(21950, '42934', '69.50', 3),
(21950, '80088', '213.00', 3),
(21951, '42939', '95.00', 5),
(21951, '80692', '39.50', 1),
(21952, '42941', '71.00', 3),
(21952, '81007', '62.50', 3),
(21953, '42945', '81.50', 1),
(21953, '82090', '30.00', 5),
(21954, '43000', '540.00', 3),
(21954, '82092', '18.00', 1),
(21955, '43014', '372.00', 2),
(21955, '82093', '24.00', 3),
(21956, '43015', '288.00', 2),
(21956, '82095', '23.50', 1),
(21957, '44939', '115.00', 3),
(21957, '82096', '27.50', 5),
(21958, '83013', '46.00', 5),
(21959, '90106', '38.00', 5),
(21960, '90109', '40.50', 5),
(21961, '37720', '42.00', 3),
(21961, '90116', '50.00', 2),
(21962, '37725', '35.00', 5),
(21962, '90164', '75.50', 5),
(21963, '37730', '23.50', 5),
(21963, '90192', '70.50', 2),
(21964, '37731', '30.00', 1),
(21964, '90208', '71.00', 2),
(21965, '37720', '42.00', 5),
(21965, '90209', '71.00', 5),
(21966, '37725', '36.00', 5),
(21966, '90212', '71.00', 1),
(21967, '33044', '14.50', 1),
(21967, '90510', '430.50', 5),
(21968, '33045', '17.50', 1),
(21968, '90521', '142.50', 5),
(21969, '33046', '15.00', 2),
(21969, '90531', '83.00', 2),
(21970, '33047', '16.00', 2),
(21970, '90545', '288.00', 1),
(21971, '35911', '11.50', 2),
(21971, '49921', '357.00', 5),
(21971, '90693', '57.00', 5),
(21972, '35912', '11.50', 5),
(21972, '55112', '598.50', 2),
(21972, '90737', '354.00', 5),
(21973, '37710', '35.00', 5),
(21973, '55129', '154.00', 2),
(21973, '91008', '94.00', 2),
(21974, '37720', '42.00', 2),
(21974, '55130', '298.50', 3),
(21974, '92606', '106.00', 5),
(21975, '37725', '36.00', 2),
(21975, '55550', '1558.50', 2),
(21975, '77249', '1558.00', 5),
(21976, '37730', '23.50', 2),
(21976, '58028', '142.50', 1),
(21976, '77251', '658.00', 3),
(21977, '37731', '30.00', 5),
(21977, '59915', '25.00', 3),
(21977, '77252', '34.50', 3),
(21978, '37732', '27.00', 3),
(21978, '64509', '142.00', 3),
(21978, '77276', '4558.00', 2),
(21979, '41020', '94.50', 3),
(21979, '64510', '154.00', 5),
(21979, '77277', '358.00', 2),
(21980, '41096', '115.00', 2),
(21980, '64511', '227.50', 1),
(21980, '78029', '142.50', 3),
(21981, '41097', '142.50', 2),
(21981, '64550', '126.00', 2),
(21981, '80032', '154.50', 5),
(21982, '41098', '83.00', 5),
(21982, '64551', '118.00', 5),
(21982, '80082', '118.50', 2),
(21983, '42613', '106.00', 5),
(21983, '64552', '276.00', 3),
(21983, '80088', '213.00', 2),
(21984, '65032', '598.50', 5),
(21984, '65060', '46.50', 1),
(21984, '80692', '39.50', 2),
(21985, '65033', '1044.00', 2),
(21985, '65070', '118.50', 2),
(21985, '81007', '62.50', 5),
(21986, '65034', '15000.00', 3),
(21986, '65080', '478.00', 3),
(21986, '82090', '30.00', 1),
(21987, '64509', '142.00', 2),
(21987, '65060', '46.50', 5),
(21987, '82092', '18.00', 2),
(21988, '64510', '154.00', 2),
(21988, '65070', '118.50', 5),
(21988, '82093', '24.00', 5),
(21989, '64511', '227.50', 3),
(21989, '65080', '478.00', 2),
(21989, '82095', '23.50', 2),
(21990, '64550', '126.00', 5),
(21990, '65081', '112.00', 1),
(21990, '82096', '27.50', 1),
(21991, '64551', '118.00', 1),
(21991, '65082', '174.00', 3),
(21991, '83013', '46.00', 2),
(21992, '64552', '276.00', 2),
(21992, '65122', '1558.00', 1),
(21992, '90106', '38.00', 1),
(21993, '65032', '598.50', 1),
(21993, '65142', '93.00', 2),
(21993, '90109', '40.50', 1),
(21994, '65033', '1044.00', 1),
(21994, '65143', '83.50', 2),
(21994, '90116', '50.00', 5),
(21995, '65034', '15000.00', 5),
(21995, '65147', '238.50', 1),
(21995, '90164', '75.50', 1),
(21996, '65060', '46.50', 1),
(21996, '65190', '190.50', 2),
(21996, '90192', '70.50', 5),
(21997, '65070', '118.50', 1),
(21997, '65191', '23.00', 5),
(21997, '90208', '71.00', 3),
(21998, '65080', '478.00', 1),
(21998, '65247', '75.00', 5),
(21998, '90209', '71.00', 2),
(21999, '65081', '112.00', 2),
(21999, '71912', '35.00', 1),
(21999, '90212', '71.00', 1),
(22000, '65082', '174.00', 2),
(22000, '72777', '154.00', 1),
(22000, '90510', '430.50', 3),
(22001, '65122', '1558.00', 5),
(22001, '72942', '35.50', 3),
(22001, '90521', '142.50', 2),
(22002, '65142', '93.00', 5),
(22002, '72943', '35.50', 2),
(22002, '90531', '83.00', 1),
(22003, '25136', '180.00', 5),
(22003, '72944', '42.00', 5),
(22003, '90545', '288.00', 3),
(22004, '25137', '228.00', 5),
(22004, '76032', '334.50', 5),
(22004, '90693', '57.00', 1),
(22005, '25138', '166.50', 1),
(22005, '77033', '358.00', 5),
(22005, '90737', '354.00', 1),
(22006, '25154', '276.00', 5),
(22006, '77036', '358.00', 1),
(22006, '91008', '94.00', 1),
(22007, '32055', '130.50', 2),
(22007, '77038', '478.00', 3),
(22007, '92606', '106.00', 3),
(22008, '10820', '46.50', 3),
(22008, '32067', '94.50', 2),
(22008, '77249', '1558.00', 1),
(22009, '10822', '46.50', 5),
(22009, '32069', '154.00', 3),
(22009, '77251', '658.00', 2),
(22010, '10830', '57.50', 2),
(22010, '32191', '402.00', 2),
(22010, '77252', '34.50', 2),
(22011, '10835', '83.00', 3),
(22011, '25079', '334.00', 2),
(22011, '77276', '4558.00', 5),
(22012, '10854', '39.50', 5),
(22012, '25121', '418.50', 5),
(22012, '77277', '358.00', 2),
(22013, '11630', '46.50', 5),
(22013, '25131', '1078.00', 6),
(22013, '78029', '142.50', 5),
(22014, '12054', '358.50', 3),
(22014, '25136', '180.00', 5),
(22014, '80032', '154.50', 1),
(22015, '12055', '238.50', 5),
(22015, '25137', '228.00', 1),
(22015, '80082', '118.50', 3),
(22016, '12056', '191.50', 1),
(22016, '25138', '166.50', 5),
(22016, '80088', '213.00', 1),
(22017, '12088', '215.00', 2),
(22017, '25154', '276.00', 1),
(22017, '80692', '39.50', 2),
(22018, '12089', '144.00', 1),
(22018, '32055', '130.50', 2),
(22018, '81007', '62.50', 5),
(22019, '12090', '192.00', 2),
(22019, '32067', '94.50', 5),
(22019, '82090', '30.00', 3),
(22020, '12091', '286.50', 3),
(22020, '32069', '154.00', 5),
(22020, '82092', '18.00', 1),
(22021, '12092', '238.50', 1),
(22021, '32191', '402.00', 5),
(22021, '82093', '24.00', 2),
(22022, '13001', '38.00', 3),
(22022, '32610', '106.50', 5),
(22022, '82095', '23.50', 1),
(22023, '15207', '24.50', 2),
(22023, '65060', '46.50', 3),
(22023, '82096', '27.50', 3),
(22024, '15208', '24.50', 5),
(22024, '65070', '118.50', 2),
(22024, '83013', '46.00', 5),
(22025, '15211', '209.00', 2),
(22025, '65080', '478.00', 2),
(22025, '90106', '38.00', 2),
(22026, '15217', '32.00', 2),
(22026, '64509', '142.00', 5),
(22026, '90109', '40.50', 3),
(22027, '15559', '38.00', 5),
(22027, '64510', '154.00', 2),
(22027, '90116', '50.00', 2),
(22028, '20936', '25.00', 2),
(22028, '64511', '227.50', 2),
(22028, '90164', '75.50', 5),
(22029, '20980', '27.50', 2),
(22029, '64550', '126.00', 5),
(22029, '90192', '70.50', 5),
(22030, '21032', '57.50', 1),
(22030, '64551', '118.00', 3),
(22030, '90208', '71.00', 3),
(22031, '21034', '504.00', 3),
(22031, '64552', '276.00', 3),
(22031, '90209', '71.00', 2),
(22032, '21037', '294.00', 5),
(22032, '65032', '598.50', 3),
(22032, '90212', '71.00', 5),
(22033, '21510', '35.50', 5),
(22033, '65033', '1044.00', 3),
(22033, '90510', '430.50', 2),
(22034, '21514', '28.00', 1),
(22034, '65034', '15000.00', 5),
(22034, '90521', '142.50', 1),
(22035, '21515', '27.00', 2),
(22035, '65060', '46.50', 2),
(22035, '90531', '83.00', 2),
(22036, '21517', '16.00', 5),
(22036, '65070', '118.50', 5),
(22036, '90545', '288.00', 5),
(22037, '21580', '13.50', 1),
(22037, '65080', '478.00', 5),
(22037, '90693', '57.00', 3),
(22038, '22002', '55.50', 5),
(22038, '65081', '112.00', 5),
(22038, '90737', '354.00', 3),
(22039, '22054', '70.50', 1),
(22039, '65082', '174.00', 5),
(22039, '91008', '94.00', 3),
(22040, '22055', '214.50', 2),
(22040, '65122', '1558.00', 5),
(22040, '92606', '106.00', 2),
(22041, '22056', '130.00', 3),
(22041, '65070', '118.50', 1),
(22041, '65142', '93.00', 1),
(22042, '22165', '5400.00', 1),
(22042, '49916', '25.00', 5),
(22042, '65080', '478.00', 1),
(22043, '22179', '1440.00', 5),
(22043, '49917', '25.50', 2),
(22043, '65081', '112.00', 2),
(22044, '22870', '21.00', 1),
(22044, '49919', '58.50', 5),
(22044, '65082', '174.00', 2),
(22045, '25079', '334.00', 1),
(22045, '49921', '357.00', 1),
(22045, '65122', '1558.00', 2),
(22046, '25121', '418.50', 2),
(22046, '55112', '598.50', 2),
(22046, '65142', '93.00', 2),
(22047, '25131', '1078.00', 8),
(22047, '49916', '25.00', 1),
(22047, '55129', '154.00', 5),
(22048, '25136', '180.00', 1),
(22048, '49917', '25.50', 5),
(22048, '55130', '298.50', 2),
(22049, '25137', '228.00', 3),
(22049, '49919', '58.50', 1),
(22049, '55550', '1558.50', 5),
(22050, '25138', '166.50', 1),
(22050, '49921', '357.00', 3),
(22050, '58028', '142.50', 3),
(22051, '25154', '276.00', 2),
(22051, '55112', '598.50', 5),
(22051, '59915', '25.00', 3),
(22052, '32055', '130.50', 5),
(22052, '55129', '154.00', 5),
(22052, '64509', '142.00', 1),
(22053, '32067', '94.50', 1),
(22053, '55130', '298.50', 5),
(22053, '64510', '154.00', 1),
(22054, '32069', '154.00', 5),
(22054, '55550', '1558.50', 1),
(22054, '64511', '227.50', 1),
(22055, '32191', '402.00', 2),
(22055, '58028', '142.50', 2),
(22055, '64550', '126.00', 1),
(22056, '32610', '106.50', 1),
(22056, '59915', '25.00', 2),
(22056, '64551', '118.00', 2),
(22057, '33044', '14.50', 3),
(22057, '42615', '106.00', 5),
(22057, '64509', '142.00', 5),
(22058, '33045', '17.50', 3),
(22058, '42626', '141.50', 3),
(22058, '64510', '154.00', 1),
(22059, '33046', '15.00', 5),
(22059, '42929', '83.00', 5),
(22059, '64511', '227.50', 3),
(22060, '33047', '16.00', 1),
(22060, '42933', '69.50', 2),
(22060, '64550', '126.00', 5),
(22061, '35911', '11.50', 2),
(22061, '42934', '69.50', 5),
(22061, '64551', '118.00', 1),
(22062, '35912', '11.50', 1),
(22062, '42615', '106.00', 2),
(22062, '42939', '95.00', 1),
(22063, '37710', '35.00', 3),
(22063, '42626', '141.50', 2),
(22063, '42941', '71.00', 1),
(22064, '37720', '42.00', 5),
(22064, '42929', '83.00', 1),
(22064, '42945', '81.50', 3),
(22065, '37725', '36.00', 1),
(22065, '42933', '69.50', 1),
(22065, '43000', '540.00', 2),
(22066, '37730', '23.50', 4),
(22066, '42934', '69.50', 3),
(22066, '43014', '372.00', 2),
(22067, '37731', '30.00', 5),
(22067, '42939', '95.00', 3),
(22067, '43015', '288.00', 2),
(22068, '37732', '27.00', 2),
(22068, '42941', '71.00', 3),
(22068, '44939', '115.00', 5),
(22069, '41020', '94.50', 3),
(22069, '42945', '81.50', 2),
(22069, '45101', '57.00', 2),
(22070, '41096', '115.00', 2),
(22070, '43000', '540.00', 5),
(22070, '45105', '45.00', 5),
(22071, '41097', '142.50', 5),
(22071, '43014', '372.00', 5),
(22071, '45923', '42.00', 1),
(22072, '41098', '83.00', 5),
(22072, '43015', '288.00', 5),
(22072, '45935', '19.50', 5),
(22073, '42613', '106.00', 1),
(22073, '44939', '115.00', 1),
(22073, '46702', '71.50', 5),
(22074, '42615', '106.00', 3),
(22074, '45101', '57.00', 5),
(22074, '46706', '27.50', 5),
(22075, '33047', '16.00', 3),
(22075, '42626', '141.50', 5),
(22075, '45105', '45.00', 1),
(22076, '35911', '11.50', 3),
(22076, '42929', '83.00', 1),
(22076, '45923', '42.00', 5),
(22077, '35912', '11.50', 5),
(22077, '42933', '69.50', 2),
(22077, '45935', '19.50', 3),
(22078, '37710', '35.00', 2),
(22078, '42934', '69.50', 1),
(22078, '46702', '71.50', 2),
(22079, '37720', '42.00', 1),
(22079, '42939', '95.00', 5),
(22079, '46706', '27.50', 1),
(22080, '33047', '16.00', 2),
(22080, '37725', '36.00', 3),
(22080, '42941', '71.00', 2),
(22081, '35911', '11.50', 2),
(22081, '37730', '23.50', 7),
(22081, '42945', '81.50', 5),
(22082, '35912', '11.50', 5),
(22082, '37731', '30.00', 5),
(22082, '43000', '540.00', 1),
(22083, '10820', '46.50', 5),
(22083, '37710', '35.00', 5),
(22083, '43014', '372.00', 1),
(22084, '10822', '46.50', 2),
(22084, '37720', '42.00', 5),
(22084, '43015', '288.00', 5),
(22085, '10830', '57.50', 3),
(22085, '37725', '36.00', 5),
(22085, '44939', '115.00', 2),
(22086, '10835', '83.00', 3),
(22086, '37730', '23.50', 15),
(22086, '45101', '57.00', 1),
(22087, '10854', '39.50', 5),
(22087, '37731', '30.00', 3),
(22087, '45105', '45.00', 3),
(22088, '10820', '46.50', 1),
(22088, '11630', '46.50', 3),
(22088, '45923', '42.00', 2),
(22089, '10822', '46.50', 5),
(22089, '12054', '358.50', 2),
(22089, '45935', '19.50', 2),
(22090, '10830', '57.50', 5),
(22090, '12055', '238.50', 3),
(22090, '46702', '71.50', 5),
(22091, '10835', '83.00', 5),
(22091, '12056', '191.50', 3),
(22091, '46706', '27.50', 5),
(22092, '10854', '39.50', 1),
(22092, '12088', '215.00', 5),
(22092, '46738', '40.00', 5),
(22093, '11630', '46.50', 2),
(22093, '12089', '144.00', 3),
(22093, '46741', '10.00', 8),
(22094, '12054', '358.50', 5),
(22094, '12090', '192.00', 5),
(22094, '46745', '43.50', 5),
(22095, '12055', '238.50', 5),
(22095, '12091', '286.50', 2),
(22095, '47903', '11214.00', 5),
(22096, '12056', '191.50', 2),
(22096, '12092', '238.50', 5),
(22096, '49916', '25.00', 5),
(22097, '12088', '215.00', 1),
(22097, '13001', '38.00', 1),
(22097, '49917', '25.50', 1),
(22098, '12089', '144.00', 5),
(22098, '15207', '24.50', 1),
(22098, '49919', '58.50', 5),
(22099, '12090', '192.00', 2),
(22099, '15208', '24.50', 3),
(22099, '49921', '357.00', 2),
(22100, '12091', '286.50', 5),
(22100, '15211', '209.00', 5),
(22100, '55112', '598.50', 1),
(22101, '12092', '238.50', 3),
(22101, '15217', '32.00', 5),
(22101, '55129', '154.00', 5),
(22102, '13001', '38.00', 3),
(22102, '15559', '38.00', 2),
(22102, '55130', '298.50', 2),
(22103, '15207', '24.50', 2),
(22103, '20936', '25.00', 1),
(22103, '55550', '1558.50', 3),
(22104, '15208', '24.50', 5),
(22104, '20980', '27.50', 1),
(22104, '58028', '142.50', 1),
(22105, '15211', '209.00', 2),
(22105, '21032', '57.50', 2),
(22105, '59915', '25.00', 5),
(22106, '15217', '32.00', 1),
(22106, '21034', '504.00', 2),
(22106, '64509', '142.00', 1),
(22107, '15559', '38.00', 1),
(22107, '21037', '294.00', 5),
(22107, '64510', '154.00', 2),
(22108, '20936', '25.00', 1),
(22108, '21510', '35.50', 1),
(22108, '64511', '227.50', 2),
(22109, '20980', '27.50', 3),
(22109, '21514', '28.00', 3),
(22109, '64550', '126.00', 1),
(22110, '21032', '57.50', 5),
(22110, '21515', '27.00', 5),
(22110, '64551', '118.00', 3),
(22111, '21034', '504.00', 5),
(22111, '21517', '16.00', 2),
(22111, '64552', '276.00', 1),
(22112, '21037', '294.00', 1),
(22112, '21580', '13.50', 2),
(22112, '42929', '83.00', 5),
(22112, '65032', '598.50', 3),
(22113, '21510', '35.50', 3),
(22113, '22002', '55.50', 2),
(22113, '42933', '69.50', 3),
(22113, '65033', '1044.00', 2),
(22114, '21514', '28.00', 2),
(22114, '22054', '70.50', 5),
(22114, '42934', '69.50', 2),
(22114, '65034', '15000.00', 3),
(22115, '21515', '27.00', 1),
(22115, '22055', '214.50', 5),
(22115, '42939', '95.00', 5),
(22115, '65060', '46.50', 5),
(22116, '21517', '16.00', 5),
(22116, '22056', '130.00', 5),
(22116, '42941', '71.00', 5),
(22116, '65070', '118.50', 3),
(22117, '21580', '13.50', 5),
(22117, '22165', '5400.00', 5),
(22117, '42945', '81.50', 1),
(22117, '65080', '478.00', 3),
(22118, '22002', '55.50', 5),
(22118, '22179', '1440.00', 2),
(22118, '43000', '540.00', 3),
(22118, '65081', '112.00', 5),
(22119, '22054', '70.50', 1),
(22119, '22870', '21.00', 3),
(22119, '43014', '372.00', 3),
(22119, '65082', '174.00', 1),
(22120, '22055', '214.50', 1),
(22120, '25079', '334.00', 3),
(22120, '43015', '288.00', 1),
(22120, '65122', '1558.00', 5),
(22121, '22056', '130.00', 2),
(22121, '25121', '418.50', 5),
(22121, '44939', '115.00', 1),
(22121, '65142', '93.00', 5),
(22122, '22165', '5400.00', 1),
(22122, '25131', '1078.00', 2),
(22122, '45101', '57.00', 3),
(22122, '65143', '83.50', 5),
(22123, '22179', '1440.00', 5),
(22123, '25136', '180.00', 5),
(22123, '45105', '45.00', 2),
(22123, '65147', '238.50', 2),
(22124, '22870', '21.00', 5),
(22124, '25137', '228.00', 2),
(22124, '45923', '42.00', 5),
(22124, '65190', '190.50', 5),
(22125, '25079', '334.00', 5),
(22125, '25138', '166.50', 3),
(22125, '45935', '19.50', 5),
(22125, '65191', '23.00', 1),
(22126, '25121', '418.50', 5),
(22126, '25154', '276.00', 3),
(22126, '46702', '71.50', 1),
(22126, '65247', '75.00', 1),
(22127, '25131', '1078.00', 3),
(22127, '32055', '130.50', 1),
(22127, '46706', '27.50', 5),
(22127, '71912', '35.00', 1),
(22128, '25136', '180.00', 1),
(22128, '32067', '94.50', 2),
(22128, '33047', '16.00', 1),
(22128, '72777', '154.00', 5),
(22129, '25137', '228.00', 5),
(22129, '32069', '154.00', 1),
(22129, '35911', '11.50', 5),
(22129, '72942', '35.50', 2),
(22130, '25138', '166.50', 5),
(22130, '32191', '402.00', 1),
(22130, '35912', '11.50', 1),
(22130, '72943', '35.50', 1),
(22131, '25154', '276.00', 2),
(22131, '32610', '106.50', 2),
(22131, '37710', '35.00', 3),
(22131, '72944', '42.00', 1),
(22132, '32055', '130.50', 3),
(22132, '33044', '14.50', 5),
(22132, '76032', '334.50', 5),
(22133, '32067', '94.50', 1),
(22133, '33045', '17.50', 2),
(22133, '77033', '358.00', 5),
(22134, '32069', '154.00', 2),
(22134, '33046', '15.00', 1),
(22134, '77036', '358.00', 2),
(22135, '32191', '402.00', 3),
(22135, '33047', '16.00', 3),
(22135, '77038', '478.00', 2),
(22136, '32610', '106.50', 5),
(22136, '35911', '11.50', 5),
(22136, '77249', '1558.00', 1),
(22137, '33044', '14.50', 2),
(22137, '35912', '11.50', 1),
(22137, '77251', '658.00', 1),
(22138, '33045', '17.50', 5),
(22138, '37710', '35.00', 2),
(22138, '77252', '34.50', 5),
(22139, '33046', '15.00', 3),
(22139, '37720', '42.00', 2),
(22139, '77276', '4558.00', 2),
(22140, '33047', '16.00', 2),
(22140, '37725', '36.00', 2),
(22140, '77277', '358.00', 5),
(22141, '35911', '11.50', 5),
(22141, '37730', '23.50', 5),
(22141, '78029', '142.50', 3),
(22142, '35912', '11.50', 2),
(22142, '37731', '30.00', 2),
(22142, '80032', '154.50', 3),
(22143, '37710', '35.00', 1),
(22143, '37732', '27.00', 3),
(22143, '80082', '118.50', 2),
(22144, '37720', '42.00', 5),
(22144, '41020', '94.50', 3),
(22144, '80088', '213.00', 3),
(22145, '37725', '36.00', 5),
(22145, '41096', '115.00', 4),
(22145, '80692', '39.50', 3),
(22146, '37730', '23.50', 2),
(22146, '41097', '142.50', 2),
(22146, '81007', '62.50', 3),
(22147, '37731', '30.00', 2),
(22147, '41098', '83.00', 3),
(22147, '82090', '30.00', 5),
(22148, '37732', '27.00', 2),
(22148, '42613', '106.00', 5),
(22148, '82092', '18.00', 4),
(22149, '41020', '94.50', 2),
(22149, '42615', '106.00', 2),
(22149, '82093', '24.00', 5),
(22150, '41096', '115.00', 7),
(22150, '42626', '141.50', 1),
(22150, '82095', '23.50', 9),
(22151, '41097', '142.50', 1),
(22151, '42929', '83.00', 2),
(22151, '82096', '27.50', 5),
(22152, '41098', '83.00', 5),
(22152, '42933', '69.50', 5),
(22152, '83013', '46.00', 1),
(22153, '42613', '106.00', 5),
(22153, '42934', '69.50', 1),
(22153, '90106', '38.00', 3),
(22154, '42615', '106.00', 5),
(22154, '42939', '95.00', 3),
(22154, '90109', '40.50', 5),
(22155, '42626', '141.50', 3),
(22155, '42941', '71.00', 1),
(22155, '90116', '50.00', 5),
(22156, '42929', '83.00', 2),
(22156, '42945', '81.50', 5),
(22156, '90164', '75.50', 1),
(22157, '42933', '69.50', 3),
(22157, '43000', '540.00', 2),
(22157, '90192', '70.50', 5),
(22158, '42934', '69.50', 2),
(22158, '43014', '372.00', 2),
(22158, '90208', '71.00', 5),
(22159, '42939', '95.00', 2),
(22159, '43015', '288.00', 5),
(22159, '90209', '71.00', 1),
(22160, '42941', '71.00', 5),
(22160, '44939', '115.00', 15),
(22160, '90212', '71.00', 3),
(22161, '42945', '81.50', 1),
(22161, '45101', '57.00', 2),
(22161, '90510', '430.50', 5),
(22162, '43000', '540.00', 5),
(22162, '45105', '45.00', 1),
(22162, '90521', '142.50', 3),
(22163, '43014', '372.00', 5),
(22163, '45923', '42.00', 2),
(22163, '90531', '83.00', 1),
(22164, '43015', '288.00', 5),
(22164, '45935', '19.50', 2),
(22164, '90545', '288.00', 1),
(22165, '44939', '115.00', 5),
(22165, '46702', '71.50', 3),
(22165, '90693', '57.00', 1),
(22166, '45101', '57.00', 3),
(22166, '46706', '27.50', 3),
(22166, '90737', '354.00', 2),
(22167, '45105', '45.00', 3),
(22167, '46738', '40.00', 2),
(22167, '91008', '94.00', 5),
(22168, '45923', '42.00', 5),
(22168, '46741', '10.00', 2),
(22168, '92606', '106.00', 1),
(22169, '45935', '19.50', 1),
(22169, '46745', '43.50', 1),
(22169, '65060', '46.50', 5),
(22170, '46702', '71.50', 2),
(22170, '47903', '11214.00', 2),
(22170, '65070', '118.50', 1),
(22171, '46706', '27.50', 2),
(22171, '49916', '25.00', 3),
(22171, '65080', '478.00', 5),
(22172, '46738', '40.00', 5),
(22172, '49917', '25.50', 5),
(22172, '65081', '112.00', 1),
(22173, '46741', '10.00', 3),
(22173, '49919', '58.50', 1),
(22173, '65082', '174.00', 3),
(22174, '46745', '43.50', 3),
(22174, '49921', '357.00', 5),
(22174, '65122', '1558.00', 2),
(22175, '47903', '11214.00', 1),
(22175, '55112', '598.50', 2),
(22175, '65142', '93.00', 2),
(22176, '10820', '46.50', 1),
(22176, '49916', '25.00', 5),
(22176, '55129', '154.00', 5),
(22177, '10822', '46.50', 5),
(22177, '49917', '25.50', 1),
(22177, '55130', '298.50', 1),
(22178, '10830', '57.50', 5),
(22178, '49919', '58.50', 5),
(22178, '55550', '1558.50', 2),
(22179, '10835', '83.00', 3),
(22179, '49921', '357.00', 1),
(22179, '58028', '142.50', 2),
(22180, '10854', '39.50', 2),
(22180, '55112', '598.50', 1),
(22180, '59915', '25.00', 5),
(22181, '11630', '46.50', 1),
(22181, '55129', '154.00', 2),
(22181, '64509', '142.00', 3),
(22182, '12054', '358.50', 1),
(22182, '55130', '298.50', 3),
(22182, '64510', '154.00', 5),
(22183, '12055', '238.50', 5),
(22183, '55550', '1558.50', 5),
(22183, '64511', '227.50', 5),
(22184, '12056', '191.50', 5),
(22184, '58028', '142.50', 5),
(22184, '64550', '126.00', 5),
(22185, '12088', '215.00', 3),
(22185, '59915', '25.00', 3),
(22185, '64551', '118.00', 2),
(22186, '12089', '144.00', 2),
(22186, '64509', '142.00', 5),
(22186, '64552', '276.00', 5),
(22187, '12090', '192.00', 5),
(22187, '64510', '154.00', 1),
(22187, '65032', '598.50', 3),
(22188, '12091', '286.50', 1),
(22188, '64511', '227.50', 1),
(22188, '65033', '1044.00', 5),
(22189, '12092', '238.50', 2),
(22189, '64550', '126.00', 2),
(22189, '65034', '15000.00', 2),
(22190, '13001', '38.00', 2),
(22190, '64551', '118.00', 5),
(22190, '65060', '46.50', 5),
(22191, '15207', '24.50', 1),
(22191, '64552', '276.00', 1),
(22191, '65070', '118.50', 3),
(22192, '15208', '24.50', 3),
(22192, '65032', '598.50', 2),
(22192, '65080', '478.00', 1),
(22193, '15211', '209.00', 1),
(22193, '65033', '1044.00', 1),
(22193, '65081', '112.00', 3),
(22194, '15217', '32.00', 2),
(22194, '65034', '15000.00', 5),
(22194, '65082', '174.00', 5),
(22195, '15559', '38.00', 5),
(22195, '65060', '46.50', 2),
(22195, '65122', '1558.00', 5),
(22196, '20936', '25.00', 2),
(22196, '65070', '118.50', 2),
(22196, '65142', '93.00', 5),
(22197, '20980', '27.50', 5),
(22197, '65080', '478.00', 5),
(22197, '65143', '83.50', 1),
(22198, '21032', '57.50', 1),
(22198, '65081', '112.00', 2),
(22198, '65147', '238.50', 1),
(22199, '21034', '504.00', 1),
(22199, '65082', '174.00', 2),
(22199, '65190', '190.50', 2),
(22200, '21037', '294.00', 5),
(22200, '65122', '1558.00', 2),
(22200, '65191', '23.00', 5),
(22201, '21510', '35.50', 3),
(22201, '65142', '93.00', 1),
(22201, '65247', '75.00', 5),
(22202, '21514', '28.00', 5),
(22202, '65143', '83.50', 2),
(22202, '71912', '35.00', 3),
(22203, '21515', '27.00', 5),
(22203, '65147', '238.50', 3),
(22203, '72777', '154.00', 3),
(22204, '21517', '16.00', 5),
(22204, '65190', '190.50', 1),
(22204, '72942', '35.50', 2),
(22205, '21580', '13.50', 2),
(22205, '65191', '23.00', 1),
(22205, '72943', '35.50', 5),
(22206, '22002', '55.50', 5),
(22206, '65247', '75.00', 1),
(22206, '72944', '42.00', 1),
(22207, '22054', '70.50', 2),
(22207, '71912', '35.00', 2),
(22207, '76032', '334.50', 3),
(22208, '22055', '214.50', 1),
(22208, '72777', '154.00', 2),
(22208, '77033', '358.00', 1),
(22209, '72942', '35.50', 1),
(22209, '77036', '358.00', 3),
(22210, '72943', '35.50', 3),
(22210, '77038', '478.00', 1),
(22211, '72944', '42.00', 3),
(22211, '77249', '1558.00', 5),
(22212, '76032', '334.50', 2),
(22212, '77251', '658.00', 3),
(22213, '77033', '358.00', 2),
(22213, '77252', '34.50', 2),
(22214, '77036', '358.00', 2),
(22214, '77276', '4558.00', 5),
(22215, '77038', '478.00', 3),
(22215, '77277', '358.00', 5),
(22216, '77249', '1558.00', 1),
(22216, '78029', '142.50', 1),
(22217, '77251', '658.00', 2),
(22217, '80032', '154.50', 5),
(22218, '77252', '34.50', 1),
(22218, '80082', '118.50', 5),
(22219, '25154', '276.00', 3),
(22219, '77276', '4558.00', 1),
(22219, '80088', '213.00', 2),
(22220, '32055', '130.50', 2),
(22220, '77277', '358.00', 1),
(22220, '80692', '39.50', 2),
(22221, '32067', '94.50', 5),
(22221, '78029', '142.50', 3),
(22221, '81007', '62.50', 2),
(22222, '32069', '154.00', 2),
(22222, '80032', '154.50', 5),
(22222, '82090', '30.00', 1),
(22223, '32191', '402.00', 5),
(22223, '80082', '118.50', 1),
(22223, '82092', '18.00', 7),
(22224, '32610', '106.50', 2),
(22224, '80088', '213.00', 5),
(22224, '82093', '24.00', 5),
(22225, '33044', '14.50', 5),
(22225, '80692', '39.50', 5),
(22225, '82095', '23.50', 10),
(22226, '33045', '17.50', 1),
(22226, '81007', '62.50', 1),
(22226, '82096', '27.50', 2),
(22227, '33046', '15.00', 2),
(22227, '82090', '30.00', 3),
(22227, '83013', '46.00', 3),
(22228, '33047', '16.00', 1),
(22228, '82092', '18.00', 15),
(22228, '90106', '38.00', 1),
(22229, '35911', '11.50', 5),
(22229, '82093', '24.00', 1),
(22229, '90109', '40.50', 5),
(22230, '35912', '11.50', 1),
(22230, '82095', '23.50', 13),
(22230, '90116', '50.00', 1),
(22231, '37710', '35.00', 5),
(22231, '82096', '27.50', 1),
(22231, '90164', '75.50', 3),
(22232, '37720', '42.00', 2),
(22232, '83013', '46.00', 2),
(22232, '90192', '70.50', 5),
(22233, '37725', '36.00', 5),
(22233, '90106', '38.00', 3),
(22233, '90208', '71.00', 5),
(22234, '37730', '23.50', 3),
(22234, '90109', '40.50', 3),
(22234, '90209', '71.00', 3),
(22235, '37731', '30.00', 5),
(22235, '90116', '50.00', 3),
(22235, '90212', '71.00', 2),
(22236, '37732', '27.00', 1),
(22236, '90164', '75.50', 5),
(22236, '90510', '430.50', 2),
(22237, '41020', '94.50', 1),
(22237, '90192', '70.50', 1),
(22237, '90521', '142.50', 2),
(22238, '41096', '115.00', 2),
(22238, '90208', '71.00', 5),
(22238, '90531', '83.00', 5),
(22239, '41097', '142.50', 5),
(22239, '90209', '71.00', 2),
(22239, '90545', '288.00', 2),
(22240, '41098', '83.00', 2),
(22240, '90212', '71.00', 1),
(22240, '90693', '57.00', 2),
(22241, '42613', '106.00', 5),
(22241, '90510', '430.50', 1),
(22241, '90737', '354.00', 1),
(22242, '42615', '106.00', 1),
(22242, '90521', '142.50', 1),
(22242, '91008', '94.00', 2),
(22243, '42626', '141.50', 2),
(22243, '90531', '83.00', 5),
(22243, '92606', '106.00', 5),
(22244, '25079', '334.00', 2),
(22244, '42929', '83.00', 5),
(22244, '90545', '288.00', 5),
(22245, '25121', '418.50', 1),
(22245, '42933', '69.50', 5),
(22245, '90693', '57.00', 5),
(22246, '25131', '1078.00', 5),
(22246, '42934', '69.50', 1),
(22246, '90737', '354.00', 3);
INSERT INTO Ordrelinje VALUES
(22247, '25136', '180.00', 5),
(22247, '42939', '95.00', 5),
(22247, '91008', '94.00', 5),
(22248, '25137', '228.00', 1),
(22248, '42941', '71.00', 3),
(22248, '92606', '106.00', 2),
(22249, '25138', '166.50', 5),
(22249, '42945', '81.50', 3),
(22249, '64550', '126.00', 5),
(22250, '25154', '276.00', 2),
(22250, '43000', '540.00', 1),
(22250, '64551', '118.00', 1),
(22251, '32055', '130.50', 5),
(22251, '43014', '372.00', 1),
(22251, '64552', '276.00', 5),
(22252, '32067', '94.50', 3),
(22252, '43015', '288.00', 1),
(22252, '65032', '598.50', 5),
(22253, '32069', '154.00', 5),
(22253, '44939', '115.00', 9),
(22253, '65033', '1044.00', 3),
(22254, '32191', '402.00', 2),
(22254, '45101', '57.00', 1),
(22254, '65034', '15000.00', 2),
(22255, '25079', '334.00', 5),
(22255, '45105', '45.00', 2),
(22255, '65060', '46.50', 5),
(22256, '25121', '418.50', 5),
(22256, '45923', '42.00', 2),
(22256, '65070', '118.50', 3),
(22257, '25131', '1078.00', 2),
(22257, '45935', '19.50', 3),
(22257, '65080', '478.00', 5),
(22258, '25136', '180.00', 2),
(22258, '46702', '71.50', 2),
(22258, '65081', '112.00', 2),
(22259, '25137', '228.00', 5),
(22259, '46706', '27.50', 3),
(22259, '65082', '174.00', 5),
(22260, '25138', '166.50', 3),
(22260, '46738', '40.00', 1),
(22260, '65122', '1558.00', 3),
(22261, '25154', '276.00', 1),
(22261, '46741', '10.00', 5),
(22261, '65142', '93.00', 3),
(22262, '25136', '180.00', 5),
(22262, '32055', '130.50', 1),
(22262, '46745', '43.50', 2),
(22263, '25137', '228.00', 1),
(22263, '32067', '94.50', 2),
(22263, '47903', '11214.00', 3),
(22264, '25138', '166.50', 2),
(22264, '32069', '154.00', 1),
(22264, '49916', '25.00', 5),
(22265, '25154', '276.00', 5),
(22265, '32191', '402.00', 5),
(22265, '49917', '25.50', 3),
(22266, '32055', '130.50', 3),
(22266, '32610', '106.50', 5),
(22266, '49919', '58.50', 2),
(22267, '22870', '21.00', 2),
(22267, '32067', '94.50', 5),
(22267, '49921', '357.00', 3),
(22268, '25079', '334.00', 5),
(22268, '32069', '154.00', 3),
(22268, '55112', '598.50', 1),
(22269, '25121', '418.50', 1),
(22269, '32191', '402.00', 5),
(22269, '55129', '154.00', 2),
(22270, '25079', '334.00', 1),
(22270, '25131', '1078.00', 1),
(22270, '55130', '298.50', 5),
(22271, '22055', '214.50', 5),
(22271, '25121', '418.50', 5),
(22271, '55550', '1558.50', 1),
(22272, '22056', '130.00', 5),
(22272, '25131', '1078.00', 3),
(22272, '58028', '142.50', 5),
(22273, '22165', '5400.00', 5),
(22273, '25136', '180.00', 1),
(22273, '59915', '25.00', 2),
(22274, '22179', '1440.00', 1),
(22274, '25137', '228.00', 3),
(22274, '64509', '142.00', 5),
(22275, '22870', '21.00', 5),
(22275, '25138', '166.50', 5),
(22275, '64510', '154.00', 5),
(22276, '25079', '334.00', 5),
(22276, '25154', '276.00', 1),
(22276, '64511', '227.50', 3),
(22277, '25121', '418.50', 2),
(22277, '32055', '130.50', 2),
(22277, '64550', '126.00', 1),
(22278, '25131', '1078.00', 2),
(22278, '32067', '94.50', 1),
(22278, '64551', '118.00', 3),
(22279, '22870', '21.00', 5),
(22279, '32069', '154.00', 1),
(22279, '64552', '276.00', 3),
(22280, '25079', '334.00', 1),
(22280, '32191', '402.00', 1),
(22280, '65032', '598.50', 3),
(22281, '25121', '418.50', 5),
(22281, '32610', '106.50', 1),
(22281, '65033', '1044.00', 2),
(22282, '25131', '1078.00', 2),
(22282, '65034', '15000.00', 1),
(22282, '65060', '46.50', 1),
(22283, '22055', '214.50', 1),
(22283, '65060', '46.50', 2),
(22283, '65070', '118.50', 2),
(22284, '22056', '130.00', 5),
(22284, '65070', '118.50', 5),
(22284, '65080', '478.00', 5),
(22285, '22165', '5400.00', 2),
(22285, '64509', '142.00', 3),
(22285, '65080', '478.00', 3),
(22286, '22179', '1440.00', 2),
(22286, '64510', '154.00', 3),
(22286, '65081', '112.00', 5),
(22287, '22870', '21.00', 1),
(22287, '64511', '227.50', 2),
(22287, '65082', '174.00', 5),
(22288, '25079', '334.00', 5),
(22288, '64550', '126.00', 2),
(22288, '65122', '1558.00', 2),
(22289, '25121', '418.50', 1),
(22289, '64551', '118.00', 2),
(22289, '65142', '93.00', 2),
(22290, '25131', '1078.00', 5),
(22290, '64552', '276.00', 5),
(22290, '65143', '83.50', 5),
(22291, '25136', '180.00', 2),
(22291, '65032', '598.50', 2),
(22291, '65147', '238.50', 5),
(22292, '25137', '228.00', 5),
(22292, '65033', '1044.00', 5),
(22292, '65190', '190.50', 3),
(22293, '25138', '166.50', 2),
(22293, '65034', '15000.00', 3),
(22293, '65191', '23.00', 3),
(22294, '25154', '276.00', 5),
(22294, '65060', '46.50', 5),
(22294, '65247', '75.00', 5),
(22295, '10820', '46.50', 2),
(22295, '65070', '118.50', 1),
(22295, '71912', '35.00', 1),
(22296, '10822', '46.50', 5),
(22296, '65080', '478.00', 2),
(22296, '72777', '154.00', 2),
(22297, '10830', '57.50', 5),
(22297, '65081', '112.00', 1),
(22297, '72942', '35.50', 2),
(22298, '10835', '83.00', 1),
(22298, '65082', '174.00', 1),
(22298, '72943', '35.50', 5),
(22299, '10854', '39.50', 1),
(22299, '65122', '1558.00', 2),
(22299, '72944', '42.00', 5),
(22300, '11630', '46.50', 1),
(22300, '65142', '93.00', 2),
(22300, '76032', '334.50', 5),
(22301, '12054', '358.50', 3),
(22301, '49916', '25.00', 1),
(22301, '77033', '358.00', 3),
(22302, '12055', '238.50', 2),
(22302, '49917', '25.50', 5),
(22302, '77036', '358.00', 2),
(22303, '12056', '191.50', 1),
(22303, '49919', '58.50', 5),
(22303, '77038', '478.00', 5),
(22304, '12088', '215.00', 2),
(22304, '49921', '357.00', 2),
(22304, '77249', '1558.00', 5),
(22305, '12089', '144.00', 5),
(22305, '55112', '598.50', 5),
(22305, '77251', '658.00', 5),
(22306, '12090', '192.00', 1),
(22306, '55129', '154.00', 1),
(22306, '77252', '34.50', 3),
(22307, '12091', '286.50', 3),
(22307, '55130', '298.50', 2),
(22307, '77276', '4558.00', 3),
(22308, '12092', '238.50', 5),
(22308, '55550', '1558.50', 3),
(22308, '77277', '358.00', 5),
(22309, '13001', '38.00', 2),
(22309, '58028', '142.50', 3),
(22309, '78029', '142.50', 1),
(22310, '15207', '24.50', 2),
(22310, '59915', '25.00', 3),
(22310, '80032', '154.50', 3),
(22311, '15208', '24.50', 1),
(22311, '64509', '142.00', 2),
(22311, '80082', '118.50', 5),
(22312, '15211', '209.00', 3),
(22312, '64510', '154.00', 3),
(22312, '80088', '213.00', 1),
(22313, '15217', '32.00', 5),
(22313, '64511', '227.50', 5),
(22313, '80692', '39.50', 3),
(22314, '15559', '38.00', 5),
(22314, '64550', '126.00', 5),
(22314, '81007', '62.50', 4),
(22315, '20936', '25.00', 5),
(22315, '64551', '118.00', 5),
(22315, '82090', '30.00', 2),
(22316, '20980', '27.50', 5),
(22316, '42615', '106.00', 5),
(22316, '82092', '18.00', 5),
(22317, '21032', '57.50', 1),
(22317, '42626', '141.50', 1),
(22317, '82093', '24.00', 5),
(22318, '21034', '504.00', 5),
(22318, '42929', '83.00', 5),
(22318, '82095', '23.50', 4),
(22319, '21037', '294.00', 1),
(22319, '42933', '69.50', 5),
(22319, '82096', '27.50', 2),
(22320, '21510', '35.50', 1),
(22320, '42934', '69.50', 1),
(22320, '83013', '46.00', 2),
(22321, '21514', '28.00', 1),
(22321, '42939', '95.00', 2),
(22321, '90106', '38.00', 1),
(22322, '21515', '27.00', 3),
(22322, '42941', '71.00', 5),
(22322, '90109', '40.50', 2),
(22323, '21517', '16.00', 3),
(22323, '42945', '81.50', 5),
(22323, '90116', '50.00', 2),
(22324, '21580', '13.50', 5),
(22324, '43000', '540.00', 5),
(22324, '90164', '75.50', 5),
(22325, '22002', '55.50', 1),
(22325, '43014', '372.00', 3),
(22325, '90192', '70.50', 2),
(22326, '22054', '70.50', 5),
(22326, '43015', '288.00', 2),
(22326, '90208', '71.00', 2),
(22327, '22055', '214.50', 3),
(22327, '44939', '115.00', 10),
(22327, '90209', '71.00', 5),
(22328, '22056', '130.00', 1),
(22328, '45101', '57.00', 3),
(22328, '90212', '71.00', 5),
(22329, '22165', '5400.00', 5),
(22329, '45105', '45.00', 5),
(22329, '90510', '430.50', 3),
(22330, '22179', '1440.00', 5),
(22330, '45923', '42.00', 1),
(22330, '90521', '142.50', 5),
(22331, '22870', '21.00', 5),
(22331, '45935', '19.50', 5),
(22331, '90531', '83.00', 1),
(22332, '25079', '334.00', 2),
(22332, '46702', '71.50', 5),
(22332, '90545', '288.00', 5),
(22333, '25121', '418.50', 2),
(22333, '46706', '27.50', 5),
(22333, '90693', '57.00', 2),
(22334, '10820', '46.50', 3),
(22334, '25131', '1078.00', 1),
(22334, '33047', '16.00', 2),
(22335, '10822', '46.50', 2),
(22335, '25136', '180.00', 5),
(22335, '35911', '11.50', 2),
(22336, '10830', '57.50', 5),
(22336, '25137', '228.00', 5),
(22336, '35912', '11.50', 5),
(22337, '10835', '83.00', 5),
(22337, '25138', '166.50', 1),
(22337, '37710', '35.00', 3),
(22338, '10854', '39.50', 2),
(22338, '25154', '276.00', 3),
(22338, '37720', '42.00', 3),
(22339, '11630', '46.50', 2),
(22339, '32055', '130.50', 1),
(22339, '37725', '36.00', 1),
(22340, '12054', '358.50', 2),
(22340, '32067', '94.50', 5),
(22340, '37730', '23.50', 6),
(22341, '12055', '238.50', 5),
(22341, '32069', '154.00', 2),
(22341, '37731', '30.00', 5),
(22342, '10820', '46.50', 5),
(22342, '12056', '191.50', 3),
(22342, '32191', '402.00', 5),
(22343, '10822', '46.50', 1),
(22343, '12088', '215.00', 5),
(22343, '32610', '106.50', 3),
(22344, '10830', '57.50', 2),
(22344, '12089', '144.00', 5),
(22344, '33044', '14.50', 5),
(22345, '10835', '83.00', 2),
(22345, '12090', '192.00', 3),
(22345, '33045', '17.50', 3),
(22346, '10854', '39.50', 5),
(22346, '12091', '286.50', 2),
(22346, '33046', '15.00', 5),
(22347, '11630', '46.50', 3),
(22347, '12092', '238.50', 1),
(22347, '33047', '16.00', 1),
(22348, '12054', '358.50', 1),
(22348, '13001', '38.00', 5),
(22348, '35911', '11.50', 2),
(22349, '12055', '238.50', 5),
(22349, '15207', '24.50', 3),
(22349, '35912', '11.50', 5),
(22350, '12056', '191.50', 2),
(22350, '15208', '24.50', 2),
(22350, '37710', '35.00', 2),
(22351, '12088', '215.00', 1),
(22351, '15211', '209.00', 5),
(22351, '37720', '42.00', 2),
(22352, '12089', '144.00', 1),
(22352, '15217', '32.00', 2),
(22352, '37725', '36.00', 5),
(22353, '12090', '192.00', 2),
(22353, '15559', '38.00', 1),
(22353, '37730', '23.50', 8),
(22354, '12091', '286.50', 5),
(22354, '20936', '25.00', 2),
(22354, '37731', '30.00', 5),
(22355, '12092', '238.50', 1),
(22355, '20980', '27.50', 5),
(22355, '37732', '27.00', 2),
(22356, '13001', '38.00', 3),
(22356, '21032', '57.50', 5),
(22356, '41020', '94.50', 1),
(22357, '15207', '24.50', 5),
(22357, '21034', '504.00', 1),
(22357, '41096', '115.00', 13),
(22358, '15208', '24.50', 1),
(22358, '21037', '294.00', 5),
(22358, '41097', '142.50', 5),
(22359, '15211', '209.00', 2),
(22359, '21510', '35.50', 5),
(22359, '41098', '83.00', 5),
(22360, '15217', '32.00', 5),
(22360, '21514', '28.00', 5),
(22360, '42613', '106.00', 1),
(22361, '15559', '38.00', 5),
(22361, '21515', '27.00', 1),
(22361, '42615', '106.00', 2),
(22362, '20936', '25.00', 5),
(22362, '21517', '16.00', 3),
(22362, '42626', '141.50', 3),
(22363, '20980', '27.50', 1),
(22363, '21580', '13.50', 1),
(22363, '42929', '83.00', 1),
(22364, '21032', '57.50', 1),
(22364, '22002', '55.50', 5),
(22364, '42933', '69.50', 3),
(22365, '21034', '504.00', 3),
(22365, '22054', '70.50', 2),
(22365, '42934', '69.50', 5),
(22366, '21037', '294.00', 2),
(22366, '22055', '214.50', 5),
(22366, '42939', '95.00', 1),
(22367, '21510', '35.50', 1),
(22367, '22056', '130.00', 5),
(22367, '42941', '71.00', 1),
(22368, '21514', '28.00', 1),
(22368, '22165', '5400.00', 1),
(22368, '42945', '81.50', 5),
(22369, '21515', '27.00', 3),
(22369, '22179', '1440.00', 2),
(22369, '43000', '540.00', 1),
(22370, '21517', '16.00', 2),
(22370, '22870', '21.00', 1),
(22370, '43014', '372.00', 2),
(22371, '21580', '13.50', 3),
(22371, '25079', '334.00', 5),
(22371, '43015', '288.00', 2),
(22372, '22002', '55.50', 1),
(22372, '25121', '418.50', 5),
(22372, '44939', '115.00', 3),
(22373, '22054', '70.50', 5),
(22373, '25131', '1078.00', 3),
(22373, '45101', '57.00', 5),
(22374, '22055', '214.50', 5),
(22374, '25136', '180.00', 2),
(22374, '45105', '45.00', 1),
(22375, '22056', '130.00', 1),
(22375, '25137', '228.00', 3),
(22375, '45923', '42.00', 5),
(22376, '22165', '5400.00', 2),
(22376, '25138', '166.50', 3),
(22376, '45935', '19.50', 2),
(22377, '22179', '1440.00', 5),
(22377, '25154', '276.00', 2),
(22377, '46702', '71.50', 1),
(22378, '22870', '21.00', 5),
(22378, '32055', '130.50', 3),
(22378, '46706', '27.50', 5),
(22379, '25079', '334.00', 1),
(22379, '32067', '94.50', 3),
(22379, '46738', '40.00', 2),
(22380, '25121', '418.50', 2),
(22380, '32069', '154.00', 5),
(22380, '46741', '10.00', 2),
(22381, '25131', '1078.00', 2),
(22381, '32191', '402.00', 1),
(22381, '46745', '43.50', 5),
(22382, '25136', '180.00', 5),
(22382, '32610', '106.50', 2),
(22382, '47903', '11214.00', 5),
(22383, '25137', '228.00', 2),
(22383, '33044', '14.50', 1),
(22383, '49916', '25.00', 5),
(22384, '25138', '166.50', 5),
(22384, '33045', '17.50', 2),
(22384, '49917', '25.50', 5),
(22385, '25154', '276.00', 5),
(22385, '33046', '15.00', 1),
(22385, '49919', '58.50', 1),
(22386, '32055', '130.50', 2),
(22386, '33047', '16.00', 5),
(22386, '49921', '357.00', 1),
(22387, '32067', '94.50', 5),
(22387, '35911', '11.50', 1),
(22387, '55112', '598.50', 1),
(22388, '32069', '154.00', 1),
(22388, '35912', '11.50', 3),
(22388, '55129', '154.00', 3),
(22389, '32191', '402.00', 5),
(22389, '37710', '35.00', 5),
(22389, '55130', '298.50', 5),
(22390, '32610', '106.50', 2),
(22390, '37720', '42.00', 1),
(22390, '55550', '1558.50', 2),
(22391, '33044', '14.50', 5),
(22391, '37725', '36.00', 1),
(22391, '58028', '142.50', 3),
(22392, '33045', '17.50', 1),
(22392, '37730', '23.50', 2),
(22392, '59915', '25.00', 1),
(22393, '33046', '15.00', 3),
(22393, '37731', '30.00', 1),
(22393, '64509', '142.00', 5),
(22394, '33047', '16.00', 1),
(22394, '37732', '27.00', 2),
(22394, '64510', '154.00', 2),
(22395, '35911', '11.50', 2),
(22395, '41020', '94.50', 5),
(22395, '64511', '227.50', 1),
(22396, '35912', '11.50', 2),
(22396, '41096', '115.00', 4),
(22396, '64550', '126.00', 2),
(22397, '37710', '35.00', 1),
(22397, '41097', '142.50', 2),
(22397, '64551', '118.00', 1),
(22398, '37720', '42.00', 3),
(22398, '41098', '83.00', 2),
(22398, '64552', '276.00', 2),
(22399, '37725', '36.00', 5),
(22399, '42613', '106.00', 5),
(22399, '65032', '598.50', 5),
(22400, '37730', '23.50', 3),
(22400, '42615', '106.00', 2),
(22400, '65033', '1044.00', 1),
(22401, '37731', '30.00', 5),
(22401, '42626', '141.50', 2),
(22401, '65034', '15000.00', 5),
(22402, '37732', '27.00', 5),
(22402, '42929', '83.00', 5),
(22402, '65060', '46.50', 2),
(22403, '41020', '94.50', 3),
(22403, '42933', '69.50', 5),
(22403, '65070', '118.50', 1),
(22404, '41096', '115.00', 6),
(22404, '42934', '69.50', 3),
(22404, '65080', '478.00', 2),
(22405, '41097', '142.50', 5),
(22405, '42939', '95.00', 3),
(22405, '65081', '112.00', 3),
(22406, '41098', '83.00', 2),
(22406, '42941', '71.00', 5),
(22406, '65082', '174.00', 5),
(22407, '42613', '106.00', 5),
(22407, '42945', '81.50', 3),
(22407, '65122', '1558.00', 1),
(22408, '42615', '106.00', 1),
(22408, '43000', '540.00', 3),
(22408, '65142', '93.00', 5),
(22409, '42626', '141.50', 5),
(22409, '43014', '372.00', 1),
(22409, '65143', '83.50', 2),
(22410, '42929', '83.00', 5),
(22410, '43015', '288.00', 5),
(22410, '65147', '238.50', 5),
(22411, '42933', '69.50', 2),
(22411, '44939', '115.00', 8),
(22411, '65190', '190.50', 5),
(22412, '42934', '69.50', 5),
(22412, '45101', '57.00', 1),
(22412, '65191', '23.00', 5),
(22413, '42939', '95.00', 5),
(22413, '45105', '45.00', 3),
(22413, '65247', '75.00', 2),
(22414, '42941', '71.00', 1),
(22414, '45923', '42.00', 2),
(22414, '71912', '35.00', 5),
(22415, '42945', '81.50', 2),
(22415, '45935', '19.50', 5),
(22415, '72777', '154.00', 5),
(22416, '43000', '540.00', 5),
(22416, '46702', '71.50', 3),
(22416, '72942', '35.50', 3),
(22417, '43014', '372.00', 3),
(22417, '46706', '27.50', 1),
(22417, '72943', '35.50', 5),
(22418, '43015', '288.00', 1),
(22418, '46738', '40.00', 5),
(22418, '72944', '42.00', 1),
(22419, '44939', '115.00', 2),
(22419, '46741', '10.00', 1),
(22419, '76032', '334.50', 2),
(22420, '45101', '57.00', 5),
(22420, '46745', '43.50', 1),
(22420, '77033', '358.00', 1),
(22421, '45105', '45.00', 2),
(22421, '47903', '11214.00', 2),
(22421, '77036', '358.00', 3),
(22422, '45923', '42.00', 3),
(22422, '49916', '25.00', 5),
(22422, '77038', '478.00', 1),
(22423, '45935', '19.50', 5),
(22423, '49917', '25.50', 3),
(22423, '77249', '1558.00', 3),
(22424, '46702', '71.50', 2),
(22424, '49919', '58.50', 2),
(22424, '77251', '658.00', 1),
(22425, '46706', '27.50', 5),
(22425, '49921', '357.00', 3),
(22425, '77252', '34.50', 5),
(22426, '46738', '40.00', 2),
(22426, '55112', '598.50', 1),
(22426, '77276', '4558.00', 2),
(22427, '46741', '10.00', 3),
(22427, '55129', '154.00', 1),
(22427, '77277', '358.00', 2),
(22428, '46745', '43.50', 5),
(22428, '55130', '298.50', 5),
(22428, '78029', '142.50', 2),
(22429, '47903', '11214.00', 5),
(22429, '55550', '1558.50', 1),
(22429, '80032', '154.50', 2),
(22430, '49916', '25.00', 1),
(22430, '58028', '142.50', 1),
(22430, '80082', '118.50', 3),
(22431, '49917', '25.50', 2),
(22431, '59915', '25.00', 5),
(22431, '80088', '213.00', 3),
(22432, '49919', '58.50', 5),
(22432, '64509', '142.00', 2),
(22432, '80692', '39.50', 1),
(22433, '49921', '357.00', 2),
(22433, '64510', '154.00', 5),
(22433, '81007', '62.50', 7),
(22434, '55112', '598.50', 3),
(22434, '64511', '227.50', 5),
(22434, '82090', '30.00', 1),
(22435, '55129', '154.00', 1),
(22435, '64550', '126.00', 5),
(22435, '82092', '18.00', 2),
(22436, '55130', '298.50', 1),
(22436, '64551', '118.00', 5),
(22436, '82093', '24.00', 1),
(22437, '55550', '1558.50', 3),
(22437, '64552', '276.00', 1),
(22437, '82095', '23.50', 5),
(22438, '58028', '142.50', 3),
(22438, '65032', '598.50', 5),
(22438, '82096', '27.50', 2),
(22439, '59915', '25.00', 2),
(22439, '65033', '1044.00', 5),
(22439, '83013', '46.00', 5),
(22440, '64509', '142.00', 1),
(22440, '65034', '15000.00', 2),
(22440, '90106', '38.00', 5),
(22441, '64510', '154.00', 3),
(22441, '65060', '46.50', 5),
(22441, '90109', '40.50', 5),
(22442, '64511', '227.50', 1),
(22442, '65070', '118.50', 5),
(22442, '90116', '50.00', 2),
(22443, '64550', '126.00', 1),
(22443, '65080', '478.00', 3),
(22443, '90164', '75.50', 3),
(22444, '64551', '118.00', 1),
(22444, '65081', '112.00', 2),
(22444, '90192', '70.50', 1),
(22445, '64552', '276.00', 3),
(22445, '65082', '174.00', 1),
(22445, '90208', '71.00', 5),
(22446, '65032', '598.50', 5),
(22446, '65122', '1558.00', 2),
(22446, '90209', '71.00', 2),
(22447, '65033', '1044.00', 1),
(22447, '65142', '93.00', 1),
(22447, '90212', '71.00', 5),
(22448, '65034', '15000.00', 5),
(22448, '65143', '83.50', 5),
(22448, '90510', '430.50', 5),
(22449, '65060', '46.50', 1),
(22449, '65147', '238.50', 2),
(22449, '90521', '142.50', 5),
(22450, '65070', '118.50', 5),
(22450, '65190', '190.50', 2),
(22450, '90531', '83.00', 1),
(22451, '65080', '478.00', 5),
(22451, '65191', '23.00', 5),
(22451, '90545', '288.00', 3),
(22452, '65081', '112.00', 5),
(22452, '65247', '75.00', 5),
(22452, '90693', '57.00', 1),
(22453, '65082', '174.00', 5),
(22453, '71912', '35.00', 1),
(22453, '90737', '354.00', 2),
(22454, '65122', '1558.00', 5),
(22454, '72777', '154.00', 5),
(22454, '91008', '94.00', 5),
(22455, '65142', '93.00', 3),
(22455, '72942', '35.50', 5),
(22455, '92606', '106.00', 3),
(22456, '65143', '83.50', 1),
(22456, '71912', '35.00', 3),
(22456, '72943', '35.50', 3),
(22457, '65147', '238.50', 5),
(22457, '72777', '154.00', 5),
(22457, '72944', '42.00', 2),
(22458, '65190', '190.50', 5),
(22458, '72942', '35.50', 2),
(22458, '76032', '334.50', 1),
(22459, '65191', '23.00', 3),
(22459, '72943', '35.50', 5),
(22459, '77033', '358.00', 1),
(22460, '65247', '75.00', 1),
(22460, '72944', '42.00', 5),
(22460, '77036', '358.00', 3),
(22461, '71912', '35.00', 5),
(22461, '76032', '334.50', 3),
(22461, '77038', '478.00', 2),
(22462, '72777', '154.00', 3),
(22462, '77033', '358.00', 2),
(22462, '77249', '1558.00', 1),
(22463, '72942', '35.50', 2),
(22463, '77036', '358.00', 5),
(22463, '77251', '658.00', 3),
(22464, '72943', '35.50', 1),
(22464, '77038', '478.00', 5),
(22464, '77252', '34.50', 2),
(22465, '72944', '42.00', 1),
(22465, '77249', '1558.00', 3),
(22465, '77276', '4558.00', 2),
(22466, '76032', '334.50', 5),
(22466, '77251', '658.00', 2),
(22466, '77277', '358.00', 1),
(22467, '77033', '358.00', 3),
(22467, '77252', '34.50', 5),
(22467, '78029', '142.50', 2),
(22468, '77036', '358.00', 2),
(22468, '77276', '4558.00', 5),
(22468, '80032', '154.50', 5),
(22469, '77038', '478.00', 5),
(22469, '77277', '358.00', 5),
(22469, '80082', '118.50', 3),
(22470, '77249', '1558.00', 2),
(22470, '78029', '142.50', 5),
(22470, '80088', '213.00', 2),
(22471, '77251', '658.00', 5),
(22471, '80032', '154.50', 2),
(22471, '80692', '39.50', 3),
(22472, '77252', '34.50', 5),
(22472, '80082', '118.50', 2),
(22472, '81007', '62.50', 15),
(22473, '77251', '658.00', 1),
(22473, '77276', '4558.00', 1),
(22473, '82090', '30.00', 5),
(22474, '77252', '34.50', 1),
(22474, '77277', '358.00', 1),
(22474, '82092', '18.00', 9),
(22475, '77276', '4558.00', 3),
(22475, '78029', '142.50', 5),
(22475, '82093', '24.00', 5),
(22476, '77277', '358.00', 5),
(22476, '80032', '154.50', 1),
(22476, '82095', '23.50', 2),
(22477, '78029', '142.50', 1),
(22477, '80082', '118.50', 5),
(22477, '82096', '27.50', 5),
(22478, '49919', '58.50', 2),
(22478, '80088', '213.00', 5),
(22478, '83013', '46.00', 1),
(22479, '49921', '357.00', 5),
(22479, '80692', '39.50', 2),
(22479, '90106', '38.00', 3),
(22480, '55112', '598.50', 3),
(22480, '81007', '62.50', 5),
(22480, '90109', '40.50', 2),
(22481, '55129', '154.00', 2),
(22481, '82090', '30.00', 2),
(22481, '90116', '50.00', 5),
(22482, '55130', '298.50', 5),
(22482, '82092', '18.00', 10),
(22482, '90164', '75.50', 2),
(22483, '55550', '1558.50', 2),
(22483, '82093', '24.00', 2),
(22483, '90192', '70.50', 3),
(22484, '58028', '142.50', 5),
(22484, '82095', '23.50', 1),
(22484, '90208', '71.00', 1),
(22485, '59915', '25.00', 5),
(22485, '82096', '27.50', 1),
(22485, '90209', '71.00', 2),
(22486, '64509', '142.00', 3),
(22486, '83013', '46.00', 3),
(22486, '90212', '71.00', 5),
(22487, '64510', '154.00', 5),
(22487, '90106', '38.00', 2),
(22487, '90510', '430.50', 2),
(22488, '64511', '227.50', 3),
(22488, '90109', '40.50', 1),
(22488, '90521', '142.50', 1),
(22489, '64550', '126.00', 3),
(22489, '90116', '50.00', 1),
(22489, '90531', '83.00', 3),
(22490, '64551', '118.00', 3),
(22490, '90164', '75.50', 5),
(22490, '90545', '288.00', 2),
(22491, '42615', '106.00', 2),
(22491, '90192', '70.50', 2),
(22491, '90693', '57.00', 3),
(22492, '42626', '141.50', 1),
(22492, '90208', '71.00', 2),
(22492, '90737', '354.00', 5),
(22493, '42929', '83.00', 2),
(22493, '90209', '71.00', 5),
(22493, '91008', '94.00', 1),
(22494, '42933', '69.50', 2),
(22494, '90212', '71.00', 1),
(22494, '92606', '106.00', 2),
(22495, '42934', '69.50', 1),
(22495, '42945', '81.50', 5),
(22495, '90510', '430.50', 5),
(22496, '42939', '95.00', 2),
(22496, '43000', '540.00', 5),
(22496, '90521', '142.50', 5),
(22497, '42941', '71.00', 3),
(22497, '43014', '372.00', 2),
(22497, '90531', '83.00', 2),
(22498, '42945', '81.50', 2),
(22498, '43015', '288.00', 2),
(22498, '90545', '288.00', 5),
(22499, '43000', '540.00', 3),
(22499, '44939', '115.00', 3),
(22499, '90693', '57.00', 5),
(22500, '43014', '372.00', 5),
(22500, '45101', '57.00', 5),
(22500, '90737', '354.00', 1),
(22501, '43015', '288.00', 1),
(22501, '45105', '45.00', 5),
(22501, '91008', '94.00', 5),
(22502, '44939', '115.00', 5),
(22502, '45923', '42.00', 3),
(22502, '92606', '106.00', 5),
(22503, '10820', '46.50', 3),
(22503, '45101', '57.00', 3),
(22503, '45935', '19.50', 1),
(22504, '10822', '46.50', 2),
(22504, '46702', '71.50', 5),
(22504, '49919', '58.50', 5),
(22505, '10830', '57.50', 2),
(22505, '46706', '27.50', 2),
(22505, '49921', '357.00', 1),
(22506, '10820', '46.50', 1),
(22506, '10835', '83.00', 5),
(22506, '55112', '598.50', 2),
(22507, '10822', '46.50', 3),
(22507, '10854', '39.50', 1),
(22507, '55129', '154.00', 2),
(22508, '10830', '57.50', 5),
(22508, '11630', '46.50', 2),
(22508, '55130', '298.50', 1),
(22509, '10835', '83.00', 1),
(22509, '12054', '358.50', 3),
(22509, '55550', '1558.50', 5),
(22510, '10854', '39.50', 3),
(22510, '12055', '238.50', 1),
(22510, '58028', '142.50', 2),
(22511, '11630', '46.50', 5),
(22511, '12056', '191.50', 5),
(22511, '59915', '25.00', 1),
(22512, '12054', '358.50', 2),
(22512, '12088', '215.00', 3),
(22512, '64509', '142.00', 5),
(22513, '12055', '238.50', 2),
(22513, '12089', '144.00', 5),
(22513, '64510', '154.00', 1),
(22514, '12056', '191.50', 1),
(22514, '12090', '192.00', 2),
(22514, '64511', '227.50', 5),
(22515, '12088', '215.00', 2),
(22515, '12091', '286.50', 1),
(22515, '64550', '126.00', 2),
(22516, '12089', '144.00', 1),
(22516, '12092', '238.50', 5),
(22516, '64551', '118.00', 5),
(22517, '12090', '192.00', 5),
(22517, '13001', '38.00', 5),
(22517, '42615', '106.00', 1),
(22518, '12091', '286.50', 5),
(22518, '15207', '24.50', 3),
(22518, '42626', '141.50', 3),
(22519, '12092', '238.50', 2),
(22519, '15208', '24.50', 2),
(22519, '42929', '83.00', 3),
(22520, '13001', '38.00', 2),
(22520, '15211', '209.00', 5),
(22520, '42933', '69.50', 3),
(22521, '15207', '24.50', 5),
(22521, '15217', '32.00', 1),
(22521, '42934', '69.50', 5),
(22522, '15208', '24.50', 2),
(22522, '15559', '38.00', 1),
(22522, '42939', '95.00', 5),
(22523, '15211', '209.00', 5),
(22523, '20936', '25.00', 2),
(22523, '42941', '71.00', 2),
(22524, '15217', '32.00', 3),
(22524, '20980', '27.50', 5),
(22524, '42945', '81.50', 1),
(22525, '15559', '38.00', 3),
(22525, '21032', '57.50', 2),
(22525, '43000', '540.00', 2),
(22526, '20936', '25.00', 5),
(22526, '21034', '504.00', 5),
(22526, '43014', '372.00', 1),
(22527, '20980', '27.50', 2),
(22527, '21037', '294.00', 5),
(22527, '43015', '288.00', 3),
(22528, '21032', '57.50', 5),
(22528, '21510', '35.50', 3),
(22528, '44939', '115.00', 2),
(22529, '21034', '504.00', 5),
(22529, '21514', '28.00', 3),
(22529, '45101', '57.00', 2),
(22530, '21037', '294.00', 1),
(22530, '21515', '27.00', 1),
(22530, '55550', '1558.50', 1),
(22531, '21510', '35.50', 5),
(22531, '21517', '16.00', 3),
(22531, '58028', '142.50', 5),
(22532, '21514', '28.00', 5),
(22532, '21580', '13.50', 2),
(22532, '59915', '25.00', 2),
(22533, '21515', '27.00', 3),
(22533, '22002', '55.50', 5),
(22533, '64509', '142.00', 2),
(22534, '21517', '16.00', 2),
(22534, '22054', '70.50', 2),
(22534, '64510', '154.00', 3),
(22535, '21580', '13.50', 2),
(22535, '22055', '214.50', 3),
(22535, '64511', '227.50', 5),
(22536, '22002', '55.50', 2),
(22536, '22056', '130.00', 5),
(22536, '64550', '126.00', 2),
(22537, '22054', '70.50', 5),
(22537, '22165', '5400.00', 5),
(22537, '64551', '118.00', 5),
(22538, '22055', '214.50', 2),
(22538, '22179', '1440.00', 1),
(22538, '42615', '106.00', 3),
(22539, '22056', '130.00', 2),
(22539, '22870', '21.00', 2),
(22539, '42626', '141.50', 2),
(22540, '22165', '5400.00', 2),
(22540, '25079', '334.00', 2),
(22540, '42929', '83.00', 2),
(22541, '22179', '1440.00', 3),
(22541, '25121', '418.50', 5),
(22541, '42933', '69.50', 2),
(22542, '22870', '21.00', 5),
(22542, '25131', '1078.00', 5),
(22542, '42934', '69.50', 5),
(22543, '25079', '334.00', 5),
(22543, '25136', '180.00', 1),
(22543, '42939', '95.00', 5),
(22544, '25121', '418.50', 1),
(22544, '25137', '228.00', 5),
(22544, '42941', '71.00', 2),
(22545, '25131', '1078.00', 1),
(22545, '25138', '166.50', 2),
(22545, '42945', '81.50', 3),
(22546, '25136', '180.00', 3),
(22546, '25154', '276.00', 5),
(22546, '43000', '540.00', 5),
(22547, '25137', '228.00', 2),
(22547, '32055', '130.50', 5),
(22547, '43014', '372.00', 3),
(22548, '25138', '166.50', 5),
(22548, '32067', '94.50', 2),
(22548, '43015', '288.00', 2),
(22549, '25154', '276.00', 2),
(22549, '32069', '154.00', 5),
(22549, '44939', '115.00', 1),
(22550, '32055', '130.50', 1),
(22550, '32191', '402.00', 2),
(22550, '45101', '57.00', 5),
(22551, '32067', '94.50', 5),
(22551, '32610', '106.50', 5),
(22551, '45105', '45.00', 1),
(22552, '32069', '154.00', 2),
(22552, '33044', '14.50', 1),
(22552, '45923', '42.00', 2),
(22553, '32191', '402.00', 5),
(22553, '33045', '17.50', 3),
(22553, '45935', '19.50', 5),
(22554, '32610', '106.50', 1),
(22554, '33046', '15.00', 2),
(22554, '46702', '71.50', 1),
(22555, '33044', '14.50', 5),
(22555, '33047', '16.00', 5),
(22555, '46706', '27.50', 5),
(22556, '33045', '17.50', 2),
(22556, '33047', '16.00', 1),
(22556, '35911', '11.50', 5),
(22557, '33046', '15.00', 1),
(22557, '35911', '11.50', 3),
(22557, '35912', '11.50', 1),
(22558, '33047', '16.00', 5),
(22558, '35912', '11.50', 2),
(22558, '37710', '35.00', 5),
(22559, '35911', '11.50', 5),
(22559, '37710', '35.00', 3),
(22559, '37720', '42.00', 5),
(22560, '35912', '11.50', 1),
(22560, '37720', '42.00', 1),
(22560, '37725', '36.00', 2),
(22561, '37710', '35.00', 2),
(22561, '37725', '35.00', 1),
(22561, '37730', '23.50', 3),
(22562, '37720', '42.00', 5),
(22562, '37730', '23.50', 2),
(22562, '37731', '30.00', 5),
(22563, '37725', '36.00', 5),
(22563, '37731', '30.00', 1),
(22563, '37732', '27.00', 2),
(22564, '37720', '42.00', 1),
(22564, '37730', '23.50', 2),
(22564, '41020', '94.50', 2),
(22565, '37725', '36.00', 1),
(22565, '37731', '30.00', 2),
(22565, '41096', '115.00', 3),
(22566, '33044', '14.50', 2),
(22566, '37732', '27.00', 5),
(22566, '41097', '142.50', 1),
(22567, '33045', '17.50', 5),
(22567, '41020', '94.50', 1),
(22567, '41098', '83.00', 5),
(22568, '33046', '15.00', 3),
(22568, '41096', '115.00', 2),
(22568, '42613', '106.00', 2),
(22569, '33047', '16.00', 1),
(22569, '41097', '142.50', 2),
(22569, '42615', '106.00', 5),
(22570, '35911', '11.50', 3),
(22570, '41098', '83.00', 1),
(22570, '42626', '141.50', 5),
(22571, '35912', '11.50', 2),
(22571, '42613', '106.00', 1),
(22571, '42929', '83.00', 3),
(22572, '37710', '35.00', 5),
(22572, '42615', '106.00', 3),
(22572, '42933', '69.50', 5),
(22573, '37720', '42.00', 3),
(22573, '42626', '141.50', 1),
(22573, '42934', '69.50', 1),
(22574, '37725', '36.00', 2),
(22574, '42929', '83.00', 2),
(22574, '42939', '95.00', 1),
(22575, '37730', '23.50', 5),
(22575, '42933', '69.50', 5),
(22575, '42941', '71.00', 5),
(22576, '37731', '30.00', 5),
(22576, '42934', '69.50', 1),
(22576, '42945', '81.50', 5),
(22577, '37732', '27.00', 1),
(22577, '42939', '95.00', 5),
(22577, '43000', '540.00', 2),
(22578, '41020', '94.50', 3),
(22578, '42941', '71.00', 1),
(22578, '43014', '372.00', 2),
(22579, '41096', '115.00', 2),
(22579, '42945', '81.50', 2),
(22579, '43015', '288.00', 5),
(22580, '41097', '142.50', 5),
(22580, '43000', '540.00', 1),
(22580, '44939', '115.00', 5),
(22581, '41098', '83.00', 1),
(22581, '43014', '372.00', 5),
(22581, '45101', '57.00', 2),
(22582, '42613', '106.00', 2),
(22582, '43015', '288.00', 1),
(22582, '45105', '45.00', 5),
(22583, '37720', '42.00', 5),
(22583, '44939', '115.00', 1),
(22583, '45923', '42.00', 5),
(22584, '37725', '36.00', 5),
(22584, '45101', '57.00', 1),
(22584, '45935', '19.50', 1),
(22585, '33044', '14.50', 5),
(22585, '45105', '45.00', 1),
(22585, '46702', '71.50', 3),
(22586, '33045', '17.50', 1),
(22586, '45923', '42.00', 3),
(22586, '46706', '27.50', 1),
(22587, '33046', '15.00', 2),
(22587, '45935', '19.50', 5),
(22587, '46738', '40.00', 5),
(22588, '33047', '16.00', 3),
(22588, '46702', '71.50', 2),
(22588, '46741', '10.00', 2),
(22589, '22056', '130.00', 5),
(22589, '35911', '11.50', 1),
(22589, '46706', '27.50', 3),
(22589, '46745', '43.50', 1),
(22590, '22165', '5400.00', 5),
(22590, '35912', '11.50', 3),
(22590, '46738', '40.00', 1),
(22590, '47903', '11214.00', 5),
(22591, '22179', '1440.00', 2),
(22591, '37710', '35.00', 2),
(22591, '46741', '10.00', 2),
(22591, '49916', '25.00', 2),
(22592, '22870', '21.00', 1),
(22592, '37720', '42.00', 2),
(22592, '46745', '43.50', 3),
(22592, '49917', '25.50', 5),
(22593, '25079', '334.00', 2),
(22593, '37725', '36.00', 2),
(22593, '47903', '11214.00', 1),
(22593, '49919', '58.50', 1),
(22594, '25121', '418.50', 3),
(22594, '37730', '23.50', 1),
(22594, '49916', '25.00', 1),
(22594, '49921', '357.00', 3),
(22595, '25131', '1078.00', 3),
(22595, '37731', '30.00', 2),
(22595, '49917', '25.50', 2),
(22595, '55112', '598.50', 5),
(22596, '25136', '180.00', 2),
(22596, '37732', '27.00', 5),
(22596, '49919', '58.50', 3),
(22596, '55129', '154.00', 5),
(22597, '25137', '228.00', 1),
(22597, '41020', '94.50', 5),
(22597, '49921', '357.00', 2),
(22597, '55130', '298.50', 5),
(22598, '25138', '166.50', 5),
(22598, '41096', '115.00', 3),
(22598, '55112', '598.50', 2),
(22598, '55550', '1558.50', 3),
(22599, '41097', '142.50', 5),
(22599, '55129', '154.00', 5),
(22599, '58028', '142.50', 2),
(22600, '41098', '83.00', 3),
(22600, '55130', '298.50', 2),
(22600, '59915', '25.00', 4),
(22601, '42613', '106.00', 1),
(22601, '55550', '1558.50', 2),
(22601, '64509', '142.00', 5),
(22602, '37730', '23.50', 3),
(22602, '58028', '142.50', 1),
(22602, '64510', '154.00', 1),
(22603, '37731', '30.00', 5),
(22603, '59915', '25.00', 7),
(22603, '64511', '227.50', 3),
(22604, '37732', '27.00', 1),
(22604, '64509', '142.00', 5),
(22604, '64550', '126.00', 5),
(22605, '41020', '94.50', 2),
(22605, '64510', '154.00', 5),
(22605, '64551', '118.00', 3),
(22606, '41096', '115.00', 2),
(22606, '64511', '227.50', 2),
(22606, '64552', '276.00', 5),
(22607, '41097', '142.50', 3),
(22607, '64550', '126.00', 1),
(22607, '65032', '598.50', 1),
(22608, '41098', '83.00', 2),
(22608, '64551', '118.00', 2),
(22608, '65033', '1044.00', 3),
(22609, '42613', '106.00', 3),
(22609, '64552', '276.00', 5),
(22609, '65034', '15000.00', 5),
(22610, '25079', '334.00', 5),
(22610, '65032', '598.50', 3),
(22610, '65060', '46.50', 1),
(22611, '25121', '418.50', 2),
(22611, '65033', '1044.00', 5),
(22611, '65070', '118.50', 2),
(22612, '25131', '1078.00', 2),
(22612, '65034', '15000.00', 1),
(22612, '65080', '478.00', 1),
(22613, '22055', '214.50', 5),
(22613, '65060', '46.50', 3),
(22613, '65081', '112.00', 1),
(22614, '22056', '130.00', 1),
(22614, '65070', '118.50', 1),
(22614, '65082', '174.00', 2),
(22615, '22165', '5400.00', 1),
(22615, '65080', '478.00', 5),
(22615, '65122', '1558.00', 1),
(22616, '22179', '1440.00', 2),
(22616, '65081', '112.00', 3),
(22616, '65142', '93.00', 2),
(22617, '22870', '21.00', 2),
(22617, '65082', '174.00', 5),
(22617, '65143', '83.50', 3),
(22618, '25079', '334.00', 1),
(22618, '65122', '1558.00', 3),
(22618, '65147', '238.50', 5),
(22619, '25121', '418.50', 2),
(22619, '65142', '93.00', 5),
(22619, '65190', '190.50', 5),
(22620, '25131', '1078.00', 1),
(22620, '65143', '83.50', 2),
(22620, '65191', '23.00', 2),
(22621, '25136', '180.00', 2),
(22621, '65147', '238.50', 1),
(22621, '65247', '75.00', 2),
(22622, '25137', '228.00', 3),
(22622, '65190', '190.50', 1),
(22622, '71912', '35.00', 1),
(22623, '25138', '166.50', 1),
(22623, '65191', '23.00', 5),
(22623, '72777', '154.00', 1),
(22624, '25154', '276.00', 1),
(22624, '65247', '75.00', 5),
(22624, '72942', '35.50', 2),
(22625, '32055', '130.50', 3),
(22625, '71912', '35.00', 4),
(22625, '72943', '35.50', 5),
(22626, '32067', '94.50', 5),
(22626, '72777', '154.00', 5),
(22626, '72944', '42.00', 5),
(22627, '32069', '154.00', 2),
(22627, '72942', '35.50', 5),
(22627, '76032', '334.50', 2),
(22628, '32191', '402.00', 1),
(22628, '72943', '35.50', 1),
(22628, '77033', '358.00', 1),
(22629, '25079', '334.00', 3),
(22629, '72944', '42.00', 2),
(22629, '77036', '358.00', 3),
(22630, '25121', '418.50', 5),
(22630, '76032', '334.50', 5),
(22630, '77038', '478.00', 1),
(22631, '25131', '1078.00', 3),
(22631, '77033', '358.00', 5),
(22631, '77249', '1558.00', 2),
(22632, '25136', '180.00', 5),
(22632, '77036', '358.00', 5),
(22632, '77251', '658.00', 5),
(22633, '25137', '228.00', 5),
(22633, '77038', '478.00', 5),
(22633, '77252', '34.50', 5),
(22634, '25138', '166.50', 5),
(22634, '77249', '1558.00', 5),
(22634, '77276', '4558.00', 2),
(22635, '25154', '276.00', 5),
(22635, '77251', '658.00', 1),
(22635, '77277', '358.00', 3),
(22636, '32055', '130.50', 2),
(22636, '77252', '34.50', 1),
(22636, '78029', '142.50', 2),
(22637, '32067', '94.50', 5),
(22637, '77276', '4558.00', 5),
(22637, '80032', '154.50', 3),
(22638, '32069', '154.00', 5),
(22638, '77277', '358.00', 2),
(22638, '80082', '118.50', 3),
(22639, '32191', '402.00', 2),
(22639, '78029', '142.50', 2),
(22639, '80088', '213.00', 1),
(22640, '32610', '106.50', 3),
(22640, '80032', '154.50', 5),
(22640, '80692', '39.50', 2),
(22641, '65060', '46.50', 2),
(22641, '80082', '118.50', 5),
(22641, '81007', '62.50', 2),
(22642, '65070', '118.50', 2),
(22642, '80088', '213.00', 5),
(22642, '82090', '30.00', 1),
(22643, '65080', '478.00', 2),
(22643, '80692', '39.50', 5),
(22643, '82092', '18.00', 13),
(22644, '64509', '142.00', 1),
(22644, '81007', '62.50', 9),
(22644, '82093', '24.00', 5),
(22645, '64510', '154.00', 1),
(22645, '82090', '30.00', 3),
(22645, '82095', '23.50', 2),
(22646, '64511', '227.50', 5),
(22646, '82092', '18.00', 3),
(22646, '82096', '27.50', 2),
(22647, '64550', '126.00', 3),
(22647, '82093', '24.00', 1),
(22647, '83013', '46.00', 2),
(22648, '64551', '118.00', 5),
(22648, '82095', '23.50', 5),
(22648, '90106', '38.00', 5),
(22649, '64552', '276.00', 1),
(22649, '82096', '27.50', 2),
(22649, '90109', '40.50', 3),
(22650, '65032', '598.50', 5),
(22650, '83013', '46.00', 5),
(22650, '90116', '50.00', 3),
(22651, '65033', '1044.00', 5),
(22651, '90106', '38.00', 2),
(22651, '90164', '75.50', 2),
(22652, '65034', '15000.00', 5),
(22652, '90109', '40.50', 5),
(22652, '90192', '70.50', 1),
(22653, '65060', '46.50', 5),
(22653, '90116', '50.00', 2),
(22653, '90208', '71.00', 3),
(22654, '65070', '118.50', 5),
(22654, '90164', '75.50', 1),
(22654, '90209', '71.00', 2),
(22655, '65080', '478.00', 5),
(22655, '90192', '70.50', 3),
(22655, '90212', '71.00', 5),
(22656, '65081', '112.00', 2),
(22656, '90208', '71.00', 1),
(22656, '90510', '430.50', 5),
(22657, '65082', '174.00', 1),
(22657, '90209', '71.00', 3),
(22657, '90521', '142.50', 5),
(22658, '65122', '1558.00', 1),
(22658, '90212', '71.00', 2),
(22658, '90531', '83.00', 5),
(22659, '65142', '93.00', 1),
(22659, '90510', '430.50', 1),
(22659, '90545', '288.00', 3),
(22660, '65143', '83.50', 2),
(22660, '90521', '142.50', 1),
(22660, '90693', '57.00', 3),
(22661, '65147', '238.50', 3),
(22661, '90531', '83.00', 1),
(22661, '90737', '354.00', 3),
(22662, '65190', '190.50', 5),
(22662, '90545', '288.00', 2),
(22662, '91008', '94.00', 1),
(22663, '65191', '23.00', 2),
(22663, '90693', '57.00', 5),
(22663, '92606', '106.00', 2),
(22664, '42945', '81.50', 5),
(22664, '65247', '75.00', 2),
(22664, '90737', '354.00', 2),
(22665, '10820', '46.50', 1),
(22665, '43000', '540.00', 3),
(22665, '71912', '35.00', 7),
(22666, '10822', '46.50', 5),
(22666, '43014', '372.00', 1),
(22666, '72777', '154.00', 2),
(22667, '10830', '57.50', 1),
(22667, '43015', '288.00', 1),
(22667, '72942', '35.50', 5),
(22668, '10835', '83.00', 3),
(22668, '44939', '115.00', 5),
(22668, '72943', '35.50', 1),
(22669, '10854', '39.50', 1),
(22669, '45101', '57.00', 2),
(22669, '72944', '42.00', 1),
(22670, '11630', '46.50', 1),
(22670, '45105', '45.00', 3),
(22670, '76032', '334.50', 5),
(22671, '12054', '358.50', 5),
(22671, '45923', '42.00', 3),
(22671, '77033', '358.00', 5),
(22672, '12055', '238.50', 2),
(22672, '45935', '19.50', 2),
(22672, '77036', '358.00', 2),
(22673, '12056', '191.50', 5),
(22673, '46702', '71.50', 1),
(22673, '77038', '478.00', 1),
(22674, '12088', '215.00', 1),
(22674, '46706', '27.50', 5),
(22674, '77249', '1558.00', 3),
(22675, '12089', '144.00', 5),
(22675, '33047', '16.00', 5),
(22675, '77251', '658.00', 3),
(22676, '12090', '192.00', 1),
(22676, '35911', '11.50', 2),
(22676, '77252', '34.50', 5),
(22677, '12091', '286.50', 1),
(22677, '35912', '11.50', 5),
(22677, '77276', '4558.00', 1),
(22678, '12092', '238.50', 2),
(22678, '37710', '35.00', 15),
(22678, '77277', '358.00', 1),
(22679, '13001', '38.00', 5),
(22679, '37720', '42.00', 5),
(22679, '78029', '142.50', 3),
(22680, '15207', '24.50', 1),
(22680, '37725', '35.00', 2),
(22680, '80032', '154.50', 2),
(22681, '15208', '24.50', 4),
(22681, '37730', '23.50', 1),
(22681, '80082', '118.50', 5),
(22682, '15211', '209.00', 1),
(22682, '37731', '30.00', 2),
(22682, '77251', '658.00', 5),
(22683, '15217', '32.00', 2),
(22683, '37720', '42.00', 2),
(22683, '77252', '34.50', 2),
(22684, '15559', '38.00', 5),
(22684, '37725', '36.00', 5),
(22684, '77276', '4558.00', 3),
(22685, '20936', '25.00', 15),
(22685, '33044', '14.50', 1),
(22685, '77277', '358.00', 3),
(22686, '20980', '27.50', 1),
(22686, '33045', '17.50', 3),
(22686, '78029', '142.50', 2),
(22687, '21032', '57.50', 3),
(22687, '33046', '15.00', 5),
(22687, '49919', '58.50', 2),
(22688, '21034', '504.00', 3),
(22688, '33047', '16.00', 5),
(22688, '49921', '357.00', 5),
(22689, '21037', '294.00', 2),
(22689, '35911', '11.50', 1),
(22689, '55112', '598.50', 2),
(22690, '21510', '35.50', 5),
(22690, '35912', '11.50', 3),
(22690, '55129', '154.00', 5),
(22691, '21514', '28.00', 5),
(22691, '37710', '35.00', 5),
(22691, '55130', '298.50', 5),
(22692, '21515', '27.00', 3),
(22692, '37720', '42.00', 5),
(22692, '55550', '1558.50', 5),
(22693, '21517', '16.00', 3),
(22693, '37725', '36.00', 1),
(22693, '58028', '142.50', 5),
(22694, '21580', '13.50', 5),
(22694, '37730', '23.50', 3),
(22694, '59915', '25.00', 5),
(22695, '22002', '55.50', 5),
(22695, '37731', '30.00', 2),
(22695, '64509', '142.00', 5),
(22696, '22054', '70.50', 2),
(22696, '37732', '27.00', 5),
(22696, '64510', '154.00', 2);
